/* PSID DATA CLEANING: 
   AUX CODE for prep_psid_1.do		*/
   
/* ********* */
/* Year 1987 */
/* ********* */	
preserve

	keep if (ER30537 == 10 & ER30536 == 1) | (ER30537 == 20 & ER30536 == 2) | (ER30537 == 22 & ER30536 == 2)
	
	bysort V13702: egen flag_spouse  = max(ER30537 == 20 | ER30537 == 22)

	/* Main Cleaning */
	keep if ER30537 == 10 /* Keep head only */

	keep if V13702 != .
	gen interview_id 	= V13702
	gen family_weight	= V14737
	gen num_of_family	= V14113

	
	/* Bring in SS Income Type */

	gen flag_di_rec = (V13935 == 1 | V13956 == 1)

	/* Indicators on whether head or spouse is DI recipient.
	   If both, use head. --> conditional on DI rec.		    */
	gen flag_di_rec_head = (V13935 == 1)
	replace flag_di_rec_head = . if flag_di_rec == 0
	gen flag_di_rec_spouse = (V13956 == 1)
	replace flag_di_rec_spouse = . if flag_di_rec == 0
		
	/* Receiving SSI (including disability and senior with low income) */
	gen flag_ssi_rec_head = .
	replace flag_ssi_rec_head = 1 if V13931 > 0
	replace flag_ssi_rec_head = 0 if V13931 == 0
	
	gen flag_ssi_rec_spouse = .
	replace flag_ssi_rec_spouse = 1 if V13952 > 0
	replace flag_ssi_rec_spouse = 0 if V13952 == 5

	gen flag_ssi_rec = (flag_ssi_rec_head == 1 | flag_ssi_rec_spouse == 1)
	replace flag_ssi_rec = . if flag_ssi_rec_head == . & flag_ssi_rec_spouse == .
	

	gen annual_mortg	= V13728
	gen 	annual_rent	= V13732
	gen cntrb_outside	= V13921

	replace annual_mortg  = .  if annual_mortg == 0
	replace annual_rent   = .  if annual_rent  == 0
	replace cntrb_outside = .k if cntrb_outside == 9999998
	replace cntrb_outside = .n if cntrb_outside == 9999999
	
	gen 	food_home	= V13876
	gen 	food_out	= V13878 
	
	/* Additional controls */
	gen head_age  = V14114 if V14114 <= 120
	gen head_male = V14115 == 1 
	gen head_emply = (V14146 == 1) if V14146 < 9
	gen non_white = V14612 != 1 if V14612 != 9
	
	gen spouse_emply = (V14321 == 1) if V14321 < 9 & V14321 != 0
	
	gen educ_hs 	 = .
	replace educ_hs 	= 0 if inrange(V14687, 1, 3)
	replace educ_hs		= 1 if inrange(V14687, 4, 8)
	gen educ_college = .
	replace educ_college= 0 if inrange(V14687, 1, 6)
	replace educ_college= 1 if inrange(V14687, 7, 8)

	gen flag_foodstamp = .
	replace flag_foodstamp = V13880
	replace flag_foodstamp = 1 if V13880 > 0
	
	gen svy_year = 1987
	
	gen inc_headwife = V13920
	gen inc_hh = V14670
	
	/* SSA REC AND DISABILITY STATUS */
	gen inc_ss_total = .
	summ inc_ss_total
	
	gen level_disabled_head   = V14517
	gen level_disabled_spouse = V14528
	tab level_disabled_head 
	tab level_disabled_spouse
	gen flag_candonothing_head = (V14516 == 7)
	gen flag_candonothing_spouse = (V14527 == 7)
	
	replace level_disabled_head = -1 if flag_candonothing_head == 1
	replace level_disabled_spouse = -1 if flag_candonothing_spouse == 1
	
	gen flag_severe_head = 0 if level_disabled_head != 0
	replace flag_severe_head = 1  if level_disabled_head == 1
	replace flag_severe_head = 1  if flag_candonothing_head == 1
	tab flag_severe_head
	
	gen flag_severe_spouse = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse = 1  if level_disabled_spouse == 1
	replace flag_severe_spouse = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse
	
	gen flag_moderate_head = 0 if level_disabled_head != 0
	replace flag_moderate_head = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_head
	
	gen flag_moderate_spouse = 0 if level_disabled_head != 0
	replace flag_moderate_spouse = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_spouse
	
	gen flag_psid_disable_head = (flag_severe_head == 1 | flag_moderate_head == 1)
	gen flag_psid_disable_spouse = (flag_severe_spouse == 1 | flag_moderate_spouse == 1)
	tab flag_psid_disable_head
	tab flag_psid_disable_spouse
	
	gen flag_severe = max(flag_severe_head, flag_severe_spouse)
	gen flag_moderate = max(flag_moderate_head, flag_moderate_spouse)
	gen flag_psid_disable = max(flag_psid_disable_head, flag_psid_disable_spouse)
	
	gen flag_severe_head2 = 0 if level_disabled_head != 0
	replace flag_severe_head2 = 1  if level_disabled_head == 1 | level_disabled_head == 3
	replace flag_severe_head2 = 1  if flag_candonothing_head == 1
	tab flag_severe_head2


	gen flag_severe_spouse2 = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse2 = 1  if level_disabled_spouse == 1 | level_disabled_spouse == 3
	replace flag_severe_spouse2 = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse2

	gen flag_severe2 = max(flag_severe_head2, flag_severe_spouse2)

	summ flag* 
	
	/******* Measures of permanent income ********/
	
	/* Year of education -- capped at 17, i.e. At least one year of postgraduate work */
	gen level_educ_head   = V14687 
	gen level_educ_spouse = V14688 
	replace level_educ_head   = . if level_educ_head == 9
	replace level_educ_spouse = . if level_educ_spouse == 9 | level_educ_spouse == 0
	
	/* Parental education */
	gen level_educ_headFa_US = V14596
	replace level_educ_headFa_US   = . if level_educ_headFa_US >= 9
	
	gen level_educ_headMo_US = V14597
	replace level_educ_headMo_US   = . if level_educ_headMo_US >= 9
	
	gen level_educ_spouseFa_US = V14532
	replace level_educ_spouseFa_US   = . if level_educ_spouseFa_US >= 9
	
	gen level_educ_spouseMo_US = V14533
	replace level_educ_spouseMo_US   = . if level_educ_spouseMo_US >= 9
	
	/* Parental family wealth when they grow up  */
	gen level_wealth_headParent = V14595
	replace level_wealth_headParent = . if level_wealth_headParent == 9
	gen level_wealth_spouseParent = .
	replace level_wealth_spouseParent = . if level_wealth_spouseParent == 9
	
	summ level_*
	
	/******* Measures of outside resources ********/
	
	/* Spousal wage/salaries */
	gen inc_earn_spouse = V13905
	replace inc_earn_spouse = . if  inc_earn_spouse >= 9999999
	
	gen level_spouseage = V14116
	replace level_spouseage = . if level_spouseage > 120	
	
	/* Earnings */
	gen inc_earn_head = V13898
	replace inc_earn_head = . if  inc_earn_head >= 9999998
	gen inc_earn_HSP = inc_earn_head
	replace inc_earn_HSP = inc_earn_head + inc_earn_spouse if inc_earn_spouse != .
	
	/* Marital Status */
	gen flag_married = (V14120 == 1)
	replace flag_married = . if V14120 >= 8
	
	summ flag_married
	summ inc_* 
	
	gen flag_home_own  = (V14126 == 1)
	gen flag_home_rent = (V14126 == 5)
	
	gen reason_move1 = V14142 if V14142 < 9
	gen reason_move2 = .
	gen reason_move3 = .
	gen reason_move4 = .
	
	gen night_hosp_hd = V14519 
	gen night_hosp_sp = V14530
	
	gen reason_posend_hd_u = V14256 
	gen reason_posend_sp_u = V14420 if flag_spouse == 1
	gen reason_posend_hd_e = .
	gen reason_posend_sp_e = V14350 if flag_spouse == 1
	
	gen health_status_head = V14513
	gen health_status_spouse = V14524
	
	
	/* ADC/AFDC, T-2, Social Security, unemployment compensation, worker's compensation*/
	
	gen flag_adc_head = (V13928 > 0) if V13928 != .
	gen flag_ss_head = 	(V13934 > 0) if V13934 != .
	gen flag_ui_head = (V13941 > 0) if V13941 != .
	gen flag_wi_head = (V13942 > 0) if V13942 != .
	
	gen flag_adc_spouse = (V13949 > 0) if V13949 != .
	gen flag_ss_spouse = (V13955 > 0) if V13955 != .	
	gen flag_ui_spouse = (V13961 > 0) if V13961 != .
	gen flag_wi_spouse = (V13962 > 0) if V13962 != .

	gen yr_work_18 = V14652 if 0 < V14652 & V14652 < 99

	/******* State of Residence ********/
	gen state_res_code = V13703  
	
    label define state_res_code 1 "AL" , modify	
	label define state_res_code 2 "AZ" , modify 
	label define state_res_code 3 "AR" , modify 
	label define state_res_code 4 "CA" , modify 
	label define state_res_code 5 "CO" , modify 
	label define state_res_code 6 "CT" , modify 
	label define state_res_code 7 "DE" , modify 
	label define state_res_code 8 "DC" , modify 
	label define state_res_code 9 "FL" , modify 
	label define state_res_code 10 "GA" , modify
	label define state_res_code 11 "ID" , modify
	label define state_res_code 12 "IL" , modify
	label define state_res_code 13 "IN" , modify
	label define state_res_code 14 "IA" , modify
	label define state_res_code 15 "KS" , modify
	label define state_res_code 16 "KY" , modify
	label define state_res_code 17 "LA" , modify
	label define state_res_code 18 "ME" , modify
	label define state_res_code 19 "MD" , modify
	label define state_res_code 20 "MA" , modify
	label define state_res_code 21 "MI" , modify
	label define state_res_code 22 "MN" , modify
	label define state_res_code 23 "MS" , modify
	label define state_res_code 24 "MO" , modify
	label define state_res_code 25 "MT" , modify
	label define state_res_code 26 "NE" , modify
	label define state_res_code 27 "NV" , modify
	label define state_res_code 28 "NH" , modify
	label define state_res_code 29 "NJ" , modify
	label define state_res_code 30 "NM" , modify
	label define state_res_code 31 "NY" , modify
	label define state_res_code 32 "NC" , modify
	label define state_res_code 33 "ND" , modify
	label define state_res_code 34 "OH" , modify
	label define state_res_code 35 "OK" , modify
	label define state_res_code 36 "OR" , modify
	label define state_res_code 37 "PA" , modify
	label define state_res_code 38 "RI" , modify
	label define state_res_code 39 "SC" , modify
	label define state_res_code 40 "SD" , modify
	label define state_res_code 41 "TN" , modify
	label define state_res_code 42 "TX" , modify
	label define state_res_code 43 "UT" , modify
	label define state_res_code 44 "VT" , modify
	label define state_res_code 45 "VA" , modify
	label define state_res_code 46 "WA" , modify
	label define state_res_code 47 "WV" , modify
	label define state_res_code 48 "WI" , modify
	label define state_res_code 49 "WY" , modify 
	label define state_res_code 50 "AK" , modify
	label define state_res_code 51 "HI" , modify	
	
	label value state_res_code state_res_code	
	decode state_res_code, gen(state_res)
	
	/******* Current State ********/
	gen state_curr_code = V14679                                       

	label define state_curr_code 1 "AL" , modify
	label define state_curr_code 2 "AK" , modify
	label define state_curr_code 4 "AZ" , modify
	label define state_curr_code 5 "AR" , modify
	label define state_curr_code 6 "CA" , modify
	label define state_curr_code 8 "CO" , modify
	label define state_curr_code 9 "CT" , modify
	label define state_curr_code 10 "DE" , modify
	label define state_curr_code 11 "DC" , modify
	label define state_curr_code 12 "FL" , modify
	label define state_curr_code 13 "GA" , modify
	label define state_curr_code 15 "HI" , modify
	label define state_curr_code 16 "ID" , modify
	label define state_curr_code 17 "IL" , modify
	label define state_curr_code 18 "IN" , modify
	label define state_curr_code 19 "IA" , modify
	label define state_curr_code 20 "KS" , modify
	label define state_curr_code 21 "KY" , modify
	label define state_curr_code 22 "LA" , modify
	label define state_curr_code 23 "ME" , modify
	label define state_curr_code 24 "MD" , modify
	label define state_curr_code 25 "MA" , modify
	label define state_curr_code 26 "MI" , modify
	label define state_curr_code 27 "MN" , modify
	label define state_curr_code 28 "MI" , modify
	label define state_curr_code 29 "MO" , modify
	label define state_curr_code 30 "MT" , modify
	label define state_curr_code 31 "NE" , modify
	label define state_curr_code 32 "NV" , modify
	label define state_curr_code 33 "NH" , modify
	label define state_curr_code 34 "NJ" , modify
	label define state_curr_code 35 "NM" , modify
	label define state_curr_code 36 "NY" , modify
	label define state_curr_code 37 "NC" , modify
	label define state_curr_code 38 "ND" , modify
	label define state_curr_code 39 "OH" , modify
	label define state_curr_code 40 "OK" , modify
	label define state_curr_code 41 "OR" , modify
	label define state_curr_code 42 "PA" , modify
	label define state_curr_code 44 "RI" , modify
	label define state_curr_code 45 "SC" , modify
	label define state_curr_code 46 "SD" , modify
	label define state_curr_code 47 "TN" , modify
	label define state_curr_code 48 "TX" , modify
	label define state_curr_code 49 "UT" , modify
	label define state_curr_code 50 "VT" , modify
	label define state_curr_code 51 "VA" , modify
	label define state_curr_code 53 "WA" , modify
	label define state_curr_code 54 "WV" , modify
	label define state_curr_code 55 "WI" , modify
	label define state_curr_code 56 "WY" , modify

	label value state_curr_code state_curr_code
	decode state_curr_code, gen(state_curr)


	keep unique_id svy_year interview_id flag_* level_*  num_of_family educ_* head_* inc_* non_white ///
		 annual_mortg annual_rent food_home food_out cntrb_outside reason* night* family_weight	///
		 health_status_* spouse_emply yr_work_18 state_res state_curr
		 

	tempfile psid1987
	save `psid1987', replace
	count
restore		
