/* PSID DATA CLEANING: 
   AUX CODE for prep_psid_1.do		*/
   
/* ********* */
/* Year 1989 */
/* ********* */	
preserve

	keep if (ER30608 == 10 & ER30607 == 1) | (ER30608 == 20 & ER30607 == 2) | (ER30608 == 22 & ER30607 == 2)
	
	bysort V16302: egen flag_spouse  = max(ER30608 == 20 | ER30608 == 22)
	
	
	/* Main Cleaning */
	keep if ER30608 == 10 /* Keep head only */

	keep if V16302 != .
	gen interview_id 	= V16302
	gen family_weight	= V17612
	gen num_of_family	= V16630


	/* Bring in SS Income Type */

	gen flag_di_rec = (V16450 == 1 | V16471 == 1)

	/* Indicators on whether head or spouse is DI recipient.
	   If both, use head. --> conditional on DI rec.		    */
	gen flag_di_rec_head = (V16450 == 1)
	replace flag_di_rec_head = . if flag_di_rec == 0
	gen flag_di_rec_spouse = (V16471 == 1)
	replace flag_di_rec_spouse = . if flag_di_rec == 0	
	
	/* Receiving SSI (including disability and senior with low income) */
	gen flag_ssi_rec_head = .
	replace flag_ssi_rec_head = 1 if V16446 > 0
	replace flag_ssi_rec_head = 0 if V16446 == 0
	
	gen flag_ssi_rec_spouse = .
	replace flag_ssi_rec_spouse = 1 if V16467 > 0
	replace flag_ssi_rec_spouse = 0 if V16467 == 5

	gen flag_ssi_rec = (flag_ssi_rec_head == 1 | flag_ssi_rec_spouse == 1)
	replace flag_ssi_rec = . if flag_ssi_rec_head == . & flag_ssi_rec_spouse == .
	
	gen annual_mortg	= .
	gen 	annual_rent	= .	
	gen cntrb_outside	= V16436

	replace annual_mortg  = .  if annual_mortg == 0
	replace annual_rent   = .  if annual_rent  == 0
	replace cntrb_outside = .k if cntrb_outside == 9999998
	replace cntrb_outside = .n if cntrb_outside == 9999999
	
	gen 	food_home	= .

	
	/* Additional controls */
	gen head_age  = V16631 if V16631 <= 120
	gen head_male = V16632 == 1 
	gen head_emply = (V16655 == 1) if V16655 < 9
	gen non_white = V17483 != 1 if V17483 != 9
	
	gen spouse_emply = (V16974 == 1) if V16974 < 9 & V16974 != 0
	
	gen educ_hs 	 = .
	replace educ_hs 	= 0 if inrange(V17545, 1, 3)
	replace educ_hs		= 1 if inrange(V17545, 4, 8)
	gen educ_college = .
	replace educ_college= 0 if inrange(V17545, 1, 6)
	replace educ_college= 1 if inrange(V17545, 7, 8)

	gen flag_foodstamp = .
	replace flag_foodstamp = V16395
	replace flag_foodstamp = 1 if V16395 > 0
	
	gen svy_year = 1989
	
	gen inc_headwife = V16435
	gen inc_hh = V17533
	
	/* SSA REC AND DISABILITY STATUS */
	gen inc_ss_total = .
	summ inc_ss_total
	
	gen level_disabled_head   = V17393
	gen level_disabled_spouse = V17399
	tab level_disabled_head 
	tab level_disabled_spouse
	gen flag_candonothing_head = (V17392 == 7)
	gen flag_candonothing_spouse = (V17398 == 7)
	
	replace level_disabled_head = -1 if flag_candonothing_head == 1
	replace level_disabled_spouse = -1 if flag_candonothing_spouse == 1
	
	gen flag_severe_head = 0 if level_disabled_head != 0
	replace flag_severe_head = 1  if level_disabled_head == 1
	replace flag_severe_head = 1  if flag_candonothing_head == 1
	tab flag_severe_head
	
	gen flag_severe_spouse = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse = 1  if level_disabled_spouse == 1
	replace flag_severe_spouse = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse
	
	gen flag_moderate_head = 0 if level_disabled_head != 0
	replace flag_moderate_head = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_head
	
	gen flag_moderate_spouse = 0 if level_disabled_head != 0
	replace flag_moderate_spouse = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_spouse
	
	gen flag_psid_disable_head = (flag_severe_head == 1 | flag_moderate_head == 1)
	gen flag_psid_disable_spouse = (flag_severe_spouse == 1 | flag_moderate_spouse == 1)
	tab flag_psid_disable_head
	tab flag_psid_disable_spouse
	
	gen flag_severe = max(flag_severe_head, flag_severe_spouse)
	gen flag_moderate = max(flag_moderate_head, flag_moderate_spouse)
	gen flag_psid_disable = max(flag_psid_disable_head, flag_psid_disable_spouse)
	
	gen flag_severe_head2 = 0 if level_disabled_head != 0
	replace flag_severe_head2 = 1  if level_disabled_head == 1 | level_disabled_head == 3
	replace flag_severe_head2 = 1  if flag_candonothing_head == 1
	tab flag_severe_head2


	gen flag_severe_spouse2 = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse2 = 1  if level_disabled_spouse == 1 | level_disabled_spouse == 3
	replace flag_severe_spouse2 = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse2

	gen flag_severe2 = max(flag_severe_head2, flag_severe_spouse2)

	summ flag* 
	
	/******* Measures of permanent income ********/
	
	/* Year of education -- capped at 17, i.e. At least one year of postgraduate work */
	gen level_educ_head   = V17545 
	gen level_educ_spouse = V17546 
	replace level_educ_head   = . if level_educ_head == 9
	replace level_educ_spouse = . if level_educ_spouse == 9 | level_educ_spouse == 0
	
	/* Parental education */
	gen level_educ_headFa_US = V17467
	replace level_educ_headFa_US   = . if level_educ_headFa_US >= 9
	
	gen level_educ_headMo_US = V17468
	replace level_educ_headMo_US   = . if level_educ_headMo_US >= 9
	
	gen level_educ_spouseFa_US = V17403
	replace level_educ_spouseFa_US   = . if level_educ_spouseFa_US >= 9
	
	gen level_educ_spouseMo_US = V17404
	replace level_educ_spouseMo_US   = . if level_educ_spouseMo_US >= 9
	
	/* Parental family wealth when they grow up  */
	gen level_wealth_headParent = V17466
	replace level_wealth_headParent = . if level_wealth_headParent == 9
	gen level_wealth_spouseParent = .
	replace level_wealth_spouseParent = . if level_wealth_spouseParent == 9
	
	summ level_*
	
	/******* Measures of outside resources ********/
	
	/* Spousal wage/salaries */
	gen inc_earn_spouse = V16420
	replace inc_earn_spouse = . if  inc_earn_spouse >= 9999999
	
	gen level_spouseage = V16633
	replace level_spouseage = . if level_spouseage > 120	
	
	/* Earnings */
	gen inc_earn_head = V16413
	replace inc_earn_head = . if  inc_earn_head >= 9999998
	gen inc_earn_HSP = inc_earn_head
	replace inc_earn_HSP = inc_earn_head + inc_earn_spouse if inc_earn_spouse != .
	
	/* Marital Status */
	gen flag_married = (V16637 == 1)
	replace flag_married = . if V16637 >= 8
	
	summ  flag_married
	summ inc_* 
	
	gen flag_home_own  = (V16641 == 1)
	gen flag_home_rent = (V16641 == 5)
	
	gen reason_move1 = V16651 if V16651 < 9
	gen reason_move2 = .
	gen reason_move3 = .
	gen reason_move4 = .
	
	gen night_hosp_hd = . 
	gen night_hosp_sp = .
	
	gen reason_posend_hd_u = V16843
	gen reason_posend_sp_u = V17162 if flag_spouse == 1
	gen reason_posend_hd_e = V16741
	gen reason_posend_sp_e = V17060 if flag_spouse == 1
	
	gen health_status_head = V17390
	gen health_status_spouse = V17396


	/* ADC/AFDC, T-2, Social Security, unemployment compensation, worker's compensation*/
	
	gen flag_adc_head = (V16443 > 0) if V16443 != .
	gen flag_ss_head = 	(V16449 > 0) if V16449 != .
	gen flag_ui_head = (V16456 > 0) if V16456 != .
	gen flag_wi_head = (V16457 > 0) if V16457 != .
	
	gen flag_adc_spouse = (V16464 > 0) if V16464 != .
	gen flag_ss_spouse = (V16470 > 0) if V16470 != .	
	gen flag_ui_spouse = (V16476 > 0) if V16476 != .
	gen flag_wi_spouse = (V16477 > 0) if V16477 != .
	
	/* total asset */
	
	gen total_asset_debt = S216
	
	/* individual asset */
	
	gen level_busi = S203
	gen level_saving = S205
	gen level_estate = S209
	gen level_stocks = S211
	gen level_vehicle = S213
	gen level_oth_asset = S215

	gen yr_work_18 = V17523 if 0 < V17523 & V17523 < 99

	/******* State of Residence ********/
	gen state_res_code = V16303    
	
    label define state_res_code 1 "AL" , modify	
	label define state_res_code 2 "AZ" , modify 
	label define state_res_code 3 "AR" , modify 
	label define state_res_code 4 "CA" , modify 
	label define state_res_code 5 "CO" , modify 
	label define state_res_code 6 "CT" , modify 
	label define state_res_code 7 "DE" , modify 
	label define state_res_code 8 "DC" , modify 
	label define state_res_code 9 "FL" , modify 
	label define state_res_code 10 "GA" , modify
	label define state_res_code 11 "ID" , modify
	label define state_res_code 12 "IL" , modify
	label define state_res_code 13 "IN" , modify
	label define state_res_code 14 "IA" , modify
	label define state_res_code 15 "KS" , modify
	label define state_res_code 16 "KY" , modify
	label define state_res_code 17 "LA" , modify
	label define state_res_code 18 "ME" , modify
	label define state_res_code 19 "MD" , modify
	label define state_res_code 20 "MA" , modify
	label define state_res_code 21 "MI" , modify
	label define state_res_code 22 "MN" , modify
	label define state_res_code 23 "MS" , modify
	label define state_res_code 24 "MO" , modify
	label define state_res_code 25 "MT" , modify
	label define state_res_code 26 "NE" , modify
	label define state_res_code 27 "NV" , modify
	label define state_res_code 28 "NH" , modify
	label define state_res_code 29 "NJ" , modify
	label define state_res_code 30 "NM" , modify
	label define state_res_code 31 "NY" , modify
	label define state_res_code 32 "NC" , modify
	label define state_res_code 33 "ND" , modify
	label define state_res_code 34 "OH" , modify
	label define state_res_code 35 "OK" , modify
	label define state_res_code 36 "OR" , modify
	label define state_res_code 37 "PA" , modify
	label define state_res_code 38 "RI" , modify
	label define state_res_code 39 "SC" , modify
	label define state_res_code 40 "SD" , modify
	label define state_res_code 41 "TN" , modify
	label define state_res_code 42 "TX" , modify
	label define state_res_code 43 "UT" , modify
	label define state_res_code 44 "VT" , modify
	label define state_res_code 45 "VA" , modify
	label define state_res_code 46 "WA" , modify
	label define state_res_code 47 "WV" , modify
	label define state_res_code 48 "WI" , modify
	label define state_res_code 49 "WY" , modify 
	label define state_res_code 50 "AK" , modify
	label define state_res_code 51 "HI" , modify	
	
	label value state_res_code state_res_code	
	decode state_res_code, gen(state_res)

   /******* Current State ********/
	gen state_curr_code = V17539                                     

	label define state_curr_code 1 "AL" , modify
	label define state_curr_code 2 "AK" , modify
	label define state_curr_code 4 "AZ" , modify
	label define state_curr_code 5 "AR" , modify
	label define state_curr_code 6 "CA" , modify
	label define state_curr_code 8 "CO" , modify
	label define state_curr_code 9 "CT" , modify
	label define state_curr_code 10 "DE" , modify
	label define state_curr_code 11 "DC" , modify
	label define state_curr_code 12 "FL" , modify
	label define state_curr_code 13 "GA" , modify
	label define state_curr_code 15 "HI" , modify
	label define state_curr_code 16 "ID" , modify
	label define state_curr_code 17 "IL" , modify
	label define state_curr_code 18 "IN" , modify
	label define state_curr_code 19 "IA" , modify
	label define state_curr_code 20 "KS" , modify
	label define state_curr_code 21 "KY" , modify
	label define state_curr_code 22 "LA" , modify
	label define state_curr_code 23 "ME" , modify
	label define state_curr_code 24 "MD" , modify
	label define state_curr_code 25 "MA" , modify
	label define state_curr_code 26 "MI" , modify
	label define state_curr_code 27 "MN" , modify
	label define state_curr_code 28 "MI" , modify
	label define state_curr_code 29 "MO" , modify
	label define state_curr_code 30 "MT" , modify
	label define state_curr_code 31 "NE" , modify
	label define state_curr_code 32 "NV" , modify
	label define state_curr_code 33 "NH" , modify
	label define state_curr_code 34 "NJ" , modify
	label define state_curr_code 35 "NM" , modify
	label define state_curr_code 36 "NY" , modify
	label define state_curr_code 37 "NC" , modify
	label define state_curr_code 38 "ND" , modify
	label define state_curr_code 39 "OH" , modify
	label define state_curr_code 40 "OK" , modify
	label define state_curr_code 41 "OR" , modify
	label define state_curr_code 42 "PA" , modify
	label define state_curr_code 44 "RI" , modify
	label define state_curr_code 45 "SC" , modify
	label define state_curr_code 46 "SD" , modify
	label define state_curr_code 47 "TN" , modify
	label define state_curr_code 48 "TX" , modify
	label define state_curr_code 49 "UT" , modify
	label define state_curr_code 50 "VT" , modify
	label define state_curr_code 51 "VA" , modify
	label define state_curr_code 53 "WA" , modify
	label define state_curr_code 54 "WV" , modify
	label define state_curr_code 55 "WI" , modify
	label define state_curr_code 56 "WY" , modify

	label value state_curr_code state_curr_code
	decode state_curr_code, gen(state_curr)
	

	keep unique_id svy_year interview_id flag_* level_*  num_of_family educ_* head_* inc_* non_white ///
		 annual_mortg annual_rent food_home cntrb_outside reason* night* family_weight ///
		 health_status_* spouse_emply total_asset_debt yr_work_18 state_res state_curr
 
		 

	tempfile psid1989
	save `psid1989', replace
	count
restore		
