/* PSID DATA CLEANING: 
   AUX CODE for prep_psid_1.do		*/
   
/* ********* */
/* Year 1995 */
/* ********* */	
preserve

	keep if (ER33203 == 10 & ER33202 == 1) | (ER33203 == 20 & ER33202 == 2) | (ER33203 == 22 & ER33202 == 2)
	
	bysort ER5002: egen flag_spouse  = max(ER33203 == 20 | ER33203 == 22)
	
	/* Main Cleaning */
	keep if ER33203 == 10 /* Keep head only */

	keep if ER5002 != .
	gen interview_id 	= ER5002
	gen family_weight	= ER7000
	gen num_of_family	= ER5005 

	/* Bring in SS Income Type */
	merge m:1 interview_id using `ss_type1995'
	
	keep if _merge == 3

	gen flag_di_rec = (hdsocsectype == 1 | wfsocsectype == 1)

	/* Indicators on whether head or spouse is DI recipient.
	   If both, use head. --> conditional on DI rec.		    */
	gen flag_di_rec_head = (flag_di_rec == 1 & hdsocsectype == 1)
	replace flag_di_rec_head = . if flag_di_rec == 0
	gen flag_di_rec_spouse = (flag_di_rec == 1 & wfsocsectype == 1)
	replace flag_di_rec_spouse = . if flag_di_rec == 0

	tab flag_di_rec flag_di_rec_head
	
	/* Receiving SSI (including disability and senior with low income) */
	gen flag_ssi_rec_head = .
	replace flag_ssi_rec_head = 1 if ER6277 == 1
	replace flag_ssi_rec_head = 0 if ER6277 == 5
	replace flag_ssi_rec_head = 0 if ER6277 == 0
	
	gen flag_ssi_rec_spouse = .
	replace flag_ssi_rec_spouse = 1 if ER6584 == 1
	replace flag_ssi_rec_spouse = 0 if ER6584 == 5
	replace flag_ssi_rec_spouse = 0 if ER6584 == 0

	gen flag_ssi_rec = (flag_ssi_rec_head == 1 | flag_ssi_rec_spouse == 1)
	replace flag_ssi_rec = . if flag_ssi_rec_head == . & flag_ssi_rec_spouse == .
	
	
	gen annual_mortg	= (ER5038 + ER5039) * 12 if ER5038 <= 99997 & ER5039 <= 99997
	
	gen 	rent_freq 	= 12 if ER5049 == 1
	replace rent_freq 	= 26  if ER5049 == 2 
	replace rent_freq 	= 52  if ER5049 == 3
	replace rent_freq 	= 12  if ER5049 == 5
	replace rent_freq 	= 1   if ER5049 == 6 
	gen 	annual_rent	= ER5048 * rent_freq if ER5048 <= 99997

	/* Food home */
	
	/* if food stamps not used, ... */
	gen 	food_freq = 365 if ER6085 == 2
	replace food_freq = 52  if ER6085 == 3
	replace food_freq = 26  if ER6085 == 4
	replace food_freq = 12  if ER6085 == 5
	replace food_freq = 1   if ER6085 == 6
	gen 	food_home = ER6084 * food_freq if ER6084 <= 99996	
	replace food_home = 0 if ER6084 == 0			
	
	/* Food out */
	gen 	food_out_freq = 365 if ER6090 == 2
	replace food_out_freq = 52  if ER6090 == 3
	replace food_out_freq = 26  if ER6090 == 4
	replace food_out_freq = 12  if ER6090 == 5
	replace food_out_freq = 1   if ER6090 == 6
	gen 	food_out = ER6089 * food_out_freq if ER6089 <= 99996	
	
	gen cntrb_outside	= ER6715

	replace annual_mortg  = .  if annual_mortg == 0
	replace annual_rent   = .  if annual_rent  == 0
	replace cntrb_outside = .k if cntrb_outside == 9999998
	replace cntrb_outside = .n if cntrb_outside == 9999999

	
	/* Additional controls */
	gen head_age  = ER5006 if ER5006 <= 120
	gen head_male = ER5007 == 1 
	gen head_emply = (ER5068 == 1) if ER5068 < 9
	replace head_emply = 1 if ER5068 != 1 & ER5069 == 1
	replace head_emply = 1 if ER5068 != 1 & ER5070 == 1

	gen spouse_emply = (ER5562 == 1) if ER5562 < 9 & ER5562 != 0
	replace spouse_emply = 1 if ER5562 != 1 & ER5563 == 1
	replace spouse_emply = 1 if ER5562 != 1 & ER5564 == 1
	
	gen non_white = ER6814 != 1 if ER6814 != 9
	
	gen educ_hs 	 = .
	replace educ_hs 	= 0 if inrange(ER6998, 0, 11)
	replace educ_hs		= 1 if inrange(ER6998, 12,17)
	gen educ_college = .
	replace educ_college= 0 if inrange(ER6998, 0, 15)
	replace educ_college= 1 if inrange(ER6998, 16,17)

	gen flag_foodstamp = (ER6058 == 1)
	replace flag_foodstamp = . if ER6058 == 9
	
	gen svy_year = 1995
	
	gen inc_headwife = ER6986 
	gen inc_hh = ER6993 
	
	/* SSA REC AND DISABILITY STATUS */
	gen inc_ss_total = .
	summ inc_ss_total
	
	gen level_disabled_head   = ER6726
	gen level_disabled_spouse = ER6731
	tab level_disabled_head 
	tab level_disabled_spouse
	gen flag_candonothing_head = (ER6725 == 7)
	gen flag_candonothing_spouse = (ER6730 == 7)
	
	replace level_disabled_head = -1 if flag_candonothing_head == 1
	replace level_disabled_spouse = -1 if flag_candonothing_spouse == 1
	
	gen flag_severe_head = 0 if level_disabled_head != 0
	replace flag_severe_head = 1  if level_disabled_head == 1
	replace flag_severe_head = 1  if flag_candonothing_head == 1
	tab flag_severe_head
	
	gen flag_severe_spouse = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse = 1  if level_disabled_spouse == 1
	replace flag_severe_spouse = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse
	
	gen flag_moderate_head = 0 if level_disabled_head != 0
	replace flag_moderate_head = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_head
	
	gen flag_moderate_spouse = 0 if level_disabled_head != 0
	replace flag_moderate_spouse = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_spouse
	
	gen flag_psid_disable_head = (flag_severe_head == 1 | flag_moderate_head == 1)
	gen flag_psid_disable_spouse = (flag_severe_spouse == 1 | flag_moderate_spouse == 1)
	tab flag_psid_disable_head
	tab flag_psid_disable_spouse
	
	gen flag_severe = max(flag_severe_head, flag_severe_spouse)
	gen flag_moderate = max(flag_moderate_head, flag_moderate_spouse)
	gen flag_psid_disable = max(flag_psid_disable_head, flag_psid_disable_spouse)
	
	gen flag_severe_head2 = 0 if level_disabled_head != 0
	replace flag_severe_head2 = 1  if level_disabled_head == 1 | level_disabled_head == 3
	replace flag_severe_head2 = 1  if flag_candonothing_head == 1
	tab flag_severe_head2


	gen flag_severe_spouse2 = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse2 = 1  if level_disabled_spouse == 1 | level_disabled_spouse == 3
	replace flag_severe_spouse2 = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse2

	gen flag_severe2 = max(flag_severe_head2, flag_severe_spouse2)

	
	summ flag* 
	
	/******* Measures of permanent income ********/
	
	/* Year of education -- capped at 17, i.e. At least one year of postgraduate work */
	gen level_educ_head   = ER6998 
	gen level_educ_spouse = ER6999 /* Note for now: some data might not be brought forward */	
	replace level_educ_head   = . if level_educ_head >= 98
	replace level_educ_spouse = . if level_educ_spouse >= 98
	
	/* Parental education */
	gen level_educ_headFa_US = ER6794
	replace level_educ_headFa_US   = . if level_educ_headFa_US >= 9
	
	gen level_educ_headMo_US = ER6796
	replace level_educ_headMo_US   = . if level_educ_headMo_US >= 9
	
	gen level_educ_spouseFa_US = ER6734
	replace level_educ_spouseFa_US   = . if level_educ_spouseFa_US >= 9
	
	gen level_educ_spouseMo_US = ER6736
	replace level_educ_spouseMo_US   = . if level_educ_spouseMo_US >= 9
	
	/* Parental family wealth when they grow up  */
	gen level_wealth_headParent = ER6793
	replace level_wealth_headParent = . if level_wealth_headParent == 9
	gen level_wealth_spouseParent = .
	replace level_wealth_spouseParent = . if level_wealth_spouseParent == 9
	
	summ level_*
	
	/******* Measures of outside resources ********/

	/* Spousal wage/salaries */
	gen inc_earn_spouse = ER6480 + ER6957 + ER6981
	replace inc_earn_spouse = . if  inc_earn_spouse >= 9999998
	
	gen level_spouseage = ER5008
	replace level_spouseage = . if level_spouseage > 120	
	
	/* Earnings */
	gen inc_earn_head = ER6962
	replace inc_earn_head = . if  inc_earn_head >= 9999998
	gen inc_earn_HSP = inc_earn_head
	replace inc_earn_HSP = inc_earn_head + inc_earn_spouse if inc_earn_spouse != .
	
	/* Marital Status */
	gen flag_married = (ER5013 == 1)
	replace flag_married = . if ER5013 >= 8
	
	summ /*flag_health_ins*/ flag_married
	summ inc_* 
	
	gen flag_home_own  = (ER5031 == 1)
	gen flag_home_rent = (ER5031 == 5)
	
	gen reason_move1 = ER5064 if ER5064 < 9 
	gen reason_move2 = ER5065 if reason_move1 != .
	gen reason_move3 = ER5066 if reason_move1 != . & ER5066 < 9
	gen reason_move4 = .
	
	gen night_hosp_hd = . 
	gen night_hosp_sp = .
	
	gen reason_posend_hd_u = ER6874
	gen reason_posend_sp_u = ER6905 if flag_spouse == 1
	gen reason_posend_hd_e = ER6863
	gen reason_posend_sp_e = ER6894 if flag_spouse == 1
	
	gen health_status_head = ER6723
	gen health_status_spouse = ER6728
	
	
	/* ADC/AFDC, T-2, Social Security, unemployment compensation, worker's compensation*/
	
	
	gen flag_adc_head = ER6262
	gen flag_ui_head = ER6371
	gen flag_wi_head = ER6386
	
	gen flag_adc_spouse = ER6600
	gen flag_ui_spouse = ER6494
	gen flag_wi_spouse = ER6509
	
	gen flag_ss = ER6308

	
	/* Relative and non-relative cash transfer */
	
	gen flag_cash_relative_head = (ER6431 == 1) if ER6431 == 1 | ER6431 == 5
	gen flag_cash_relative_spouse = (ER6660 == 1) if ER6660 == 1 | ER6660 == 5
	
	gen flag_cash_nonrelative_head = (ER6446 == 1) if ER6446 == 1 | ER6446 == 5
	gen flag_cash_nonrelative_spouse = (ER6675 == 1) if ER6675 == 1 | ER6675 == 5


	/* exp for rent and mortgage monthly reported */
	
	gen exp_rent_old = ER5048 if ER5048 < 99998
	gen exp_mortg_old = ER5038 if ER5038 < 99998

	
	/* exp for food weekly reported */
	
	gen exp_food_N_fdstamp = ER6084 if ER6084 < 99998 & ER6084 != 0
	gen exp_food_fdstamp = ER6077 if ER6077 < 99998 & ER6077 != 0

	count if exp_food_N_fdstamp != . & exp_food_fdstamp != .

	gen exp_food_old = exp_food_N_fdstamp
	replace exp_food_old = exp_food_fdstamp if exp_food_old == .

	gen yr_work_18 = ER6855 if 0 < ER6855 & ER6855 < 99
	
	/******* State of Residence ********/
	gen state_res_code = ER6996       
	
    label define state_res_code 1 "AL" , modify	
	label define state_res_code 2 "AZ" , modify 
	label define state_res_code 3 "AR" , modify 
	label define state_res_code 4 "CA" , modify 
	label define state_res_code 5 "CO" , modify 
	label define state_res_code 6 "CT" , modify 
	label define state_res_code 7 "DE" , modify 
	label define state_res_code 8 "DC" , modify 
	label define state_res_code 9 "FL" , modify 
	label define state_res_code 10 "GA" , modify
	label define state_res_code 11 "ID" , modify
	label define state_res_code 12 "IL" , modify
	label define state_res_code 13 "IN" , modify
	label define state_res_code 14 "IA" , modify
	label define state_res_code 15 "KS" , modify
	label define state_res_code 16 "KY" , modify
	label define state_res_code 17 "LA" , modify
	label define state_res_code 18 "ME" , modify
	label define state_res_code 19 "MD" , modify
	label define state_res_code 20 "MA" , modify
	label define state_res_code 21 "MI" , modify
	label define state_res_code 22 "MN" , modify
	label define state_res_code 23 "MS" , modify
	label define state_res_code 24 "MO" , modify
	label define state_res_code 25 "MT" , modify
	label define state_res_code 26 "NE" , modify
	label define state_res_code 27 "NV" , modify
	label define state_res_code 28 "NH" , modify
	label define state_res_code 29 "NJ" , modify
	label define state_res_code 30 "NM" , modify
	label define state_res_code 31 "NY" , modify
	label define state_res_code 32 "NC" , modify
	label define state_res_code 33 "ND" , modify
	label define state_res_code 34 "OH" , modify
	label define state_res_code 35 "OK" , modify
	label define state_res_code 36 "OR" , modify
	label define state_res_code 37 "PA" , modify
	label define state_res_code 38 "RI" , modify
	label define state_res_code 39 "SC" , modify
	label define state_res_code 40 "SD" , modify
	label define state_res_code 41 "TN" , modify
	label define state_res_code 42 "TX" , modify
	label define state_res_code 43 "UT" , modify
	label define state_res_code 44 "VT" , modify
	label define state_res_code 45 "VA" , modify
	label define state_res_code 46 "WA" , modify
	label define state_res_code 47 "WV" , modify
	label define state_res_code 48 "WI" , modify
	label define state_res_code 49 "WY" , modify 
	label define state_res_code 50 "AK" , modify
	label define state_res_code 51 "HI" , modify	
	
	label value state_res_code state_res_code	
	decode state_res_code, gen(state_res)

	/******* Current State ********/
	gen state_curr_code = ER6997                               

	label define state_curr_code 1 "AL" , modify
	label define state_curr_code 2 "AK" , modify
	label define state_curr_code 4 "AZ" , modify
	label define state_curr_code 5 "AR" , modify
	label define state_curr_code 6 "CA" , modify
	label define state_curr_code 8 "CO" , modify
	label define state_curr_code 9 "CT" , modify
	label define state_curr_code 10 "DE" , modify
	label define state_curr_code 11 "DC" , modify
	label define state_curr_code 12 "FL" , modify
	label define state_curr_code 13 "GA" , modify
	label define state_curr_code 15 "HI" , modify
	label define state_curr_code 16 "ID" , modify
	label define state_curr_code 17 "IL" , modify
	label define state_curr_code 18 "IN" , modify
	label define state_curr_code 19 "IA" , modify
	label define state_curr_code 20 "KS" , modify
	label define state_curr_code 21 "KY" , modify
	label define state_curr_code 22 "LA" , modify
	label define state_curr_code 23 "ME" , modify
	label define state_curr_code 24 "MD" , modify
	label define state_curr_code 25 "MA" , modify
	label define state_curr_code 26 "MI" , modify
	label define state_curr_code 27 "MN" , modify
	label define state_curr_code 28 "MI" , modify
	label define state_curr_code 29 "MO" , modify
	label define state_curr_code 30 "MT" , modify
	label define state_curr_code 31 "NE" , modify
	label define state_curr_code 32 "NV" , modify
	label define state_curr_code 33 "NH" , modify
	label define state_curr_code 34 "NJ" , modify
	label define state_curr_code 35 "NM" , modify
	label define state_curr_code 36 "NY" , modify
	label define state_curr_code 37 "NC" , modify
	label define state_curr_code 38 "ND" , modify
	label define state_curr_code 39 "OH" , modify
	label define state_curr_code 40 "OK" , modify
	label define state_curr_code 41 "OR" , modify
	label define state_curr_code 42 "PA" , modify
	label define state_curr_code 44 "RI" , modify
	label define state_curr_code 45 "SC" , modify
	label define state_curr_code 46 "SD" , modify
	label define state_curr_code 47 "TN" , modify
	label define state_curr_code 48 "TX" , modify
	label define state_curr_code 49 "UT" , modify
	label define state_curr_code 50 "VT" , modify
	label define state_curr_code 51 "VA" , modify
	label define state_curr_code 53 "WA" , modify
	label define state_curr_code 54 "WV" , modify
	label define state_curr_code 55 "WI" , modify
	label define state_curr_code 56 "WY" , modify

	label value state_curr_code state_curr_code
	decode state_curr_code, gen(state_curr)


	keep unique_id svy_year interview_id flag_* level_*  num_of_family educ_* head_* inc_* non_white  ///
		 annual_mortg annual_rent food_home food_out cntrb_outside reason* night* family_weight ///
		 health_status_* spouse_emply exp_* yr_work_18 state_res state_curr


	tempfile psid1995
	save `psid1995', replace
	count
restore		
