/* PSID DATA CLEANING: 
   AUX CODE for prep_psid_1.do		*/
   
/* ********* */
/* Year 1996 */
/* ********* */	
preserve

	keep if (ER33303 == 10 & ER33302 == 1) | (ER33303 == 20 & ER33302 == 2) | (ER33303 == 22 & ER33302 == 2)
	
	bysort ER7002: egen flag_spouse  = max(ER33303 == 20 | ER33303 == 22)

	/* Main Cleaning */
	keep if ER33303 == 10 /* Keep head only */

	keep if ER7002 != .
	gen interview_id 	= ER7002
	gen family_weight	= ER9251
	gen num_of_family	= ER7005 

	/* Bring in SS Income Type */
	merge m:1 interview_id using `ss_type1996'
	
	keep if _merge == 3

	gen flag_di_rec = (hdsocsectype == 1 | wfsocsectype == 1)

	/* Indicators on whether head or spouse is DI recipient.
	   If both, use head. --> conditional on DI rec.		    */
	gen flag_di_rec_head = (flag_di_rec == 1 & hdsocsectype == 1)
	replace flag_di_rec_head = . if flag_di_rec == 0
	gen flag_di_rec_spouse = (flag_di_rec == 1 & wfsocsectype == 1)
	replace flag_di_rec_spouse = . if flag_di_rec == 0
	tab flag_di_rec flag_di_rec_head
	
	/* Receiving SSI (including disability and senior with low income) */
	gen flag_ssi_rec_head = .
	replace flag_ssi_rec_head = 1 if ER8394 == 1
	replace flag_ssi_rec_head = 0 if ER8394 == 5
	replace flag_ssi_rec_head = 0 if ER8394 == 0
	
	gen flag_ssi_rec_spouse = .
	replace flag_ssi_rec_spouse = 1 if ER8701 == 1
	replace flag_ssi_rec_spouse = 0 if ER8701 == 5
	replace flag_ssi_rec_spouse = 0 if ER8701 == 0

	gen flag_ssi_rec = (flag_ssi_rec_head == 1 | flag_ssi_rec_spouse == 1)
	replace flag_ssi_rec = . if flag_ssi_rec_head == . & flag_ssi_rec_spouse == .
	
	gen annual_mortg	= (ER7044 + ER7045) * 12 if ER7044 <= 99997 & ER7045 <= 99997
	
	gen 	rent_freq = 365 if ER7122 == 2
	replace rent_freq = 52  if ER7122 == 3 
	replace rent_freq = 26  if ER7122 == 4
	replace rent_freq = 12  if ER7122 == 5
	replace rent_freq = 1   if ER7122 == 6 
	gen 	annual_rent	= ER7121 * rent_freq if ER7121 <= 99997
	
	gen cntrb_outside	= ER8833

	replace annual_mortg  = .  if annual_mortg == 0
	replace annual_rent   = .  if annual_rent  == 0
	replace cntrb_outside = .k if cntrb_outside == 9999998
	replace cntrb_outside = .n if cntrb_outside == 9999999
	
	/* Food variables */
	
	gen 	food_freq = 365 if ER8182 == 2
	replace food_freq = 52  if ER8182 == 3
	replace food_freq = 26  if ER8182 == 4
	replace food_freq = 12  if ER8182 == 5
	replace food_freq = 1   if ER8182 == 6
	gen 	food_home = ER8181 * food_freq if ER8181 <= 99996	
	replace food_home = 0 if ER8181 == 0				

	gen 	food_out_freq = 365 if ER8187 == 2
	replace food_out_freq = 52  if ER8187 == 3
	replace food_out_freq = 26  if ER8187 == 4
	replace food_out_freq = 12  if ER8187 == 5
	replace food_out_freq = 1   if ER8187 == 6
	gen 	food_out = ER8186 * food_out_freq if ER8186 <= 99996	
	
	/* Additional controls */
	gen head_age  = ER7006 if ER7006 <= 120
	gen head_male = ER7007 == 1 
	gen head_emply = (ER7164 == 1) if ER7164 < 9
	replace head_emply = 1 if ER7164 != 1 & ER7165 == 1
	replace head_emply = 1 if ER7164 != 1 & ER7166 == 1

	gen spouse_emply = (ER7658 == 1) if ER7658 < 9 & ER7658 != 0
	replace spouse_emply = 1 if ER7658 != 1 & ER7659 == 1
	replace spouse_emply = 1 if ER7658 != 1 & ER7660 == 1
	
	gen non_white = ER9060 != 1 if ER9060 != 9
	
	gen educ_hs 	 = .
	replace educ_hs 	= 0 if inrange(ER9249, 0, 11)
	replace educ_hs		= 1 if inrange(ER9249, 12,17)
	gen educ_college = .
	replace educ_college= 0 if inrange(ER9249, 0, 15)
	replace educ_college= 1 if inrange(ER9249, 16,17)

	gen flag_foodstamp = (ER8155 == 1)
	replace flag_foodstamp = . if ER8155 == 9
	
	gen svy_year = 1996
	
	gen inc_headwife = ER9237 
	gen inc_hh = ER9244 
	
	/* SSA REC AND DISABILITY STATUS */
	gen inc_ss_total = .
	summ inc_ss_total
	
	gen level_disabled_head   = ER8972
	gen level_disabled_spouse = ER8977
	tab level_disabled_head 
	tab level_disabled_spouse
	gen flag_candonothing_head = (ER8971 == 7)
	gen flag_candonothing_spouse = (ER8976 == 7)
	
	replace level_disabled_head = -1 if flag_candonothing_head == 1
	replace level_disabled_spouse = -1 if flag_candonothing_spouse == 1
	
	gen flag_severe_head = 0 if level_disabled_head != 0
	replace flag_severe_head = 1  if level_disabled_head == 1
	replace flag_severe_head = 1  if flag_candonothing_head == 1
	tab flag_severe_head
	
	gen flag_severe_spouse = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse = 1  if level_disabled_spouse == 1
	replace flag_severe_spouse = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse
	
	gen flag_moderate_head = 0 if level_disabled_head != 0
	replace flag_moderate_head = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_head
	
	gen flag_moderate_spouse = 0 if level_disabled_head != 0
	replace flag_moderate_spouse = 1 if (level_disabled_head == 3 | level_disabled_head == 5 | level_disabled_head == 7) 
	tab flag_moderate_spouse
	
	gen flag_psid_disable_head = (flag_severe_head == 1 | flag_moderate_head == 1)
	gen flag_psid_disable_spouse = (flag_severe_spouse == 1 | flag_moderate_spouse == 1)
	tab flag_psid_disable_head
	tab flag_psid_disable_spouse
	
	gen flag_severe = max(flag_severe_head, flag_severe_spouse)
	gen flag_moderate = max(flag_moderate_head, flag_moderate_spouse)
	gen flag_psid_disable = max(flag_psid_disable_head, flag_psid_disable_spouse)
	
	gen flag_severe_head2 = 0 if level_disabled_head != 0
	replace flag_severe_head2 = 1  if level_disabled_head == 1 | level_disabled_head == 3
	replace flag_severe_head2 = 1  if flag_candonothing_head == 1
	tab flag_severe_head2


	gen flag_severe_spouse2 = 0 if level_disabled_spouse != 0
	replace flag_severe_spouse2 = 1  if level_disabled_spouse == 1 | level_disabled_spouse == 3
	replace flag_severe_spouse2 = 1  if flag_candonothing_spouse == 1
	tab flag_severe_spouse2

	gen flag_severe2 = max(flag_severe_head2, flag_severe_spouse2)

	summ flag* 
	
	/******* Measures of permanent income ********/
	
	/* Year of education -- capped at 17, i.e. At least one year of postgraduate work */
	gen level_educ_head   = ER9249 
	gen level_educ_spouse = ER9250 /* Note for now: some data might not be brought forward */	
	replace level_educ_head   = . if level_educ_head >= 98
	replace level_educ_spouse = . if level_educ_spouse >= 98
	
	/* Parental education */
	gen level_educ_headFa_US = ER9040
	replace level_educ_headFa_US   = . if level_educ_headFa_US >= 9
	
	gen level_educ_headMo_US = ER9042
	replace level_educ_headMo_US   = . if level_educ_headMo_US >= 9
	
	gen level_educ_spouseFa_US = ER8980
	replace level_educ_spouseFa_US   = . if level_educ_spouseFa_US >= 9
	
	gen level_educ_spouseMo_US = ER8982
	replace level_educ_spouseMo_US   = . if level_educ_spouseMo_US >= 9
	
	/* Parental family wealth when they grow up  */
	gen level_wealth_headParent = ER9039
	replace level_wealth_headParent = . if level_wealth_headParent == 9
	gen level_wealth_spouseParent = .
	replace level_wealth_spouseParent = . if level_wealth_spouseParent == 9
	
	summ level_*
	
	/******* Measures of outside resources ********/
	
	/* Spousal wage/salaries */
	gen inc_earn_spouse = ER8597 + ER9208 + ER9232
	replace inc_earn_spouse = . if  inc_earn_spouse >= 9999998
	
	gen level_spouseage = ER7008
	replace level_spouseage = . if level_spouseage > 120	
	
	/* Earnings */
	gen inc_earn_head = ER9213
	replace inc_earn_head = . if  inc_earn_head >= 9999998
	gen inc_earn_HSP = inc_earn_head
	replace inc_earn_HSP = inc_earn_head + inc_earn_spouse if inc_earn_spouse != .
	
	/* Marital Status -- current status. I treat widowed or dicorved as single */
	gen flag_married = (ER7013 == 1)
	replace flag_married = . if ER7013 >= 8
	
	summ flag_married
	summ inc_* 
	
	gen flag_home_own  = (ER7031 == 1)
	gen flag_home_rent = (ER7031 == 5)
	
	gen reason_move1 = ER7158 if ER7158 < 9
	gen reason_move2 = ER7159 if reason_move1 != .
	gen reason_move3 = ER7160 if reason_move1 != .
	gen reason_move4 = .
	
	
	gen reason_posend_hd_u = ER9125
	gen reason_posend_sp_u = ER9156 
	gen reason_posend_hd_e = ER9114
	gen reason_posend_sp_e = ER9145
	
	gen night_hosp_hd = . 
	gen night_hosp_sp = .
	

	gen health_status_head = ER8969
	gen health_status_spouse = ER8974
	
	
	/* ADC/AFDC, T-2, Social Security, unemployment compensation, worker's compensation*/
	
	gen flag_adc_head = ER8379
	gen flag_ui_head = ER8488
	gen flag_wi_head = ER8503
	
	gen flag_adc_spouse = ER8717
	gen flag_ui_spouse = ER8611
	gen flag_wi_spouse = ER8626
	
	gen flag_ss = ER8425
	
	/* financial distress since 1991 */

	gen flag_bankruptcy = (ER8915 == 1) if ER8915 == 1 | ER8915 == 5
	gen flag_consolidate = (ER8853 > 0) if ER8853 != 8 & ER8853 != 9
	gen flag_garnish = (ER8872 > 0) if ER8872 != 8 & ER8872 != 9
	
	/* types of money problem since 1991 */

	gen money_prob1 = ER8841 if 0 < ER8841 & ER8841 < 8
	gen money_prob2 = ER8842 if 0 < ER8842 & ER8842 < 8
	gen money_prob3 = ER8843 if 0 < ER8843 & ER8843 < 8
	gen money_prob4 = ER8844 if 0 < ER8844 & ER8844 < 8
	gen money_prob5 = ER8845 if 0 < ER8845 & ER8845 < 8
	/* gen money_prob6 = ER8846 if 0 < ER8846 & ER8846 < 8, 0 for all samples */
	
	tab money_prob1, m
	tab money_prob2, m
	tab money_prob3, m
	tab money_prob4, m
	tab money_prob5, m
	
	forval i = 1(1)5{
		gen flag_money_prob`i' = 1 if money_prob`i' != .
		replace flag_money_prob`i' = 0 if money_prob`i' == 7
	}

	tab flag_money_prob1, m
	tab flag_money_prob2, m
	tab flag_money_prob3, m
	tab flag_money_prob4, m
	tab flag_money_prob5, m
	
	gen flag_money_prob = (flag_money_prob1 == 1 | flag_money_prob2 == 1 | flag_money_prob3 == 1 | flag_money_prob4 == 1 | flag_money_prob5 == 1)
	replace flag_money_prob = . if flag_money_prob1 == . & flag_money_prob2 == . & flag_money_prob3 == . & flag_money_prob4 == . & flag_money_prob5 == . 
	
	/* Relative and non-relative cash transfer */
	
	gen flag_cash_relative_head = (ER8548 == 1) if ER8548 == 1 | ER8548 == 5
	gen flag_cash_relative_spouse = (ER8777 == 1) if ER8777 == 1 | ER8777 == 5
	
	gen flag_cash_nonrelative_head = (ER8563 == 1) if ER8563 == 1 | ER8563 == 5
	gen flag_cash_nonrelative_spouse = (ER8792 == 1) if ER8792 == 1 | ER8792 == 5

	egen money_prob_num = rowtotal(flag_money_prob1 - flag_money_prob5), m
	tab money_prob_num, m
	
	/* exp for rent and mortgage monthly reported */
	
	gen exp_rent_old = ER7121 if ER7121 < 99998
	gen exp_mortg_old = ER7044 if ER7044 < 99998

	/* exp for food weekly reported */
	
	gen exp_food_N_fdstamp = ER8181 if ER8181 < 99998 & ER8181 != 0
	gen exp_food_fdstamp = ER8174 if ER8174 < 99998 & ER8174 != 0

	count if exp_food_N_fdstamp != . & exp_food_fdstamp != .
	
	gen exp_food_old = exp_food_N_fdstamp
	replace exp_food_old = exp_food_fdstamp if exp_food_old == .

	gen yr_work_18 = ER9101 if 0 < ER9101 & ER9101 < 99

	/******* State of Residence ********/

	gen state_res_code = ER9247        
	
    label define state_res_code 1 "AL" , modify	
	label define state_res_code 2 "AZ" , modify 
	label define state_res_code 3 "AR" , modify 
	label define state_res_code 4 "CA" , modify 
	label define state_res_code 5 "CO" , modify 
	label define state_res_code 6 "CT" , modify 
	label define state_res_code 7 "DE" , modify 
	label define state_res_code 8 "DC" , modify 
	label define state_res_code 9 "FL" , modify 
	label define state_res_code 10 "GA" , modify
	label define state_res_code 11 "ID" , modify
	label define state_res_code 12 "IL" , modify
	label define state_res_code 13 "IN" , modify
	label define state_res_code 14 "IA" , modify
	label define state_res_code 15 "KS" , modify
	label define state_res_code 16 "KY" , modify
	label define state_res_code 17 "LA" , modify
	label define state_res_code 18 "ME" , modify
	label define state_res_code 19 "MD" , modify
	label define state_res_code 20 "MA" , modify
	label define state_res_code 21 "MI" , modify
	label define state_res_code 22 "MN" , modify
	label define state_res_code 23 "MS" , modify
	label define state_res_code 24 "MO" , modify
	label define state_res_code 25 "MT" , modify
	label define state_res_code 26 "NE" , modify
	label define state_res_code 27 "NV" , modify
	label define state_res_code 28 "NH" , modify
	label define state_res_code 29 "NJ" , modify
	label define state_res_code 30 "NM" , modify
	label define state_res_code 31 "NY" , modify
	label define state_res_code 32 "NC" , modify
	label define state_res_code 33 "ND" , modify
	label define state_res_code 34 "OH" , modify
	label define state_res_code 35 "OK" , modify
	label define state_res_code 36 "OR" , modify
	label define state_res_code 37 "PA" , modify
	label define state_res_code 38 "RI" , modify
	label define state_res_code 39 "SC" , modify
	label define state_res_code 40 "SD" , modify
	label define state_res_code 41 "TN" , modify
	label define state_res_code 42 "TX" , modify
	label define state_res_code 43 "UT" , modify
	label define state_res_code 44 "VT" , modify
	label define state_res_code 45 "VA" , modify
	label define state_res_code 46 "WA" , modify
	label define state_res_code 47 "WV" , modify
	label define state_res_code 48 "WI" , modify
	label define state_res_code 49 "WY" , modify 
	label define state_res_code 50 "AK" , modify
	label define state_res_code 51 "HI" , modify	
	
	label value state_res_code state_res_code	
	decode state_res_code, gen(state_res)
	
	/******* Current State ********/

	gen state_curr_code = ER9248                              

	label define state_curr_code 1 "AL" , modify
	label define state_curr_code 2 "AK" , modify
	label define state_curr_code 4 "AZ" , modify
	label define state_curr_code 5 "AR" , modify
	label define state_curr_code 6 "CA" , modify
	label define state_curr_code 8 "CO" , modify
	label define state_curr_code 9 "CT" , modify
	label define state_curr_code 10 "DE" , modify
	label define state_curr_code 11 "DC" , modify
	label define state_curr_code 12 "FL" , modify
	label define state_curr_code 13 "GA" , modify
	label define state_curr_code 15 "HI" , modify
	label define state_curr_code 16 "ID" , modify
	label define state_curr_code 17 "IL" , modify
	label define state_curr_code 18 "IN" , modify
	label define state_curr_code 19 "IA" , modify
	label define state_curr_code 20 "KS" , modify
	label define state_curr_code 21 "KY" , modify
	label define state_curr_code 22 "LA" , modify
	label define state_curr_code 23 "ME" , modify
	label define state_curr_code 24 "MD" , modify
	label define state_curr_code 25 "MA" , modify
	label define state_curr_code 26 "MI" , modify
	label define state_curr_code 27 "MN" , modify
	label define state_curr_code 28 "MI" , modify
	label define state_curr_code 29 "MO" , modify
	label define state_curr_code 30 "MT" , modify
	label define state_curr_code 31 "NE" , modify
	label define state_curr_code 32 "NV" , modify
	label define state_curr_code 33 "NH" , modify
	label define state_curr_code 34 "NJ" , modify
	label define state_curr_code 35 "NM" , modify
	label define state_curr_code 36 "NY" , modify
	label define state_curr_code 37 "NC" , modify
	label define state_curr_code 38 "ND" , modify
	label define state_curr_code 39 "OH" , modify
	label define state_curr_code 40 "OK" , modify
	label define state_curr_code 41 "OR" , modify
	label define state_curr_code 42 "PA" , modify
	label define state_curr_code 44 "RI" , modify
	label define state_curr_code 45 "SC" , modify
	label define state_curr_code 46 "SD" , modify
	label define state_curr_code 47 "TN" , modify
	label define state_curr_code 48 "TX" , modify
	label define state_curr_code 49 "UT" , modify
	label define state_curr_code 50 "VT" , modify
	label define state_curr_code 51 "VA" , modify
	label define state_curr_code 53 "WA" , modify
	label define state_curr_code 54 "WV" , modify
	label define state_curr_code 55 "WI" , modify
	label define state_curr_code 56 "WY" , modify

	label value state_curr_code state_curr_code
	decode state_curr_code, gen(state_curr)
	
	
	keep unique_id svy_year interview_id flag_* level_*  num_of_family head_* inc_* educ_* ///
		 non_white spouse_emply annual_mortg annual_rent cntrb_outside reason* night* family_weight ///
		 health_status_* money* exp_* yr_work_18 food_home food_out state_res state_curr
		 
	tempfile psid1996
	save `psid1996', replace
	count
restore		
