version 15
capture log close
clear all
set maxvar 10000
set more off
pause off
#delim;	

local output "";
local log "";
local raw "$data/raw";
local results "$results";
local do "$code";
local psid_batch  J296232;
local deflationyr 2016;

/* ******************************* */
/* CPI ADJUSTMENT - BASE YEAR 2016 */
/* ******************************* */

/* Adjustment using CPIAUCNS */
freduse CPIAUCNS A191RD3A086NBEA, clear;

gen date_n = date(date,"YMD");
gen year = year(date_n);
rename A191RD3A086NBEA GDPDEF;
collapse (mean) CPIAUCNS GDPDEF, by(year);
tsset year;
sum CPIAUCNS if year== `deflationyr';
gen factor_CPI = r(mean)/CPIAUCNS;
sum GDPDEF if year== `deflationyr';
gen factor_GDPDEF = r(mean)/GDPDEF;

/* Keep selected year range */
keep if year >= 1951 & year <= 2017;
keep year factor_CPI;  
tempfile deflators;
save `deflators';


/* ********************** */
/* PREP FOR PSID AUX FILE */
/* ********************** */

use "`raw'/socsectype94_07.dta", clear; 	/* PSID raw data on Social Security Income of head of household and wife */
rename yrid interview_id;

foreach yr in 1994 1995 1996 1997 1999 2001 2003 2005 2007 {;
	preserve;
	keep if year == `yr';
	tempfile ss_type`yr';
	save `ss_type`yr'';
	restore;
};


/* *********** */
/* PSID IMPORT */
/* *********** */

/* Run scripts from PSID UMich 
Import raw PSID (script generated by PSID DATA CENTER  with selected variables) */

qui do "`do'/0/prep_psid_0.do";
qui do "`do'/0//prep_psid_0_format.do";
qui compress;										
save "`results'/for_psid_clean1_`psid_batch'.dta", replace;

use "`results'/for_psid_clean1_`psid_batch'.dta", clear ;

/* Generate row ID for later linkage 
   Data has been pre-linked into panel format by PSID DATA CENTER	*/
   
gen unique_id = ER30001*1000 + ER30002;


/* ******************** */
/* PROCESS PSID BY YEAR */
/* ******************** */

foreach aux_yr in 1999 2001 2003 2005 2007 2009 2011 2013 2015 2017 {;
	include "`do'/by_year/psid_1clean_aux`aux_yr'.do";
};

foreach aux_yr in 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 {;
	include "`do'/by_year/psid_1clean_aux`aux_yr'.do";
};


/* ******************* */
/* APPEND PSID BY YEAR */
/* ******************* */

use `psid1997', clear;

forval i = 1999(2)2017 {;
	append using `psid`i'';
};

forval i = 1986(1)1996 {;
	append using `psid`i'';
};


/* ********* */
/* DEFLATING */
/* ********* */

gen year = svy_year - 1;  /* Survey reference year */
drop svy_year;

merge m:1 year using `deflators';
drop if _merge != 3;
drop _merge;

tab year;

foreach var in annual_mortg annual_rent food_home food_out cntrb_outside
			   exp_hhtotal exp_food 
			   exp_housing exp_mortg exp_rent exp_utility
			   exp_transport exp_educ exp_child
			   exp_health exp_hospital exp_doctor exp_rx exp_insurance exp_medicalcare
			   inc_headwife inc_hh inc_earn_HSP inc_earn_head inc_earn_spouse level_cash 
			   exp_rent_old exp_mortg_old exp_food_N_fdstamp exp_food_fdstamp exp_food_old
			   total_asset_debt level_busi level_saving level_estate level_stocks level_vehicle
			   level_oth_asset level_annuity
	{;
			   
	replace `var' = `var' * factor_CPI;
	
	};
		

/* *********************** */
/* EXPORT LONG FORMAT DATA */
/* *********************** */

compress;
save "`results'/psid_clean_update_`deflationyr'usd_long_`psid_batch'.dta", replace;

	
/* *********************** */
/* EXPORT WIDE FORMAT DATA */
/* *********************** */
#delim;
reshape wide interview_id num_of_family flag_* level_* educ_* head_* inc_* spouse_emply
			 non_white family_weight factor_CPI state_res state_curr
			 annual_mortg annual_rent cntrb_outside 			
			 exp_housing exp_mortg exp_rent exp_utility 
			 exp_transport exp_food exp_educ exp_child reason* night*  
			 exp_health exp_hhtotal exp_hospital exp_doctor exp_rx exp_insurance exp_medicalcare compared*
			 adl* iadl* health_status* depression time_* wealth_child* live* amt* freq* food* worry* hhfood* lf_* money*
			 exp_rent_old exp_mortg_old exp_food_N_fdstamp exp_food_fdstamp exp_food_old total_asset_debt yr_work_18, 
			 i(unique_id) j(year)
		;	 
			 
save "`results'/psid_clean_update_`deflationyr'usd_`psid_batch'.dta", replace;

capture log close;

