version 15
clear all
set more off
capture log close
set logtype text
#delim;

local output "$results";
local log "";
local do "";

local psid_batch J296232;

use "`output'/psid_clean_update_2016usd_long_`psid_batch'.dta", clear;

/* *************** */
/* CLEAN VARIABLES */
/* *************** */
rename level_spouseage spouse_age;
replace spouse_age = . if flag_spouse == 0;

/* SSDI/SSI */
replace flag_di_rec = . if head_age > 66 & spouse_age > 66;			
replace flag_di_rec = . if head_age > 66 & flag_di_rec_head == 1 & flag_di_rec_spouse == 0;
replace flag_di_rec = . if spouse_age > 66 & flag_di_rec_head == 0 & flag_di_rec_spouse == 1;
replace flag_di_rec_head = . if head_age > 66;
replace flag_di_rec_spouse = . if spouse_age > 66;
tab year flag_di_rec,m;
tab year flag_di_rec_head,m; /* missing if HH does not receive DI */
tab year flag_di_rec_spouse,m; /* missing if HH does not receive DI */

gen flag_dissi_rec = (flag_di_rec == 1 | flag_ssi_rec == 1) ;
tab flag_dissi_rec, m ;

foreach var in head spouse{;
	gen flag_dissi_rec_`var' = (flag_di_rec_`var' == 1 | flag_ssi_rec_`var' == 1) ;
	tab flag_dissi_rec_`var', m;
};

/* Disability */
replace level_disabled_head   = 7.5 if level_disabled_head == 0;
replace level_disabled_spouse = 7.5 if level_disabled_spouse == 0;
gen level_disabled = level_disabled_head;

/* Use the most severe condition for head and spouse */
replace level_disabled = level_disabled_spouse 
			if (level_disabled_spouse < level_disabled_head) & flag_spouse == 1;
gen flag_moresevereinHH = 0;
replace flag_moresevereinHH = 1 if (level_disabled == level_disabled_head) & 
				(inrange(level_disabled, 1, 7.5) | level_disabled_head == -1) ;	
tab level_disabled flag_di_rec, m; 
/* missing if both head and spouse older than 67, or the one report receiving is older than 67 */

/* MEAN CONSUMPTIONS */
gen exp_foodmortgrent = exp_food + exp_mortg + exp_rent;
gen exp_mortgrent = exp_mortg + exp_rent;
gen exp_fdhouse = exp_food + exp_housing;

/* missing for year 1985 to 1996 */

count if exp_foodmortgrent == .;
count if exp_mortgrent == .;
count if exp_fdhouse == .;

/* Take out education expenses */

gen hhexp_N_educ = exp_hhtotal - exp_educ;	
gen hhexp_fd_ho_hlth_tp = hhexp_N_educ - exp_child;
gen hhexp_fd_ho_hlth = hhexp_N_educ - exp_child - exp_transport;
gen hhexp_fd_ho = hhexp_N_educ - exp_child - exp_transport - exp_health;

gen hhexp_N_hlth = exp_hhtotal - exp_health;

rename exp_hhtotal hhexp_total;


count if hhexp_total == .;
count if hhexp_N_educ == .;
count if hhexp_fd_ho_hlth_tp == .;
count if hhexp_fd_ho_hlth == .;
count if hhexp_fd_ho == .;
count if hhexp_N_hlth == .;
sum hhexp*; /* missing for year 1985 - 1996 */

/* Create consumption variables for mean MU with consumption floor at 5k */
		foreach i in total N_educ fd_ho_hlth_tp fd_ho_hlth fd_ho N_hlth{;
			gen hhexp`i'_muflr = max(5000, hhexp_`i');
		};	

/* Alternative definitions of severity */
capture drop flag_severe;
capture drop flag_severe2;
capture drop flag_severe3;
capture drop flag_moderate;
capture drop flag_anydis; 

/* only include "can do nothing" and "A lot" */
gen flag_severe = . ;
replace flag_severe = 1 if level_disabled == -1  | level_disabled == 1 ;
replace flag_severe = 0 if level_disabled == 7.5 | level_disabled == 7 | level_disabled == 5 | level_disabled == 3;
tab flag_severe, m; /* missing if level_disabled == 8 or 9 */

/* include "Somewhat" */
gen flag_severe2 = . ;
replace flag_severe2 = 1 if level_disabled == -1  | level_disabled == 1 | level_disabled == 3;
replace flag_severe2 = 0 if level_disabled == 7.5 | level_disabled == 7 | level_disabled == 5;
tab flag_severe2, m; /* missing if level_disabled == 8 or 9 */
		
/* include "Somewhat" and "Just a little" */
gen flag_severe3 = . ;
replace flag_severe3 = 1 if level_disabled == -1  | level_disabled == 1 | 
									level_disabled == 3 | level_disabled == 5;
replace flag_severe3 = 0 if level_disabled == 7.5 | level_disabled == 7 ;
tab flag_severe3, m; /* missing if level_disabled == 8 or 9 */
	
/* only "Somewhat" and "Just a little"*/

gen flag_moderate = . ;
replace flag_moderate = 1 if level_disabled == 3 | level_disabled == 5 ;
replace flag_moderate = 0 if level_disabled == -1 | level_disabled == 1 | level_disabled == 7 | level_disabled == 7.5 ;
tab flag_moderate, m;

/* those are used for stacked bar graph */

gen flag_moderate3 = . ;
replace flag_moderate3 = 1 if level_disabled == 3 ;
replace flag_moderate3 = 0 if level_disabled == -1 | level_disabled == 1 | level_disabled == 5 | level_disabled == 7 | level_disabled == 7.5 ;

gen flag_moderate5 = . ;
replace flag_moderate5 = 1 if level_disabled == 5;
replace flag_moderate5 = 0 if level_disabled == -1 | level_disabled == 1 | level_disabled == 3 | level_disabled == 7 | level_disabled == 7.5 ;
										
tab flag_moderate3 flag_moderate5, m; /* missing if level_disabled == 8 or 9 */

gen flag_notatall7 = . ;
replace flag_notatall7 = 1 if level_disabled == 7;
replace flag_notatall7 = 0 if level_disabled == -1 | level_disabled == 1 | level_disabled == 3 | level_disabled == 5 | level_disabled == 7.5 ;
										
tab flag_notatall7, m; /* missing if level_disabled == 8 or 9 */

gen flag_nolimit = .;
replace flag_nolimit = 1 if level_disabled == 7.5;
replace flag_nolimit = 0 if level_disabled == -1 | level_disabled == 1 | level_disabled == 3 | level_disabled == 5 | level_disabled == 7 ;
										
tab flag_nolimit, m; /* missing if level_disabled == 8 or 9 */

capture drop flag_psid_disable;
gen flag_psid_disable = flag_severe3 ;


/* Some recodings */
gen inc_earn_spouse_cond = inc_earn_spouse;
replace inc_earn_spouse_cond = . if flag_spouse == 0;

replace level_educ_spouse = . if flag_spouse == 0;
replace level_educ_spouseFa_US = . if flag_spouse == 0;
replace level_educ_spouseMo_US = . if flag_spouse == 0;
replace level_educ_spouseFa_F = . if flag_spouse == 0;
replace level_educ_spouseMo_F = . if flag_spouse == 0;

		
foreach role in head {;

	gen educ_hsdrop_`role' = (level_educ_`role' < 12); 
	replace educ_hsdrop_`role' = . if level_educ_`role' == .;
			
	gen educ_hsgrad_`role' = (level_educ_`role' == 12); 
	replace educ_hsgrad_`role' = . if level_educ_`role' == .;
			
	gen educ_some_college_`role' = (level_educ_`role' > 12 & level_educ_`role' < 16); 
	replace educ_some_college_`role' = . if level_educ_`role' == .;

	gen educ_college_`role' = (level_educ_`role' >= 16); 
	replace educ_college_`role' = . if level_educ_`role' == .;
};


/*
   Parental family wealth when they grow up 
   Value/Range	Text
1	Poor
3	Average, it varied
5	Pretty well off		
*/

	gen level_wealth_Parent = level_wealth_headParent; 
	tab level_wealth_Parent, m; /* missing if original value = 9 (DK, NA, refused) */


/* 
Parental educations 
Value/Range	Text [US Education]
0	Could not read or write, DK grade and could not read or write
1	0 - 5 grades; illiterate
2	6 - 8 grades
3	9 - 11 grades
4	12 grades
5	12 grades plus non-academic training
6	College, no degree
7	College, bachelor's degree
8	College, advanced or professional degree
9	NA; DK											*/


/*** PARENTAL EDUCATION ***/
/* neither graduated from high school */

#delim;
gen educ_parent_hsdrop_head = 1;
replace educ_parent_hsdrop_head = 0 if ( inrange(level_educ_headFa_US, 4, 8) | level_educ_headFa_F >= 12 );
replace educ_parent_hsdrop_head = 0 if ( inrange(level_educ_headMo_US, 4, 8) | level_educ_headMo_F >= 12 );
replace educ_parent_hsdrop_head = . if (level_educ_headFa_US == . & level_educ_headFa_F == .) | (level_educ_headMo_US == . & level_educ_headMo_F == .);

gen educ_parent_hsdrop_spouse = 1;
replace educ_parent_hsdrop_spouse = 0 if ( inrange(level_educ_spouseFa_US, 4, 8) | level_educ_spouseFa_F >= 12 );
replace educ_parent_hsdrop_spouse = 0 if ( inrange(level_educ_spouseMo_US, 4, 8) | level_educ_spouseMo_F >= 12 );
replace educ_parent_hsdrop_spouse = . if (level_educ_spouseFa_US == . & level_educ_spouseFa_F == .)| (level_educ_spouseMo_US == . & level_educ_spouseMo_F == .);
												 
tab educ_parent_hsdrop_head, m;
tab educ_parent_hsdrop_spouse, m;											 


/* both at least graduated from college */
gen educ_parent_college_head = 0;
replace educ_parent_college_head = 1 if ( inrange(level_educ_headFa_US, 7, 8) | level_educ_headFa_F >= 16 )  & ( inrange(level_educ_headMo_US, 7, 8) | level_educ_headMo_F >= 16 );
replace educ_parent_college_head = . if (level_educ_headFa_US == . & level_educ_headFa_F == .) | (level_educ_headMo_US == . & level_educ_headMo_F == .);
											   
gen educ_parent_college_spouse = 0;
replace educ_parent_college_spouse = 1 if ( inrange(level_educ_spouseFa_US, 7, 8) | level_educ_spouseFa_F >= 16 ) & ( inrange(level_educ_spouseMo_US, 7, 8) | level_educ_spouseMo_F >= 16 );
replace educ_parent_college_spouse = . if (level_educ_spouseFa_US == . & level_educ_spouseFa_F == .) | (level_educ_spouseMo_US == . & level_educ_spouseMo_F == .);
														
tab educ_parent_college_head, m;
tab educ_parent_college_spouse, m;

/* one graduated from high school + one dropout */
gen educ_parent_hsdropgrad_head = 0;
replace educ_parent_hsdropgrad_head = 1 if ( inrange(level_educ_headFa_US, 4, 6) | inrange(level_educ_headFa_F, 12,15) ) & ( inrange(level_educ_headMo_US, 0, 3) | inrange(level_educ_headMo_F, 1,11) );
replace educ_parent_hsdropgrad_head = 1 if ( inrange(level_educ_headMo_US, 4, 6) | inrange(level_educ_headMo_F, 12,15) ) & ( inrange(level_educ_headFa_US, 0, 3) | inrange(level_educ_headFa_F, 1,11) );									 
replace educ_parent_hsdropgrad_head = . if (level_educ_headFa_US == . & level_educ_headFa_F == .) | (level_educ_headMo_US == . & level_educ_headMo_F == .);
											   
gen educ_parent_hsdropgrad_spouse = 0;
replace educ_parent_hsdropgrad_spouse = 1 if ( inrange(level_educ_spouseFa_US, 4, 6) | inrange(level_educ_spouseFa_F, 12,15) ) & ( inrange(level_educ_spouseMo_US, 0, 3) | inrange(level_educ_spouseMo_F, 1,11) );
replace educ_parent_hsdropgrad_spouse = 1 if ( inrange(level_educ_spouseMo_US, 4, 6) | inrange(level_educ_spouseMo_F, 12,15) ) & ( inrange(level_educ_spouseFa_US, 0, 3) | inrange(level_educ_spouseFa_F, 1,11) );									 
replace educ_parent_hsdropgrad_spouse = . if (level_educ_spouseFa_US == . & level_educ_spouseFa_F == .) | (level_educ_spouseMo_US == . & level_educ_spouseMo_F == .);

tab educ_parent_hsdropgrad_head, m;
tab educ_parent_hsdropgrad_spouse, m;


/* both at least graduated from high school but neither college*/
gen educ_parent_hsgrad_head = 0;
replace educ_parent_hsgrad_head = 1 if ( inrange(level_educ_headFa_US, 4, 6) | inrange(level_educ_headFa_F, 12,15) ) & ( inrange(level_educ_headMo_US, 4, 6) | inrange(level_educ_headMo_F, 12,15) );
replace educ_parent_hsgrad_head = . if (level_educ_headFa_US == . & level_educ_headFa_F == .) | (level_educ_headMo_US == . & level_educ_headMo_F == .);
											   
gen educ_parent_hsgrad_spouse = 0;
replace educ_parent_hsgrad_spouse = 1 if ( inrange(level_educ_spouseFa_US, 4, 6) | inrange(level_educ_spouseFa_F,12,15) ) &   ( inrange(level_educ_spouseMo_US, 4, 6) | inrange(level_educ_spouseMo_F,12,15) );
replace educ_parent_hsgrad_spouse = . if (level_educ_spouseFa_US == . & level_educ_spouseFa_F == .) | (level_educ_spouseMo_US == . & level_educ_spouseMo_F == .);

replace educ_parent_hsgrad_head = 0 if educ_parent_college_head == 1;
replace educ_parent_hsgrad_spouse = 0 if educ_parent_college_spouse == 1;		
				 
tab educ_parent_hsgrad_head, m;
tab educ_parent_hsgrad_spouse, m;


/* one graduated from high school + one college */
gen educ_parent_hsgradcollege_head = 0;
replace educ_parent_hsgradcollege_head = 1 if ( inrange(level_educ_headFa_US, 4, 6) | inrange(level_educ_headFa_F, 12,15) )	& ( inrange(level_educ_headMo_US, 7, 8) | inrange(level_educ_headMo_F, 16,17) );
replace educ_parent_hsgradcollege_head = 1 if ( inrange(level_educ_headMo_US, 4, 6) | inrange(level_educ_headMo_F, 12,15) )	& ( inrange(level_educ_headFa_US, 7, 8) | inrange(level_educ_headFa_F, 16,17) );									 
replace educ_parent_hsgradcollege_head = . if (level_educ_headFa_US == . & level_educ_headFa_F == .) |  (level_educ_headMo_US == . & level_educ_headMo_F == .);
											   
gen educ_parent_hsgradcollege_spouse = 0;
replace educ_parent_hsgradcollege_spouse = 1 if ( inrange(level_educ_spouseFa_US, 4, 6) | inrange(level_educ_spouseFa_F, 12,15) )  & ( inrange(level_educ_spouseMo_US, 7, 8) | inrange(level_educ_spouseMo_F, 16,17) );
replace educ_parent_hsgradcollege_spouse = 1 if ( inrange(level_educ_spouseMo_US, 4, 6) | inrange(level_educ_spouseMo_F, 12,15) )  & ( inrange(level_educ_spouseFa_US, 7, 8) | inrange(level_educ_spouseFa_F, 16,17) );									 
replace educ_parent_hsgradcollege_spouse = . if (level_educ_spouseFa_US == . & level_educ_spouseFa_F == .) | (level_educ_spouseMo_US == . & level_educ_spouseMo_F == .);	
				 
tab educ_parent_hsgradcollege_head, m;
tab educ_parent_hsgradcollege_spouse, m;

/* one high school dropout + one college */
gen educ_parent_hsdropcollege_head = 0;
replace educ_parent_hsdropcollege_head = 1 if ( inrange(level_educ_headFa_US, 0, 3) | inrange(level_educ_headFa_F, 1,11) ) & ( inrange(level_educ_headMo_US, 7, 8) | inrange(level_educ_headMo_F, 16,17) );
replace educ_parent_hsdropcollege_head = 1 if ( inrange(level_educ_headMo_US, 0, 3) | inrange(level_educ_headMo_F, 1,11) ) & ( inrange(level_educ_headFa_US, 7, 8) | inrange(level_educ_headFa_F, 16,17) );									 
replace educ_parent_hsdropcollege_head = . if (level_educ_headFa_US == . & level_educ_headFa_F == .) | (level_educ_headMo_US == . & level_educ_headMo_F == .);
											   
gen educ_parent_hsdropcollege_spouse = 0;
replace educ_parent_hsdropcollege_spouse = 1 if ( inrange(level_educ_spouseFa_US, 0, 3) | inrange(level_educ_spouseFa_F, 1,11) )  & ( inrange(level_educ_spouseMo_US, 7, 8) | inrange(level_educ_spouseMo_F, 16,17) );
replace educ_parent_hsdropcollege_spouse = 1 if ( inrange(level_educ_spouseMo_US, 0, 3) | inrange(level_educ_spouseMo_F, 1,11) )  & ( inrange(level_educ_spouseFa_US, 7, 8) | inrange(level_educ_spouseFa_F, 16,17) );									 
replace educ_parent_hsdropcollege_spouse = . if (level_educ_spouseFa_US == . & level_educ_spouseFa_F == .) | (level_educ_spouseMo_US == . & level_educ_spouseMo_F == .);	
				 
tab educ_parent_hsdropcollege_head, m;
tab educ_parent_hsdropcollege_spouse, m;

sum educ_*;

/* the numbers of observations are smaller for parent education because some 
education variables for parents do not go farther back */

#delim;

/* Generate combined categories */				
		gen educ_parent_hsdrop2_head  = educ_parent_hsdrop_head;
		gen educ_parent_hsgrad1_head  = max(educ_parent_hsdropgrad_head, educ_parent_hsgrad_head);
		gen educ_parent_college1_head = max(educ_parent_hsgradcollege_head, educ_parent_hsdropcollege_head, educ_parent_college_head);

		summ educ_parent_hsdrop2_head educ_parent_hsgrad1_head educ_parent_college1_head;


	/* General health condition  

	1. Excellent
	2. Very good
	3. Good 
	4. Fair
	5. Poor

	*/

#delim;

	tab health_status_head, m;
	tab health_status_spouse, m;
	replace health_status_head = . if health_status_head > 7| health_status_head == 0 ; /* NA or DK or wild code */
	replace health_status_spouse = . if health_status_spouse > 7 | health_status_spouse == 0; /* NA or DK or no wife */

	gen health_status = health_status_head;
	replace health_status = health_status_spouse if flag_spouse == 1 & health_status_spouse > health_status_head & health_status_spouse != .;

	tab health_status flag_severe;

	gen flag_health_status45 = .;
	replace flag_health_status45 = 0 if health_status != .;
	replace flag_health_status45 = 1 if health_status == 4 | health_status == 5;

	gen flag_health_status5 = .;
	replace flag_health_status5 = 0 if health_status != .;
	replace flag_health_status5 = 1 if health_status == 5;

	forval i = 1(1)4{;
		
		gen flag_health_status`i' = .;
		replace flag_health_status`i' = 0 if health_status != .;
		replace flag_health_status`i' = 1 if health_status == `i';


	};

	tab flag_health_status45, m;
	tab flag_health_status5, m;
	tab flag_health_status4, m;
	tab flag_health_status3, m;
	tab flag_health_status2, m;
	tab flag_health_status1, m;
	
	gen flag_hfairpoor = flag_health_status45 ;
	gen flag_hpoor     = flag_health_status5 ;


	/* ADLS, IADLS */

		foreach var in bath dress eat out_bed outdoor toilet walk{;
			foreach pos in head spouse{;
				replace adl_`var'_`pos' = . if adl_`var'_`pos' > 7 | adl_`var'_`pos' == 0;
				replace adl_`var'_`pos' = 0 if adl_`var'_`pos' == 5;
			};
		};

	/* number of adls that are equal to 1 */
		egen num_adl_head = rowtotal(adl_*_head),m;
		egen num_adl_spouse = rowtotal(adl_*_spouse),m;

		gen num_adl = num_adl_head;
		replace num_adl = num_adl_spouse if num_adl_spouse > num_adl_head & flag_spouse == 1 & num_adl_spouse != .;

		tab num_adl, m;
		tab flag_severe;
		tab num_adl if flag_severe == 1;
		tab num_adl if flag_severe == 0;
		
	/* How many are satisfied among 7 variables for ADLS */

		tab num_adl, m;

		forval i = 0(1)7{;

			gen flag_adl`i' = (num_adl == `i') if num_adl != .;
			
		};

	/* IADLS */

		foreach var in heavy light manage_money meal shop tel{;
			foreach pos in head spouse{;
				replace iadl_`var'_`pos' = . if iadl_`var'_`pos' > 6 | iadl_`var'_`pos' == 0;
				replace iadl_`var'_`pos' = 0 if iadl_`var'_`pos' == 5;
			};
		};

		egen num_iadl_head = rowtotal(iadl_*_head),m;
		egen num_iadl_spouse = rowtotal(iadl_*_spouse),m;

	/* take the higher one between head and sposue if spouse exists */

		gen num_iadl = num_iadl_head;
		replace num_iadl = num_iadl_spouse if num_iadl_spouse > num_iadl_head & flag_spouse == 1 & num_iadl_spouse != .;


		forval i = 0(1)6{;

			gen flag_iadl`i' = (num_iadl == `i') if num_iadl != .;
			
		};


		tab num_iadl;
		tab flag_severe;
		tab num_iadl if flag_severe == 1;
		tab num_iadl if flag_severe == 0;

		gen flag_adl = .;
		replace flag_adl = 0 if num_adl != .;
		replace flag_adl = 1 if num_adl > 1 & num_adl != .;

		gen flag_iadl = .;
		replace flag_iadl = 0 if num_iadl != .;
		replace flag_iadl = 1 if num_iadl > 1 & num_iadl != .;


		tab flag_adl;
		tab flag_iadl;

		tab flag_adl flag_iadl;
		tab flag_adl flag_severe;
		tab flag_severe flag_iadl;

/* Physical and mental condition */
	
/* depression, only for head, define depression as 13 or higher */

tab depression, m;
replace depression = 0 if depression < 13 & depression != .;
replace depression = 1 if depression >= 13 & depression != .;

tab flag_arthritis_head, m;
foreach var in arthritis asthma blood cancer diabete heart_attack heart_disease
				lung_disease other stroke psychiatric learning memory {;
	foreach pos in head spouse{;
		replace flag_`var'_`pos' = . if flag_`var'_`pos' > 7 | flag_`var'_`pos' == 0;
		replace flag_`var'_`pos' = 0 if flag_`var'_`pos' == 5;	
	};
};
		
/* household level */ 
foreach diag in arthritis asthma blood cancer diabete heart_attack heart_disease 
				lung_disease other stroke psychiatric learning memory {;			
	gen diag_`diag' = (flag_`diag'_head > 0 | flag_`diag'_spouse > 0) if flag_`diag'_head != . & flag_`diag'_spouse != .;
	replace diag_`diag' = (flag_`diag'_head > 0) if flag_`diag'_head != . & flag_spouse == 0;
} ;
				
gen diag_depress = depression ;
		
summ diag_* ;
			
/* All conditions including physical and mental health */

gen num_anycondition_head = flag_arthritis_head + flag_asthma_head + flag_blood_head
									+ flag_cancer_head + flag_diabete_head + flag_heart_attack_head
									+ flag_heart_disease_head + flag_lung_disease_head + flag_stroke_head 
									+ depression + flag_psychiatric_head + flag_learning_head + flag_memory_head;

			
gen num_anycondition_spouse = flag_arthritis_spouse + flag_asthma_spouse + flag_blood_spouse
									+ flag_cancer_spouse + flag_diabete_spouse + flag_heart_attack_spouse
									+ flag_heart_disease_spouse + flag_lung_disease_spouse + flag_stroke_spouse
									+ flag_psychiatric_spouse + flag_learning_spouse + flag_memory_spouse;

			
gen flag_anycondition_head = 1 if num_anycondition_head > 0 & num_anycondition_head != .;
gen flag_anycondition_spouse = 1 if num_anycondition_spouse > 0 & num_anycondition_spouse != .;

gen flag_anycondition = flag_anycondition_head;
replace flag_anycondition = flag_anycondition_spouse if flag_anycondition_spouse == 1;
			
tab flag_anycondition, m;

/* missing from 1985 to 1996 */


/* All mental condition */

gen flag_all_mental_head = depression + flag_psychiatric_head + flag_learning_head + flag_memory_head ;
gen flag_all_mental_spouse = flag_psychiatric_spouse + flag_learning_spouse + flag_memory_spouse ;

gen flag_anymental = (flag_all_mental_head > 0| flag_all_mental_spouse > 0) if flag_all_mental_head != . & flag_all_mental_spouse != .;
replace flag_anymental = (flag_all_mental_head > 0) if flag_all_mental_head != . & flag_spouse == 0;
		
tab flag_anymental, m;
		
/* severity by mental health */

gen flag_severe_mhd = (depression == 1 | flag_memory_head == 1 | flag_memory_spouse == 1)
				if depression != . & flag_memory_head != . & 
				flag_memory_spouse != . & flag_spouse == 1 ;

replace flag_severe_mhd = (depression == 1 | flag_memory_head == 1 )
					if depression != . & flag_memory_head != . & flag_spouse == 0 ;

replace flag_severe_mhd = 1 if flag_severe == 1 ;
		

gen flag_severe_mhp = (flag_memory_head == 1 | flag_memory_spouse == 1 |
flag_psychiatric_head == 1 | flag_psychiatric_spouse == 1)
				if flag_psychiatric_head != . & flag_psychiatric_spouse != . & 
						flag_memory_head != . & flag_memory_spouse != . 
						& flag_spouse == 1 ;

replace flag_severe_mhp = (flag_memory_head == 1 | flag_psychiatric_head == 1)
				if flag_psychiatric_head != . & flag_memory_head != . & flag_spouse == 0 ;
					
replace flag_severe_mhp = 1 if flag_severe == 1 ;
		
gen flag_severe_mhdp = (depression == 1 | flag_memory_head == 1 | 
						flag_memory_spouse == 1 | flag_psychiatric_head == 1 | 
						flag_psychiatric_spouse == 1)
					if depression != . & flag_psychiatric_head != . & 
					   flag_psychiatric_spouse != . & flag_memory_head != . & 
					   flag_memory_spouse != . & flag_spouse == 1 ;
						
replace flag_severe_mhdp = (depression == 1 | flag_memory_head == 1 | flag_psychiatric_head == 1)
					if depression != . & flag_psychiatric_head != . & flag_memory_head != . & flag_spouse == 0 ;
					
replace flag_severe_mhdp = 1 if flag_severe == 1 ;

				
/* Imputing mental health issue for missings */
replace flag_severe_mhdp = 0 if flag_severe_mhdp == . & flag_severe == 0 ;
replace flag_severe_mhdp = . if flag_severe == . ;
		

gen flag_Nsevere_mh = (flag_all_mental_head == 0 & flag_all_mental_spouse == 0) if flag_all_mental_head != . & flag_all_mental_spouse != .;
replace flag_Nsevere_mh = (flag_all_mental_head == 0) if flag_all_mental_head != . & flag_spouse == 0 ;
replace flag_Nsevere_mh = 0 if flag_severe == 1 ;
		
/* Some mental condition */

gen flag_mental_head = depression + flag_psychiatric_head + flag_memory_head;
tab  flag_mental_head, m;
gen flag_mental_spouse = flag_psychiatric_spouse + flag_memory_spouse;
tab  flag_mental_spouse, m;

gen flag_somemental = (flag_mental_head == 1|flag_mental_spouse == 1) if flag_mental_head != . & flag_mental_spouse != .;
replace flag_somemental = (flag_mental_head == 1) if flag_mental_head != . & flag_spouse == 0;

tab flag_somemental, m;

/* Any physical condition */

#delim;

gen flag_physical_head = flag_arthritis_head + flag_asthma_head + flag_blood_head
									+ flag_cancer_head + flag_diabete_head + flag_heart_attack_head
									+ flag_heart_disease_head + flag_lung_disease_head + flag_stroke_head;
									
gen flag_physical_spouse = flag_arthritis_spouse + flag_asthma_spouse + flag_blood_spouse
									+ flag_cancer_spouse + flag_diabete_spouse + flag_heart_attack_spouse
									+ flag_heart_disease_spouse + flag_lung_disease_spouse + flag_stroke_spouse;

gen flag_anyphysical = (flag_physical_head > 0 | flag_physical_spouse > 0) if flag_physical_head != . & flag_physical_spouse != .;
		replace flag_anyphysical = (flag_physical_head > 0) if flag_physical_head != . & flag_spouse == 0;

tab flag_anyphysical, m;

/* Some physical condition */

#delim;
gen flag_somephysical_head = flag_arthritis_head + flag_asthma_head
									+ flag_cancer_head + flag_diabete_head + flag_heart_attack_head
									+ flag_heart_disease_head + flag_lung_disease_head + flag_stroke_head;
									
gen flag_somephysical_spouse = flag_arthritis_spouse + flag_asthma_spouse
									+ flag_cancer_spouse + flag_diabete_spouse + flag_heart_attack_spouse
									+ flag_heart_disease_spouse + flag_lung_disease_spouse + flag_stroke_spouse;

gen flag_somephysical = (flag_somephysical_head > 0 | flag_somephysical_spouse > 0) 
																 if flag_somephysical_head != . & flag_somephysical_spouse != .;
replace flag_somephysical = (flag_somephysical_head > 0) if flag_somephysical_head != . & flag_spouse == 0;
					
tab flag_somephysical, m;
	
/* Limited physical condition */

gen flag_limitphysical_head = flag_cancer_head + flag_heart_attack_head + flag_lung_disease_head + flag_stroke_head;
		
gen flag_limitphysical_spouse = flag_cancer_spouse + flag_heart_attack_spouse + flag_lung_disease_spouse + flag_stroke_spouse;
		
gen flag_limitphysical = (flag_limitphysical_head > 0|flag_limitphysical_spouse > 0) 
																if flag_limitphysical_head != . & flag_limitphysical_spouse!=.;
replace flag_limitphysical = (flag_limitphysical_head > 0) if flag_limitphysical_head != . & flag_spouse == 0;
		
tab flag_limitphysical, m;
				
/* Some condition */
#delim;
		gen flag_mental = .;
		replace flag_mental = 0 if flag_mental_head == 0 & flag_mental_spouse == 0;	/* both head and spouse have no mental condition */
		replace flag_mental = 0 if flag_mental_head == 0 & flag_spouse == 0; /* or head have no mental condition and no spouse */
		replace flag_mental = 1 if flag_mental_head > 0 & flag_mental_head != .;
		replace flag_mental = 1 if flag_mental_spouse > 0 & flag_mental_spouse != .;

		tab flag_mental if year == 2016, m;
							
		gen flag_physical = .;
		replace flag_physical = 0 if flag_physical_head == 0 & flag_physical_spouse == 0;
		replace flag_physical = 0 if flag_physical_head == 0 & flag_spouse == 0;
		replace flag_physical = 0 if flag_health_status5 == 0 & year == 2016;
		replace flag_physical = 1 if flag_physical_head > 0 & health_status_head == 5;
		replace flag_physical = 1 if flag_physical_spouse > 0 & health_status_spouse == 5;

		tab flag_physical, m;

		gen flag_condition = .;
		replace flag_condition = 1 if flag_physical == 1;
		replace flag_condition = 1 if flag_mental == 1;
		replace flag_condition = 0 if flag_physical == 0 & flag_mental == 0;

		tab flag_condition, m;

/* ADC, UI, WC */

		replace flag_adc_head = 0 if flag_adc_head == 5;
		replace flag_ui_head = 0 if flag_ui_head == 5;
		replace flag_wi_head = 0 if flag_wi_head == 5;

		replace flag_adc_spouse = 0 if flag_adc_spouse == 5;
		replace flag_ui_spouse = 0 if flag_ui_spouse == 5;
		replace flag_wi_spouse = 0 if flag_wi_spouse == 5;

		gen flag_adc = 1 if flag_adc_head == 1 | flag_adc_spouse == 1;
		replace flag_adc = 0 if flag_adc_head == 0 & flag_adc_spouse == 0;
		gen flag_ui = 1 if flag_ui_head == 1 | flag_ui_spouse == 1;
		replace flag_ui = 0 if flag_ui_head == 0 & flag_ui_spouse == 0;
		gen flag_wi = 1 if flag_wi_head == 1 | flag_wi_spouse == 1;
		replace flag_wi = 0 if flag_wi_head == 0 & flag_wi_spouse == 0;

		tab flag_adc, m;
		tab flag_ui, m;
		tab flag_wi,m;

/* Social Security */

replace flag_ss_head = 0 if flag_ss_head == 5;
replace flag_ss_spouse = 0 if flag_ss_spouse == 5;

replace flag_ss = 1 if flag_ss_head == 1 | flag_ss_spouse == 1;
replace flag_ss = 0 if flag_ss_head == 0 & flag_ss_spouse == 0;
replace flag_ss = 0 if flag_ss == 5 | flag_ss == 8 | flag_ss == 9;

tab flag_ss, m;

/* Means-tested transfer, including foodstamp, SSI, ADC */
gen flag_mean_tested = .;
replace flag_mean_tested = 0 if flag_foodstamp == 0 & flag_adc == 0;
replace flag_mean_tested = 1 if flag_foodstamp == 1 | flag_adc == 1;

/* Social insurance, including SS, UI, WC */
gen flag_si_all = .;
replace flag_si_all = 0 if flag_wi == 0 & flag_ui == 0 & flag_ss == 0;
replace flag_si_all = 1 if flag_wi == 1 | flag_ui == 1 | flag_ss == 1;

gen flag_si_no_ss = .;
replace flag_si_no_ss = 0 if flag_wi == 0 & flag_ui == 0;
replace flag_si_no_ss = 1 if flag_wi == 1 | flag_ui == 1;

/* Non-cash assistant */

/* from communities */
gen flag_help = 0 if flag_childcare == 0 & flag_clothing == 0 & flag_food == 0 
				& flag_healthcare == 0 & flag_housing == 0 & flag_jobassist == 0 & flag_trasnp == 0;
replace flag_help = 1 if flag_childcare == 1 | flag_clothing == 1 | flag_food == 1 
				| flag_healthcare == 1 | flag_housing == 1 | flag_jobassist == 1 | flag_trasnp == 1;

tab flag_help, m;

/* from family */
gen flag_help_fam = 0 if flag_childcare_fam == 0 & flag_clothing_fam == 0 & flag_food_fam == 0 
				& flag_healthcare_fam == 0 & flag_housing_fam == 0 & flag_jobassist_fam == 0 & flag_trasnp_fam == 0;
replace flag_help_fam = 1 if flag_childcare_fam == 1 | flag_clothing_fam == 1 | flag_food_fam == 1 
				| flag_healthcare_fam == 1 | flag_housing_fam == 1 | flag_jobassist_fam == 1 | flag_trasnp_fam == 1;

tab flag_help_fam, m;

		
/* Cash transfer from relative / non-relative */
			
gen flag_cash_relative = (flag_cash_relative_head == 1|flag_cash_relative_spouse == 1) 
							if flag_cash_relative_head != . & flag_cash_relative_spouse != .;
replace flag_cash_relative = (flag_cash_relative_head == 1) if flag_cash_relative_head != . & flag_spouse == 0;

gen flag_cash_nonrelative = (flag_cash_nonrelative_head == 1|flag_cash_nonrelative_spouse == 1) 
								if flag_cash_nonrelative_head != . & flag_cash_nonrelative_spouse != .;
replace flag_cash_nonrelative = (flag_cash_nonrelative_head == 1) 
									if flag_cash_nonrelative_head != . & flag_spouse == 0;

tab flag_cash_relative, m;
tab flag_cash_nonrelative, m;

/* total assets not including debt */
		
gen total_asset = level_busi + level_saving + level_estate + level_stocks + level_vehicle + level_oth_asset + level_annuity;
		
tab year if total_asset != .;
		
/*********************************************************************************************************************************************/

/* Youngest age to receive DI and to be severe */

/* youngest age when they receive DI from what we can observe from the data */
	
foreach x in di dissi{;
	preserve;
		if "`x'" == "di"{;
		};
	
		else if "`x'" == "dissi"{;
			drop flag_di_rec;
			rename flag_dissi_rec flag_di_rec;
		};

		sort unique_id year;

		gen rec_age = head_age if flag_di_rec == 1; /* head age when someone receiving DI */
		tab rec_age, m; /* it is possible to have rec_age > 66 if spouse receives DI and head is older than 66 */

		replace rec_age = spouse_age if rec_age != . & rec_age > 66; /* For this case, use spouse age */
		bysort unique_id: egen temp_first_rec_age1 = min(rec_age); /* youngest age receiving DI from what we can observe */
		tab temp_first_rec_age1, m;

		bysort unique_id: egen min_yr = min(year);
		gen first_observ =(min_yr == year); /* whether it is the first observation */

		gen temp_first_rec_age2 = .;

	/* the age when it is not the first observation, and the year before is not receiving DI */
		bysort unique_id: replace temp_first_rec_age2 = head_age if flag_di_rec == 1 & flag_di_rec[_n-1] == 0 & first_observ != 1; 
	/* Change to spouse age when head age above 66 */
		replace temp_first_rec_age2 = spouse_age if temp_first_rec_age2 > 66 & temp_first_rec_age2 != .; 
		tab temp_first_rec_age2, m;

		bysort unique_id: egen temp_first_rec_age3 = min(temp_first_rec_age2);

		tab temp_first_rec_age3, m;


		gen first_di_rec_age = .;
		replace first_di_rec_age = temp_first_rec_age3 if temp_first_rec_age3 == temp_first_rec_age1;
		replace first_di_rec_age = temp_first_rec_age1 if temp_first_rec_age1 < 35 & temp_first_rec_age1 != .;

		tab first_di_rec_age, m; /* the first DI receiving age should be 66 or below 66 */
		tab first_di_rec_age;


	/* earliest year receiving DI */

		gen rec_year = year if flag_di_rec == 1;
		bysort unique_id: egen temp_first_rec_year1 = min(rec_year); /* the earliest year receiving DI */
		gen temp_first_rec_year2 = .;
		bysort unique_id: replace temp_first_rec_year2 = year if flag_di_rec == 1 & flag_di_rec[_n-1] == 0 & first_observ != 1; 

		bysort unique_id: egen temp_first_rec_year3 = min(temp_first_rec_year2);

		gen first_di_rec_year = .;
		replace first_di_rec_year = temp_first_rec_year3 if temp_first_rec_year3 == temp_first_rec_year1;

		tab first_di_rec_age;
		tab first_di_rec_year;	
		
		replace first_di_rec_age = rec_age if temp_first_rec_year3 == temp_first_rec_year1 
											& temp_first_rec_year1 != . & temp_first_rec_age3 != temp_first_rec_age1;

										
		replace first_di_rec_age = . if temp_first_rec_age3 == temp_first_rec_age1 
											& temp_first_rec_age1 != . & temp_first_rec_year3 != temp_first_rec_year1;
										
										
		rename first_di_rec_age temp_first_di_rec_age;
		bysort unique_id: egen first_di_rec_age = max(temp_first_di_rec_age);
											
		tab first_di_rec_age;
		tab first_di_rec_year;									
											
		drop temp_first_rec_age*;

/*********************************************************************************************************************************************/

/* youngest age when they become severe from what we can observe from the data */
/* the basic procedures are similar as above */

sort unique_id year;

#delim;

	
foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
 					 {;
	
		gen `sev'_age = head_age if flag_`sev' == 1;
		tab `sev'_age, m;

		bysort unique_id: egen temp_first_`sev'_age1 = min(`sev'_age);
		
		gen temp_first_`sev'_age2 = .;
		
		bysort unique_id: replace temp_first_`sev'_age2 = head_age if flag_`sev' == 1 & flag_`sev'[_n-1] == 0 & first_observ != 1;

		bysort unique_id: egen temp_first_`sev'_age3 = min(temp_first_`sev'_age2);

		gen first_`sev'_age = .;
		
		
		replace first_`sev'_age = temp_first_`sev'_age3 if temp_first_`sev'_age3 == temp_first_`sev'_age1;

		tab first_`sev'_age ;

		gen `sev'_year = year if flag_`sev' == 1;
		bysort unique_id: egen temp_first_`sev'_year1 = min(`sev'_year); /* the earliest year being severe */

		gen temp_first_`sev'_year2 = .;
		bysort unique_id: replace temp_first_`sev'_year2 = year if flag_`sev' == 1 & flag_`sev'[_n-1] == 0 & first_observ != 1; 
		bysort unique_id: egen temp_first_`sev'_year3 = min(temp_first_`sev'_year2);

		gen first_`sev'_year = .;
		replace first_`sev'_year = temp_first_`sev'_year3 if temp_first_`sev'_year3 == temp_first_`sev'_year1;

		tab first_`sev'_year, m;

	};

foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
				{;
		foreach var in age year {;
			replace first_`sev'_`var' = . if temp_first_`sev'_year3 == temp_first_`sev'_year1 
							& temp_first_`sev'_year1 != . & temp_first_`sev'_age3 != temp_first_`sev'_age1;
							
			replace first_`sev'_`var' = . if temp_first_`sev'_age3 == temp_first_`sev'_age1 
							& temp_first_`sev'_age1 != . & temp_first_`sev'_year3 != temp_first_`sev'_year1;
		};
		
		tab first_`sev'_age ;
		tab first_`sev'_year, m ;
		drop temp_first_`sev'_age* ;

	};



/*********************************************************************************************************************************************/


#delim;

/* whether severe at first DI receiving year */

foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp hfairpoor hpoor	{;
	
		gen temp_flag_`sev'_app = (flag_`sev' == 1) if first_di_rec_year == year & flag_`sev' != .; 
		bysort unique_id: egen flag_`sev'_app = max(temp_flag_`sev'_app);

		tab flag_`sev'_app, m;
		tab flag_`sev'_app;
	
		gen oldest_`sev' = (flag_`sev' == 1 & flag_di_rec == 1) if year == min_yr & flag_`sev' != . & flag_di_rec != .;
		gen temp_flag_`sev'_app2 = flag_`sev'_app;
		replace temp_flag_`sev'_app2 = oldest_`sev' if flag_`sev'_app == .;
		bysort unique_id: egen flag_`sev'_app2 = max(temp_flag_`sev'_app2);

		tab flag_`sev'_app2, m;
		tab flag_`sev'_app2;

/* Ever severe (for decompositions) */
bysort unique_id: egen flag_`sev'_ever = max(flag_`sev');				
tab flag_`sev'_ever, m;
		
/* Ever severe before application */
gen temp_`sev'_predi = flag_`sev' if (year < first_di_rec_year & first_di_rec_year !=.) ;
bysort unique_id: egen flag_`sev'_predi = max(temp_`sev'_predi);				
tab flag_`sev'_predi, m;
drop temp* ;
	};
	
rename flag_severe_ever flag_sev_ever ;

bysort unique_id: egen flag_di_rec_ever = max(flag_di_rec);				
tab flag_di_rec_ever;	
tab flag_di_rec_ever, m;
																						
/* strict measure of non-recipients */

#delim;
																					
	gen num_SScredit = 0; /* try to see if it is missing */
	replace num_SScredit = min(4, int(inc_earn_head/440)) if year == 1986;  
	replace num_SScredit = min(4, int(inc_earn_head/460)) if year == 1987;  
	replace num_SScredit = min(4, int(inc_earn_head/470)) if year == 1988;  
	replace num_SScredit = min(4, int(inc_earn_head/500)) if year == 1989;  
	replace num_SScredit = min(4, int(inc_earn_head/520)) if year == 1990;  
	replace num_SScredit = min(4, int(inc_earn_head/540)) if year == 1991;  
	replace num_SScredit = min(4, int(inc_earn_head/570)) if year == 1992;  
	replace num_SScredit = min(4, int(inc_earn_head/590)) if year == 1993;  
	replace num_SScredit = min(4, int(inc_earn_head/620)) if year == 1994;
	replace num_SScredit = min(4, int(inc_earn_head/630)) if year == 1995;
	replace num_SScredit = min(4, int(inc_earn_head/640)) if year == 1996;
	replace num_SScredit = min(4, int(inc_earn_head/670)) if year == 1997;
	replace num_SScredit = min(4, int(inc_earn_head/700)) if year == 1998;
	replace num_SScredit = min(4, int(inc_earn_head/740)) if year == 1999;
	replace num_SScredit = min(4, int(inc_earn_head/780)) if year == 2000;
	replace num_SScredit = min(4, int(inc_earn_head/830)) if year == 2001;
	replace num_SScredit = min(4, int(inc_earn_head/870)) if year == 2002;
	replace num_SScredit = min(4, int(inc_earn_head/890)) if year == 2003;
	replace num_SScredit = min(4, int(inc_earn_head/900)) if year == 2004;
	replace num_SScredit = min(4, int(inc_earn_head/920)) if year == 2005;
	replace num_SScredit = min(4, int(inc_earn_head/970)) if year == 2006;
	replace num_SScredit = min(4, int(inc_earn_head/1000)) if year == 2007;
	replace num_SScredit = min(4, int(inc_earn_head/1050)) if year == 2008;
	replace num_SScredit = min(4, int(inc_earn_head/1090)) if year == 2009;
	replace num_SScredit = min(4, int(inc_earn_head/1120)) if year == 2010;
	replace num_SScredit = min(4, int(inc_earn_head/1120)) if year == 2011;
	replace num_SScredit = min(4, int(inc_earn_head/1130)) if year == 2012;
	replace num_SScredit = min(4, int(inc_earn_head/1160)) if year == 2013;
	replace num_SScredit = min(4, int(inc_earn_head/1200)) if year == 2014;
	replace num_SScredit = min(4, int(inc_earn_head/1220)) if year == 2015;
	replace num_SScredit = min(4, int(inc_earn_head/1260)) if year == 2016;
	replace num_SScredit = min(4, int(inc_earn_head/1300)) if year == 2017;


	bysort unique_id: egen min_year = min(year) ;


#delim;
	forval yr = 1998(2)2014{;
		replace num_SScredit = num_SScredit * 2 if year == `yr';			
	};

	foreach yr in 1996 2016{;
		replace num_SScredit = num_SScredit * 1.5 if year == `yr';
	};

/* */
	replace num_SScredit = num_SScredit + 4 * yr_work_18 if year == min_year ;
/* */


	tab num_SScredit, m;

	sort unique_id year;
	by unique_id: gen total_SScredit = sum(num_SScredit);
	by unique_id: egen total_current_SScredit = total(num_SScredit);


	gen flag_strict_ssqualified = 0;

	replace flag_strict_ssqualified =(total_SScredit + 22 >= head_age) if head_age > 41 & head_age != .;

	replace flag_strict_ssqualified = (total_SScredit > 19) if 30 < head_age & head_age < 42;

	replace flag_strict_ssqualified = ((head_age - 21)*2 <= total_SScredit ) if 23 < head_age & head_age < 31;

	bysort unique_id: egen strict_qualified_nonrec = max(flag_strict_ssqualified);


	tab strict_qualified_nonrec, m;

	
/************************************************************************************************************************************************/

/* groups by age */

	/* first age receiving DI */
		gen gp_rec_pre35 = .;
		replace gp_rec_pre35 = 1 if first_di_rec_age < 35;

		gen gp_rec_3544 = .;
		replace gp_rec_3544 = 1 if 35 <= first_di_rec_age & first_di_rec_age < 45;
		gen gp_rec_4554 = .;
		replace gp_rec_4554 = 1 if 45 <= first_di_rec_age & first_di_rec_age < 55;
		gen gp_rec_5565 = .;
		replace gp_rec_5565 = 1 if 55 <= first_di_rec_age & first_di_rec_age < 66;

		sum gp_rec*;
		count if first_di_rec_age != .; /* age 66 is not included */

	/* first age being severe  */

		foreach sev in severe {;
			gen gp_`sev'_pre35 = .;
			replace gp_`sev'_pre35 = 1 if first_`sev'_age < 35;
			count if first_`sev'_age < 35;

			gen gp_`sev'_3544 = .;
			replace gp_`sev'_3544 = 1 if 35 <= first_`sev'_age & first_`sev'_age < 45;
			gen gp_`sev'_4554 = .;
			replace gp_`sev'_4554 = 1 if 45 <= first_`sev'_age & first_`sev'_age < 55;
			gen gp_`sev'_5565 = .;
			replace gp_`sev'_5565 = 1 if 55 <= first_`sev'_age & first_`sev'_age < 66;

			sum gp_`sev'*;
			count if first_`sev'_age != .; /* above age 65 is not included */
		};
			
	/* Recipients: overall, no disability, no severe disability, any disability, severe disability */
		gen gp_rec_all 			= (flag_di_rec_ever == 1);
		gen gp_rec_nondis 		= (flag_di_rec_ever == 1 & flag_psid_disable == 0) if flag_di_rec_ever != . & flag_psid_disable != .;
		gen gp_rec_anydis		= (flag_di_rec_ever == 1 & flag_psid_disable == 1) if flag_di_rec_ever != . & flag_psid_disable != .;
		gen gp_rec_moderate 	= (flag_di_rec_ever == 1 & flag_psid_disable == 1 & flag_severe == 0) 
												if flag_di_rec_ever != . & flag_psid_disable != . & flag_severe !=.; 
		gen gp_rec_severe 		= (flag_di_rec_ever == 1 & flag_severe == 1) if flag_di_rec_ever != . & flag_severe !=.;
		gen gp_rec_severe2 		= (flag_di_rec_ever == 1 & flag_severe2 == 1) if flag_di_rec_ever != . & flag_severe2 !=.;
		gen gp_rec_severe3 		= (flag_di_rec_ever == 1 & flag_psid_disable == 1) if flag_di_rec_ever != . & flag_psid_disable !=.;

		
		foreach age in pre35 3544 4554 5565 {;	
			gen gp_rec_`age'_nondis = .;
			replace gp_rec_`age'_nondis = 0 if gp_rec_`age' == 0 | flag_psid_disable == 1;
			replace gp_rec_`age'_nondis = 1 if gp_rec_`age' == 1 & flag_psid_disable == 0;
			gen gp_rec_`age'_anydis = .;	
			replace gp_rec_`age'_anydis = 0 if gp_rec_`age' == 0 | flag_psid_disable == 0;	
			replace gp_rec_`age'_anydis = 1 if gp_rec_`age' == 1 & flag_psid_disable == 1;
			

/* first time receive in the specific age group, and not severe but moderate */
			
foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
							 {;
			
gen gp_rec_`age'_`sev' = .;
replace gp_rec_`age'_`sev' = 0 if gp_rec_`age' == 0 | flag_`sev'_app == 0;
replace gp_rec_`age'_`sev' = 1 if gp_rec_`age' == 1 & flag_`sev'_app == 1;

gen gp_rec_`age'_N`sev' = .;
replace gp_rec_`age'_N`sev' = 0 if gp_rec_`age' == 0 | flag_`sev'_app == 1;
replace gp_rec_`age'_N`sev' = 1 if gp_rec_`age' == 1 & flag_`sev'_app == 0;

			};	
			
		};
		

/* All any disability */
gen gp_anydis = (flag_psid_disable == 1) if flag_psid_disable != .;

/* All severe disability */
gen gp_severe = (flag_severe == 1) if flag_severe != .;
gen gp_severe2 = (flag_severe2 == 1) if flag_severe2 != .;
gen gp_severe3 = (flag_severe3 == 1) if flag_severe3 != .;

/* All severe disability */
gen gp_moderate = (flag_psid_disable == 1 & flag_severe == 0) if flag_psid_disable != . & flag_severe != .;

/* Two-category Groups */

foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
				/* severe_mh severe_mh2 severe_mh3 severe_mh4 */ {;

	gen gp_nonrec_N`sev'  = (flag_di_rec_ever == 0 & flag_`sev' == 0) if flag_`sev' != .;
	gen gp_rec_N`sev'     = (flag_di_rec_ever == 1 & flag_`sev' == 0) if flag_`sev' != .;
	gen gp_N`sev' 	 	  = (flag_`sev' == 0) if flag_`sev' != .;

};

summ gp_*;						

unab gps_miss : gp_*;

foreach gp in `gps_miss' {;
	replace `gp' = . if flag_di_rec == . | flag_psid_disable == . | flag_severe == .;
};


/*********************************************************************************************************************************************/

capture log close;

/********************/
/*****  EXPORT  *****/
/********************/
		order year, a(unique_id);
		sort unique_id year;
		save "`output'/psid_forinteract_2016usd_long_`x'.dta", replace;
	restore;
};
