version 15
#delimit;
clear all ;
set more off ;
set maxvar 20000 ;

do "../../load_directories.do" ;
do "load_normative_directories.do" ;

log using "$output/normative_decomp_analysis.log", replace ;


/* ************************* */
/* ***** PREPARE MACROS **** */
/* ************************* */
local ed_list "all hsdrop hsgrad somecoll college" ;
local decomp_by_sev_progs "di hdi ad2 td2 ie ee sdi" ;
local by_sev_decomp_groups1 "sev ns" ;
local by_sev_decomp_groups2 "ev nev" ;
local by_sev_decomp_groups3 "sap nap" ;
local by_sev_decomp_groups4 "dis1 dis2 dis3 dis4" ;
local by_sev_decomp_groups5 "hth1 hth2 hth3 hth4 hth5" ;
local by_sev_decomp_groups6 "" ;
local groups6 "" ;
forvalues i = 1/30 { ;
	local by_sev_decomp_groups6 "`by_sev_decomp_groups6' dhs`i'" ;
	local groups6 "`groups6' di_dhs`i' ndi_dhs`i'" ;
} ;
local by_sev_decomp_groups7 "ld1 ld2 ld3 ld4 ld5 ld6" ;
local groups7 "" ;
forvalues i = 1/6 { ;
	local groups7 "`groups7' di_ld`i' ndi_ld`i'" ;
} ;
local n_by_sev_decomps = 7 ;
local max_num_h = 30 ;
local groups "di ndi di_sev di_ns ndi_sev ndi_ns" ;
local groups "`groups' hdi nhdi hdi_sev hdi_ns nhdi_sev nhdi_ns" ;
local groups "`groups' ad2 nad2 ad2_sev ad2_ns nad2_sev nad2_ns" ;
local groups "`groups' td2 ntd2 td2_sev td2_ns ntd2_sev ntd2_ns" ;
local groups "`groups' ie nie ie_sev ie_ns nie_sev nie_ns" ;
local groups "`groups' ee nee ee_sev ee_ns nee_sev nee_ns" ;
local groups "`groups' sdi nsdi sdi_sev sdi_ns nsdi_sev nsdi_ns" ;
local groups "`groups' di_ev di_nev ndi_ev ndi_nev" ;
local groups "`groups' di_sap di_nap ndi_sap ndi_nap" ;
local groups "`groups' di_dis1 di_dis2 di_dis3 di_dis4 ndi_dis1 ndi_dis2 ndi_dis3 ndi_dis4" ;
local groups "`groups' di_hth1 di_hth2 di_hth3 di_hth4 di_hth5 ndi_hth1 ndi_hth2 ndi_hth3 ndi_hth4 ndi_hth5" ;
local groups "`groups' `groups6' `groups7'" ;
forvalues i = 1/`n_by_sev_decomps' { ;
	local groups "`groups' `by_sev_decomp_groups`i''" ;
} ;


/* *********************** */
/* ***** PREPARE DATA **** */
/* *********************** */
use "$temp/psid_hhlevel_forsummstats_dissi_severe_2016.dta", clear ;

local key_vars_with_missing_vals "gp_sev gp_hsgrad" ;
foreach var of varlist `key_vars_with_missing_vals' { ;
	drop if `var' == . ;
} ;
local key_vars "floor_MU2_Nhls gp_di gp_ndi gp_di_sev gp_di_ns gp_ndi_sev 
	gp_ndi_ns gp_sdi gp_ie gp_ee gp_sev gp_ns gp_hdi gp_adi gp_tdi
	gp_all gp_hsdrop gp_hsgrad gp_somecoll gp_college family_weight" ;

tab level_disabled, m ;
gen byte gp_dis1 = (level_disabled == -1 | level_disabled == 1) ;
gen byte gp_dis2 = (level_disabled == 3) ;
gen byte gp_dis3 = (level_disabled == 5) ;
gen byte gp_dis4 = (level_disabled == 7 | level_disabled == 7.5) ;

forvalues i = 1/5 { ;
	gen byte gp_hth`i' = (health_status == `i') ;
} ;

gen byte gp_dh1 = (level_disabled == -1 | level_disabled == 1 ) & health_status == 5 ;
gen byte gp_dh2 = (level_disabled == -1 | level_disabled == 1 ) & health_status == 4 ;
gen byte gp_dh3 = (level_disabled == 3 & (health_status == 4 | health_status == 5) ) ;
gen byte gp_dh4 = ((level_disabled == -1 | level_disabled == 1 ) & health_status < 4 ) |
					(level_disabled == 3 & health_status == 3) ;
gen byte gp_dh5 = (level_disabled == 3 & health_status < 3) | 
					 level_disabled == 5 ;
gen byte gp_dh6 = (level_disabled == 7 | level_disabled == 7.5 ) & (health_status > 3 & health_status != .) ;
gen byte gp_dh7 = (level_disabled == 7 | level_disabled == 7.5 ) & (health_status == 3) ;
gen byte gp_dh8 = (level_disabled == 7 | level_disabled == 7.5 ) & (health_status == 1 | health_status == 2) ;

local i = 1;
foreach lev_dis of numlist -1 1 3 5 7 7.5 { ;
	forvalues srh = 1/5 { ;
		gen gp_dhs`i' = (level_disabled == `lev_dis' & health_status == `srh' ) ;
		local i = `i' + 1 ;
	} ;
} ;

local i = 1;
foreach lev_dis of numlist -1 1 3 5 7 7.5 { ;
	gen gp_ld`i' = (level_disabled == `lev_dis') ;
	local i = `i' + 1 ;
} ;

summ earnHSP35, det ;
gen earnHSP35_p25 = r(p25) ;
gen earnHSP35_p50 = r(p50) ;
gen earnHSP35_p75 = r(p75) ;

foreach prog in `decomp_by_sev_progs' { ;
	if "`prog'" == "di" { ;
		continue ;
	} ;
	gen gp_`prog'_sev  = (gp_`prog'  &  gp_sev) ;
	gen gp_`prog'_ns   = (gp_`prog'  & !gp_sev) ;
	gen gp_`prog'_ev   = (gp_`prog'  &  gp_ev) ;
	gen gp_`prog'_nev  = (gp_`prog'  & !gp_ev) ;
	gen gp_`prog'_sap  = (gp_`prog'  &  gp_sap) ;
	gen gp_`prog'_nap  = (gp_`prog'  & !gp_sap) ;
	gen gp_n`prog'     = (!gp_`prog') ;
	gen gp_n`prog'_sev = (!gp_`prog' &  gp_sev) ;
	gen gp_n`prog'_ns  = (!gp_`prog' & !gp_sev) ;
	gen gp_n`prog'_ev  = (!gp_`prog' &  gp_ev) ;
	gen gp_n`prog'_nev = (!gp_`prog' & !gp_ev) ;
	gen gp_n`prog'_sap = (!gp_`prog' &  gp_sap) ;
	gen gp_n`prog'_nap = (!gp_`prog' & !gp_sap) ;
} ;

foreach prog in di { ;
	forvalues i = 1(1)4 { ;
		gen gp_`prog'_dis`i'  = (gp_`prog' & gp_dis`i') ;
		gen gp_n`prog'_dis`i' = (!gp_`prog' & gp_dis`i') ;
	} ;
	forvalues i = 1(1)5 { ;
		gen gp_`prog'_hth`i'  = (gp_`prog' & gp_hth`i') ;
		gen gp_n`prog'_hth`i' = (!gp_`prog' & gp_hth`i') ;
	} ;
	forvalues i = 1(1)8 { ;
		gen gp_`prog'_dh`i'  = (gp_`prog' & gp_dh`i') ;
		gen gp_n`prog'_dh`i' = (!gp_`prog' & gp_dh`i') ;
	} ;
	forvalues i = 1(1)30 { ;
		gen gp_`prog'_dhs`i'  = (gp_`prog' & gp_dhs`i') ;
		gen gp_n`prog'_dhs`i' = (!gp_`prog' & gp_dhs`i') ;
	} ;
	forvalues i = 1(1)6 { ;
		gen gp_`prog'_ld`i'  = (gp_`prog' & gp_ld`i') ;
		gen gp_n`prog'_ld`i' = (!gp_`prog' & gp_ld`i') ;
	} ;
} ;


/* ******************************************* */
/* **** CALCULATE MARK-UP (M), RECIP, ETC. *** */
/* ******************************************* */
local weight_str "[aweight = family_weight]" ;
summ floor_MU2_Nhls `weight_str' ;
scalar mu_pop = r(mean) ;
reg floor_MU2_Nhls gp_hsdrop gp_hsgrad gp_somecoll `weight_str' ;
predict double mu_resid, residuals ;
replace mu_resid = max(0, mu_resid + mu_pop) if mu_resid != . ;
summ mu_resid `weight_str' ;
scalar mu_pop = r(mean) ;

foreach ed in `ed_list' { ;
foreach gp in `groups' { ;
	summ gp_`ed' `weight_str' ;
	scalar p_ed_`ed' = r(mean) ;
	
	summ gp_`gp' if gp_`ed' == 1 `weight_str' ;
	scalar pr_`gp'_`ed' = r(mean) ;
	
	gen gp_and_ed = (gp_`gp' & gp_`ed') ;
	summ gp_and_ed `weight_str' ;
	scalar p_`ed'_and_`gp' = r(mean) ;
	drop gp_and_ed ;
	
	summ mu_resid if gp_`ed' == 1 `weight_str' ;
	scalar mu_`ed' = r(mean) ;
	summ mu_resid if gp_`ed' == 1 & gp_`gp' == 1 `weight_str' ;
	scalar mu_`gp'_`ed' = r(mean) ;
	scalar M1_`gp'_`ed' = (mu_`gp'_`ed' - mu_`ed')/mu_`ed' ;
	
	summ mu_resid if gp_`ed' == 1 & gp_`gp' == 0 `weight_str' ;
	scalar mu_`gp'_n_`ed' = r(mean) ;
	reg mu_resid gp_`gp' if gp_`ed' == 1 `weight_str' ;
	matrix temp = e(b) ;
	scalar M2_`gp'_`ed' = temp[1,1] / mu_`gp'_n_`ed' ;
	
	scalar M3_`ed' = (mu_`ed' - mu_pop) / mu_pop ;
	
	summ mu_resid if gp_`gp' == 1 `weight_str' ;
	scalar mu_`gp' = r(mean) ;
	scalar M4_`gp' = (mu_`gp' - mu_pop) / mu_pop ;
	
	scalar M5_`gp'_`ed' = (mu_`gp'_`ed' - mu_pop) / mu_pop ;
} ;
} ;
drop mu_resid ;


/* ******************************************* */
/* ********** DECOMPOSE THE MARKUP *********** */
/* ******************************************* */
local col_names "M_total M_across M_within Share_across Share_within" ;
local num_cols_decomps = 5 ;
local ed "all" ;

foreach prog in `decomp_by_sev_progs' { ;
	matrix decomp_by_sev_`prog' = J(1, `num_cols_decomps', .)  ;
	matrix colnames decomp_by_sev_`prog' = `col_names' ;
} ;

foreach prog in di { ;
	forvalues num = 2(1)`n_by_sev_decomps' { ;
		matrix decomp_by_sev_`prog'_`num' = J(1, `num_cols_decomps', .) ;
		matrix colnames decomp_by_sev_`prog'_`num' = `col_names' ;
	} ;
} ;

foreach prog in `decomp_by_sev_progs' { ;
	local p_`prog'_pop = pr_`prog'_all ;
	local M_across_tot = 0 ;
	local M_within_tot = 0 ;
	foreach dis in `by_sev_decomp_groups1' { ;
		local p_g = pr_`dis'_`ed' ;
		local p_r_given_g = p_`ed'_and_`prog'_`dis' / `p_g' ;
		local M_across_`dis' = 
			`p_g' * `p_r_given_g'/`p_`prog'_pop' * M4_`dis' ;
		local M_within_`dis' = 
			`p_g' * `p_r_given_g'/`p_`prog'_pop' * (1 - `p_r_given_g' ) * 
			( M4_`prog'_`dis' - M4_n`prog'_`dis' ) ;
		if `M_across_`dis'' == . { ;
			local M_across_`dis' = 0 ;
		} ;
		if `M_within_`dis'' == . { ;
			local M_within_`dis' = 0 ;
		} ;
		local M_across_tot = `M_across_tot' + `M_across_`dis'' ;
		local M_within_tot = `M_within_tot' + `M_within_`dis'' ;
	} ;
	matrix decomp_by_sev_`prog'[1,1] = `M_across_tot' + `M_within_tot' ;
	matrix decomp_by_sev_`prog'[1,2] = `M_across_tot' ;
	matrix decomp_by_sev_`prog'[1,3] = `M_within_tot' ;
	matrix decomp_by_sev_`prog'[1,4] = 
		`M_across_tot' / (`M_across_tot' + `M_within_tot' ) ;
	matrix decomp_by_sev_`prog'[1,5] = 
		`M_within_tot' / (`M_across_tot' + `M_within_tot' ) ;
} ;

foreach prog in di { ;
	local p_`prog'_pop = pr_`prog'_all ;
	forvalues num = 2(1)`n_by_sev_decomps' { ;
		local M_across_tot = 0 ;
		local M_within_tot = 0 ;
		foreach dis in `by_sev_decomp_groups`num'' { ;
			local p_g = pr_`dis'_`ed' ;
			local p_r_given_g = p_`ed'_and_`prog'_`dis' / `p_g' ;
			local M_across_`dis' = 
				`p_g' * `p_r_given_g'/`p_`prog'_pop' * M4_`dis' ;
			local M_within_`dis' = 
				`p_g' * `p_r_given_g'/`p_`prog'_pop' * (1 - `p_r_given_g' ) * 
				( M4_`prog'_`dis' - M4_n`prog'_`dis' ) ;
			if `M_across_`dis'' == . { ;
				local M_across_`dis' = 0 ;
			} ;
			if `M_within_`dis'' == . { ;
				local M_within_`dis' = 0 ;
			} ;
			local M_across_tot = `M_across_tot' + `M_across_`dis'' ;
			local M_within_tot = `M_within_tot' + `M_within_`dis'' ;
		} ;
		matrix decomp_by_sev_`prog'_`num'[1,1] = `M_across_tot' + `M_within_tot' ;
		matrix decomp_by_sev_`prog'_`num'[1,2] = `M_across_tot' ;
		matrix decomp_by_sev_`prog'_`num'[1,3] = `M_within_tot' ;
		matrix decomp_by_sev_`prog'_`num'[1,4] = 
			`M_across_tot' / (`M_across_tot' + `M_within_tot' ) ;
		matrix decomp_by_sev_`prog'_`num'[1,5] = 
			`M_within_tot' / (`M_across_tot' + `M_within_tot' ) ;
	} ;
} ;

foreach prog in `decomp_by_sev_progs' { ;
	if "`prog'" == "di" { ;
		local prog_name "DI" ;
	} ;
	else if "`prog'" == "hdi" { ;
		local prog_name "HDI" ;
	} ;
	else if "`prog'" == "ad2" { ;
		local prog_name "Random-App DI" ;
	} ;
	else if "`prog'" == "td2" { ;
		local prog_name "Earnings-Test DI" ;
	} ;
	else if "`prog'" == "ie" { ;
		local prog_name "L-DI" ;
	} ;
	else if "`prog'" == "sdi" { ;
		local prog_name "M-DI" ;
	} ;
	else if "`prog'" == "ee" { ;
		local prog_name "M-NDI" ;
	} ;
	di "Benefits: `prog_name'" ;
	matrix list decomp_by_sev_`prog' ;
} ;

forvalues num = 2/`n_by_sev_decomps' { ;
	if `num' == 2 { ;
		local h_cat_type "Ever vs. never severe" ;
	} ;
	else if `num' == 3 { ;
		local h_cat_type "More- vs. less-severe at first receipt" ;
	} ;
	else if `num' == 4 { ;
		local h_cat_type "Severe/moderate/minor/none" ;
	} ;
	else if `num' == 5 { ;
		local h_cat_type "Self-reported health" ;
	} ;
	else if `num' == 6 { ;
		local h_cat_type "Severity x self-reported health" ;
	} ;
	else if `num' == 7 { ;
		local h_cat_type "6 severity categories" ;
	} ;
	di "Health categorization type: `h_cat_type'" ;
	matrix list decomp_by_sev_di_`num' ;
} ;

log close ;
