version 15
clear all 
set more off
set logtype text
set maxvar 20000
set matsize 10000
capture log close
#delim;

do "../../load_directories.do" ;
do "load_normative_directories.do" ;

log using "$output/normative_hi_ben_stats.log", replace ;

local hi_options "HI_OOP HI_TOT HI_OOP_UP_BND HI_TOT_UP_BND HI_FHL_MAX" ;
foreach hi_opt in `hi_options' { ;
	local HI_OOP        = 0 ;
	local HI_TOT        = 0 ;
	local HI_OOP_UP_BND = 0 ;
	local HI_TOT_UP_BND = 0 ;
	local HI_FHL_MAX    = 0 ;
	
	local `hi_opt' = 1 ;
	
	if `HI_OOP' == 1 { ;
		local share_who_gain_hi_from_di = 1 ;
		local val_of_hi_as_share_of_net_cost = 0.85 ;
		local mean_oop_sev = 1471 ;
		local mean_oop_ns  =  521 ;
		local net_cost_per_full_hi_sev = `mean_oop_sev' ;
		local net_cost_per_full_hi_ns  =  `mean_oop_ns' ;
		local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
		local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
		local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
		local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
	} ;
	else if `HI_TOT' == 1 { ;
		local share_who_gain_hi_from_di = 1 ;
		local val_of_hi_as_share_of_net_cost = 0.85 ;
		local net_cost_share_of_tot = (1/5+1/3)/2 ;
		local mean_tot_sev = 20459 ;
		local mean_tot_ns  =  5662 ;
		local net_cost_per_full_hi_sev = `net_cost_share_of_tot' * `mean_tot_sev' ;
		local net_cost_per_full_hi_ns  = `net_cost_share_of_tot' *  `mean_tot_ns' ;
		local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
		local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
		local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
		local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
	} ;
	else if `HI_OOP_UP_BND' == 1 { ;
		local share_who_gain_hi_from_di = 1.0 ;
		local val_of_hi_as_share_of_net_cost = 1.2 ;
		local mean_oop_sev = 1471 ;
		local mean_oop_ns  =  521 ;
		local net_cost_per_full_hi_sev = `mean_oop_sev' ;
		local net_cost_per_full_hi_ns  =  `mean_oop_ns' ;
		local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
		local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
		local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
		local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
	} ;
	else if `HI_TOT_UP_BND' == 1 { ;
		local share_who_gain_hi_from_di = 1.0 ;
		local val_of_hi_as_share_of_net_cost = 1.2 ;
		local net_cost_share_of_tot = 1/3 ;
		local mean_tot_sev = 20459 ;
		local mean_tot_ns  =  5662 ;
		local net_cost_per_full_hi_sev = `net_cost_share_of_tot' * `mean_tot_sev' ;
		local net_cost_per_full_hi_ns  = `net_cost_share_of_tot' *  `mean_tot_ns' ;
		local hi_cost_sev = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_sev' ;
		local hi_cost_ns  = `share_who_gain_hi_from_di' * `net_cost_per_full_hi_ns'  ;
		local hi_val_sev  = `val_of_hi_as_share_of_net_cost' * `hi_cost_sev' ;
		local hi_val_ns   = `val_of_hi_as_share_of_net_cost' * `hi_cost_ns' ;
	} ;
	else if `HI_FHL_MAX' == 1 { ;
		local share_who_gain_hi_from_di = 1.0 ;
		local hi_val_fhl  = 1675 ;
		local hi_cost_fhl = 1448 ;
		local hi_val_sev  = `hi_val_fhl'  ;
		local hi_cost_sev = `hi_cost_fhl' ;
		local hi_val_ns   = `hi_val_fhl'  ;
		local hi_cost_ns  = `hi_cost_fhl' ;
	} ;
	else { ;
		error ;
	} ;
	local hi_net_val_sev = `hi_val_sev' - `hi_cost_sev' ;
	local hi_net_val_ns  = `hi_val_ns ' - `hi_cost_ns' ;
	
	if "`hi_opt'" == "HI_OOP" { ;
		local name "Health insurance based on out-of-pocket health care spending (main)" ;
	} ;
	else if "`hi_opt'" == "HI_TOT" { ;
		local name "Health insurance based on total health care spending (main)" ;
	} ;
	else if "`hi_opt'" == "HI_OOP_UP_BND" { ;
		local name "Health insurance based on out-of-pocket health care spending (ratio-minimizing)" ;
	} ;
	else if "`hi_opt'" == "HI_TOT_UP_BND" { ;
		local name "Health insurance based on total health care spending (ratio-minimizing)" ;
	} ;
	else if "`hi_opt'" == "HI_FHL_MAX" { ;
		local name "Health insurance based on Finkelstein, Hendren and Luttmer's (2019) maximum estimates" ;
	} ;
	local ldi_share = 0.0565/0.1060 ;
	local hi_val_di = (1-`ldi_share') * `hi_val_sev' + `ldi_share' * `hi_val_ns' ;
	di "HI value: `name'" ;
	di "  DI:    `hi_val_di'" ;
	di "  M-DI:  `hi_val_sev'" ;
	di "  L-DI:  `hi_val_ns'" ;
	di "  M-NDI: `hi_val_sev'" ;
} ;

log close ;
