version 15
clear all
set more off
set scrollbufsize 2000000

do "../../load_directories.do"
do "load_normative_directories.do"

log using "$output/normative_med_spending_stats.log", replace

local var_stems_year_at_end_all_yrs "TOTEXP TOTSLF INSCOV"
local var_stems_year_then_X_at_end "AGE"

local ind_weight_var "PERWT18F"
local nwk_vars "NWK31 NWK42 NWK53"
local vars "`nwk_vars' `ind_weight_var'"
local var_stems_year_at_end "`var_stems_year_at_end_all_yrs'"
foreach varstem in `var_stems_year_at_end' {
	local vars "`vars' `varstem'18"
}
foreach varstem in `var_stems_year_then_X_at_end' {
	local vars "`vars' `varstem'18X"
}

use `vars' using "$data/raw/h209.dta", clear

rename `ind_weight_var' ind_weight
foreach varstem in `var_stems_year_at_end' {
	rename `varstem'18 `varstem'
}
foreach varstem in `var_stems_year_then_X_at_end' {
	rename `varstem'18X `varstem'
}

rename AGE age
replace age = . if age < 0

rename TOTSLF oop
rename TOTEXP tot

gen uninsured = (INSCOV == 3) if INSCOV < .
gen hi_indiv = (1 - uninsured)
drop INSCOV uninsured

rename NWK31 no_work1
rename NWK42 no_work2
rename NWK53 no_work3
forvalues i = 1/3 {
	gen h_prevents_work`i' = .
	replace h_prevents_work`i' = 1 if no_work`i' == 3
	replace h_prevents_work`i' = 0 if no_work`i' == 1 | no_work`i' == 2 | ///
		(no_work`i' > 3 & no_work`i' < .) | no_work`i' == -1
}
gen h_prevents_work_all = ///
	(h_prevents_work1 == 1 & h_prevents_work2 == 1 & h_prevents_work3 == 1) ///
	if h_prevents_work1 < . & h_prevents_work2 < . & h_prevents_work3 < .
gen h_prevents_work_none = ///
	(h_prevents_work1 == 0 & h_prevents_work2 == 0 & h_prevents_work3 == 0) ///
	if (h_prevents_work1 < . & h_prevents_work2 < . & h_prevents_work3 < .)

local aweight = "[aweight=ind_weight]"
local insample "age >= 25 & age < 65 & h_prevents_work_all < . & hi_indiv < . & oop < . & tot < ."

summ oop if `insample' & hi_indiv == 0 & h_prevents_work_all == 1 `aweight'
local mean_oop_sev = r(mean)
summ oop if `insample' & hi_indiv == 0 & h_prevents_work_none == 1 `aweight'
local mean_oop_ns = r(mean)

summ tot if `insample' & hi_indiv == 1 & h_prevents_work_all == 1 `aweight'
local mean_tot_sev = r(mean)
summ tot if `insample' & hi_indiv == 1 & h_prevents_work_none == 1 `aweight'
local mean_tot_ns = r(mean)

di "E(tot|severe, HI=1)     = `mean_tot_sev'"
di "E(tot|non-severe, HI=1) = `mean_tot_ns'"
di "E(oop|severe, HI=0)     = `mean_oop_sev'"
di "E(oop|non-severe, HI=0) = `mean_oop_ns'"

log close
