version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause on
#delim;


import excel "$data/state_safetynet.xls", sheet(ranking-2017) firstrow clear ;
xtile state_gen = Welfare, nq(4) ;
rename region state_region ;
tempfile state ;
save `state' ;

import excel "$data/state_safetynet_tanfpov.xls", firstrow clear ;
xtile state_tanf95 = tanfpov_1995, nq(4) ;
xtile state_tanf05 = tanfpov_2005, nq(4) ;
xtile state_tanf17 = tanfpov_2017, nq(4) ;
gen diff9517 = tanfpov_2017 - tanfpov_1995 ;
gen diff9505 = tanfpov_2005 - tanfpov_1995 ;
xtile state_tanfdiff9517 = diff9517, nq(4) ;
xtile state_tanfdiff9505 = diff9505, nq(4) ;
tempfile state_tanf ;
save `state_tanf' ;

local x = "dissi" ;


forval targetyr = 1998(2)2016 { ;

foreach sev in severe severe2 severe_mhdp { ;

use "$temp/psid_forinteract_2016usd_long_`x'.dta", clear;

rename exp_hospital hosp; 

gen flag_banking = (level_cash > 0) if level_cash != .;


sort unique_id year;
gen foodrentmortg = exp_food + exp_rent + exp_mortg;

gen flag_severe_moderate = (flag_severe == 1|flag_moderate == 1) if flag_severe != . & flag_moderate != .;

drop if head_age == .;


keep 
	unique_id family_weight num_of_family head_age year state* first_observ
	first_di_rec_age first_di_rec_year
	flag_di_rec flag_di_rec_ever
	flag_di_rec_head flag_di_rec_spouse flag_dissi_rec_head flag_dissi_rec_spouse 
	flag_severe* flag_moderate flag_psid_disable flag_severe_head flag_severe_spouse flag*app flag*ever flag*predi
	educ_hsdrop_head educ_hsgrad_head educ_some_college_head educ_college_head 
	reason_move* flag_married reason_posend_hd_u reason_posend_hd_e reason_posend_sp_u reason_posend_sp_e
	flag_home_own flag_banking
	exp_food  hhexp_total hhexp_N_hlth
	depression flag_psychiatric_head flag_learning_head flag_psychiatric_spouse flag_learning_spouse 
	flag_chronic_head flag_chronic_spouse flag_memory_head flag_memory_spouse flag_somephysical
	flag_spouse first_di_rec_year
	compared_2yrs_head compared_2yrs_spouse
	inc_earn_HSP inc_earn_head inc_earn_spouse total_SScredit
	total_asset
	flag_ui
	num_adl num_iadl health_status level_disabled diag_* inc_hh
	hhfood_secur hhfood_secur1 hhfood_secur2 hhfood_secur34 
	food_Nlast food_Nlast1 food_Nlast2 food_Nlast3 
	worry_food_Nlast worry_food_Nlast1 worry_food_Nlast2 worry_food_Nlast3 
	food_Nbalanced food_Nbalanced1 food_Nbalanced2 food_Nbalanced3
	;

rename flag_sev_ever flag_severe_ever ;

gen temp = year if first_observ == 1 ;
egen year_psid = max(temp), by(unique_id) ;
drop temp ;

rename food_Nbalanced3 		fdsec_bal_good ;
rename food_Nbalanced2 		fdsec_bal_okay ;
rename food_Nbalanced1 		fdsec_bal_bad ;

rename worry_food_Nlast3 	fdsec_worry_good ;
rename worry_food_Nlast2 	fdsec_worry_okay ;
rename worry_food_Nlast1 	fdsec_worry_bad ;

rename food_Nlast3 			fdsec_runout_good ;
rename food_Nlast2 			fdsec_runout_okay ;
rename food_Nlast1 			fdsec_runout_bad ;

rename hhfood_secur1 		fdsec_overall_good ;
rename hhfood_secur2 		fdsec_overall_okay ;
rename hhfood_secur34 		fdsec_overall_bad ;

merge m:1 state_curr using `state', keepusing(state_region state_gen) ;
drop if _merge == 2 ;
drop _merge ;

merge m:1 state_curr using `state_tanf', keepusing(state_tanf*) ;
drop if _merge == 2 ;
drop _merge ;


	gen flag_work_age = (head_age > 24 & head_age < 66) if year == `targetyr';
	
	bysort unique_id: egen first_age = min(head_age) ;
	
	gen temp_current_DI = flag_di_rec if year == `targetyr';
	
	bysort unique_id: egen current_DI = max(temp_current_DI);
	
	gen current_nonrec = 1 - current_DI;
	
	gen temp_current_`sev' = flag_`sev' if year == `targetyr';
	
	bysort unique_id: egen current_`sev' = max(temp_current_`sev');
	
	gen temp_current_moderate = flag_moderate if year == `targetyr';
	
	bysort unique_id: egen current_moderate = max(temp_current_moderate);
	
	gen temp_current_anydis = flag_psid_disable if year == `targetyr';
	
	bysort unique_id: egen current_anydis = max(temp_current_anydis);
	
	gen temp_current_none = 1 -  flag_psid_disable if year == `targetyr';
	
	bysort unique_id: egen current_none = max(temp_current_none);
	
	bysort unique_id: egen hsdrop = max(educ_hsdrop_head);
	
	bysort unique_id: egen hsgrad = max(educ_hsgrad_head);
	
	bysort unique_id: egen somecollege = max(educ_some_college_head);
	
	bysort unique_id: egen college = max(educ_college_head);
	
	replace hsdrop = 0 if hsgrad == 1 | somecollege == 1 | college == 1;
	replace hsgrad = 0 if somecollege == 1 | college == 1;
	replace somecollege = 0 if college == 1;
	
	forval i = 1(1)4{;
		gen moving_shock`i' = .;
		replace moving_shock`i' = 0 if reason_move`i' != .;
		replace moving_shock`i' = 1 if reason_move`i' == 7;
		gen broad_moving_shock`i' = .;
		replace broad_moving_shock`i' = 0 if reason_move`i' !=. ;
		replace broad_moving_shock`i' = 1 if reason_move`i' == 4 | reason_move`i' == 7 | reason_move`i' == 8;

	};
	
	gen temp_shock_broad_moving = .;
			
	replace temp_shock_broad_moving = 0 if broad_moving_shock1 != . | broad_moving_shock2 != . | 
										   broad_moving_shock3 != .|broad_moving_shock4 != .;
												   
	replace temp_shock_broad_moving = 1 if broad_moving_shock1 == 1|broad_moving_shock2 == 1 | 
										   broad_moving_shock3 == 1|broad_moving_shock4 == 1;
	
	sort unique_id year ;

	forval i = 0(1)5{;
		gen temp_shock_broad_moving_pre`i' = .;
		forval yr = 1985(1)1996{;
			by unique_id: replace temp_shock_broad_moving_pre`i' = temp_shock_broad_moving[_n-`i'] 
													if year == `yr' & year[_n-`i'] == `yr' - `i';
		};
	};
		
	sort unique_id year ;
	
	foreach i in 0 2 4{;
		forval yr = 1998(2)2016{;
			bysort unique_id: replace temp_shock_broad_moving_pre`i' = temp_shock_broad_moving[_n-`i'/2] 
													if year == `yr' & year[_n-`i'/2] == `yr' - `i';
			
		};
	};								   
										   
										   
										   
	gen temp_shock_moving = .;
	replace temp_shock_moving = 0 if moving_shock1 != .|moving_shock2 != .|moving_shock3 != .|moving_shock4 != .;	
	replace temp_shock_moving = 1 if moving_shock1 == 1|moving_shock2 == 1|moving_shock3 == 1|moving_shock4 == 1;
	bysort unique_id: egen shock_moving = max(temp_shock_moving);
	
	gen moving_shock_pre40 = .;
	replace moving_shock_pre40 = 0 if temp_shock_moving == 0 & head_age < 40 & head_age != . ;
	replace moving_shock_pre40 = 1 if temp_shock_moving == 1 & head_age < 40 & head_age != .;

	gen temp_shock_broad_moving4 = .;
	replace temp_shock_broad_moving4 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre1 == 1|
										temp_shock_broad_moving_pre2 == 1|temp_shock_broad_moving_pre3 == 1|
										temp_shock_broad_moving_pre4 == 1)
										if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre1 != . & 
										   temp_shock_broad_moving_pre2 != . & temp_shock_broad_moving_pre3 != . & 
										   temp_shock_broad_moving_pre4 != . & year < 1997;
				
	replace temp_shock_broad_moving4 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre2 == 1|
										temp_shock_broad_moving_pre4 == 1) 
										if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre2 != . & 
										temp_shock_broad_moving_pre4 != . & year > 1997;
	
	
	sort unique_id year ;

	gen temp_pre4_broad_moving_shock = temp_shock_broad_moving4 if first_di_rec_year == year & flag_di_rec_ever == 1;
	bysort unique_id: egen pre4_move_broad_shock = max(temp_pre4_broad_moving_shock);
	drop temp_pre4_broad_moving_shock ;
	
	sort unique_id year;

	bysort unique_id: gen temp_shock_marriage = flag_married[_n] - flag_married[_n-1];
	replace temp_shock_marriage = (temp_shock_marriage == -1) if temp_shock_marriage != .;
	bysort unique_id: egen shock_marriage = max(temp_shock_marriage);
	
	gen marriage_shock_pre40 = .;
	replace marriage_shock_pre40 = 0 if temp_shock_marriage == 0 & head_age < 40 & head_age != .;
	replace marriage_shock_pre40 = 1 if temp_shock_marriage == 1 & head_age < 40 & head_age != .;
	
	sort unique_id year;
		
	forval i = 0(1)5{;
		gen temp_shock_marriage_pre`i' =.;
			
		forval yr = 1985(1)1996{;
			by unique_id: replace temp_shock_marriage_pre`i' =  temp_shock_marriage[_n-`i'] 
															if year == `yr' & year[_n-`i'] == `yr' - `i' ;
		};
	};

	sort unique_id year ;

	forval i = 0(2)4{;
		
		forval yr = 1998(2)2016{;
			by unique_id: replace temp_shock_marriage_pre`i' = temp_shock_marriage[_n-`i'/2] 
														if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
			
		};
	};
	
	gen temp_shock_marriage4 =.;
		
	replace temp_shock_marriage4 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre1 == 1|
									temp_shock_marriage_pre2 == 1 | temp_shock_marriage_pre3 == 1|temp_shock_marriage_pre4 == 1)
										if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre1 != . & 
										   temp_shock_marriage_pre2 != . & temp_shock_marriage_pre3 != . & 
										   temp_shock_marriage_pre4 != . & year < 1997;
								
	replace temp_shock_marriage4 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre2 == 1|
									temp_shock_marriage_pre4 == 1)
											if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre2 != . & 
											temp_shock_marriage_pre4 != . & year > 1997;

	gen temp_pre4_marriage_shock = temp_shock_marriage4 if first_di_rec_year == year & flag_di_rec_ever == 1;
	bysort unique_id: egen pre4_marriage_shock = max(temp_pre4_marriage_shock);
	drop temp_pre4_marriage_shock ;
	
	sort unique_id year ;

	foreach var in hd sp{; 
		foreach z in u e{; 		
			forvalue i = 0(1)5{;
				gen reason_posend_`var'_`z'_pre`i' = .;
				forval yr = 1985(1)1996{;
					by unique_id: replace reason_posend_`var'_`z'_pre`i' = reason_posend_`var'_`z'[_n-`i'] 
																			if year == `yr' & year[_n-`i'] == `yr' - `i';
				};
			};
		};
	};
	
	sort unique_id year ;
		
	foreach var in hd sp{;
		foreach z in u e{; 		
			forvalue i = 0(2)4{;
				forval yr = 1998(2)2016{;
					by unique_id: replace reason_posend_`var'_`z'_pre`i' = reason_posend_`var'_`z'[_n-`i'/2] 
																			if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
				};
			};
		};
	};
	
	sort unique_id year ;

	forvalue i = 0(1)4{;
			foreach var in hd sp{;
			
				gen temp_shock_pre`i'_job_`var' = .;
				
				replace temp_shock_pre`i'_job_`var' = 0 if reason_posend_`var'_u_pre`i' != .|reason_posend_`var'_e_pre`i' != .;
				
				replace temp_shock_pre`i'_job_`var' = 1 if reason_posend_`var'_u_pre`i' == 1| reason_posend_`var'_u_pre`i' == 2| 
														   reason_posend_`var'_u_pre`i' == 3| reason_posend_`var'_e_pre`i' == 1| 
														   reason_posend_`var'_e_pre`i' == 2| reason_posend_`var'_e_pre`i' == 3;
														   
				bysort unique_id: egen shock_pre`i'_job_`var' = max(temp_shock_pre`i'_job_`var');		
				
				gen temp_shock_pre`i'_bd_job_`var' = .;
							
				replace temp_shock_pre`i'_bd_job_`var' = 0 if reason_posend_`var'_u_pre`i' != .|reason_posend_`var'_e_pre`i' != .;
				
				replace temp_shock_pre`i'_bd_job_`var' = 1 if reason_posend_`var'_u_pre`i' == 1| reason_posend_`var'_u_pre`i' == 2| 
															  reason_posend_`var'_u_pre`i' == 3| reason_posend_`var'_u_pre`i' == 7| 
															  reason_posend_`var'_u_pre`i' == 8| reason_posend_`var'_e_pre`i' == 1| 
															  reason_posend_`var'_e_pre`i' == 2| reason_posend_`var'_e_pre`i' == 3|
															  reason_posend_`var'_e_pre`i' == 7| reason_posend_`var'_e_pre`i' == 8;
															  
				bysort unique_id: egen shock_pre`i'_bd_job_`var' = max(temp_shock_pre`i'_bd_job_`var');
			};	
	};
	
	
	foreach var in hd sp {;
			
			gen temp_shock_job_`var'4 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre1_job_`var' != . & 
											 temp_shock_pre2_job_`var' != . & temp_shock_pre3_job_`var' != . & 
											 temp_shock_pre4_job_`var' != . & year < 1997;
											 
			replace temp_shock_job_`var'4 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre2_job_`var' != . & 
												 temp_shock_pre4_job_`var' != . & year > 1997;
											 
			replace temp_shock_job_`var'4 = 1 if temp_shock_pre0_job_`var' == 1 |temp_shock_pre1_job_`var' == 1 | 
												 temp_shock_pre2_job_`var' == 1 | temp_shock_pre3_job_`var' == 1|
												 temp_shock_pre4_job_`var' == 1;
		
	};
	
		gen temp_shock_job4 = temp_shock_job_hd4 ;
		replace temp_shock_job4 = temp_shock_job_sp4 
					if flag_spouse == 1 & temp_shock_job_sp4 != 0 & temp_shock_job_hd4 != 1 ;

		gen temp_pre4_job_shock = temp_shock_job4 if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre4_job_shock = max(temp_pre4_job_shock);
		drop temp_pre4_job_shock ;
			
	gen temp_job_shock_hd = .;
	replace temp_job_shock_hd = 0 if reason_posend_hd_u != .| reason_posend_hd_e !=.;
	replace temp_job_shock_hd = 1 if reason_posend_hd_u == 1| reason_posend_hd_u == 2|
									   reason_posend_hd_u == 3| reason_posend_hd_e == 1|
									   reason_posend_hd_e == 2| reason_posend_hd_e == 3;
	
	gen temp_job_shock_sp = .;
	replace temp_job_shock_sp = 0 if reason_posend_sp_u != .| reason_posend_sp_e !=.;
	replace temp_job_shock_sp = 1 if reason_posend_sp_u == 1| reason_posend_sp_u == 2|
									   reason_posend_sp_u == 3| reason_posend_sp_e == 1|
									   reason_posend_sp_e == 2| reason_posend_sp_e == 3;
	
	foreach var in hd sp{;
		gen `var'_job_shock_pre40 = .;
		replace `var'_job_shock_pre40 = 0 if temp_job_shock_hd == 0 & head_age < 40 & head_age != .;
		replace `var'_job_shock_pre40 = 1 if temp_job_shock_hd == 1 & head_age < 40 & head_age != .;
	};
	
	gen hdsp_job_shock_pre40 = hd_job_shock_pre40;
	replace hdsp_job_shock_pre40 = 1 if sp_job_shock_pre40 == 1; 
	
	foreach var in moving marriage hd_job sp_job hdsp_job{;
		rename `var'_shock_pre40 temp_`var'_shock_pre40;
		bysort unique_id: egen `var'_shock_pre40 = max(temp_`var'_shock_pre40) if first_age < 35 ;
	};
	
	gen non_medical_shock_pre40 = (moving_shock_pre40 == 1|marriage_shock_pre40 == 1|
									hdsp_job_shock_pre40 == 1) if moving_shock_pre40 != .|
									marriage_shock_pre40 != .| hdsp_job_shock_pre40 != .;
									
	gen non_medical_shock_pre40_2 = ((moving_shock_pre40 == 1 	& marriage_shock_pre40 == 1 ) |
									(moving_shock_pre40 == 1 	& hdsp_job_shock_pre40 == 1 ) |
									(marriage_shock_pre40 == 1 	& hdsp_job_shock_pre40 == 1 ) )
									if 
									(moving_shock_pre40 !=.	& marriage_shock_pre40 !=. ) |
									(moving_shock_pre40 !=. 	& hdsp_job_shock_pre40 !=. ) |
									(marriage_shock_pre40 !=. 	& hdsp_job_shock_pre40 !=. ) ;
									
	gen non_medical_shock_pre40_3 = (moving_shock_pre40 == 1 	& marriage_shock_pre40 == 1 	& hdsp_job_shock_pre40 == 1 )  
									if 
									(moving_shock_pre40 !=.	& marriage_shock_pre40 !=. & hdsp_job_shock_pre40 !=. ) ;
	
	gen non_medical_shock_pre40_NO = (non_medical_shock_pre40 == 0) if non_medical_shock_pre40 != .;
	gen non_medical_shock_pre40_2_NO = (non_medical_shock_pre40_2 == 0) if non_medical_shock_pre40_2 != .;
	
	gen married_pre40 = .;
	replace married_pre40 = 0 if flag_married == 0 & head_age < 40 & head_age != .;
	replace married_pre40 = 1 if flag_married == 1 & head_age < 40 & head_age != .;
	
	gen homeown_pre40 = .;
	replace homeown_pre40 = 0 if flag_home_own == 0 & head_age < 40 & head_age != .;
	replace homeown_pre40 = 1 if flag_home_own == 1 & head_age < 40 & head_age != .;
	
	gen bank_pre40 = .;
	replace bank_pre40 = 0 if flag_banking == 0 & head_age < 40 & head_age != .;
 	replace bank_pre40 = 1 if flag_banking == 1 & head_age < 40 & head_age != .;
	
	foreach var in married homeown bank{;
		rename `var'_pre40 temp_`var'_pre40;
		bysort unique_id: egen `var'_pre40 = max(temp_`var'_pre40);
	};
	
	gen flag_all_resources_pre40 = (married_pre40 == 1 & homeown_pre40 == 1 & bank_pre40 == 1);
	gen flag_none_resources_pre40 = (married_pre40 == 0 & homeown_pre40 == 0 & bank_pre40 == 0);
	gen flag_some_resources_pre40 = (flag_all_resources_pre40 == 0 & flag_none_resources_pre40 == 0);
	
	gen `sev'_pre40 = .;
	replace `sev'_pre40 =  0 if flag_`sev' == 0 & head_age < 40 & head_age != .;
	replace `sev'_pre40 = 1 if flag_`sev' == 1 & head_age < 40 & head_age != .;
	
	rename `sev'_pre40 temp_`sev'_pre40;
	bysort unique_id: egen `sev'_pre40 = max(temp_`sev'_pre40);
	
	gen any_shock = (`sev'_pre40 == 1 | non_medical_shock_pre40 == 1) if `sev'_pre40 != . & non_medical_shock_pre40 !=. ;
	gen any_shock_NO = 1 - any_shock;
	
	sort unique_id year;
		
		forval i = 0(1)5{;
			gen temp_flag_ui_pre`i' = .;
			
			forval yr = 1985(1)1996{;
				by unique_id: replace temp_flag_ui_pre`i' =  flag_ui[_n-`i'] if year == `yr' & year[_n-`i'] == `yr' - `i' ;
			};
		};

		forval i = 0(2)4{;
		
			forval yr = 1998(2)2016{;
				by unique_id: replace temp_flag_ui_pre`i' = flag_ui[_n-`i'/2] if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
			
			};
		};
	
		gen temp_flag_ui4 =.;
		
		replace temp_flag_ui4 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1|
										temp_flag_ui_pre2 == 1 | temp_flag_ui_pre3 == 1|temp_flag_ui_pre4 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != . & 
												   temp_flag_ui_pre2 != . & temp_flag_ui_pre3 != . & 
												   temp_flag_ui_pre4 != . & year < 1997;
								
		replace temp_flag_ui4 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre2 == 1|
										temp_flag_ui_pre4 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre2 != . & 
												   temp_flag_ui_pre4 != . & year > 1997;

		gen temp_pre4_ui = temp_flag_ui4 if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre4_ui = max(temp_pre4_ui);
		drop temp_pre4_ui ;


	gen temp_head = depression + flag_psychiatric_head + flag_learning_head;
	gen temp_spouse = flag_psychiatric_head + flag_learning_head;
	gen temp_gp_rand_mental = (temp_head > 0 | temp_spouse > 0) if temp_head != . & temp_spouse != .;
	replace temp_gp_rand_mental = (temp_head > 0) if temp_head != . & flag_spouse == 0;

	gen temp_gp_rand_chronic = (flag_chronic_head == 1|flag_chronic_spouse == 1) if flag_chronic_head != . & flag_chronic_spouse != . ;
	replace temp_gp_rand_chronic = (flag_chronic_head == 1) if flag_chronic_head != . & flag_spouse == 0;			
	
	gen flag_memory = (flag_memory_head == 1|flag_memory_spouse == 1) if flag_memory_head != . & flag_memory_spouse != .;
	replace flag_memory = (flag_memory_head == 1) if flag_memory_head != . & flag_spouse == 0;
	gen temp_gp_rand_infra = (flag_somephysical==1 | flag_memory == 1) if flag_somephysical != . & flag_memory != .;									

	gen byte gp_rand = (flag_di_rec == 1 & (temp_gp_rand_mental == 1 | temp_gp_rand_chronic == 1) & temp_gp_rand_infra != 1) ;

	drop temp_* ;
	
	gen temp_pre0_app_`sev' = flag_`sev' if first_di_rec_year == year;
 	bysort unique_id: egen pre0_app_`sev' = max(temp_pre0_app_`sev');
	drop temp_pre0_app_`sev' ;
	
	gen temp_post2_app_`sev' = flag_`sev' if first_di_rec_year + 2 == year ;			
	bysort unique_id: egen post2_app_`sev' = max(temp_post2_app_`sev');	
	drop temp_post2_app_`sev' ;
	
	gen byte gp_tempDI = (flag_di_rec == 1 & pre0_app_`sev' == 0 & post2_app_`sev' == 0) ;
	
	gen byte gp_cdr_nolonger = (flag_di_rec == 1 & pre0_app_`sev' == 1 & flag_`sev' == 0 ) ;
	
	gen flag_better_2yrs_head = (compared_2yrs_head == 1) if compared_2yrs_head != .;
	gen flag_better_2yrs_spouse = (compared_2yrs_spouse == 1) if compared_2yrs_spouse != .;
	
	gen flag_better_2yrs = 0 if flag_better_2yrs_spouse != . & flag_better_2yrs_head != .;
	replace flag_better_2yrs = 0 if flag_better_2yrs_head != . & flag_spouse == 0;
	replace flag_better_2yrs = 1 if flag_better_2yrs_spouse == 1 | flag_better_2yrs_head == 1;
	
	gen byte temp_better = (year >= first_di_rec_year & flag_better_2yrs == 1 & first_di_rec_year != .) ;
	bysort unique_id: egen temp_better_ever = total(temp_better) ;
	gen byte gp_cdr_better = (flag_di_rec == 1 & temp_better_ever > 0 & temp_better_ever != .) ;
	drop temp_better temp_better_ever ;

	summ year ;
	local maxyr = r(max) ;
	local minyr = r(min) ;
	gen earn_cut = . ;
	forval yr = `minyr'(1)`maxyr' { ;
		summ inc_earn_HSP if year == `yr', det ;
		replace earn_cut = r(p50) if year == `yr' ;
	} ;
	gen byte gp_means_earn = (flag_di_rec == 1 & inc_earn_HSP > earn_cut & inc_earn_HSP !=.) ;
	
	gen asset_cut = . ;
	forval yr = `minyr'(1)`maxyr' { ;
		summ total_asset if year == `yr', det ;
		replace asset_cut = r(p50) if year == `yr' ;
	} ;
	gen byte gp_means_asset = (flag_di_rec == 1 & total_asset > asset_cut & total_asset !=.) ;
	
	gen temp_pre0_app_SScredit = total_SScredit if first_di_rec_year == year ;
 	bysort unique_id: egen pre0_app_SScredit = max(temp_pre0_app_SScredit);
	drop temp_pre0_app_SScredit ;

	gen temp_pre0_headage = head_age if first_di_rec_year == year ;
	bysort unique_id: egen pre0_headage = max(temp_pre0_headage);
	drop temp_pre0_headage ;
	
	gen byte old_gp_workreq = (pre0_app_SScredit < max(20, (pre0_headage - 21)) & flag_di_rec == 1) ;
	gen byte gp_workreq = (pre0_app_SScredit < max(25, (pre0_headage - 21)*1.25) & flag_di_rec == 1) ;	
	

gen byte flag_ue = (reason_posend_hd_u == 1 | reason_posend_hd_u == 2 | reason_posend_hd_u == 3 |
					reason_posend_sp_u == 1 | reason_posend_sp_u == 2 | reason_posend_sp_u == 3 ) ;

gen flag_ue_and_ui = . ;
replace flag_ue_and_ui = (flag_ui & flag_ue) if (flag_ui < . & flag_ue < .) ;

sort unique_id year ;
foreach seve in severe {;
	by unique_id: gen temp_pre1_app_`seve' = flag_`sev'[_n-1] if first_di_rec_year == year; 		 
	bysort unique_id: egen pre1_app_`seve' = max(temp_pre1_app_`seve');
};

gen pre4_non_medical_shock_broad = (pre4_marriage_shock == 1 | 
									pre4_move_broad_shock == 1 | 
									pre4_job_shock == 1)
										if pre4_marriage_shock != . 
										 & pre4_move_broad_shock !=. 
										 & pre4_job_shock != .;

gen pre4_non_medical_shock_job = (pre4_job_shock == 1) if pre4_job_shock != .;										

gen flag_shock_UI = (pre4_ui == 1 & pre4_non_medical_shock_broad == 1) 
						if pre4_ui != . & pre4_non_medical_shock_broad != . ;
replace flag_shock_UI = 0 if flag_ui == 1 & flag_shock_UI != . ;			

gen flag_shock_NUI = (pre4_ui == 0 & pre4_non_medical_shock_broad == 1) 
						if pre4_ui != . & pre4_non_medical_shock_broad != . ;
replace flag_shock_NUI = 0 if flag_ui == 1 & flag_shock_UI != . ;	

gen flag_shock_NUIjob = (pre4_ui == 0 & pre4_non_medical_shock_job == 1) 
						if pre4_ui != . & pre4_non_medical_shock_job != . ;
replace flag_shock_NUIjob = 0 if flag_ui == 1 & flag_shock_UI != . ;	
		
sort unique_id year ;
gen temp_pre1_app_marriage = flag_married[_n-1] if first_di_rec_year == year;
bysort unique_id: egen pre1_app_marriage = max(temp_pre1_app_marriage);

gen temp_pre1_app_banking = flag_banking[_n-1] if first_di_rec_year == year;	
bysort unique_id: egen pre1_app_banking = max(temp_pre1_app_banking);

gen temp_pre1_app_homeown = flag_home_own[_n-1] if first_di_rec_year == year;	
bysort unique_id: egen pre1_app_homeown = max(temp_pre1_app_homeown);

drop temp_pre1* ;

gen pre1_sum_resource = pre1_app_marriage + pre1_app_banking + pre1_app_homeown ;
gen flag_low = (pre1_sum_resource < 2) if pre1_sum_resource != . ;			
gen flag_Nshock_low = (pre4_non_medical_shock_broad == 0 & flag_low == 1) 
							if flag_low != . & pre4_non_medical_shock_broad != . ;


gen food = exp_food/sqrt(num_of_family) ;
gen tot  = hhexp_total/sqrt(num_of_family) ;
gen Nhls = hhexp_N_hlth/sqrt(num_of_family) ;

foreach var in food tot Nhls {;

	summ `var' , det ; 
	local c_floor = r(p10) ;
	gen floor_`var' = max(`var', `c_floor') ;
	replace floor_`var' = . if `var' == . ;
	
	gen MU1_`var' = (1 / `var') * 10000 ;
	gen floor_MU1_`var' = (1 / floor_`var') * 10000 ;
	
	gen MU2_`var' = (1 / `var'^2) * 10000000 ;
	gen floor_MU2_`var' = (1 / floor_`var'^2) * 10000000 ;
	
	gen MU3_`var' = (1 / `var'^3) * 10000000000 ;
	gen floor_MU3_`var' = (1 / floor_`var'^3) * 10000000000 ;
	
	gen MU4_`var' = (1 / `var'^4) * 10000000000000 ;
	gen floor_MU4_`var' = (1 / floor_`var'^4) * 10000000000000 ;
} ;

foreach var in food tot Nhls {;
	forval gamma=1(1)4 { ;

		gen floor_MU`gamma'st10n_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st10n_`var' = floor_MU`gamma'_`var' * .9 if current_`sev' == 1 ;
		
		gen floor_MU`gamma'st25n_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st25n_`var' = floor_MU`gamma'_`var' * .75 if current_`sev' == 1 ;
		
		gen floor_MU`gamma'st10p_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st10p_`var' = floor_MU`gamma'_`var' * 1.1 if current_`sev' == 1 ;
		
		gen floor_MU`gamma'st25p_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st25p_`var' = floor_MU`gamma'_`var' * 1.25 if current_`sev' == 1 ;
		
	} ;
} ;
	
rename current_DI 					gp_di ;
rename current_`sev' 				gp_sev ;
rename current_moderate				gp_mod ;
rename current_anydis				gp_any ;
rename flag_severe_ever				gp_ev ;
rename flag_moderate_ever			gp_evmod ;
rename flag_hfairpoor_ever			gp_evfp ;
rename flag_hpoor_ever				gp_evpoor ;
rename flag_severe_predi			gp_predisev ;
rename flag_moderate_predi			gp_predimod ;
rename flag_hfairpoor_predi			gp_predifp ;
rename flag_hpoor_predi				gp_predipoor ;
rename hsdrop						gp_hsdrop ;
rename hsgrad						gp_hsgrad ;
rename somecollege					gp_somecoll ;
rename college						gp_college ;
rename non_medical_shock_pre40		gp_shockY ;
rename non_medical_shock_pre40_NO	gp_shockN ;
rename non_medical_shock_pre40_2	gp_shock2Y ;
rename non_medical_shock_pre40_2_NO	gp_shock2N ;
rename flag_all_resources_pre40		gp_res_all ;
rename flag_some_resources_pre40 	gp_res_some ;
rename flag_none_resources_pre40	gp_res_none ;
rename flag_ui						gp_ui ;
rename flag_ue						gp_ue ;
rename flag_ue_and_ui				gp_ue_ui ;

gen gp_di_yr =						flag_di_rec ;
gen gp_sev_yr =						flag_`sev' ;

gen gp_hdi = (gp_sev) ;
gen gp_ie  = (gp_di  & !gp_sev) ;
gen gp_ee  = (!gp_di & gp_sev) ;
gen gp_sdi = (gp_di   &  gp_sev) ;
gen gp_ns  = (!gp_sev) ;
gen gp_nev = (gp_ev != 1) ;
gen gp_sap = (flag_`sev'_app == 1) ;
gen gp_nap = (gp_sap != 1) ;
gen gp_map = (flag_moderate_app == 1) ;
gen gp_hpap= (flag_hpoor_app == 1) ;
gen gp_hfpap=(flag_hfairpoor_app == 1) ;

gen gp_thresh = . ;
replace gp_thresh = 0 if !gp_di ;
replace gp_thresh = 1 if (gp_di & !gp_sev) ;

gen gp_pop = 1 ;
gen gp_ndi     = (!gp_di) ;
gen gp_sev_di  = ( gp_sev &  gp_di) ;
gen gp_ns_di   = (!gp_sev &  gp_di) ;
gen gp_sev_ndi = ( gp_sev & !gp_di) ;
gen gp_ns_ndi  = (!gp_sev & !gp_di) ;

gen gp_di_sev  = (gp_di  &  gp_sev) ;
gen gp_di_ns   = (gp_di  & !gp_sev) ;
gen gp_ndi_sev = (!gp_di &  gp_sev) ;
gen gp_ndi_ns  = (!gp_di & !gp_sev) ;

foreach stub in ev evmod evfp evpoor { ;
	gen gp_di_`stub'  	= (gp_di  &  gp_`stub') ;
	gen gp_di_n`stub'  	= (gp_di  & !gp_`stub') ;
	gen gp_ndi_`stub'   = (!gp_di &  gp_`stub') ;
	gen gp_ndi_n`stub'  = (!gp_di & !gp_`stub') ;
} ;

foreach stub in sap map hpap hfpap { ;
	gen gp_di_`stub'  	= (gp_di  &  gp_`stub') ;
	gen gp_di_n`stub'  	= (gp_di  & !gp_`stub') ;
	gen gp_ndi_`stub'   = (!gp_di &  gp_`stub') ;
	gen gp_ndi_n`stub'  = (!gp_di & !gp_`stub') ;
} ;
rename gp_di_nsap  gp_di_nap ; 
rename gp_ndi_nsap gp_ndi_nap ;

gen gp_ndi_yr     = (!gp_di_yr) ;
gen gp_sev_di_yr  = ( gp_sev_yr &  gp_di_yr) ;
gen gp_ns_di_yr   = (!gp_sev_yr &  gp_di_yr) ;
gen gp_sev_ndi_yr = ( gp_sev_yr & !gp_di_yr) ;
gen gp_ns_ndi_yr  = (!gp_sev_yr & !gp_di_yr) ;

gen gp_di_ns_sevapp 	= pre1_app_severe 	if gp_di_ns == 1 ;
gen gp_di_ns_uifirst 	= flag_shock_UI 	if gp_di_ns == 1 ;
gen gp_di_ns_someshock 	= flag_shock_NUI 	if gp_di_ns == 1 ;
gen gp_di_ns_jobshock 	= flag_shock_NUIjob	if gp_di_ns == 1 ;
gen gp_di_ns_noshock 	= flag_Nshock_low 	if gp_di_ns == 1 ;

gen gp_di_ns_sub 		= (flag_shock_UI == 1 | flag_shock_UI == 0) 	if gp_di_ns == 1 ;
gen gp_di_ns_sub2		= (pre1_app_severe == 1 | pre1_app_severe == 0) if gp_di_ns == 1 ;
gen gp_di_ns_sub3		= (flag_Nshock_low == 1 | flag_Nshock_low == 0) if gp_di_ns == 1 ;

set seed 1010101010 ;

gen u_draw = runiform() ;
gen gp_adi = . ;
replace gp_adi = (u_draw <= 0.006) if gp_any == 0 & head_age < 45;
replace gp_adi = (u_draw <= 0.075) if gp_any == 0 & head_age >= 45;
replace gp_adi = (u_draw <= 0.171) if gp_mod == 1 & head_age < 45;
replace gp_adi = (u_draw <= 0.180) if gp_mod == 1 & head_age >= 45;
replace gp_adi = (u_draw <= 0.331) if gp_sev == 1 & head_age < 45;
replace gp_adi = (u_draw <= 0.626) if gp_sev == 1 & head_age >= 45;
drop u_draw ;

gen u_draw = runiform() ;
gen gp_ad2 = gp_adi ;
replace gp_ad2 = (u_draw <= 0.006) if gp_adi == 0 & gp_any == 0 & head_age < 45;
replace gp_ad2 = (u_draw <= 0.075) if gp_adi == 0 & gp_any == 0 & head_age >= 45;
replace gp_ad2 = (u_draw <= 0.171) if gp_adi == 0 & gp_mod == 1 & head_age < 45;
replace gp_ad2 = (u_draw <= 0.180) if gp_adi == 0 & gp_mod == 1 & head_age >= 45;
replace gp_ad2 = (u_draw <= 0.331) if gp_adi == 0 & gp_sev == 1 & head_age < 45;
replace gp_ad2 = (u_draw <= 0.626) if gp_adi == 0 & gp_sev == 1 & head_age >= 45;
drop u_draw ;

gen u_draw = runiform() ;
gen gp_ad3 = gp_ad2 ;
replace gp_ad3 = (u_draw <= 0.006) if gp_ad2 == 0 & gp_any == 0 & head_age < 45;
replace gp_ad3 = (u_draw <= 0.075) if gp_ad2 == 0 & gp_any == 0 & head_age >= 45;
replace gp_ad3 = (u_draw <= 0.171) if gp_ad2 == 0 & gp_mod == 1 & head_age < 45;
replace gp_ad3 = (u_draw <= 0.180) if gp_ad2 == 0 & gp_mod == 1 & head_age >= 45;
replace gp_ad3 = (u_draw <= 0.331) if gp_ad2 == 0 & gp_sev == 1 & head_age < 45;
replace gp_ad3 = (u_draw <= 0.626) if gp_ad2 == 0 & gp_sev == 1 & head_age >= 45;
drop u_draw ;

gen inc_earn_recip 		= inc_earn_spouse 	if flag_`x'_rec_spouse == 1 ;
replace inc_earn_recip 	= inc_earn_head 	if flag_`x'_rec_head == 1 ;

local zndi_thresh_etdi = 15120 * 2 ;
local FS_ESTIMATES_TYPE "diagnosis" ;
local fs_scaling_factor = 1 ;

gen_zndi_zdi_vars "$data" "`FS_ESTIMATES_TYPE'" `fs_scaling_factor' ;

gen gp_tdi = gp_adi ;
replace gp_tdi = 0 if gp_adi == 1 & z_ndi > `zndi_thresh_etdi' & z_ndi < . ;

gen gp_td2 = gp_ad2 ;
replace gp_td2 = 0 if gp_ad2 == 1 & z_ndi > `zndi_thresh_etdi' & z_ndi < . ;

gen gp_td3 = gp_ad3 ;
replace gp_td3 = 0 if gp_ad3 == 1 & z_ndi > `zndi_thresh_etdi' & z_ndi < . ;

drop z_indiv z_ndi z_di ;

gen temp_earn = inc_earn_HSP if head_age >= 34 & head_age <= 36 ;
bysort unique_id: egen earnHSP35 = max(temp_earn) ;

gen inverse_optimum_weight = . ;

drop temp* ;

keep 		
	unique_id family_weight year year_psid state* flag_spouse
	flag_work_age head_age first_age first_di_rec_age first_di_rec_year
	flag_di_rec flag_di_rec_ever     
	num_adl num_iadl health_status level_disabled diag_* 
	inc_earn_HSP inc_earn_recip inc_earn_head inc_hh earnHSP35 
	gp_* floor_* 
	pre1_app_severe flag_shock_UI flag_shock_NUI flag_Nshock_low fdsec_* ;
	
order 		
	unique_id year state* flag_work_age flag_di_rec head_age family_weight flag_spouse num_adl num_iadl health_status level_disabled diag_* 
	inc_earn_HSP inc_earn_recip inc_earn_head earnHSP35 
	gp_* floor_* inc_hh
	;

preserve ;

	keep if year == `targetyr';
	drop if flag_work_age == 0;
	
	gen gp_all = 1 ;
	
	cross using "$data/inverse_optimum_weights_merge.dta" ;
	keep if low_income < inc_hh & inc_hh <= high_income ;
	drop quantile low_income high_income income ;
		
	save "$temp/psid_hhlevel_forsummstats_`x'_`sev'_`targetyr'.dta", replace ;				

restore ;

};

};

capture log close ;
