version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause on
#delim;


import excel "$data/state_safetynet.xls", sheet(ranking-2017) firstrow clear ;
xtile state_gen = Welfare, nq(4) ;
rename region state_region ;
tempfile state ;
save `state' ;

import excel "$data/state_safetynet_tanfpov.xls", firstrow clear ;
xtile state_tanf95 = tanfpov_1995, nq(4) ;
xtile state_tanf05 = tanfpov_2005, nq(4) ;
xtile state_tanf17 = tanfpov_2017, nq(4) ;
gen diff9517 = tanfpov_2017 - tanfpov_1995 ;
gen diff9505 = tanfpov_2005 - tanfpov_1995 ;
xtile state_tanfdiff9517 = diff9517, nq(4) ;
xtile state_tanfdiff9505 = diff9505, nq(4) ;
tempfile state_tanf ;
save `state_tanf' ;

local x = "dissi" ; 
local sev "severe" ; 

forval targetyr = 1985(1)1996 { ;

use "$temp/psid_forinteract_2016usd_long_`x'.dta", clear;

sort unique_id year;

egen food_all = rowtotal(food_home food_out), missing ;
egen annual_housing = rowtotal(annual_mortg annual_rent), missing ; 
gen foodrentmortg = food_all + annual_housing ;

gen flag_severe_moderate = (flag_severe == 1|flag_moderate == 1) if flag_severe != . & flag_moderate != .;

drop if head_age == .;

keep 
	unique_id family_weight num_of_family head_age year state* first_observ
	first_di_rec_age first_di_rec_year
	flag_di_rec flag_di_rec_ever
	flag_di_rec_head flag_di_rec_spouse flag_dissi_rec_head flag_dissi_rec_spouse 
	flag_severe* flag_moderate flag_psid_disable flag_severe_head flag_severe_spouse flag*app flag*ever flag*predi
	educ_hsdrop_head educ_hsgrad_head educ_some_college_head educ_college_head 
	reason_move* flag_married reason_posend_hd_u reason_posend_hd_e reason_posend_sp_u reason_posend_sp_e
	flag_home_own
	food_all food_home food_out annual_mortg annual_rent annual_housing foodrentmortg
	flag_spouse first_di_rec_year
	inc_earn_HSP inc_earn_head inc_earn_spouse total_SScredit
	flag_ui
	health_status level_disabled inc_hh
	;

rename flag_sev_ever flag_severe_ever ;

gen temp = year if first_observ == 1 ;
egen year_psid = max(temp), by(unique_id) ;
drop temp ;

merge m:1 state_curr using `state', keepusing(state_region state_gen) ;
drop if _merge == 2 ;
drop _merge ;

merge m:1 state_curr using `state_tanf', keepusing(state_tanf*) ;
drop if _merge == 2 ;
drop _merge ;

	
	gen flag_work_age = (head_age > 24 & head_age < 66) if year == `targetyr';
	
	bysort unique_id: egen first_age = min(head_age) ;

	gen temp_current_DI = flag_di_rec if year == `targetyr';
	
	bysort unique_id: egen current_DI = max(temp_current_DI);
	
	gen current_nonrec = 1 - current_DI;
	
	gen temp_current_`sev' = flag_`sev' if year == `targetyr';
	
	bysort unique_id: egen current_`sev' = max(temp_current_`sev');
	
	gen temp_current_moderate = flag_moderate if year == `targetyr';
	
	bysort unique_id: egen current_moderate = max(temp_current_moderate);
	
	gen temp_current_anydis = flag_psid_disable if year == `targetyr';
	
	bysort unique_id: egen current_anydis = max(temp_current_anydis);
	
	gen temp_current_none = 1 -  flag_psid_disable if year == `targetyr';
	
	bysort unique_id: egen current_none = max(temp_current_none);
	
	bysort unique_id: egen hsdrop = max(educ_hsdrop_head);
	
	bysort unique_id: egen hsgrad = max(educ_hsgrad_head);
	
	bysort unique_id: egen somecollege = max(educ_some_college_head);
	
	bysort unique_id: egen college = max(educ_college_head);
	
	replace hsdrop = 0 if hsgrad == 1 | somecollege == 1 | college == 1;
	replace hsgrad = 0 if somecollege == 1 | college == 1;
	replace somecollege = 0 if college == 1;
	
	sort unique_id year;
		
		forval i = 0(1)5{;
			gen temp_flag_ui_pre`i' = .;
			
			forval yr = 1985(1)1996{;
				by unique_id: replace temp_flag_ui_pre`i' =  flag_ui[_n-`i'] if year == `yr' & year[_n-`i'] == `yr' - `i' ;
			};
		};

		forval i = 0(2)4{;
		
			forval yr = 1998(2)2016{;
				by unique_id: replace temp_flag_ui_pre`i' = flag_ui[_n-`i'/2] if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
			
			};
		};
	
		gen temp_flag_ui4 =.;
		
		replace temp_flag_ui4 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1|
										temp_flag_ui_pre2 == 1 | temp_flag_ui_pre3 == 1|temp_flag_ui_pre4 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != . & 
												   temp_flag_ui_pre2 != . & temp_flag_ui_pre3 != . & 
												   temp_flag_ui_pre4 != . & year < 1997;
								
		replace temp_flag_ui4 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre2 == 1|
										temp_flag_ui_pre4 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre2 != . & 
												   temp_flag_ui_pre4 != . & year > 1997;

		gen temp_pre4_ui = temp_flag_ui4 if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre4_ui = max(temp_pre4_ui);
		drop temp_pre4_ui ;


gen food = food_all/sqrt(num_of_family) ;
gen tot  = foodrentmortg/sqrt(num_of_family) ;

foreach var in food tot {;

	summ `var' , det ; 
	local c_floor = r(p10) ;
	gen floor_`var' = max(`var', `c_floor') ;
	replace floor_`var' = . if `var' == . ;
	
	gen MU1_`var' = (1 / `var') * 10000 ;
	gen floor_MU1_`var' = (1 / floor_`var') * 10000 ;
	
	gen MU2_`var' = (1 / `var'^2) * 10000000 ;
	gen floor_MU2_`var' = (1 / floor_`var'^2) * 10000000 ;
	
	gen MU3_`var' = (1 / `var'^3) * 10000000000 ;
	gen floor_MU3_`var' = (1 / floor_`var'^3) * 10000000000 ;
	
	gen MU4_`var' = (1 / `var'^4) * 10000000000000 ;
	gen floor_MU4_`var' = (1 / floor_`var'^4) * 10000000000000 ;
} ;

foreach var in food tot {;
	forval gamma=1(1)4 { ;

		gen floor_MU`gamma'st10n_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st10n_`var' = floor_MU`gamma'_`var' * .9 if current_`sev' == 1 ;
		
		gen floor_MU`gamma'st25n_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st25n_`var' = floor_MU`gamma'_`var' * .75 if current_`sev' == 1 ;
		
		gen floor_MU`gamma'st10p_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st10p_`var' = floor_MU`gamma'_`var' * 1.1 if current_`sev' == 1 ;
		
		gen floor_MU`gamma'st25p_`var' = floor_MU`gamma'_`var' if current_`sev' != 1 ;
		replace floor_MU`gamma'st25p_`var' = floor_MU`gamma'_`var' * 1.25 if current_`sev' == 1 ;
		
	} ;
} ;
	
	
rename current_DI 					gp_di ;
rename current_`sev' 				gp_sev ;
rename current_moderate				gp_mod ;
rename current_anydis				gp_any ;
rename flag_severe_ever				gp_ev ;
rename flag_moderate_ever			gp_evmod ;
rename flag_hfairpoor_ever			gp_evfp ;
rename flag_hpoor_ever				gp_evpoor ;
rename flag_severe_predi			gp_predisev ;
rename flag_moderate_predi			gp_predimod ;
rename flag_hfairpoor_predi			gp_predifp ;
rename flag_hpoor_predi				gp_predipoor ;
rename hsdrop						gp_hsdrop ;
rename hsgrad						gp_hsgrad ;
rename somecollege					gp_somecoll ;
rename college						gp_college ;
rename flag_ui						gp_ui ;

gen gp_di_yr =						flag_di_rec ;
gen gp_sev_yr =						flag_`sev' ;

gen gp_hdi = (gp_sev) ;
gen gp_ie  = (gp_di  & !gp_sev) ;
gen gp_ee  = (!gp_di & gp_sev) ;
gen gp_sdi = (gp_di   &  gp_sev) ;
gen gp_ns  = (!gp_sev) ;
gen gp_nev = (gp_ev != 1) ;
gen gp_sap = (flag_`sev'_app == 1) ;
gen gp_nap = (gp_sap != 1) ;
gen gp_map = (flag_moderate_app == 1) ;
gen gp_hpap= (flag_hpoor_app == 1) ;
gen gp_hfpap=(flag_hfairpoor_app == 1) ;

gen gp_thresh = . ;
replace gp_thresh = 0 if !gp_di ;
replace gp_thresh = 1 if (gp_di & !gp_sev) ;

gen gp_pop = 1 ;
gen gp_ndi     = (!gp_di) ;
gen gp_sev_di  = ( gp_sev &  gp_di) ;
gen gp_ns_di   = (!gp_sev &  gp_di) ;
gen gp_sev_ndi = ( gp_sev & !gp_di) ;
gen gp_ns_ndi  = (!gp_sev & !gp_di) ;

gen gp_di_sev  = (gp_di  &  gp_sev) ;
gen gp_di_ns   = (gp_di  & !gp_sev) ;
gen gp_ndi_sev = (!gp_di &  gp_sev) ;
gen gp_ndi_ns  = (!gp_di & !gp_sev) ;

foreach stub in ev evmod evfp evpoor { ;
	gen gp_di_`stub'  	= (gp_di  &  gp_`stub') ;
	gen gp_di_n`stub'  	= (gp_di  & !gp_`stub') ;
	gen gp_ndi_`stub'   = (!gp_di &  gp_`stub') ;
	gen gp_ndi_n`stub'  = (!gp_di & !gp_`stub') ;
} ;

foreach stub in sap map hpap hfpap { ;
	gen gp_di_`stub'  	= (gp_di  &  gp_`stub') ;
	gen gp_di_n`stub'  	= (gp_di  & !gp_`stub') ;
	gen gp_ndi_`stub'   = (!gp_di &  gp_`stub') ;
	gen gp_ndi_n`stub'  = (!gp_di & !gp_`stub') ;
} ;
rename gp_di_nsap  gp_di_nap ; 
rename gp_ndi_nsap gp_ndi_nap ;

gen inc_earn_recip 		= inc_earn_spouse 	if flag_`x'_rec_spouse == 1 ;
replace inc_earn_recip 	= inc_earn_head 	if flag_`x'_rec_head == 1 ;

gen temp_earn = inc_earn_HSP if head_age >= 34 & head_age <= 36 ;
bysort unique_id: egen earnHSP35 = max(temp_earn) ;

gen inverse_optimum_weight = . ;

drop temp* ;

keep 		
	unique_id year year_psid state* flag_work_age flag_di_rec flag_di_rec_ever head_age first_age first_di_rec_age first_di_rec_year  
	family_weight flag_spouse health_status level_disabled 
	inc_earn_HSP inc_earn_head inc_earn_recip earnHSP35
	gp_* floor_* inc_hh
	food_all food_home food_out annual_mortg annual_rent annual_housing foodrentmortg
	;
	
order 		
	unique_id year year_psid flag_work_age flag_di_rec head_age family_weight flag_spouse health_status level_disabled 
	inc_earn_HSP inc_earn_head inc_earn_recip earnHSP35
	food_all food_home food_out annual_mortg annual_rent annual_housing foodrentmortg
	gp_* floor_* inc_hh
	;

	keep if year == `targetyr';
	drop if flag_work_age == 0;
	
	gen gp_all = 1 ;
	
	cross using "$data/inverse_optimum_weights_merge.dta" ;
	keep if low_income < inc_hh & inc_hh <= high_income ;
	drop quantile low_income high_income income ;
		
	save "$temp/psid_hhlevel_forsummstats_`x'_`sev'_`targetyr'.dta", replace ;				

};

capture log close ;
