version 15
clear all 
set more off
set logtype text
set maxvar 20000
set matsize 10000
capture log close
pause on
#delim;


local data "$results";
local results "$results";
local log "";
local do "";

local groups "gp_m_ndi gp_l_di gp_l_ndi" ;
local di "gp_l_di" ;
local m "gp_m_ndi" ;

/* Figure F1: PSID */

foreach z in dissi{;
	use "`data'/psid_figure_`z'.dta", clear;	
	
	preserve ;
	
		gen temp_flag_2016_ever = (year == 2016) ;

		bysort unique_id: egen flag_2016_ever = max(temp_flag_2016_ever) ;

		tab flag_2016_ever ;

		drop if flag_2016_ever == 0 ;

		drop temp_flag_2016_ever ;

		/* Create earnings controls */
		foreach age in 35 { ;

			gen temp_flag_di_pre`age' = 1 if flag_di_rec_head == 1 & head_age <= `age' ;

			bysort unique_id: egen flag_di_pre`age' = max(temp_flag_di_pre`age') ;
			
			gen temp_inc_earn_head_pre`age' = inc_earn_head if head_age == `age' & flag_di_pre`age' == . ;
			
			bysort unique_id: egen inc_earn_head_pre`age' = max(temp_inc_earn_head_pre`age') ;
			
		} ;
		
		forvalues i = 31(1)35{;
		
			gen temp_earnings_`i' = inc_earn_head if head_age == `i' ;
			
			bysort unique_id: egen earnings_`i' = max(temp_earnings_`i') ;
			
			drop temp_earnings_`i' ;
		
		};
		
		egen avg_earnings_3135 = rowmean(earnings_31-earnings_35) ;
		summ avg_earnings_3135 ;
		
		xtile avg_z_3135_decile = avg_earnings_3135, nq(10) ;
		
		/* Keep only current year */
		keep if year == 2016 ;

		/* Assign to groups */
		gen byte gp_m_di 	= (flag_di_rec == 1 & flag_severe == 1) ;
		gen byte gp_m_ndi 	= (flag_di_rec == 0 & flag_severe == 1) ;
		gen byte gp_l_di 	= (flag_di_rec == 1 & flag_severe == 0) ;
		gen byte gp_l_ndi 	= (flag_di_rec == 0 & flag_severe == 0) ;

		egen temp = rowtotal(gp_m_di gp_m_ndi gp_l_di gp_l_ndi) ;
		tab temp, m ;
		drop if temp != 1 ;
		drop temp ;
			

		/* Education control */
		gen educ = "< HS" if educ_hsdrop_head == 1 ;					
		replace educ = "HS grad" if educ_hsgrad_head == 1 ;
		replace educ = "Some coll" if educ_some_college_head == 1 ;
		replace educ = "College" if educ_college_head == 1 ;
		tab educ, m ;
		drop if educ == "" ;
		
		rename hhexp_N_hlth main_c ;
		rename flag_banking main_bank ;
		rename flag_married main_married ;
		rename flag_home_own main_home ;
		rename inc_earn_head_pre35 main_z35 ;

		rename pre4_non_medical_shock_broad mainshock_all ;
		rename pre4_move_broad_shock		mainshock_move ;
		rename pre4_marriage_shock			mainshock_divorce ;
		rename pre4_job_shock				mainshock_job ;		

		/* Main outcomes */
			reg main_c `groups' [w=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs.xls", replace ;
		
		foreach var of varlist main_* { ;
		
			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_`var'_none_`z'.dta", replace):
				reg `var' `groups' [aw=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;
			
			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_`var'_ed_`z'.dta", replace):
				reg `var' `groups' head_age i.educ [aw=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;
			
			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_`var'_edz3135dec_`z'.dta", replace):
				reg `var' `groups' head_age i.educ i.avg_z_3135_decile [aw=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;

			
			};
			

		/* Main outcomes: DI only comparisons: shocks */
		foreach var of varlist mainshock* { ;
		

			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_`var'_none_`z'.dta", replace):
				reg `var' `di' if gp_m_di == 1 | gp_l_di == 1 [aw=family_weight];
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;

			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_`var'_ed_`z'.dta", replace):
				reg `var' `di' head_age i.educ if gp_m_di == 1 | gp_l_di == 1 [aw=family_weight];
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;

			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_`var'_edz3135dec_`z'.dta", replace):
				reg `var' `di' head_age i.educ i.avg_z_3135_decile if gp_m_di == 1 | gp_l_di == 1 [aw=family_weight];
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;

			
			};				
	
	local allvars "" ;
	foreach var of varlist main_* mainshock_* { ;
		local allvars "`allvars' `var'" ;
	} ;
	
	restore ;
	
		/* Regressions for matrix variables are run here */
	
		foreach age in 35 { ;

			gen temp_flag_di_pre`age' = 1 if flag_di_rec_head == 1 & head_age <= `age' ;

			bysort unique_id: egen flag_di_pre`age' = max(temp_flag_di_pre`age') ;
			
			gen temp_inc_earn_head_pre`age' = inc_earn_head if head_age == `age' & flag_di_pre`age' == . ;
			
			bysort unique_id: egen inc_earn_head_pre`age' = max(temp_inc_earn_head_pre`age') ;
			
		} ;
		
		forvalues i = 31(1)35{;
		
			gen temp_earnings_`i' = inc_earn_head if head_age == `i' ;
			
			bysort unique_id: egen earnings_`i' = max(temp_earnings_`i') ;
			
			drop temp_earnings_`i' ;
		
		};
	
		egen avg_earnings_3135 = rowmean(earnings_31-earnings_35) ;
		summ avg_earnings_3135 ;
		xtile avg_z_3135_decile = avg_earnings_3135, nq(10) ;


		/* Assign to groups */
		gen byte gp_m_ndi 	= (flag_di_rec_ever == 0 & severe == 1) ;
		gen byte gp_m_di_2534 = (gp_rec_pre35_severe == 1) ;
		gen byte gp_m_di_3544 = (gp_rec_3544_severe == 1) ;
		gen byte gp_m_di_4554 = (gp_rec_4554_severe == 1) ;
		gen byte gp_m_di_5565 = (gp_rec_5565_severe == 1) ;
			
		/* Education control */
		gen educ = "< HS" if educ_hsdrop_head == 1 ;					
		replace educ = "HS grad" if educ_hsgrad_head == 1 ;
		replace educ = "Some coll" if educ_some_college_head == 1 ;
		replace educ = "College" if educ_college_head == 1 ;
		tab educ, m ;
		drop if educ == "" ;
			
		
		foreach age in 2534 3544 4554 5565 {;
			rename shock_non_medical_broad_`age' mainmatrixshock_age`age' ;
		} ;
		
		duplicates drop unique_id, force ;

		/* Main outcomes: Severe only comparisons */
				
		foreach age in 2534 3544 4554 5565 {;
		
			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_mainmatrixshock_age`age'_none_`z'.dta", replace):
				reg mainmatrixshock_age`age' `m' if gp_m_di_`age' == 1 | gp_m_ndi == 1 [aw=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;
					
			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_mainmatrixshock_age`age'_ed_`z'.dta", replace):
				reg mainmatrixshock_age`age' `m' head_age i.educ if gp_m_di_`age' == 1 | gp_m_ndi == 1 [aw=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;

			xi: statsby _b _se N=e(N), saving("`results'/figF1_abilityreg_mainmatrixshock_age`age'_edz3135dec_`z'.dta", replace):
				reg mainmatrixshock_age`age' `m' head_age i.educ i.avg_z_3135_decile if gp_m_di_`age' == 1 | gp_m_ndi == 1 [aw=family_weight] ;
			outreg2 using "`results'/figF1_psid_positive_abilityregs_`z'.xls", append ;
		
		};
	
		
/* Collect statsby */
local matrixvars "" ;
foreach var of varlist mainmatrixshock_age* { ;
	local matrixvars "`matrixvars' `var'" ;
} ;

local negvars "mainmatrixshock_age2534 mainmatrixshock_age3544 
			   main_shockmatrixage4554 mainmatrixshock_age5565 
			   mainshock_all mainshock_job mainshock_move mainshock_divorce" ;


use "`results'/figF1_abilityreg_main_c_none_`z'.dta", clear ;
gen var = "main_c" ;
gen spec = "none" ;
foreach var in `allvars' `matrixvars' { ;
	foreach spec in none ed edz3135dec { ;
		append using "`results'/figF1_abilityreg_`var'_`spec'_`z'.dta" ;
		replace var = "`var'" if var == "" ;
		replace spec = "`spec'" if spec == "" ;	
	} ;
} ;
drop if _n == 1 ;
save 	"`results'/figF1_abilityreg_compiled_`z'.dta", replace ;
};
