version 15
clear all 
set more off
set logtype text
set maxvar 20000
set matsize 10000
capture log close
pause on
#delim;


local results "$results";
local output "$tab";
local log "";
local do "";

/* Table F1: Selection into USDP within severity, controlling for fine health measures */

local groups "gp_m_ndi gp_l_di gp_l_ndi" ;

local di "gp_l_di" ;

local s "gp_m_ndi" ;

local z "dissi" ;
use "`results'/psid_figure_`z'.dta", clear;	

/* All regressions except the matrix variable will be run first since the data structure and groups used are slightly different */
		
		gen temp_flag_2016_ever = (year == 2016) ;

		bysort unique_id: egen flag_2016_ever = max(temp_flag_2016_ever) ;

		tab flag_2016_ever ;

		drop if flag_2016_ever == 0 ;

		drop temp_flag_2016_ever ;

		/* Create earnings controls */
		foreach age in 35 { ;

			gen temp_flag_di_pre`age' = 1 if flag_di_rec_head == 1 & head_age <= `age' ;

			bysort unique_id: egen flag_di_pre`age' = max(temp_flag_di_pre`age') ;
			
			gen temp_inc_earn_head_pre`age' = inc_earn_head if head_age == `age' & flag_di_pre`age' == . ;
			
			bysort unique_id: egen inc_earn_head_pre`age' = max(temp_inc_earn_head_pre`age') ;
			
		} ;
		
		forvalues i = 31(1)35{;
		
			gen temp_earnings_`i' = inc_earn_head if head_age == `i' ;
			
			bysort unique_id: egen earnings_`i' = max(temp_earnings_`i') ;
			
			drop temp_earnings_`i' ;
		
		};
		
		egen avg_earnings_3135 = rowmean(earnings_31-earnings_35) ;
		summ earnings_35 avg_earnings_3135 ;
		
		xtile z_35_decile = earnings_35, nq(10) ;
		xtile avg_z_3135_decile = avg_earnings_3135, nq(10) ;
		
		/* Keep only current year */
		keep if year == 2016 ;

		/* Assign to groups */
		gen byte gp_m_di 	= (flag_di_rec == 1 & flag_severe == 1) ;
		gen byte gp_m_ndi 	= (flag_di_rec == 0 & flag_severe == 1) ;
		gen byte gp_l_di 	= (flag_di_rec == 1 & flag_severe == 0) ;
		gen byte gp_l_ndi 	= (flag_di_rec == 0 & flag_severe == 0) ;

		egen temp = rowtotal(gp_m_di gp_m_ndi gp_l_di gp_l_ndi) ;
		tab temp, m ;
		drop if temp != 1 ;
		drop temp ;
			
		/* Education control */
		gen educ = "< HS" if educ_hsdrop_head == 1 ;					
		replace educ = "HS grad" if educ_hsgrad_head == 1 ;
		replace educ = "Some coll" if educ_some_college_head == 1 ;
		replace educ = "College" if educ_college_head == 1 ;
		tab educ, m ;
		drop if educ == "" ;
		
		/* Rename outcomes */
		foreach c in hhexp_N_hlth hhexp_total { ;
			replace `c' = `c'/sqrt(num_of_family) ;
			replace pre1_app_`c' = pre1_app_`c'/sqrt(num_of_family) ;
			replace pre1_sev_`c' = pre1_sev_`c'/sqrt(num_of_family) ;

		} ;
		
		rename hhexp_N_hlth main_c ;
		rename flag_banking main_bank ;
		rename flag_married main_married ;
		rename flag_home_own main_home ;
		rename inc_earn_head_pre35 main_z35 ;

		rename pre4_non_medical_shock_broad mainshock_all ;
		rename pre4_move_broad_shock		mainshock_move ;
		rename pre4_marriage_shock			mainshock_divorce ;
		rename pre4_job_shock				mainshock_job ;
		
		rename flag_ins_private_head 		apdx_inspri ;
		rename flag_ins_public_head  		apdx_inspub ;
		rename flag_anyins_head		 		apdx_insany ;
		rename flag_foodstamp 		 		apdx_Xfood ;
		rename flag_mean_tested 	 		apdx_Xmeans ;
		rename flag_si_no_ss		 		apdx_Xsi ;
		rename flag_cash_relative 	 		apdx_cashrel ;
		rename flag_cash_nonrelative 		apdx_cashnon ;
		
		rename pre1_app_hhexp_N_hlth	 	apdxapp1_c ;
		rename pre1_app_banking 			apdxapp1_bank ;
		rename pre1_app_marriage 			apdxapp1_married ;
		rename pre1_app_homeown				apdxapp1_homeown ;
		rename pre1_app_ins_private 		apdxapp1_inspri ;
		rename pre1_app_ins_public  		apdxapp1_inspub ;
		rename pre1_app_anyins		 		apdxapp1_insany ;
		rename pre1_app_fdstamp 		 	apdxapp1_Xfood ;
		rename pre1_app_mean_tested 	 	apdxapp1_Xmeans ;
		rename pre1_app_si_no_ss		 	apdxapp1_Xsi ;
		rename pre1_cash_relative 	 		apdxapp1_cashrel ;
		rename pre1_cash_nonrelative 		apdxapp1_cashnon ;
		
		rename pre1_sev_hhexp_N_hlth	 	apdxsev1_c ;
		rename pre1_sev_banking 			apdxsev1_bank ;
		rename pre1_sev_marriage 			apdxsev1_married ;
		rename pre1_sev_homeown				apdxsev1_homeown ;
		rename pre1_sev_ins_private 		apdxsev1_inspri ;
		rename pre1_sev_ins_public  		apdxsev1_inspub ;
		rename pre1_sev_anyins		 		apdxsev1_insany ;
		rename pre1_sev_fdstamp 		 	apdxsev1_Xfood ;
		rename pre1_sev_mean_tested 	 	apdxsev1_Xmeans ;
		rename pre1_sev_si_no_ss		 	apdxsev1_Xsi ;
		rename pre1_sev_cash_relative 	 	apdxsev1_cashrel ;
		rename pre1_sev_cash_nonrelative 	apdxsev1_cashnon ;
		
		
		/* Finer disability/health measures */
		tab level_disabled, m ;
		gen byte gp_dis1 = (level_disabled == -1 | level_disabled == 1) ;  /* Can do nothing | H limits work a lot */
		gen byte gp_dis2 = (level_disabled == 3) ;                         /* H limits work somewhat */
		gen byte gp_dis3 = (level_disabled == 5) ;                         /* H limits work just a little */
		gen byte gp_dis4 = (level_disabled == 7 | level_disabled == 7.5) ; /* H limits work not at all | No health condition that limits work */

		tab health_status, m ;
		forval j=1(1)5 { ;
			gen byte gp_hth`j' = (health_status == `j') ;
		} ;

		gen byte gp_dh1 = (level_disabled == -1 | level_disabled == 1 ) & health_status == 5 ;
		gen byte gp_dh2 = (level_disabled == -1 | level_disabled == 1 ) & health_status == 4 ;
		gen byte gp_dh3 = (level_disabled == 3 & (health_status == 4 | health_status == 5) ) ;
		gen byte gp_dh4 = ((level_disabled == -1 | level_disabled == 1 ) & health_status < 4 ) |
							(level_disabled == 3 & health_status == 3) ;
		gen byte gp_dh5 = (level_disabled == 3 & health_status < 3) | 
							 level_disabled == 5 ;
		gen byte gp_dh6 = (level_disabled == 7 | level_disabled == 7.5 ) & (health_status > 3 & health_status != .) ;
		gen byte gp_dh7 = (level_disabled == 7 | level_disabled == 7.5 ) & (health_status == 3) ;
		gen byte gp_dh8 = (level_disabled == 7 | level_disabled == 7.5 ) & (health_status == 1 | health_status == 2) ;

		summ gp_dis* gp_hth* gp_dh* ;
		foreach stub in dis hth dh { ;
			egen temp`stub' = rowtotal(gp_`stub'*) ;
			tab temp`stub', m ;
		} ;
		drop temp* ;
		
		gen temp_current_severe = flag_severe if year == 2016 ;
		bysort unique_id: egen current_severe = max(temp_current_`sev');
		gen temp_current_moderate = flag_moderate if year == 2016 ;
		bysort unique_id: egen current_moderate = max(temp_current_moderate);
		gen temp_current_anydis = flag_psid_disable if year == 2016 ;
		bysort unique_id: egen current_anydis = max(temp_current_anydis);
		gen temp_current_none = 1 -  flag_psid_disable if year == 2016 ;
		bysort unique_id: egen current_none = max(temp_current_none);
		summ current_* ;
		
			
		/* Main outcomes within L and M, controlling for health */
			reg main_c gp_l_di gp_m_di [w=family_weight] ;
			
		foreach var of varlist main_c main_bank main_married main_home main_z35 { ;
		
			/* L-DI vs L-NDI */
			xi: 
				reg `var' gp_l_di 
				if gp_l_ndi == 1 | gp_l_di == 1 [aw=family_weight] ;
			gen `var'_noc_l_b = _b[gp_l_di]   ;
			gen `var'_noc_l_se = _se[gp_l_di] ;
			gen star_`var'_noc_l = 2 * (normal(-abs(`var'_noc_l_b/`var'_noc_l_se))) ;
			gen sta_sign_`var'_noc_l = "*" if star_`var'_noc_l <= 0.1 & 
			star_`var'_noc_l > 0.05 ;
			replace sta_sign_`var'_noc_l = "**" if star_`var'_noc_l <= 0.05 & 
			star_`var'_noc_l > 0.01 ;
			replace sta_sign_`var'_noc_l = "***" if star_`var'_noc_l <= 0.01 ;
			
			xi: 
				reg `var' gp_l_di 
				head_age gp_dh* current_severe current_moderate current_anydis flag_sev_ever flag_moderate_ever flag_hfairpoor_ever flag_hpoor_ever	
				i.num_adl i.num_iadl i.health_status i.level_disabled diag_*
				if gp_l_ndi == 1 | gp_l_di == 1  [aw=family_weight] ;
			gen `var'_hc_l_b = _b[gp_l_di] 	 ;
			gen `var'_hc_l_se = _se[gp_l_di] ;		
			gen star_`var'_hc_l = 2 * (normal(-abs(`var'_hc_l_b/`var'_hc_l_se))) ;
			gen sta_sign_`var'_hc_l = "*" if star_`var'_hc_l <= 0.1 & 
			star_`var'_hc_l > 0.05 ;
			replace sta_sign_`var'_hc_l = "**" if star_`var'_hc_l <= 0.05 & 
			star_`var'_noc_l > 0.01 ;
			replace sta_sign_`var'_hc_l = "***" if star_`var'_hc_l <= 0.01 ;
			
			} ;

			
		foreach var of varlist main_c main_bank main_married main_home main_z35 { ;
			/* M-DI vs M-NDI */
			xi: 
				reg `var' gp_m_di 
				if gp_m_ndi == 1 | gp_m_di == 1 [aw=family_weight] ;
			gen `var'_noc_m_b = _b[gp_m_di]   ;
			gen `var'_noc_m_se = _se[gp_m_di] ;
			gen star_`var'_noc_m = 2 * (normal(-abs(`var'_noc_m_b/`var'_noc_m_se))) ;
			gen sta_sign_`var'_noc_m = "*" if star_`var'_noc_m <= 0.1 & 
			star_`var'_noc_m > 0.05 ;
			replace sta_sign_`var'_noc_m = "**" if star_`var'_noc_m <= 0.05 & 
			star_`var'_noc_m > 0.01 ;
			replace sta_sign_`var'_noc_m = "***" if star_`var'_noc_m <= 0.01 ;
			
			xi: 
				reg `var' gp_m_di 
				head_age gp_dh* current_severe current_moderate current_anydis flag_sev_ever flag_moderate_ever flag_hfairpoor_ever flag_hpoor_ever
				i.num_adl i.num_iadl i.health_status i.level_disabled diag_*
				if gp_m_ndi == 1 | gp_m_di == 1  [aw=family_weight] ;
			gen `var'_hc_m_b = _b[gp_m_di]	 ;
			gen `var'_hc_m_se = _se[gp_m_di] ;	
			gen star_`var'_hc_m = 2 * (normal(-abs(`var'_hc_m_b/`var'_hc_m_se))) ;
			gen sta_sign_`var'_hc_m = "*" if star_`var'_hc_m <= 0.1 & 
			star_`var'_hc_m > 0.05 ;
			replace sta_sign_`var'_hc_m = "**" if star_`var'_hc_m <= 0.05 & 
			star_`var'_noc_m > 0.01 ;
			replace sta_sign_`var'_hc_m = "***" if star_`var'_hc_m <= 0.0 ;			
			
			} ;


keep *_b *_se star_* sta_sign_* ; 
keep in 1 ;

 
/* Exporting results to table */

putexcel set "`output'/tabF1.xls", sheet(results) replace ;

putexcel B1 = "Within-L difference (Fact 2)" ;
putexcel F1 = "Within-M difference (Fact 3)" ;

putexcel B2 = "No controls" ;
putexcel D2 = "Health controls" ;
putexcel F2 = "No controls" ;
putexcel H2 = "Health controls" ;

putexcel A3 = "Consumption" ;
putexcel B3 = main_c_noc_l_b ;
putexcel B4 = main_c_noc_l_se ;
putexcel C3 = sta_sign_main_c_noc_l ;
putexcel D3 = main_c_hc_l_b ;
putexcel D4 = main_c_hc_l_se ;
putexcel E3 = sta_sign_main_c_hc_l ;
putexcel F3 = main_c_noc_m_b ;
putexcel F4 = main_c_noc_m_se ; 
putexcel G3 = sta_sign_main_c_noc_m ;
putexcel H3 = main_c_hc_m_b ;
putexcel H4 = main_c_hc_m_se ;
putexcel I3 = sta_sign_main_c_hc_m ;

putexcel A5 = "Married" ;
putexcel B5 = main_married_noc_l_b ;
putexcel B6 = main_married_noc_l_se ;
putexcel C5 = sta_sign_main_married_noc_l ;
putexcel D5 = main_married_hc_l_b ;
putexcel D6 = main_married_hc_l_se ;
putexcel E5 = sta_sign_main_married_hc_l ;
putexcel F5 = main_married_noc_m_b ;
putexcel F6 = main_married_noc_m_se ; 
putexcel G5 = sta_sign_main_married_noc_m ;
putexcel H5 = main_married_hc_m_b ;
putexcel H6 = main_married_hc_m_se ;
putexcel I5 = sta_sign_main_married_hc_m ;

putexcel A7 = "Homeownership" ;
putexcel B7 = main_home_noc_l_b ;
putexcel B8 = main_home_noc_l_se ;
putexcel C7 = sta_sign_main_home_noc_l ;
putexcel D7 = main_home_hc_l_b ;
putexcel D8 = main_home_hc_l_se ;
putexcel E7 = sta_sign_main_home_hc_l ;
putexcel F7 = main_home_noc_m_b ;
putexcel F8 = main_home_noc_m_se ; 
putexcel G7 = sta_sign_main_home_noc_m ;
putexcel H7 = main_home_hc_m_b ;
putexcel H8 = main_home_hc_m_se ;
putexcel I7 = sta_sign_main_home_hc_m ;
	 
putexcel A9 = "Banking relationship" ;
putexcel B9 = main_bank_noc_l_b ;
putexcel B10 = main_bank_noc_l_se ;
putexcel C9 = sta_sign_main_bank_noc_l ;
putexcel D9 = main_bank_hc_l_b ;
putexcel D10 = main_bank_hc_l_se ;
putexcel E9 = sta_sign_main_bank_hc_l ;
putexcel F9 = main_bank_noc_m_b ;
putexcel F10 = main_bank_noc_m_se ; 
putexcel G9 = sta_sign_main_bank_noc_m ;
putexcel H9 = main_bank_hc_m_b ;
putexcel H10 = main_bank_hc_m_se ;       
putexcel I9 = sta_sign_main_bank_hc_m ;

putexcel A11 = "Age-35 earnings" ;
putexcel B11 = main_z35_noc_l_b ;
putexcel B12 = main_z35_noc_l_se ;
putexcel C11 = sta_sign_main_z35_noc_l ;
putexcel D11 = main_z35_hc_l_b ;
putexcel D12 = main_z35_hc_l_se ;
putexcel E11 = sta_sign_main_z35_hc_l ;
putexcel F11 = main_z35_noc_m_b ;
putexcel F12 = main_z35_noc_m_se ; 
putexcel G11 = sta_sign_main_z35_noc_m ;
putexcel H11 = main_z35_hc_m_b ;
putexcel H12 = main_z35_hc_m_se ; 
putexcel I11 = sta_sign_main_z35_hc_m ;

putexcel A14 = "Head age" ;
putexcel D14 = "X" ;
putexcel H14 = "X" ;

putexcel A15 = "Diagnosis" ;
putexcel D15 = "X" ;
putexcel H15 = "X" ;

putexcel A16 = "Self-reported health (prior)" ;
putexcel D16 = "X" ;
putexcel H16 = "X" ;       

putexcel A17 = "Self-reported health (current)" ;
putexcel D17 = "X" ;
putexcel H17 = "X" ;   		 

putexcel A18 = "ADLs/IADLs" ;
putexcel D18 = "X" ;
putexcel H18 = "X" ;   	
