version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause off
#delim;


local data "$results";
local log "";
local do "";

/* Figure G10: PSID: Distressed move and divorce by DI and health status */

foreach z in dissi{;
	foreach sev in severe {;	
		use "`data'/psid_figure_`z'.dta", clear;
		
/* ****************************************** */
/* *** PREPARING VARIABLES TO BE EXPORTED *** */
/* ****************************************** */

		gen group = "";

		/* the first receipt at age group and severe */
		replace group = "rec_moresevere_2534" if gp_rec_pre35_`sev' == 1; 
		replace group = "rec_moresevere_3544" if gp_rec_3544_`sev' == 1;
		replace group = "rec_moresevere_4554" if gp_rec_4554_`sev' == 1;
		replace group = "rec_moresevere_5565" if gp_rec_5565_`sev' == 1;
					
		/* the first receipt at age group and non-severe */
		replace group = "rec_lesssevere_2534" if gp_rec_pre35_N`sev' == 1;
		replace group = "rec_lesssevere_3544" if gp_rec_3544_N`sev' == 1;
		replace group = "rec_lesssevere_4554" if gp_rec_4554_N`sev' == 1;
		replace group = "rec_lesssevere_5565" if gp_rec_5565_N`sev' == 1;
					
		preserve ;
					
			drop if group == "" ;
			duplicates drop unique_id, force ;
					
			tempfile rec_sev_age;
			save `rec_sev_age';
					
		restore;

		preserve;

			drop if group == "";
			replace group = "rec_2534" if group == "rec_moresevere_2534" | group == "rec_lesssevere_2534"; 
			replace group = "rec_3544" if group == "rec_moresevere_3544" | group == "rec_lesssevere_3544"; 
			replace group = "rec_4554" if group == "rec_moresevere_4554" | group == "rec_lesssevere_4554"; 
			replace group = "rec_5565" if group == "rec_moresevere_5565" | group == "rec_lesssevere_5565";

			duplicates drop unique_id, force ;
			tempfile rec_age;
			save `rec_age';
					
		restore;
			
		preserve;
			/* only keep those who never receive DI */
			keep if flag_di_rec_ever == 0;
			drop group;
					
			/* all non-recipients */	
			gen group = "";
			replace group = "nonrec_moresevere" if `sev' == 1;
			replace group = "nonrec_lesssevere" if `sev' == 0;
			drop if group == "";
			replace group = "nonrec_all";
					
			/* since all values are copied to all observations, only keep one observation */
			duplicates drop unique_id, force ;	
			tempfile nonrec_all;
			save `nonrec_all';
		restore;
						
		preserve;		
			/* only keep those who never receive DI */
			keep if flag_di_rec_ever == 0;
			drop group;
					
			/* all non-recipients */
					
			gen group = "";
			replace group = "nonrec_moresevere" if `sev' == 1;
			replace group = "nonrec_lesssevere" if `sev' == 0;
			drop if group == "";
					
			/* since all values are copied to all observations, only keep one observation */

			duplicates drop unique_id, force ;
			tempfile nonrec_sev;
			save `nonrec_sev';
		restore;
	
/* ********************** */
/* *** EXPORTING DATA *** */
/* ********************** */

		clear;
					
		append using `rec_age';
		append using `rec_sev_age';									
		append using `nonrec_all';
		append using `nonrec_sev';
					
		/* the number of observations */
					
		foreach var in  marriage_pre0 broad_moving_pre0 {;					
			foreach age in 2534 3544 4554 5565{;
							
				gen num_`var'_`age' = . ;
								
				foreach age2 in 2534 3544 4554 5565{;
					sum shock_`var'_`age' if group == "rec_`age2'", det ;
					local `var'_`age'_`age2' r(N);
					replace num_`var'_`age' = ``var'_`age'_`age2'' if group == "rec_`age2'";
									
					foreach gp in moresevere lesssevere{;
						sum shock_`var'_`age' if group == "rec_`gp'_`age2'", det ;
						local `var'_`age'_`age2' r(N) ;
						replace num_`var'_`age' = ``var'_`age'_`age2'' if group == "rec_`gp'_`age2'" ;
					};
				};
												
				foreach gp in moresevere lesssevere all{;
					sum shock_`var'_`age' if group == "nonrec_`gp'", det ;
					local `var'_`age' r(N) ;
					replace num_`var'_`age' = ``var'_`age'' if group == "nonrec_`gp'" ;
				};
			};
		};
					
		preserve ;
				
			collapse (count) unique_id (mean) 
				shock_marriage_pre0_2534 shock_marriage_pre0_3544 shock_marriage_pre0_4554 shock_marriage_pre0_5565
				num_marriage_pre0_2534 num_marriage_pre0_3544 num_marriage_pre0_4554 num_marriage_pre0_5565
				shock_broad_moving_pre0_2534 shock_broad_moving_pre0_3544 shock_broad_moving_pre0_4554 shock_broad_moving_pre0_5565 
				num_broad_moving_pre0_2534 num_broad_moving_pre0_3544 num_broad_moving_pre0_4554 num_broad_moving_pre0_5565 
				[aw=family_weight], by(group);
					
			export delimited using "`data'/figG10.csv", replace;
				
		restore;
		
	};
};
