version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause off
#delim;


local data "$results";
local log "";
local do "";

/* Figure G1: PSID: College or above */

foreach var in  dissi{;
	foreach sev in severe {;
		use "`data'/psid_figure_`var'.dta", clear;

/* ****************************************** */
/* *** PREPARING VARIABLES TO BE EXPORTED *** */
/* ****************************************** */

		replace educ_hsgrad_head = 1 if educ_some_college_head == 1;

		/* DI group */	
		preserve;
			keep if flag_di_rec == 1 & year == 2016;
					
			gen group = "Recipients, more-severe (M-DI)" if flag_`sev' == 1;
			replace group = "Recipients, less-severe (L-DI)" if flag_`sev' == 0;
					
			tempfile rec_sev_current;
			save `rec_sev_current';			
		restore;
				
		/* NDI group */		
		preserve;
			keep if flag_di_rec == 0 & year == 2016;
			gen group = ""; 
					
			replace group = "Non-recipients, more-severe (M-NDI)" if flag_`sev' == 1 ;
			replace group = "Non-recipients, less-severe (L-NDI)" if flag_`sev' == 0;
					
			tab group, m ;
					
			drop if group == "" ;
					
			tempfile nonrec_sev_current;
			save `nonrec_sev_current';			
		restore;

/* ********************** */
/* *** EXPORTING DATA *** */
/* ********************** */

		preserve;	
			clear;
			
			append using `rec_sev_current';
			append using `nonrec_sev_current';

			drop if group == "" ;
					
			collapse (count) unique_id (mean) 
				educ_college_head 
				[aw=family_weight], by(group);
						
			export delimited using "`data'/figG1.csv", replace;
		restore;
	};
};

