rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages if do not have them

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

# Read Excel file
df1 <- read.csv('./temp/figG3.csv')
df12.base <- melt(df1, id = 'group')

df12.base$group <- as.character(df12.base$group)

pre4_bar_shock <- subset(df12.base, grepl("^pre4", df12.base$variable))

pre4_bar_shock_broad <- subset(pre4_bar_shock, grepl("pre4_job_shock$", pre4_bar_shock$variable)|
                                               grepl("pre4_move_broad_shock", pre4_bar_shock$variable)|
                                               grepl("pre4_marriage_shock", pre4_bar_shock$variable))

pre4_bar_shock_broad$variable <- factor(pre4_bar_shock_broad$variable, 
                                        levels = c('pre4_job_shock', 'pre4_move_broad_shock', 'pre4_marriage_shock'),
                                        labels=c('Job loss', 'Distressed move', 'Divorce'))

final <- subset(pre4_bar_shock_broad, grepl("severe", pre4_bar_shock_broad$group))

final$num[final$group == "rec_lesssevere_current"] <- 1/3
final$num[final$group == "rec_moresevere_current"] <- 5/6

# Draft Figure
(draft <- ggplot(final) + geom_line(aes(x=num, y=value, color = variable), linetype = "dotted", size = 0.7) 
  + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable)) 
  + geom_vline(xintercept = 2/3, linetype="dashed") 
  + coord_cartesian(xlim = c(0,1), ylim = c(0, 0.5), clip="off") + scale_y_continuous(name ="Fraction with event in 4 years before DI receipt", expand = c(0, 0))
  + scale_size_manual(values=c(4,4,4)) 
  + scale_color_manual(values=c("gray", "gray", "gray", "blue", "deeppink4"), guide = FALSE) 
)

# Final Figure
(final <- draft + theme_classic() 
  + theme(legend.title = element_blank(), 
          legend.position = "none",
          plot.title = element_text(hjust = 0.5, size=12),
          axis.title.x=element_blank(),
          axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
  + annotate("text", c(1/3, 5/6), size = 4, y =  -0.015, label = c("Less-severe (L)", "More-severe (M)"))
  + annotate("text", x = c(1, 0.95, 1), size = 3, y = c(0.1, 0.3, 0.45), label = c("Divorce", "Job loss", "Distressed move"))
  + annotate("text", x = c(0.5, 0.71), size = 3, y = 0.02, label = c("L-DI", "M-DI"))
  + geom_segment(x = 0.474 , y = 0.02, xend = 0.35, yend = 0.048,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))
  + geom_segment(x = 0.74 , y = 0.02, xend = 0.817, yend = 0.055,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed")) 
  + geom_segment(x = 0.96 , y = 0.1, xend = 0.849, yend = 0.062,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))   
  + geom_segment(x = 0.907 , y = 0.3, xend = 0.845, yend = 0.225,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))   
  + geom_segment(x = 0.913 , y = 0.45, xend = 0.845, yend = 0.4,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))    
)

# Export the figure
ggsave(paste0(figure, 'figG3.png'), height = 4, width = 6)








