rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages('reshape2')
#install.packages('gridExtra')
#install.packages('gtable')
#install.packages('grid')

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(gridExtra)
library(gtable)
library(grid)


# different length of lines that are inserted in figures
# loong.line <- data.frame(x=c(2.5, 4.5, 6.5, 8.5), y=c(.5, .5, .5,.5), xend=c(2.5,4.5, 6.5, 8.5), yend=c(20.5, 20.5, 20.5,20.5))
# long.line <- data.frame(x=c(2.5, 4.5, 6.5, 8.5), y=c(.5, .5, .5,.5), xend=c(2.5,4.5, 6.5, 8.5), yend=c(16.5, 16.5, 16.5,16.5))
# middle.line <- data.frame(x=c(2.5, 4.5, 6.5, 8.5), y=c(.5, .5, .5,.5), xend=c(2.5,4.5, 6.5, 8.5), yend=c(8.5, 8.5, 8.5,8.5))
short.line <- data.frame(x=c(2.5, 4.5, 6.5, 8.5), y=c(.5, .5, .5,.5), xend=c(2.5,4.5, 6.5, 8.5), yend=c(4.5, 4.5, 4.5,4.5))

str_eval=function(x) {return(eval(parse(text=x)))}

y_pre0_job_hd <- "Head loses job at age..."
y_pre0_job_sp <- "Spouse loses job at age..."
title_pre0_job_hd <- "PSID: Head job loss"
title_pre0_job_sp <- "PSID: Spouse job loss"

# used for legend below heatmaps

df <- data.frame(
  x = 1:10,
  y = 1:10)

( plot <- ggplot(df, aes(x, y))
  + geom_point(data=df, size = 4, aes(x=x, y=y, shape='Insufficient sample'), fill='white') 
  + scale_shape_manual(values = 23, labels=c('Insufficient sample'))
  + theme(legend.title = element_blank(), legend.background = element_blank(),legend.key = element_rect(fill = "white"))
)   

leg1 <- gtable_filter(ggplot_gtable(ggplot_build(plot)), "guide-box") 

################################################################################################################################################

for (var in c("pre0_job_hd", "pre0_job_sp")) {

    # Read and clean dataset 
    
    df1 <- read.csv('./temp/figG9.csv')
    df1.m1 <- melt(df1, id = "group")
    
      # group only by age 
      
      attach(df1.m1)
      (df1.new <- df1.m1[which(group == 'rec_2534' | group == 'rec_4554' | group == 'rec_5565'
                               |group == 'rec_3544'|group == 'nonrec_all'),]) 
      detach(df1.m1)
      
      df1.new$group <- as.character(df1.new$group)
      df1.new$group[df1.new$group == 'rec_2534'] <- 'DI, < 35'
      df1.new$group[df1.new$group == 'rec_3544'] <- 'DI, 35 - 44'
      df1.new$group[df1.new$group == 'rec_4554'] <- 'DI, 45 - 54'
      df1.new$group[df1.new$group == 'rec_5565'] <- 'DI, 55 - 64'
      df1.new$group[df1.new$group == 'nonrec_all'] <- 'NDI'
      
      # group by age and severity
      
      attach(df1.m1)
      (df1.newsevere <- df1.m1[which(group == 'rec_lesssevere_2534' | group == 'rec_lesssevere_4554' | 
                                       group == 'rec_lesssevere_5565'|group == 'rec_lesssevere_3544'|
                                       group == 'rec_moresevere_2534'  |group == 'rec_moresevere_3544' |
                                       group == 'rec_moresevere_4554'|group == 'rec_moresevere_5565'|
                                       group == 'nonrec_lesssevere' | group == 'nonrec_moresevere'),])
      detach(df1.m1)
    
      
        eval(parse(text = paste0("(df1.severe_",var," <- subset(df1.newsevere, grepl('shock_",var,"_2534', df1.newsevere$variable) 
                                 | grepl('shock_",var,"_3544', df1.newsevere$variable) | grepl('shock_",var,"_4554', df1.newsevere$variable) 
                                 | grepl('shock_",var,"_5565', df1.newsevere$variable))) ")))
        
        
        # generate dummy group
        
        eval(parse(text = paste0("df1.severe_", var, "$age[df1.severe_", var, "$variable == 'shock_", var, "_2534'] <- '2534'")))
        eval(parse(text = paste0("df1.severe_", var, "$age[df1.severe_", var, "$variable == 'shock_", var, "_3544'] <- '3544'")))
        eval(parse(text = paste0("df1.severe_", var, "$age[df1.severe_", var, "$variable == 'shock_", var, "_4554'] <- '4554'")))
        eval(parse(text = paste0("df1.severe_", var, "$age[df1.severe_", var, "$variable == 'shock_", var, "_5565'] <- '5565'")))
        
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_moresevere_2534'] <- '2534'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_lesssevere_2534'] <- '2534'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_moresevere_3544'] <- '3544'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_lesssevere_3544'] <- '3544'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_moresevere_4554'] <- '4554'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_lesssevere_4554'] <- '4554'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_moresevere_5565'] <- '5565'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupage[df1.severe_", var, "$group == 'rec_lesssevere_5565'] <- '5565'")))
        
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_moresevere_2534'] <- 'moresevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_lesssevere_2534'] <- 'lesssevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_moresevere_3544'] <- 'moresevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_lesssevere_3544'] <- 'lesssevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_moresevere_4554'] <- 'moresevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_lesssevere_4554'] <- 'lesssevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_moresevere_5565'] <- 'moresevere'")))
        eval(parse(text = paste0("df1.severe_", var, "$groupsev[df1.severe_", var, "$group == 'rec_lesssevere_5565'] <- 'lesssevere'")))
        

        
        eval(parse(text = paste0("df1.severe_",var,"$group <- as.character(df1.severe_",var,"$group) ")))
      
        eval(parse(text = paste0(" (df1.severe_",var,"$group <- factor(df1.severe_",var,"$group, 
                            levels = c('rec_moresevere_2534', 'rec_lesssevere_2534', 'rec_moresevere_3544', 'rec_lesssevere_3544', 'rec_moresevere_4554', 
                                        'rec_lesssevere_4554', 'rec_moresevere_5565', 'rec_lesssevere_5565', 'nonrec_moresevere', 'nonrec_lesssevere'), 
                            labels = c('M-DI, <35', 'L-DI, <35', 'M-DI, 35-44', 'L-DI, 35-44', 'M-DI, 45-54', 
                                        'L-DI, 45-54', 'M-DI, 55-64','L-DI, 55-64', 'M-NDI', 'L-NDI'))) ")))
        
        eval(parse(text = paste0("(df1.severe_",var,"$variable <- factor(df1.severe_",var,"$variable, levels = 
                                  c('shock_",var,"_5565', 'shock_",var,"_4554', 'shock_",var,"_3544', 'shock_",var,"_2534'), 
                                labels = 
                                  c('55 - 64', '45 - 54', '35 - 44', '25 - 34'))) ")))
        
        
        # Putting the value as missing if the sample size is below 50
        for (age in c('2534', '3544', '4554', '5565')) {
          for (agegroup in c('2534', '3544', '4554', '5565')) {
            for (sev in c('moresevere', 'lesssevere')) {
            
              eval(parse(text = paste0("i <- df1.m1$value[df1.m1$group == 'rec_", sev, "_", age, "' & df1.m1$variable == 'num_", var, "_", agegroup, "']")))
              
              if (i < 50) { 
                
                eval(parse(text = paste0("df1.severe_", var, "$value[df1.severe_", var, "$groupage == '", age, "' 
                                         & df1.severe_", var, "$age == '", agegroup, "' 
                                         & df1.severe_", var, "$groupsev == '", sev, "'] <- NA")))
              }
            }
          }
        }
        
        eval(parse(text = paste0("df1.severe_", var, "$na <- (is.na(df1.severe_", var, "$value))")))
        eval(parse(text = paste0("df1.severe_",var,".frames = df1.severe_", var, "[df1.severe_", var, "$na, c('group', 'variable')]")))
        
        # Export for paper
        
        eval(parse(text = paste0("(gph_severe_",var, "<- ggplot(df1.severe_",var,",aes(as.factor(group),as.factor(variable)))+geom_tile(aes(fill=value))
          +scale_fill_gradient(low='white',high='deeppink4') +scale_x_discrete(expand = c(0, 0), position = 'top')
          + labs(x = '',y = '') + scale_y_discrete(expand = c(0, 0)) +  labs(x = 'First DI receipt at age...', y = eval(parse(text = paste0('y_',var)))) 
          + theme(legend.title = element_blank(), axis.ticks = element_blank(), axis.text.x = element_text(size = 8, angle = 30, hjust = 0), 
            axis.title=element_text(size=10), plot.title = element_text(hjust = 0.5, size=12, vjust = 5), 
            plot.margin = margin(20, 20, 20, 20)) 
            
          + geom_point(data=df1.severe_", var, ".frames, shape = 23, size = 5, aes(x=group, y=variable, shape='Insufficient sample'), fill='white') 
          + annotation_custom(grob = leg1, xmin = 4.5, xmax = 6, ymin = -2, ymax = 2)
          
          + coord_equal()
          + geom_segment(data=short.line, aes(x,y,xend=xend, yend=yend), size=0.3, inherit.aes=F)) ")))
        
        eval(parse(text = paste0("ggsave(paste0(figure, 'figG9_", var, ".png'), 
                                 height = 3, width = 6)")))
      
}



