version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause off
#delim;


local data "$results";
local log "";
local do "";

/* Figure J10: Figure 2a for alternative definitions (SSDI only) */

foreach pg in di{;
	foreach severity in severe2 severe_mhdp { ;
		use "`data'/psid_figure_`pg'.dta", clear;
		
/* **************************************** */
/* *** CALCULATE INDIVIDUAL CONSUMPTION *** */
/* **************************************** */
				
		replace hhexp_N_hlth = hhexp_N_hlth/sqrt(num_of_family) ;
		
/* *************************************** */
/* *** PREPARING GROUPS TO BE EXPORTED *** */
/* *************************************** */
			
		/* S and NS */
		
		preserve ;
				
			keep if year == 2016 ;
					
			gen group = "M" if flag_`severity' == 1 ;
			replace group = "L" if flag_`severity' == 0 ;
					
			drop if group == "" ;
				
			tempfile sev_current ;
			save `sev_current' ;
				
		restore ;
				
		/* L-NDI, M-NDI, L-DI, M-DI */
				
		preserve;
			
			keep if flag_`severity' == 1 & year == 2016;
								
			gen group = "M-DI" if flag_di_rec == 1 ;
			replace group = "M-NDI" if flag_di_rec == 0 ;
			drop if group == "" ;

			tempfile sev;
			save `sev' ;
					
		restore;
				
		preserve;
			
			keep if flag_`severity' == 0 & year == 2016;
								
			gen group = "L-DI" if flag_di_rec == 1 ;
			replace group = "L-NDI" if flag_di_rec == 0 ;
			drop if group == "" ;
				
			tempfile nonsev;
			save `nonsev' ;
					
		restore;
			
/* ********************** */
/* *** EXPORTING DATA *** */
/* ********************** */
			
		/* M and L */
		
		preserve;
				
			clear;
								
			append using `sev_current' ;
					
			keep group family_weight unique_id hhexp_N_hlth ;
			
			/* 10 and 90 percentile of consumpution */
			
			sum hhexp_N_hlth if group == "M", det ; 
			local hhexp_N_hlth_M_10 r(p10) ;
			local hhexp_N_hlth_M_90 r(p90) ;

			gen hhexp_N_hlth_10 = `hhexp_N_hlth_M_10' if group == "M";
			gen hhexp_N_hlth_90 = `hhexp_N_hlth_M_90' if group == "M";
				
			sum hhexp_N_hlth if group == "L", det ;
			local hhexp_N_hlth_L_10 r(p10) ;
			local hhexp_N_hlth_L_90 r(p90) ;

			replace hhexp_N_hlth_10 = `hhexp_N_hlth_L_10' if group == "L";
			replace hhexp_N_hlth_90 = `hhexp_N_hlth_L_90' if group == "L";
					
			collapse (count) unique_id (mean) 
					hhexp_N_hlth*
					[aw=family_weight], by(group);
							
			export delimited using "`data'/figJ10_dist_consumption_ML_`pg'_`severity'.csv", replace;	

		restore;
				
		/* All groups */
		
		preserve;
				
			clear;
								
			append using `sev' ;
			append using `nonsev' ;
					
			keep group family_weight unique_id hhexp_N_hlth ;
			
			/* Mean consumption for each group */
			
			collapse (count) unique_id (mean) 
						hhexp_N_hlth*
						[aw=family_weight], by(group);
								
			export delimited using "`data'/figJ10_dist_consumption_all_`pg'_`severity'.csv", replace;
				
		restore;
				
	}; /* severity end */
}; /* pg end */

			
