rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages if do not have them

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

for (x in c("severe2", "severe_mhdp")){
  
  # Figure 2a
  
  # Read two Excel files
  eval(parse(text = paste0("df1 <- read.csv('./temp/figJ10_dist_consumption_ML_di_", x, ".csv')")))  
  eval(parse(text = paste0("df33 <- read.csv('./temp/figJ10_dist_consumption_all_di_", x, ".csv')")))  
  
  # Define the horizontal position for each group
  df1$num[df1$group == "L"] <- 1/3
  df1$num[df1$group == "M"] <- 5/6
  df33$num[df33$group == "L-NDI"] <- 1/3-0.01 
  df33$num[df33$group == "L-DI"] <- 1/3-0.01
  df33$num[df33$group == "M-NDI"] <- 5/6+0.01
  df33$num[df33$group == "M-DI"] <- 5/6 +0.01
  
  # Add variables to df33 so that df33 and df1 can be appended
  df33$hhexp_N_hlth_10 <- NA
  df33$hhexp_N_hlth_90 <- NA
  
  # Append two data sets
  all <- do.call(rbind, list(df1, df33))
  
  # Divide by 1000 dollars
  all$hhexp_N_hlth <- all$hhexp_N_hlth/1000
  all$hhexp_N_hlth_10 <- all$hhexp_N_hlth_10/1000
  all$hhexp_N_hlth_90 <- all$hhexp_N_hlth_90/1000
  
  # Plot the figure
  ( p <- ggplot(all, aes(x=num, y = hhexp_N_hlth, color = group, shape = group, size = group)) 
    + geom_errorbar(aes(ymin=hhexp_N_hlth_10, ymax=hhexp_N_hlth_90), width=.05) + theme_classic() 
    + geom_point(size=3) 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 45), clip="off") 
    + scale_shape_manual(values = c(16,15,15,16,15,15))
    + scale_size_manual(values = c(0.5,0.5,0.5,0.5,0.5,0.5))
    + scale_y_continuous(name ="Annual consumption in thousands (excluding health care)", expand = c(0, 0))
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + scale_color_manual(values=c('deepskyblue2', 'blue', 'lightblue', 'maroon1', 'deeppink4', 'pink'), guide = FALSE)
    + theme(axis.title.x=element_blank(),
            plot.title = element_text(hjust = 0.5, size=12),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            legend.position =  'none',
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -1, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", c(1/3, 5/6), size = 3, y =  c(44, 44), label = c("90-10 L interval", "90-10 M interval"))
    + annotate('text', x = c(0.17,0.17,1,1), size = 3, y = c(30, 15, 25, 12.5), label = c('L-NDI', 'L-DI', 'M-NDI', 'M-DI'))
    + annotate("text", c(0.50, 0.75), size = 3, y =  c(25, 20), label = c("Mean (L)", "Mean (M)"))
  )
  
  eval(parse(text = paste0("ggsave(paste0(figure, 'figJ10_J1a_", x, ".png'), height = 4, width = 6)")))
  
  
  # Figure C4
  
  # Read the Excel file
  eval(parse(text = paste0("df2 <- read.csv('./temp/figJ10_bar_shock_current_di_", x, "_w.csv')")))  
  
  df12.base <- melt(df2, id = 'group')
  
  df12.base$group <- as.character(df12.base$group)
  
  pre4_bar_shock <- subset(df12.base, grepl("^pre4", df12.base$variable))
  
  
  pre4_bar_shock_broad <- subset(pre4_bar_shock, grepl("pre4_job_shock$", pre4_bar_shock$variable)|grepl("pre4_move_broad_shock", pre4_bar_shock$variable)|
                                   grepl("pre4_marriage_shock", pre4_bar_shock$variable))
  
  pre4_bar_shock_broad$variable <- factor(pre4_bar_shock_broad$variable, levels = c('pre4_job_shock', 'pre4_move_broad_shock', 'pre4_marriage_shock'),
                                          labels=c('Job loss', 'Distressed move', 'Divorce'))
  
  
  
  final <- subset(pre4_bar_shock_broad, grepl("severe", pre4_bar_shock_broad$group))
  
  final$num[final$group == "rec_lesssevere_current"] <- 1/3
  final$num[final$group == "rec_moresevere_current"] <- 5/6
  
  # Draft Figure
  (sample.new8 <- ggplot(final) + geom_line(aes(x=num, y=value, color = variable), linetype = "dotted", size = 0.7) 
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 0.5), clip="off") + scale_y_continuous(name ="Fraction with event in 4 years before DI receipt", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4)) 
    + scale_color_manual(values=c("gray", "gray", "gray", "blue", "deeppink4"), guide = FALSE) 
  )
  
  # Final Figure
  (sample.new9 <- sample.new8 + theme_classic() 
    + theme(legend.title = element_blank(), 
            legend.position = "none",
            plot.title = element_text(hjust = 0.5, size=12),
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.015, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(1, 0.95, 1), size = 3, y = c(0.1, 0.3, 0.45), label = c("Divorce", "Job loss", "Distressed move"))
    + annotate("text", x = c(0.5, 0.71), size = 3, y = 0.02, label = c("L-DI", "M-DI"))
    
  )
  
  # Export the figure
  eval(parse(text = paste0("ggsave(paste0(figure, 'figJ10_J6_", x, ".png'), height = 4, width = 6)")))
  
  
  #Figure 2c 
  
  # Read the Excel file
  eval(parse(text = paste0("df3 <- read.csv('./temp/figJ10_bar_new_outside_di_", x, "_w.csv')")))  
  
  # Clean the data set
  df1.m2 <- melt(df3, id = "group")
  
  (outside <- subset(df1.m2, grepl("flag_married", df1.m2$variable) | grepl("flag_banking", df1.m2$variable) 
                     | grepl("flag_home_own$", df1.m2$variable)))
  
  outside$group <- factor(outside$group, 
                          levels = c('Non-recipients, less-severe (L-NDI)', 'Non-recipients, more-severe (M-NDI)',  
                                     'Recipients, less-severe (L-DI)', 'Recipients, more-severe (M-DI)'))
  
  outside$variable <- factor(outside$variable, levels = c('flag_married', 'flag_banking', 'flag_home_own'),
                             labels=c('Married', 'Banking relationship', 'Own home'))
  
  # Define the position of each group
  outside$num[outside$group == 'Non-recipients, less-severe (L-NDI)'] <- 1/3
  outside$num[outside$group == 'Recipients, less-severe (L-DI)'] <- 1/3
  outside$num[outside$group == 'Non-recipients, more-severe (M-NDI)'] <- 5/6
  outside$num[outside$group == 'Recipients, more-severe (M-DI)'] <- 5/6
  
  # Determine the group
  outside$DI[outside$group == "Non-recipients, less-severe (L-NDI)"] <- 'NDI'   
  outside$DI[outside$group == "Recipients, less-severe (L-DI)"] <- 'DI'
  outside$DI[outside$group == "Non-recipients, more-severe (M-NDI)"] <- 'NDI'   
  outside$DI[outside$group == "Recipients, more-severe (M-DI)"] <- 'DI'   
  
  # Keep two DI groups: L-DI and M-DI
  (outside_2 <-subset(outside, grepl("Recipients", outside$group)))
  
  # Plot the figure 
  (temp.out_2 <- ggplot(outside_2) + geom_line(aes(x = num, y = value, color = interaction(variable, DI)), linetype = "dotted", size = 0.7)
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with resource", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) 
    + scale_color_manual(values=c("gray", "gray", "gray", 'blue', 'deeppink4'), guide = FALSE) 
    + scale_shape_manual(values=c(15,16,17), guide = FALSE) + scale_fill_manual(values = c( 'white', 'white'))
  )
  
  
  # Plot the figure with more options
  (out_2 <- temp.out_2 + theme_classic() 
    #+ ggtitle('PSID: Outside Resources')
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(7/12-0.05, 7/12, 7/12), size = 3, y = c(0.80, 0.55, 0.25), label = c("Banking relationship", "Own home", "Married"))
    + annotate("text", c(1/3, 5/6), size = 3, y = c(0.85, 0.85), label = c("L-DI", "M-DI"))
  )
  
  # Export the figure
  eval(parse(text = paste0("ggsave(paste0(figure, 'figJ10_J1c_", x, ".png'), height = 4, width = 6)")))
  
}



