rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

# Read The data set
df1 <- read.csv('./temp/figJ11.csv')
df1.m2 <- melt(df1, id = "group")

# Banking relationship, Own home, Marriage
(outside2 <- subset(df1.m2, grepl("marriage", df1.m2$variable)|grepl("homeown", df1.m2$variable)|grepl("banking", df1.m2$variable)))
outside2$num[outside2$group == "Recipients, less-severe (L-DI)"] <- 1/3
outside2$num[outside2$group == "Recipients, more-severe (M-DI)"] <- 5/6
  
# Draft Figure
(temp.out.app1 <- ggplot(outside2) + geom_line(aes(x = num, y = value, color = variable), linetype = "dotted", size = 0.7)
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with resource", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) + scale_color_manual(values=c("gray", "gray", "gray", "blue", "deeppink4"), guide = FALSE) 
    + scale_shape_manual(values=c(21,22,24), guide = FALSE) + scale_fill_manual(values = c("blue", 'deeppink4'))
)

# Final Figure
(out.app1 <- temp.out.app1 + theme_classic() 
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(0.95, 1, 1), size = 3, y = c(0.6, 0.4, 0.3), label = c("Banking relationship", "Own home", "Married"))
    + annotate("text", c(0.5, 0.71), size = 3, y = c(0.3, 0.3), label = c("L-DI", "M-DI"))
)
  
ggsave(paste0(figure, 'figJ11a.png'), height = 4, width = 6)
  
# Insurance
(insurance.app1 <- subset(df1.m2, grepl("pre1_app_anyins$", df1.m2$variable) | 
                                  grepl("pre1_app_ins_private", df1.m2$variable) | 
                                  grepl("pre1_app_ins_public", df1.m2$variable)))
insurance.app1$num[insurance.app1$group == 'Recipients, less-severe (L-DI)'] <- 1/3
insurance.app1$num[insurance.app1$group == 'Recipients, more-severe (M-DI)'] <- 5/6
  
# Draft Figure
(temp.insurance.app1 <- ggplot(insurance.app1) + geom_line(aes(x = num, y = value, color = variable), linetype = "dotted", size = 0.7)
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with insurance", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) + scale_color_manual(values=c("gray", "gray", "gray", "blue", "deeppink4"), guide = FALSE) 
    + scale_shape_manual(values=c(22,21,24), guide = FALSE) + scale_fill_manual(values = c("blue", 'deeppink4'))
)
  
# Main Figure
(insur.app1 <- temp.insurance.app1 + theme_classic() 
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(0.95, 0.95, 0.95), size = 3, y = c(0.9, 0.4, 0.6), 
               label = c("Any health insurance", "Public health insurance", "Private health insurance"))
    + annotate("text", c(0.5, 0.71), size = 3, y = c(0.15, 0.15), label = c("L-DI", "M-DI"))
    + geom_segment(x = 0.47 , y = 0.15, xend = 0.35, yend = 0.3,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))   
    + geom_segment(x = 0.74 , y = 0.15, xend = 0.82, yend = 0.3,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed")) 
    + geom_segment(x = 0.93 , y = 0.88, xend = 0.85, yend = 0.8,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.93 , y = 0.38, xend = 0.85, yend = 0.34,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))     
    + geom_segment(x = 0.93 , y = 0.58, xend = 0.85, yend = 0.55,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed")) 
)
  
ggsave(paste0(figure, 'figJ11b.png'), height = 4, width = 6)
  
  
# Transfers
fdstamp.app1 <- subset(df1.m2, grepl("pre1_app_fdstamp", df1.m2$variable)
                         |grepl("pre1_app_si_no_ss", df1.m2$variable))
fdstamp.app1$num[fdstamp.app1$group == "Recipients, less-severe (L-DI)"] <- 1/3
fdstamp.app1$num[fdstamp.app1$group == "Recipients, more-severe (M-DI)"] <- 5/6

# Draft Figure   
(temp.fdstamp.app1 <- ggplot(fdstamp.app1) + geom_line(aes(x = num, y = value, color = variable), linetype = "dotted", size = 0.7)
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with transfers", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) + scale_color_manual(values=c("gray", "gray", "blue", "deeppink4"), guide = FALSE) 
    + scale_shape_manual(values=c(22,21,24), guide = FALSE) + scale_fill_manual(values = c("blue", 'deeppink4'))
)
  
# Final Figure
(fdstamp.atapp1 <- temp.fdstamp.app1 + theme_classic() 
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(0.95, 0.95), size = 3, y = c(0.3, 0.1), label = c("Food stamps", "UI and WC"))
    + annotate("text", c(0.5, 0.71), size = 3, y = c(0.15, 0.15), label = c("L-DI", "M-DI"))
    + geom_segment(x = 0.47 , y = 0.15, xend = 0.35, yend = 0.19,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed")) 
    + geom_segment(x = 0.74 , y = 0.15, xend = 0.822, yend = 0.198,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed")) 
    + geom_segment(x = 0.875 , y = 0.3, xend = 0.85, yend = 0.36,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.885 , y = 0.1, xend = 0.85, yend = 0.205,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))     
)
  
ggsave(paste0(figure, 'figJ11c.png'), height = 4, width = 6)
  
# Cash assistance  
relative.app1 <- subset(df1.m2, grepl("pre1_cash_", df1.m2$variable))
relative.app1$num[relative.app1$group == "Recipients, less-severe (L-DI)"] <- 1/3
relative.app1$num[relative.app1$group == "Recipients, more-severe (M-DI)"] <- 5/6
  
# Draft Figure
(temp.relative.app1 <- ggplot(relative.app1) + geom_line(aes(x = num, y = value, color = variable), linetype = "dotted", size = 0.7)
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 0.3), clip="off") + scale_y_continuous(name ="Fraction with cash assistance", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) + scale_color_manual(values=c("gray", "gray", "blue", "deeppink4"), guide = FALSE) 
    + scale_shape_manual(values=c(22,21,24), guide = FALSE) + scale_fill_manual(values = c("blue", 'deeppink4'))
)
  
# Main Figure
(relative.app <- temp.relative.app1 + theme_classic() 
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.01, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(0.95, 0.95), size = 3, y = c(0.3, 0.1), label = c("Help from relatives", "Help from non-relatives"))
    + annotate("text", c(0.23, 0.71), size = 3, y = c(0.05, 0.05), label = c("L-DI", "M-DI"))
    + geom_segment(x = 0.26 , y = 0.05, xend = 0.316, yend = 0.065,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed")) 
    + geom_segment(x = 0.74 , y = 0.05, xend = 0.817, yend = 0.065,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))      
    + geom_segment(x = 0.93 , y = 0.094, xend = 0.85, yend = 0.07,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))   
    + geom_segment(x = 0.93 , y = 0.295, xend = 0.85, yend = 0.25,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))   
)
  
ggsave(paste0(figure, 'figJ11d.png'), height = 4, width = 6)
  
  
  