rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages if do not have them

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)


################################################################################################################################################

# Read two data sets
df1 <- read.csv('./temp/figJ1a_pt1.csv')  
df33 <- read.csv('./temp/figJ1a_pt2.csv')  

# Define the horizontal position for each group
df1$num[df1$group == "L"] <- 1/3
df1$num[df1$group == "M"] <- 5/6
df33$num[df33$group == "L-NDI"] <- 1/3-0.01 
df33$num[df33$group == "L-DI"] <- 1/3-0.01
df33$num[df33$group == "M-NDI"] <- 5/6+0.01
df33$num[df33$group == "M-DI"] <- 5/6 +0.01

# Add variables to df33 so that df33 and df1 can be appended
df33$hhexp_N_hlth_10 <- NA
df33$hhexp_N_hlth_90 <- NA

# Append two data sets
all <- do.call(rbind, list(df1, df33))

# Divide by 1000 dollars
all$hhexp_N_hlth <- all$hhexp_N_hlth/1000
all$hhexp_N_hlth_10 <- all$hhexp_N_hlth_10/1000
all$hhexp_N_hlth_90 <- all$hhexp_N_hlth_90/1000

# Plot the figure
( p <- ggplot(all, aes(x=num, y = hhexp_N_hlth, color = group, shape = group, size = group)) 
  #+ggtitle("PSID: Consumption (excluding health care)")
  + geom_errorbar(aes(ymin=hhexp_N_hlth_10, ymax=hhexp_N_hlth_90), width=.05) + theme_classic() 
  + geom_point(size=3) 
  + coord_cartesian(xlim = c(0,1), ylim = c(0, 45), clip="off") 
  + scale_shape_manual(values = c(16,15,15,16,15,15))
  + scale_size_manual(values = c(0.5,0.5,0.5,0.5,0.5,0.5))
  + scale_y_continuous(name ="Annual consumption in thousands (excluding health care)", expand = c(0, 0))
  + geom_vline(xintercept = 2/3, linetype="dashed") 
  + scale_color_manual(values=c('deepskyblue2', 'blue', 'lightblue', 'maroon1', 'deeppink4', 'pink'), guide = FALSE)
  + theme(axis.title.x=element_blank(),
          plot.title = element_text(hjust = 0.5, size=12),
          axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          legend.position =  'none',
          plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
  + annotate("text", c(1/3, 5/6), size = 4, y =  -1, label = c("Less-severe (L)", "More-severe (M)"))
  + annotate("text", c(1/3, 5/6), size = 3, y =  c(44, 44), label = c("90-10 L interval", "90-10 M interval"))
  + annotate('text', x = c(0.17,0.17,1,1), size = 3, y = c(30, 15, 25, 12.5), label = c('L-NDI', 'L-DI', 'M-NDI', 'M-DI'))
  + annotate("text", c(0.50, 0.75), size = 3, y =  c(25, 20), label = c("Mean (L)", "Mean (M)"))
)

# Export the figure
ggsave(paste0(figure, 'figJ1a.png'), height = 4, width = 6)





