rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

# Read the data set
df1 <- read.csv('./temp/figJ1c.csv')

# Clean the data set
df1.m2 <- melt(df1, id = "group")

(outside <- subset(df1.m2, grepl("flag_married", df1.m2$variable) | grepl("flag_banking", df1.m2$variable) 
                     | grepl("flag_home_own$", df1.m2$variable)))
  
outside$group <- factor(outside$group, 
                          levels = c('Non-recipients, less-severe (L-NDI)', 'Non-recipients, more-severe (M-NDI)',  
                                     'Recipients, less-severe (L-DI)', 'Recipients, more-severe (M-DI)'))
  
outside$variable <- factor(outside$variable, levels = c('flag_married', 'flag_banking', 'flag_home_own'),
                             labels=c('Married', 'Banking relationship', 'Own home'))

# Define the position of each group
outside$num[outside$group == 'Non-recipients, less-severe (L-NDI)'] <- 1/3
outside$num[outside$group == 'Recipients, less-severe (L-DI)'] <- 1/3
outside$num[outside$group == 'Non-recipients, more-severe (M-NDI)'] <- 5/6
outside$num[outside$group == 'Recipients, more-severe (M-DI)'] <- 5/6

# Determine the group
outside$DI[outside$group == "Non-recipients, less-severe (L-NDI)"] <- 'NDI'   
outside$DI[outside$group == "Recipients, less-severe (L-DI)"] <- 'DI'
outside$DI[outside$group == "Non-recipients, more-severe (M-NDI)"] <- 'NDI'   
outside$DI[outside$group == "Recipients, more-severe (M-DI)"] <- 'DI'   

# Keep two DI groups: L-DI and M-DI
(outside_2 <-subset(outside, grepl("Recipients", outside$group)))
  
# Plot the figure 
(temp.out_2 <- ggplot(outside_2) + geom_line(aes(x = num, y = value, color = interaction(variable, DI)), linetype = "dotted", size = 0.7)
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with resource", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) 
    + scale_color_manual(values=c("gray", "gray", "gray", 'blue', 'deeppink4'), guide = FALSE) 
    + scale_shape_manual(values=c(15,16,17), guide = FALSE) + scale_fill_manual(values = c( 'white', 'white'))
  )
  
  
# Plot the figure with more options
(out_2 <- temp.out_2 + theme_classic() 
    #+ ggtitle('PSID: Outside Resources')
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(7/12-0.05, 7/12, 7/12), size = 3, y = c(0.80, 0.55, 0.25), label = c("Banking relationship", "Own home", "Married"))
    + annotate("text", c(1/3, 5/6), size = 3, y = c(0.85, 0.85), label = c("L-DI", "M-DI"))
  )

# Export the figure  
ggsave(paste0(figure, 'figJ1c.png'), height = 4, width = 6)
  
  
 