version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause off
#delim;


local data "$results";
local log "";
local do "";

/* Figure J1d: PSID: Earnings at age 35 */

foreach z in di{;
	foreach sev in severe {;
		use "`data'/psid_figure_`z'.dta", clear;

/* ****************************************** */
/* *** PREPARING VARIABLES TO BE EXPORTED *** */
/* ****************************************** */

		gen temp_flag_2016_ever = (year == 2016) ;

		bysort unique_id: egen flag_2016_ever = max(temp_flag_2016_ever) ;

		tab flag_2016_ever ;

		drop if flag_2016_ever == 0 ;

		drop temp_flag_2016_ever ;


		gen temp_flag_di_pre35 = 1 if flag_di_rec_head == 1 & head_age <= 35 ;
		
		bysort unique_id: egen flag_di_pre35 = max(temp_flag_di_pre35) ;
			
		gen temp_inc_earn_head_pre35 = inc_earn_head if head_age == 35 & flag_di_pre35 == . ;
			
		bysort unique_id: egen inc_earn_head_pre35 = max(temp_inc_earn_head_pre35) ;

		keep if year == 2016 ;

		gen group = "M-DI" if flag_di_rec == 1 & flag_`sev' == 1 ;
		replace group = "M-NDI" if flag_di_rec == 0 & flag_`sev' == 1 ;
		replace group = "L-DI" if flag_di_rec == 1 & flag_`sev' == 0 ;
		replace group = "L-NDI" if flag_di_rec == 0 & flag_`sev' == 0 ;

		drop if group == "" ;

		gen num_earn_pre35 = . ;

		foreach gp in M-DI M-NDI L-DI L-NDI{;

			sum inc_earn_head_pre35 if group == "`gp'" ;
			local pre35 r(N) ;
			replace num_earn_pre35 = `pre35' if group == "`gp'" ;
				
		};
		
/* ********************** */
/* *** EXPORTING DATA *** */
/* ********************** */

		collapse (count) unique_id (mean) inc_earn_head_pre35 num_earn_pre35 
										  [aw=family_weight], by(group);
								
		export delimited using "`data'/figJ1d.csv", replace;

	};
};




