rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages('reshape2')
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

# Read the data set
df1 <- read.csv('./temp/figJ1d.csv')

# Clean the data set
df2 <- melt(df1, id = "group")

df2$num[df2$group == 'L-NDI'] <- 1/3
df2$num[df2$group == 'L-DI'] <- 1/3
df2$num[df2$group == 'M-NDI'] <- 5/6
df2$num[df2$group == 'M-DI'] <- 5/6

df2$DI[df2$group == 'L-NDI'] <- 'NDI'
df2$DI[df2$group == 'L-DI'] <- 'DI'
df2$DI[df2$group == 'M-NDI'] <- 'NDI'
df2$DI[df2$group == 'M-DI'] <- 'DI'

(pre35 <- subset(df2, grepl("inc_earn_head_pre35", df2$variable)))

# Divide by 1000 dollars
pre35$value <- pre35$value/1000

# Plot the figure
(temp.earn.pre35 <- ggplot(pre35) 
  + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
  + geom_vline(xintercept = 2/3, linetype="dashed") 
  + coord_cartesian(xlim = c(0,1), ylim = c(0, 65), clip="off") 
  + scale_y_continuous(name ="Earnings at age 35 (thousands $)", expand = c(0, 0))
  + scale_color_manual(values=c('blue', 'lightblue', "deeppink4", "pink"), guide = FALSE) 
  + scale_size_manual(values=c(4,4,4), guide = FALSE) 
)

# Plot the figure with more options
(earn.pre35 <- temp.earn.pre35 + theme_classic() 
  + theme(legend.title = element_blank(), 
          plot.title = element_text(hjust = 0.5, size=12),
          legend.position = "none",
          axis.title.x=element_blank(),
          axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
  + annotate("text", c(1/3, 5/6), size = 4, y =  -1.5, label = c("Less-severe (L)", "More-severe (M)"))
  + annotate("text", c(1/3-0.05, 5/6+0.05), size = 3, y = c(30, 30), label = c("L-DI", "M-DI"))
  + annotate("text", c(1/3-0.05, 5/6+0.05), size = 3, y = c(60, 45), label = c("L-NDI", "M-NDI"))
)

# Export the figure
ggsave(paste0(figure, 'figJ1d.png'), height = 4, width = 6)
