rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages('reshape2')
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

# Read the data set
df1 <- read.csv('./temp/figJ2a.csv')
df1.m1 <- melt(df1, id = "group")

attach(df1.m1)
(df1.new <- df1.m1[which(group == 'rec_moresevere_2534' | group == 'rec_moresevere_3544' |
                           group == 'rec_moresevere_4554' | group == 'rec_moresevere_5565' |
                           group == 'rec_lesssevere_2534' | group == 'rec_lesssevere_3544' |
                           group == 'rec_lesssevere_4554' | group == 'rec_lesssevere_5565' |
                           group == 'nonrec_moresevere' | group == 'nonrec_lesssevere'),]) 
detach(df1.m1)

attach(df1.new)
(df1.new <- df1.new[which(variable == 'shock_non_medical_broad_2534' | variable == 'shock_non_medical_broad_3544' | variable == 'shock_non_medical_broad_4554' 
                          | variable == 'shock_non_medical_broad_5565'),]) 
detach(df1.new)

df1.new$group <- as.character(df1.new$group)
df1.new$group[df1.new$group == 'rec_moresevere_2534' & df1.new$variable == 'shock_non_medical_broad_2534'] <- 'rec_moresevere'
df1.new$group[df1.new$group == 'rec_moresevere_3544' & df1.new$variable == 'shock_non_medical_broad_3544'] <- 'rec_moresevere'
df1.new$group[df1.new$group == 'rec_moresevere_4554' & df1.new$variable == 'shock_non_medical_broad_4554'] <- 'rec_moresevere'
df1.new$group[df1.new$group == 'rec_moresevere_5565' & df1.new$variable == 'shock_non_medical_broad_5565'] <- 'rec_moresevere'
df1.new$group[df1.new$group == 'rec_lesssevere_2534' & df1.new$variable == 'shock_non_medical_broad_2534'] <- 'rec_lesssevere'
df1.new$group[df1.new$group == 'rec_lesssevere_3544' & df1.new$variable == 'shock_non_medical_broad_3544'] <- 'rec_lesssevere'
df1.new$group[df1.new$group == 'rec_lesssevere_4554' & df1.new$variable == 'shock_non_medical_broad_4554'] <- 'rec_lesssevere'
df1.new$group[df1.new$group == 'rec_lesssevere_5565' & df1.new$variable == 'shock_non_medical_broad_5565'] <- 'rec_lesssevere'

attach(df1.new)
(df1.new <- df1.new[which(group == 'rec_moresevere' | group == 'nonrec_moresevere'| group == 'rec_lesssevere'| group == 'nonrec_lesssevere'),]) 
detach(df1.new)

df1.new$num[df1.new$group == 'rec_lesssevere'] <- 1/3
df1.new$num[df1.new$group == 'nonrec_lesssevere'] <- 1/3
df1.new$num[df1.new$group == 'rec_moresevere'] <- 5/6
df1.new$num[df1.new$group == 'nonrec_moresevere'] <- 5/6

df1.new$DI[df1.new$group == 'rec_lesssevere'] <- 'DI'
df1.new$DI[df1.new$group == 'nonrec_lesssevere'] <- 'NDI'
df1.new$DI[df1.new$group == 'rec_moresevere'] <- 'DI'
df1.new$DI[df1.new$group == 'nonrec_moresevere'] <- 'NDI'


(df1.new_2 <-subset(df1.new, grepl("rec_moresevere", df1.new$group)))

df1.new_3 <- df1.new_2

df1.new_3$num[df1.new_3$group == 'rec_moresevere'] <- 5/6 - 0.02
df1.new_3$num[df1.new_3$group == 'nonrec_moresevere'] <- 5/6 + 0.02

(sample.new4_3 <- ggplot(df1.new_3) 
  + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
  + geom_vline(xintercept = 2/3, linetype="dashed") 
  + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction of any adverse non-health event", expand = c(0, 0))
  + scale_size_manual(values=c(5,4,5,4)) + scale_shape_manual(values=c(21,24,22,23)) 
  + scale_color_manual(values=c("pink", "deeppink4"), guide = FALSE)
  + scale_fill_manual(values=c("pink", "white")) 
)

(sample.new5_3 <- sample.new4_3 + theme_classic() 
  + theme(legend.title = element_blank(), 
          legend.position = "none",
          plot.title = element_text(hjust = 0.5, size=12),
          axis.title.x=element_blank(),
          axis.text.x=element_blank(),
          axis.ticks.x=element_blank(),
          plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
  + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
  + annotate("text", x = c(1, 1, 1, 1), size = 3, y = c(0.20, 0.35, 0.5, 0.6), label = c("55 - 64", "45 - 54", "35 - 44", "25 - 34"))
  + annotate("text", x = c(0.7, 0.71), size = 3, y =  c(0.78, 0.25), label = c("M-DI", "M-NDI"))
  + geom_segment(x = 0.728 , y = 0.78, xend = 0.795, yend = 0.62,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
  + geom_segment(x = 0.75 , y = 0.25, xend = 0.84, yend = 0.275,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
  + geom_segment(x = 0.96 , y = 0.2, xend = 0.87, yend = 0.27,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
  + geom_segment(x = 0.96 , y = 0.35, xend = 0.872, yend = 0.42,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
  + geom_segment(x = 0.96 , y = 0.5, xend = 0.87, yend = 0.479,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
  + geom_segment(x = 0.96 , y = 0.6, xend = 0.875, yend = 0.587,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))      
)

# Export the figure
ggsave(paste0(figure, 'figJ2a.png'), height = 4, width = 6)


