rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################

# Read The data set
df1 <- read.csv('./temp/figJ4.csv')

# Clean the data set
df1.m2 <- melt(df1, id = "group")

df1.m2$group <- gsub("less", "non", df1.m2$group)
df1.m2$group <- gsub("more-", "", df1.m2$group)
df1.m2$group <- gsub("L-NDI", "NDI-NS", df1.m2$group)
df1.m2$group <- gsub("M-NDI", "NDI-S", df1.m2$group)
df1.m2$group <- gsub("L-DI", "DI-NS", df1.m2$group)
df1.m2$group <- gsub("M-DI", "DI-S", df1.m2$group)

# Education (only college)

(education <- subset(df1.m2,grepl("educ_college_head", df1.m2$variable)))
  

education$variable <- factor(education$variable, levels = c('educ_college_head'),
                               labels=c('College or above'))
  
education$num[education$group == "Non-recipients, non-severe (NDI-NS)"] <- 1/3   
education$num[education$group == "Recipients, non-severe (DI-NS)"] <- 1/3   
education$num[education$group == "Non-recipients, severe (NDI-S)"] <- 5/6   
education$num[education$group == "Recipients, severe (DI-S)"] <- 5/6   
  
education$DI[education$group == "Non-recipients, non-severe (NDI-NS)"] <- 'NDI'   
education$DI[education$group == "Recipients, non-severe (DI-NS)"] <- 'DI'
education$DI[education$group == "Non-recipients, severe (NDI-S)"] <- 'NDI'   
education$DI[education$group == "Recipients, severe (DI-S)"] <- 'DI'   
  
# Draft Figure  
(temp.educ <- ggplot(education) 
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with college or above", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) 
    + scale_color_manual(values=c("lightblue", "pink", "blue", "deeppink4"), guide = FALSE) 
    + scale_shape_manual(values=c(22,21,24), guide = FALSE) + scale_fill_manual(values = c("lightblue", 'pink', "white", "white"))
  )
  
# Final Figure
(educ <- temp.educ + theme_classic() 
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", c(1/3, 5/6, 1/3, 5/6), size = 3, y = c(0.05, 0.05, 0.5, 0.25), label = c("L-DI", "M-DI", 'L-NDI', 'M-NDI'))
  )

# Export the figure
ggsave(paste0(figure, 'figJ4.png'), height = 4, width = 6)
  
  
  
  
  
  
  