version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause off
#delim;


local data "$results";
local log "";
local do "";

/* Figure J5: PSID: Consumption distribution at application (SSDI only) */

foreach x in di {;
	foreach severity in severe { ;
		use "`data'/psid_figure_`x'.dta", clear;

/* ****************************************** */
/* *** PREPARING VARIABLES TO BE EXPORTED *** */
/* ****************************************** */

		/* Divide by square root of number of family */
		
		sum pre1_app_hhexp_N_hlth, det;
		replace pre1_app_hhexp_N_hlth = . if pre1_app_hhexp_N_hlth > 1000000;

		replace hhexp_N_hlth = hhexp_N_hlth/sqrt(num_of_family) ;
		replace pre1_app_hhexp_N_hlth = pre1_app_hhexp_N_hlth/sqrt(num_of_family) ;
		replace pre1_sev_hhexp_N_hlth = pre1_sev_hhexp_N_hlth/sqrt(num_of_family) ;
		
		/* Recipients, severe and non-severe */
				
		preserve;
			keep if flag_di_rec == 1 & year == 2016;
						
			gen group = "M-DI" if flag_`severity' == 1;
			replace group = "L-DI" if flag_`severity' == 0;
					
			drop if group == "" ;
					
			tempfile rec_sev_current;
			save `rec_sev_current';
											
		restore;

		/* Non-recipients, severe and non-severe */
		
		preserve;
				
			keep if flag_di_rec == 0 & year == 2016;
					
			gen group = "M-NDI" if flag_`severity' == 1 ;
			replace group = "L-NDI" if flag_`severity' == 0 ;
			drop if group == "";
			tempfile nonrec_sev_current;
			save `nonrec_sev_current';
					
		restore;

/* ********************** */
/* *** EXPORTING DATA *** */
/* ********************** */
			
		preserve;
				
			clear;
			append using `rec_sev_current';
			append using `nonrec_sev_current';

			keep group family_weight unique_id hhexp_N_hlth 
					pre1_app_hhexp_N_hlth pre1_sev_hhexp_N_hlth;
								
			export delimited using "`data'/figJ5.csv", replace;
		restore;				
	};
};

			
