rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
# install.packages("plotrix")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(plotrix)

################################################################################################################################################

x_N_hlth <- "Total excluding health"
limit_N_hlth <-80000

# Read the Excel file 

df1 <- read.csv('./temp/figJ5.csv')
  
df1$group <- factor(df1$group, levels = c('L-NDI', 'L-DI', 'M-NDI', 'M-DI'),
                               labels=c('Less-severe, non-recipients (L-NDI)', 'Less-severe, recipients (L-DI)',
                                        'More-severe, non-recipients (M-NDI)', 'More-severe, recipients (M-DI)')
                    )
  
attach(df1)
DI.L <- df1[which(group == 'Less-severe, recipients (L-DI)'),]
DI.M <- df1[which(group == 'More-severe, recipients (M-DI)'),] 
detach(df1)

DI.L.app <- DI.L[complete.cases(DI.L[ , 4]),]
DI.M.app <- DI.M[complete.cases(DI.M[ , 4]),]
   
# Final Figure
(dist.di.weighted <- ggplot() 
      + geom_density(aes(x=pre1_app_hhexp_N_hlth, colour = 'Less-severe, recipients (L-DI)', weight = family_weight/sum(family_weight)), data = DI.L.app)
      + geom_density(aes(x=pre1_app_hhexp_N_hlth, colour = 'More-severe, recipients (M-DI)', weight = family_weight/sum(family_weight)), data = DI.M.app)
      + theme_classic() 
      + coord_cartesian(xlim=c(0, 80000)) + labs(x = 'Total excluding health', y = 'Density')
      + scale_colour_manual('', breaks = c('Less-severe, recipients (L-DI)', 'More-severe, recipients (M-DI)'),
                                values = c('blue', 'deeppink4'), drop = TRUE)
      + theme(text = element_text(size=9), axis.text = element_text(size=10), axis.title = element_text(size=10), 
                  legend.position = 'bottom', legend.title = element_blank(), panel.grid.major = element_blank(), plot.title = element_text(hjust = 0.5, size=12),
                  panel.grid.minor = element_blank()) 
      + scale_y_continuous(expand = c(0, 0))
      + guides(colour=guide_legend(nrow=1, byrow=TRUE)))
        
# Export the figure
ggsave(paste0(figure, 'figJ5.png'), height = 4, width = 6)
        
  

