rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages('reshape2')
#install.packages('gridExtra')
#install.packages('gtable')
#install.packages('grid')

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(gridExtra)
library(gtable)
library(grid)


str_eval=function(x) {return(eval(parse(text=x)))}

y_non_medical_broad <- "Any adverse non-health event at age..."

# used for legend below heatmaps

df <- data.frame(
  x = 1:10,
  y = 1:10)

( plot <- ggplot(df, aes(x, y))
  + geom_point(data=df, size = 4, aes(x=x, y=y, shape='Insufficient sample'), fill='white') 
  + scale_shape_manual(values = 23, labels=c('Insufficient sample'))
  + theme(legend.title = element_blank(), legend.background = element_blank(),legend.key = element_rect(fill = "white"))
)   

leg1 <- gtable_filter(ggplot_gtable(ggplot_build(plot)), "guide-box") 

################################################################################################################################################

for (var in c("non_medical_broad")) {

  for (x in c("di")){
    
    # Read and clean dataset 
    
      df1 <- read.csv('./temp/figJ9.csv')
      df1.m1 <- melt(df1, id = "group")
      
      # group only by age 
      
      attach(df1.m1)
      (df1.new <- df1.m1[which(group == 'rec_2534' | group == 'rec_4554' | group == 'rec_5565'
                               |group == 'rec_3544'|group == 'nonrec_all'),]) 
      detach(df1.m1)
      
      df1.new$group <- as.character(df1.new$group)
      df1.new$group[df1.new$group == 'rec_2534'] <- 'DI, < 35'
      df1.new$group[df1.new$group == 'rec_3544'] <- 'DI, 35 - 44'
      df1.new$group[df1.new$group == 'rec_4554'] <- 'DI, 45 - 54'
      df1.new$group[df1.new$group == 'rec_5565'] <- 'DI, 55 - 64'
      df1.new$group[df1.new$group == 'nonrec_all'] <- 'NDI'
      
      # group by age and severity
      
      attach(df1.m1)
      (df1.newsevere <- df1.m1[which(group == 'rec_nonsevere_2534' | group == 'rec_nonsevere_4554' | 
                                       group == 'rec_nonsevere_5565'|group == 'rec_nonsevere_3544'|
                                       group == 'rec_severe_2534'  |group == 'rec_severe_3544' |
                                       group == 'rec_severe_4554'|group == 'rec_severe_5565'|
                                       group == 'nonrec_never_severe' | group == 'nonrec_severe'),])
      detach(df1.m1)
    
        # keep shock variables interested in
        
        eval(parse(text = paste0("(df1.",var," <- subset(df1.new, grepl('shock_",var,"_2534', df1.new$variable) | 
                                 grepl('shock_",var,"_3544', df1.new$variable) | grepl('shock_",var,"_4554', df1.new$variable) | 
                                 grepl('shock_",var,"_5565', df1.new$variable)))" )))
        
        
        # generate dummy group
        
        eval(parse(text = paste0("df1.", var, "$age[df1.", var, "$variable == 'shock_", var, "_2534'] <- '2534'")))
        eval(parse(text = paste0("df1.", var, "$age[df1.", var, "$variable == 'shock_", var, "_3544'] <- '3544'")))
        eval(parse(text = paste0("df1.", var, "$age[df1.", var, "$variable == 'shock_", var, "_4554'] <- '4554'")))
        eval(parse(text = paste0("df1.", var, "$age[df1.", var, "$variable == 'shock_", var, "_5565'] <- '5565'")))

        eval(parse(text = paste0("df1.", var, "$groupage[df1.", var, "$group == 'DI, < 35'] <- '2534'")))
        eval(parse(text = paste0("df1.", var, "$groupage[df1.", var, "$group == 'DI, 35 - 44'] <- '3544'")))
        eval(parse(text = paste0("df1.", var, "$groupage[df1.", var, "$group == 'DI, 45 - 54'] <- '4554'")))
        eval(parse(text = paste0("df1.", var, "$groupage[df1.", var, "$group == 'DI, 55 - 64'] <- '5565'")))
        
        eval(parse(text = paste0("df1.",var,"$variable <- as.character(df1.",var,"$variable)")))
      
        # Rename the group names
        eval(parse(text = paste0("df1.",var,"$variable[df1.",var,"$variable == 'shock_",var,"_2534'] <- '25 - 34'")))
        eval(parse(text = paste0("df1.",var,"$variable[df1.",var,"$variable == 'shock_",var,"_3544'] <- '35 - 44'")))
        eval(parse(text = paste0("df1.",var,"$variable[df1.",var,"$variable == 'shock_",var,"_4554'] <- '45 - 54'")))
        eval(parse(text = paste0("df1.",var,"$variable[df1.",var,"$variable == 'shock_",var,"_5565'] <- '55 - 64'")))
        
        # Set the order to be presented 
        eval(parse(text = paste0("df1.",var,"$group <- factor(df1.",var,"$group, levels = c('DI, < 35', 'DI, 35 - 44', 'DI, 45 - 54', 'DI, 55 - 64', 'NDI'))")))
        eval(parse(text = paste0("df1.",var,"$variable <- factor(df1.",var,"$variable, levels = c('55 - 64', '45 - 54', '35 - 44', '25 - 34'))")))
        
        
        # Putting the value as missing if the sample size is below 50
        for (age in c('2534', '3544', '4554', '5565')) {
          for (agegroup in c('2534', '3544', '4554', '5565')) {
            
            eval(parse(text = paste0("i <- df1.m1$value[df1.m1$group == 'rec_", age, "' & df1.m1$variable == 'num_", var, "_", agegroup, "']")))
            
            if (i < 50) { 
              
              eval(parse(text = paste0("df1.", var, "$value[df1.", var, "$groupage == '", age, "' & df1.", var, "$age == '", agegroup, "'] <- NA")))
              
            }
          }
        }
        
        eval(parse(text = paste0("df1.", var, "$na <- (is.na(df1.", var, "$value))")))
        eval(parse(text = paste0("df1.",var,".frames = df1.", var, "[df1.", var, "$na, c('group', 'variable')]")))
        
        
        # Export the figure
        
        eval(parse(text = paste0("(gph_",var, "<- ggplot(df1.",var,",aes(as.factor(group),as.factor(variable))) + geom_tile(aes(fill=value))
            + scale_fill_gradient(low='white',high='deeppink4') +scale_x_discrete(expand = c(0, 0), position = 'top')
            + labs(x = '',y = '') + scale_y_discrete(expand = c(0, 0)) + labs(x = 'First DI receipt at age...', y = eval(parse(text = paste0('y_',var))))
            + geom_point(data=df1.", var, ".frames, shape = 23, size = 7, aes(x=group, y=variable, shape='Insufficient sample'), fill='white') 
            + annotation_custom(grob = leg1, xmin = 2, xmax = 4, ymin = -1.8, ymax = 2.2)

            + theme(legend.title = element_blank(), axis.ticks = element_blank(), axis.text.x = element_text(size = 8, angle = 0, hjust = 0.5), 
              axis.title=element_text(size=10), plot.title = element_text(hjust = 0.5, size=12, vjust = 5), 
              plot.margin = margin(20, 20, 20, 20)) + coord_equal()) ")))
        
        ggsave(paste0(figure, 'figJ9.png'), height = 4.5, width = 6)
  }
}



