version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause off
#delim;


local data "$results";
local log "";
local do "";

/* Figure 3a: PSID: Any adverse life event by DI status and age */

foreach pg in dissi{;
	foreach sev in severe {;	
	
		use "`data'/psid_figure_`pg'.dta", clear;

/* ****************************************** */
/* *** PREPARING VARIABLES TO BE EXPORTED *** */
/* ****************************************** */

		gen group = "";
		
		replace group = "M_DI_2534" if gp_rec_pre35_`sev' == 1; 
		replace group = "L_DI_2534" if gp_rec_pre35_N`sev' == 1;
		
		foreach age in 3544 4554 5565 {; 
		
			replace group = "M_DI_`age'" 		if gp_rec_`age'_`sev' == 1 ;
			replace group = "L_DI_`age'" 	if gp_rec_`age'_N`sev' == 1 ;
		
		};
		
		preserve ;
					
			drop if group == "" ;
			duplicates drop unique_id, force ;
					
			tempfile rec_sev_age;
			save `rec_sev_age';
					
			bysort unique_id: egen maxage = max(head_age);

		restore;		
						
		preserve;
					
			/* only keep those who never receive DI */
			keep if flag_di_rec_ever == 0;
			drop group;
					
			/* all non-recipients */
					
			gen group = "";
			replace group = "M_NDI" if `sev' == 1;
			replace group = "L_NDI" if `sev' == 0;
			drop if group == "";
					
			/* since all values are copied to all observations, only keep one observation */

			duplicates drop unique_id, force ;
			tempfile nonrec_sev;
			save `nonrec_sev';
		restore;
							
/* ********************** */
/* *** EXPORTING DATA *** */
/* ********************** */
					
		clear;
					
		append using `rec_sev_age';			
		append using `nonrec_sev';
										
		preserve;
				
			collapse (count) unique_id (mean) 
					shock_non_medical_broad_2534 shock_non_medical_broad_3544 
					shock_non_medical_broad_4554 shock_non_medical_broad_5565
					[aw=family_weight], by(group);
					
			export delimited using "`data'/fig3a.csv", replace;

		restore;
				
	}; /* severity end*/
}; /* pg end */
