rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages('reshape2')
#install.packages("grid")

# choose library necessary
library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)

################################################################################################################################################
# Read The data set
df1 <- read.csv('./temp/fig3b.csv')

# Clean the data set
df1.m2 <- melt(df1, id = "group")

# severe onset
  
(outside4 <- subset(df1.m2, grepl("flag_married", df1.m2$variable) | grepl("flag_banking", df1.m2$variable) | 
                        grepl("flag_home_own$", df1.m2$variable)|grepl("marriage", df1.m2$variable)|grepl("homeown", df1.m2$variable)
                      |grepl("banking", df1.m2$variable)))
  
(outside4 <- subset(outside4, grepl("pre1_sev_", outside4$variable)))
  
outside4 <- outside4[-c(1, 3, 5, 7, 9, 11),]
  
outside4$num[outside4$group == "Recipients, more-severe (M-DI)"] <- 5/6 - 0.02
outside4$num[outside4$group == "Non-recipients, more-severe (M-NDI)"] <- 5/6 + 0.02
  
# Draft Figure  
(temp.outside4 <- ggplot(outside4) 
    + geom_point(aes(x = num, y = value, color = group, shape = variable, size = variable, fill = group)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 1), clip="off") + scale_y_continuous(name ="Fraction with resource", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4), guide = FALSE) 
    + scale_color_manual(values=c("pink", "deeppink4"), guide = FALSE) 
    + scale_shape_manual(values=c(21,24,22), guide = FALSE) + scale_fill_manual(values = c("pink", "white"))
  )
  
# Final Figure
(out4 <- temp.outside4 + theme_classic()
    + theme(legend.title = element_blank(), 
            plot.title = element_text(hjust = 0.5, size=12),
            legend.position = "none",
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.03, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(0.95, 0.95, 0.95), size = 3, y = c(0.75, 0.35, 0.15), label = c("Banking relationship", "Own home", "Married"))
    + annotate("text", c(0.71, 0.71), size = 3, y = c(0.25, 0.75), label = c("M-DI", 'M-NDI'))
    + geom_segment(x = 0.96 , y = 0.73, xend = 0.87, yend = 0.673,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.895 , y = 0.34, xend = 0.837, yend = 0.43,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.909 , y = 0.15, xend = 0.837, yend = 0.35,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.74 , y = 0.26, xend = 0.796, yend = 0.33,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.745 , y = 0.75, xend = 0.837, yend = 0.66,
                 arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))     
  )

# Export the figure  
ggsave(paste0(figure, 'fig3b.png'), height = 4, width = 6)
  

  
  