version 15
clear all 
set more off
set logtype text
set maxvar 20000
capture log close
pause on 
#delim;

local output "$results";
local log "";
local do "";

foreach z in di dissi{;
use "`output'/psid_forinteract_2016usd_long_`z'.dta", clear;

rename exp_health OOP_all; 
gen OOP = exp_doctor + exp_hospital + exp_rx;
rename exp_medicalcare medicalcare;


gen flag_banking = (level_cash > 0) if level_cash != .; 
										/* This variable starts in 1998 (vs 1985 first year) */

#delim;
sort unique_id year;
gen foodrentmortg = exp_food + exp_rent + exp_mortg; /* These variables start in 1998 (vs 1985 first year) */

gen flag_severe_moderate = (flag_severe == 1|flag_moderate == 1) if flag_severe != . & flag_moderate != .;

gen flag_work_age = (head_age > 24 & head_age < 66);

keep if flag_work_age == 1;


/* A. Preparing shock variables */

/* Moving Shock */

	/* some years have multiple reasons for why you moved */
	/* max 4 reasons */
	#delim;
	tab reason_move1, m;
	tab reason_move2, m;
	tab reason_move3, m;
	tab reason_move4, m;
	
	forval i = 1(1)4{;
		gen moving_shock`i' = .;
		replace moving_shock`i' = 0 if reason_move`i' != .; 
		
		/* experienced distressed move */
		replace moving_shock`i' = 1 if reason_move`i' == 7; 
		
		gen broad_moving_shock`i' = .;
		replace broad_moving_shock`i' = 0 if reason_move`i' !=. ;
		
		replace broad_moving_shock`i' = 1 if reason_move`i' == 4 | reason_move`i' == 7 | reason_move`i' == 8;
	};
	
	tab moving_shock1, m;
	tab broad_moving_shock1, m;	
	tab moving_shock2, m;
	tab broad_moving_shock2, m;	
	tab moving_shock3, m;
	tab broad_moving_shock3, m;	
	tab moving_shock4, m;
	tab broad_moving_shock4, m;	
	
	
	/* 1. Experienced moving shock x years ago */
	
		#delim;
		count if reason_move1 == . & reason_move2 != . ;
		count if reason_move1 == . & reason_move3 != . ;
		count if reason_move1 == . & reason_move4 != . ;
		
		gen temp_shock_moving = .;
		/* no need to be non-missing for all moving shock variables since not all years have moving_shock2 - moving_shock4*/
		replace temp_shock_moving = 0 if moving_shock1 != .|moving_shock2 != .|moving_shock3 != .|moving_shock4 != .;	
		
		replace temp_shock_moving = 1 if moving_shock1 == 1|moving_shock2 == 1|moving_shock3 == 1|moving_shock4 == 1;
		
		bysort unique_id: egen shock_moving = max(temp_shock_moving); /* ever experienced moving shock */
		
		tab shock_moving, m ; /* the number of missing is consistent with HH-level reason_move1 */
		
		sort unique_id year;
		
		gen temp_shock_broad_moving = .;
		
		replace temp_shock_broad_moving = 0 if broad_moving_shock1 != . | broad_moving_shock2 != . | 
											   broad_moving_shock3 != .|broad_moving_shock4 != .;
											   
		replace temp_shock_broad_moving = 1 if broad_moving_shock1 == 1|broad_moving_shock2 == 1 | 
											   broad_moving_shock3 == 1|broad_moving_shock4 == 1;
											   
		bysort unique_id: egen shock_broad_moving = max(temp_shock_broad_moving); /* ever experienced moving shock */
		
		tab shock_broad_moving, m ;
		sort unique_id year;
		
		/* experienced shock i years ago */
		
		#delim; 
		
		forval i = 0(1)5{;
			gen temp_shock_moving_pre`i' = .;
			forval yr = 1985(1)1996{;
				by unique_id: replace temp_shock_moving_pre`i' = temp_shock_moving[_n-`i'] 
														if year == `yr' & year[_n-`i'] == `yr' - `i';
			};
		};
		
		
		foreach i in 0 2 4{;
			forval yr = 1998(2)2016{;
				bysort unique_id: replace temp_shock_moving_pre`i' = temp_shock_moving[_n-`i'/2] 
														if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
			
			};
		};
		
		tab temp_shock_moving_pre0, m ;
		
		/* broad shock */
		
		forval i = 0(1)5{;
			gen temp_shock_broad_moving_pre`i' = .;
			forval yr = 1985(1)1996{;
				by unique_id: replace temp_shock_broad_moving_pre`i' = temp_shock_broad_moving[_n-`i'] 
														if year == `yr' & year[_n-`i'] == `yr' - `i';
			};
		};
		
		
		foreach i in 0 2 4{;
			forval yr = 1998(2)2016{;
				bysort unique_id: replace temp_shock_broad_moving_pre`i' = temp_shock_broad_moving[_n-`i'/2] 
														if year == `yr' & year[_n-`i'/2] == `yr' - `i';
			
			};
		};
		
		tab temp_shock_broad_moving_pre0, m ;
	
	/* 2. Experienced moving shock in past x years */
	
	#delim;
	
		gen temp_shock_moving0 = temp_shock_moving_pre0;

	
		/* Experienced distressed move 1 year before (only prior to 1997) */
		
		gen temp_shock_moving1_8596 = (temp_shock_moving_pre0 == 1|temp_shock_moving_pre1 == 1)
											if temp_shock_moving_pre1 != . & temp_shock_moving_pre0 != . ;
		
		/* Experienced distressed move in past 2 years */
		
		gen temp_shock_moving2 = .;
		replace temp_shock_moving2 = (temp_shock_moving_pre0 == 1 | temp_shock_moving_pre1 == 1 | temp_shock_moving_pre2 == 1)
											if temp_shock_moving_pre0 != . & temp_shock_moving_pre1 != . & 
											   temp_shock_moving_pre2 != . & year < 1997;
					
		replace temp_shock_moving2 = (temp_shock_moving_pre0 == 1|temp_shock_moving_pre2 == 1) 
											if temp_shock_moving_pre0 != . & temp_shock_moving_pre2 != . & year > 1997;

		/* Experienced distressed move in past 3 years (only prior to 1997) */
		
		gen temp_shock_moving3_8596 = .;
		replace temp_shock_moving3_8596 = (temp_shock_moving_pre0 == 1 | temp_shock_moving_pre1 == 1 | 
										   temp_shock_moving_pre2 == 1 | temp_shock_moving_pre3 == 1)
											if temp_shock_moving_pre0 != . & temp_shock_moving_pre1 != . & 
											   temp_shock_moving_pre2 != . & temp_shock_moving_pre3 != .;

		/* Experienced distressed move in past 4 years */
		
		gen temp_shock_moving4 = .;
		replace temp_shock_moving4 = (temp_shock_moving_pre0 == 1|temp_shock_moving_pre1 == 1|temp_shock_moving_pre2 == 1|
										temp_shock_moving_pre3 == 1|temp_shock_moving_pre4 == 1)
										if temp_shock_moving_pre0 != . & temp_shock_moving_pre1 != . & 
										   temp_shock_moving_pre2 != . & temp_shock_moving_pre3 != . & 
										   temp_shock_moving_pre4 != . & year < 1997;
				
		replace temp_shock_moving4 = (temp_shock_moving_pre0 == 1|temp_shock_moving_pre2 == 1|temp_shock_moving_pre4 == 1) 
										if temp_shock_moving_pre0 != . & temp_shock_moving_pre2 != . & 
										   temp_shock_moving_pre4 != . & year > 1997;

		tab temp_shock_moving4, m ;
				
		/* Experienced distressed move in past 5 years (only prior to 1997) */
		
		#delim;
		gen temp_shock_moving5_8596 = .;
		replace temp_shock_moving5_8596 = (temp_shock_moving_pre0 == 1|temp_shock_moving_pre1 == 1|
											temp_shock_moving_pre2 == 1|temp_shock_moving_pre3 == 1|
											temp_shock_moving_pre4 == 1|temp_shock_moving_pre5 == 1)
											if temp_shock_moving_pre0 != . & temp_shock_moving_pre1 != . & 
											   temp_shock_moving_pre2 != . & temp_shock_moving_pre3 != . & 					
											   temp_shock_moving_pre4 != . & temp_shock_moving_pre5 != .;
				
	/* broad shock */

		gen temp_shock_broad_moving0 = temp_shock_broad_moving_pre0;

		/* Experienced distressed move 1 year before (only prior to 1997) */
		
		gen temp_shock_broad_moving1_8596 = (temp_shock_broad_moving_pre0 == 1 | temp_shock_broad_moving_pre1 == 1)
											if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre1 != .;
				
		/* Experienced distressed move in past 2 years */
		
		gen temp_shock_broad_moving2 = .;
		replace temp_shock_broad_moving2 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre1 == 1|
											temp_shock_broad_moving_pre2 == 1)
											if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre1 != . & 
											   temp_shock_broad_moving_pre2 != . & year < 1997;
					
		replace temp_shock_broad_moving2 = (temp_shock_broad_moving_pre0 == 1 | temp_shock_broad_moving_pre2 == 1) 
											if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre2 != . & 
											   year > 1997;

		/* Experienced distressed move in past 3 years (only prior to 1997) */
		
		gen temp_shock_broad_moving3_8596 = .;
		replace temp_shock_broad_moving3_8596 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre1 == 1|
											temp_shock_broad_moving_pre2 == 1|temp_shock_broad_moving_pre3 == 1)
											if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre1 != . & 
											   temp_shock_broad_moving_pre2 != . & temp_shock_broad_moving_pre3 != .;

		/* Experienced distressed move in past 4 years */
		
		gen temp_shock_broad_moving4 = .;
		replace temp_shock_broad_moving4 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre1 == 1|
											temp_shock_broad_moving_pre2 == 1|temp_shock_broad_moving_pre3 == 1|
											temp_shock_broad_moving_pre4 == 1)
											if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre1 != . & 
											   temp_shock_broad_moving_pre2 != . & temp_shock_broad_moving_pre3 != . & 
											   temp_shock_broad_moving_pre4 != . & year < 1997;
				
		replace temp_shock_broad_moving4 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre2 == 1|
											temp_shock_broad_moving_pre4 == 1) 
											if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre2 != . & 
											   temp_shock_broad_moving_pre4 != . & year > 1997;

		tab temp_shock_broad_moving4, m ;
		
		/* Experienced distressed move in past 5 years (only prior to 1997) */
		
		gen temp_shock_broad_moving5_8596 = .;
		replace temp_shock_broad_moving5_8596 = (temp_shock_broad_moving_pre0 == 1 |temp_shock_broad_moving_pre1 == 1|
												 temp_shock_broad_moving_pre2 == 1|temp_shock_broad_moving_pre3 == 1|
												 temp_shock_broad_moving_pre4 == 1|temp_shock_broad_moving_pre5 == 1)
												 if temp_shock_broad_moving_pre0 != . & temp_shock_broad_moving_pre1 != . & 
												    temp_shock_broad_moving_pre2 != . & temp_shock_broad_moving_pre3 != . & 
												    temp_shock_broad_moving_pre4 != . & temp_shock_broad_moving_pre5 != .;

	

/* Marriage Shock (Divorce) */

	/* 1. Divorced or not last year */
	#delim; 

		sort unique_id year;

		bysort unique_id: gen temp_shock_marriage = flag_married - flag_married[_n-1]; 
								
		tab temp_shock_marriage, m ;
			
		#delim;
		replace temp_shock_marriage = (temp_shock_marriage == -1) if temp_shock_marriage != .;
		bysort unique_id: egen shock_marriage = max(temp_shock_marriage); /* ever divorced */
		
		
	/* 2. Experienced marriage shock x years ago */
	
		sort unique_id year;
		
		forval i = 0(1)5{;
			gen temp_shock_marriage_pre`i' =.;
			
			forval yr = 1985(1)1996{;
				by unique_id: replace temp_shock_marriage_pre`i' =  temp_shock_marriage[_n-`i'] 
															if year == `yr' & year[_n-`i'] == `yr' - `i' ;
			};
		};

		forval i = 0(2)4{;
		
			forval yr = 1998(2)2016{;
				by unique_id: replace temp_shock_marriage_pre`i' = temp_shock_marriage[_n-`i'/2] 
															if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
			
			};
		};
	
	/* 3. Experienced marriage shock in past x years */
	
	#delim;

		gen temp_shock_marriage0 = temp_shock_marriage_pre0;
		
		gen temp_shock_marriage1_8596 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre1 == 1)
											if temp_shock_marriage_pre1 != . & temp_shock_marriage_pre0 != .;
		
		gen temp_shock_marriage2 =.;
		
		replace temp_shock_marriage2 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre1 == 1|temp_shock_marriage_pre2 == 1)
											if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre1 != . & 
											   temp_shock_marriage_pre2 != . & year < 1997;
			
		replace temp_shock_marriage2 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre2 == 1) 
											if temp_shock_marriage_pre2 != . & temp_shock_marriage_pre0 != . & year > 1997;
					
		gen temp_shock_marriage3_8596 =.;
		
		replace temp_shock_marriage3_8596 = (temp_shock_marriage_pre0 == 1 |temp_shock_marriage_pre1 == 1|
											 temp_shock_marriage_pre2 == 1|temp_shock_marriage_pre3 == 1)
												if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre1 != . & 
												   temp_shock_marriage_pre2 != . & temp_shock_marriage_pre3 != .;
						
		gen temp_shock_marriage4 =.;
		
		replace temp_shock_marriage4 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre1 == 1|
										temp_shock_marriage_pre2 == 1 | temp_shock_marriage_pre3 == 1|temp_shock_marriage_pre4 == 1)
												if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre1 != . & 
												   temp_shock_marriage_pre2 != . & temp_shock_marriage_pre3 != . & 
												   temp_shock_marriage_pre4 != . & year < 1997;
								
		replace temp_shock_marriage4 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre2 == 1|
										temp_shock_marriage_pre4 == 1)
												if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre2 != . & 
												   temp_shock_marriage_pre4 != . & year > 1997;
					
		gen temp_shock_marriage5_8596 =.;
		replace temp_shock_marriage5_8596 = (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre1 == 1|
											 temp_shock_marriage_pre2 == 1 | temp_shock_marriage_pre3 == 1|
											 temp_shock_marriage_pre4 == 1|temp_shock_marriage_pre5 == 1)
												if temp_shock_marriage_pre0 != . & temp_shock_marriage_pre1 != . & 
												   temp_shock_marriage_pre2 != . & temp_shock_marriage_pre3 != . & 
												   temp_shock_marriage_pre4 != . & temp_shock_marriage_pre5 != .;
				
		count if (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre1 == 1 | temp_shock_marriage_pre2 == 1|
				  temp_shock_marriage_pre3 == 1|temp_shock_marriage_pre4 == 1) & temp_shock_marriage_pre0 != . &
				  temp_shock_marriage_pre1 != . & temp_shock_marriage_pre2 != . & temp_shock_marriage_pre3 != . & 
				  temp_shock_marriage_pre4 != . & year < 1997;

		count if (temp_shock_marriage_pre0 == 1 | temp_shock_marriage_pre2 == 1|temp_shock_marriage_pre4 == 1) & 
				  temp_shock_marriage_pre0 != . & temp_shock_marriage_pre2 != . & temp_shock_marriage_pre4 != . & year > 1997;
		
		tab temp_shock_marriage4, m ;

	
/* Job Shock */

	#delim ;
	rename head_emply hd_emply;
	rename spouse_emply sp_emply;

	/* 1. Experienced job shock x years ago */
	
		sort unique_id year;
		
		foreach var in hd sp{; 
			foreach x in u e{; 		
				forvalue i = 0(1)5{;
					gen reason_posend_`var'_`x'_pre`i' = .;
					forval yr = 1985(1)1996{;
						by unique_id: replace reason_posend_`var'_`x'_pre`i' = reason_posend_`var'_`x'[_n-`i'] 
																				if year == `yr' & year[_n-`i'] == `yr' - `i';
					};
				};
			};
		};
		
		foreach var in hd sp{;
			foreach x in u e{; 		
				forvalue i = 0(2)4{;
					forval yr = 1998(2)2016{;
						by unique_id: replace reason_posend_`var'_`x'_pre`i' = reason_posend_`var'_`x'[_n-`i'/2] 
																				if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
					};
				};
			};
		};
		
		/* Mechanism */
		foreach var in hd sp{;
			gen temp_vol_quit_job_`var' = . ;
			replace temp_vol_quit_job_`var' = 0 if reason_posend_`var'_u_pre0 != . | reason_posend_`var'_e_pre0 != . ;
			replace temp_vol_quit_job_`var' = 1 if reason_posend_`var'_u_pre0 == 4 | reason_posend_`var'_e_pre0 == 4 ;
			tab temp_vol_quit_job_`var' , m ;
		};
		
		gen temp_vol_quit_job = . ;
		replace temp_vol_quit_job = 0 if temp_vol_quit_job_hd == 0 & temp_vol_quit_job_sp == 0 ;
		replace temp_vol_quit_job = 1 if temp_vol_quit_job_hd == 1 | temp_vol_quit_job_sp == 1 ; 
		
		tab temp_vol_quit_job, m ;
		
		/* Shock variables */
		
		forvalue i = 0(1)5{;
			foreach var in hd sp{;
			
				gen temp_shock_pre`i'_job_`var' = .;
				
				/* not experienced shock i years ago */
				replace temp_shock_pre`i'_job_`var' = 0 if reason_posend_`var'_u_pre`i' != .|reason_posend_`var'_e_pre`i' != .;
				
				/* experienced job shock i years ago */
				replace temp_shock_pre`i'_job_`var' = 1 if reason_posend_`var'_u_pre`i' == 1| reason_posend_`var'_u_pre`i' == 2| 
														   reason_posend_`var'_u_pre`i' == 3| reason_posend_`var'_e_pre`i' == 1| 
														   reason_posend_`var'_e_pre`i' == 2| reason_posend_`var'_e_pre`i' == 3;
														   
				bysort unique_id: egen shock_pre`i'_job_`var' = max(temp_shock_pre`i'_job_`var');		
				
				/* broad shock */
				
				gen temp_shock_pre`i'_bd_job_`var' = .;
							
				replace temp_shock_pre`i'_bd_job_`var' = 0 if reason_posend_`var'_u_pre`i' != .|reason_posend_`var'_e_pre`i' != .;
				
				replace temp_shock_pre`i'_bd_job_`var' = 1 if reason_posend_`var'_u_pre`i' == 1| reason_posend_`var'_u_pre`i' == 2| 
															  reason_posend_`var'_u_pre`i' == 3| reason_posend_`var'_u_pre`i' == 7| 
															  reason_posend_`var'_u_pre`i' == 8| reason_posend_`var'_e_pre`i' == 1| 
															  reason_posend_`var'_e_pre`i' == 2| reason_posend_`var'_e_pre`i' == 3|
															  reason_posend_`var'_e_pre`i' == 7| reason_posend_`var'_e_pre`i' == 8;
															  
				bysort unique_id: egen shock_pre`i'_bd_job_`var' = max(temp_shock_pre`i'_bd_job_`var');
			};	
		};
	
	
	/* Conditional to having a job */

	#delim;
	
		forvalue i = 0(1)5{;
			foreach var in hd sp{;
				gen temp_shock_pre`i'_job_`var'_cond = .;
				
				/* not experienced shock i years ago */
				bysort unique_id: replace temp_shock_pre`i'_job_`var'_cond = 0 
												if (reason_posend_`var'_u_pre`i' != .| 
													reason_posend_`var'_e_pre`i' != .) & 
													`var'_emply[_n-1-`i'] == 1;
				
				/* experienced job shock i years ago */
				
				bysort unique_id: replace temp_shock_pre`i'_job_`var'_cond = 1 
												if `var'_emply[_n-1-`i'] == 1 & (reason_posend_`var'_u_pre`i' == 1| 
													reason_posend_`var'_u_pre`i' == 2| reason_posend_`var'_u_pre`i' == 3| 
													reason_posend_`var'_e_pre`i' == 1| reason_posend_`var'_e_pre`i' == 2|
													reason_posend_`var'_e_pre`i' == 3);
				
				bysort unique_id: egen shock_pre`i'_job_`var'_cond = max(temp_shock_pre`i'_job_`var'_cond);		
				
				/* broad shock */
			
				gen temp_shock_pre`i'_bd_job_`var'_cond = .;
							
				bysort unique_id: replace temp_shock_pre`i'_bd_job_`var'_cond = 0 
												if (reason_posend_`var'_u_pre`i' != . | reason_posend_`var'_e_pre`i' != .) & 
													`var'_emply[_n-1-`i'] == 1;
				
				bysort unique_id: replace temp_shock_pre`i'_bd_job_`var'_cond = 1 
												if `var'_emply[_n-1-`i'] == 1 & reason_posend_`var'_u_pre`i' == 1| 
													reason_posend_`var'_u_pre`i' == 2| reason_posend_`var'_u_pre`i' == 3|
													reason_posend_`var'_u_pre`i' == 7| reason_posend_`var'_u_pre`i' == 8|
													reason_posend_`var'_e_pre`i' == 1| reason_posend_`var'_e_pre`i' == 2| 
													reason_posend_`var'_e_pre`i' == 3| reason_posend_`var'_e_pre`i' == 7| 
													reason_posend_`var'_e_pre`i' == 8;
										
				bysort unique_id: egen shock_pre`i'_bd_job_`var'_cond = max(temp_shock_pre`i'_bd_job_`var'_cond);
				
			};	
		};
		

	
	/* 2. Experienced job shock in past x years */	
	
	#delim;
	
		foreach var in hd sp hd_cond sp_cond{;
			gen temp_shock_job_`var'0 = temp_shock_pre0_job_`var'; 
					
			gen temp_shock_job_`var'1_8596 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre1_job_`var' != . ;
			replace temp_shock_job_`var'1_8596 = 1 if temp_shock_pre1_job_`var' == 1 | temp_shock_pre0_job_`var' == 1;
			
			/* experienced job shock in past 2 years */
			gen temp_shock_job_`var'2 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre1_job_`var' != . & 
											 temp_shock_pre2_job_`var' != . & year < 1997;
						
			replace temp_shock_job_`var'2 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre2_job_`var' != . & 
												 year > 1997;
						
			replace temp_shock_job_`var'2 = 1 if temp_shock_pre0_job_`var' == 1 | temp_shock_pre1_job_`var' == 1 | 
												 temp_shock_pre2_job_`var' == 1;

						
			/* experienced job shock in past 3 years */
			gen temp_shock_job_`var'3_8596 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre1_job_`var' != . & 
												  temp_shock_pre2_job_`var' != . & temp_shock_pre3_job_`var' != .;
													
			replace temp_shock_job_`var'3_8596 = 1 if temp_shock_pre0_job_`var' == 1 |temp_shock_pre1_job_`var' == 1 |
													  temp_shock_pre2_job_`var' == 1|temp_shock_pre3_job_`var' == 1;
					
					
			/* experienced job shock in past 4 years */
			gen temp_shock_job_`var'4 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre1_job_`var' != . & 
											 temp_shock_pre2_job_`var' != . & temp_shock_pre3_job_`var' != . & 
											 temp_shock_pre4_job_`var' != . & year < 1997;
											 
			replace temp_shock_job_`var'4 = 0 if temp_shock_pre0_job_`var' != . & temp_shock_pre2_job_`var' != . & 
												 temp_shock_pre4_job_`var' != . & year > 1997;
											 
			replace temp_shock_job_`var'4 = 1 if temp_shock_pre0_job_`var' == 1 |temp_shock_pre1_job_`var' == 1 | 
												 temp_shock_pre2_job_`var' == 1 | temp_shock_pre3_job_`var' == 1|
												 temp_shock_pre4_job_`var' == 1;
									
			/* experienced job shock in past 5 years */
			gen temp_shock_job_`var'5_8596 = (temp_shock_pre0_job_`var' == 1 | temp_shock_pre1_job_`var' == 1|
											  temp_shock_pre2_job_`var' == 1 | temp_shock_pre3_job_`var' == 1|
											  temp_shock_pre4_job_`var' == 1|temp_shock_pre5_job_`var' == 1)
											  if temp_shock_pre0_job_`var' != . & temp_shock_pre1_job_`var' != . & 
												 temp_shock_pre2_job_`var' != . &  temp_shock_pre3_job_`var' != . & 
												 temp_shock_pre4_job_`var' != . & temp_shock_pre5_job_`var' != .;
					
					
		/* broad shock */
			gen temp_shock_bd_job_`var'0 = temp_shock_pre0_bd_job_`var';
			
			gen temp_shock_bd_job_`var'1_8596 = (temp_shock_pre0_bd_job_`var' == 1|temp_shock_pre1_bd_job_`var' == 1)
													if temp_shock_pre1_bd_job_`var' != . & temp_shock_pre0_bd_job_`var' != .; 
			
			/* experienced job shock in past 2 years */
			gen temp_shock_bd_job_`var'2 = (temp_shock_pre0_bd_job_`var' == 1|temp_shock_pre1_bd_job_`var' == 1|
											temp_shock_pre2_bd_job_`var' == 1)
													if temp_shock_pre0_bd_job_`var' != . & temp_shock_pre1_bd_job_`var' != . &
													   temp_shock_pre2_bd_job_`var' != . & year < 1997;
													   
			replace temp_shock_bd_job_`var'2 = (temp_shock_pre0_bd_job_`var' == 1 | temp_shock_pre2_bd_job_`var' == 1) 
													if year > 1997 & temp_shock_pre0_bd_job_`var' != . & 
													   temp_shock_pre2_bd_job_`var' != . ;
					
			/* experienced job shock in past 3 years */
			gen temp_shock_bd_job_`var'3_8596 = (temp_shock_pre0_bd_job_`var' == 1| temp_shock_pre1_bd_job_`var' == 1|
												 temp_shock_pre2_bd_job_`var' == 1| temp_shock_pre3_bd_job_`var' == 1)
													if temp_shock_pre0_bd_job_`var' != . & temp_shock_pre1_bd_job_`var' != . & 
													   temp_shock_pre2_bd_job_`var' != . & temp_shock_pre3_bd_job_`var' != .;
							
			/* experienced job shock in past 4 years */
			gen temp_shock_bd_job_`var'4 = (temp_shock_pre0_bd_job_`var' == 1 | temp_shock_pre1_bd_job_`var' == 1|
											temp_shock_pre2_bd_job_`var' == 1 | temp_shock_pre3_bd_job_`var' == 1|
											temp_shock_pre4_bd_job_`var' == 1)
													if temp_shock_pre0_bd_job_`var' != . & temp_shock_pre1_bd_job_`var' != . & 
													   temp_shock_pre2_bd_job_`var' != . & temp_shock_pre3_bd_job_`var' != . & 
													   temp_shock_pre4_bd_job_`var' != . & year < 1997;
							
			replace temp_shock_bd_job_`var'4 = (temp_shock_pre0_bd_job_`var' == 1 | temp_shock_pre2_bd_job_`var' == 1 | 
												temp_shock_pre3_bd_job_`var' == 1)
													if temp_shock_pre0_bd_job_`var' != . & temp_shock_pre2_bd_job_`var' != . & 
													   temp_shock_pre4_bd_job_`var' != . & year > 1997;
					
			/* experienced job shock in past 5 years */
			gen temp_shock_bd_job_`var'5_8596 = (temp_shock_pre0_bd_job_`var' == 1 | temp_shock_pre1_bd_job_`var' == 1 |
												 temp_shock_pre2_bd_job_`var' == 1 | temp_shock_pre3_bd_job_`var' == 1 |
												 temp_shock_pre4_bd_job_`var' == 1 | temp_shock_pre5_bd_job_`var' == 1)
													if temp_shock_pre0_bd_job_`var' != . & temp_shock_pre1_bd_job_`var' != . & 
													   temp_shock_pre2_bd_job_`var' != . & temp_shock_pre3_bd_job_`var' != . & 
													   temp_shock_pre4_bd_job_`var' != . & temp_shock_pre5_bd_job_`var' != .;

		};
		
		forval i = 0(2)4{;
			gen temp_shock_job`i' = temp_shock_job_hd`i' ;
			replace temp_shock_job`i' = temp_shock_job_sp`i' 
						if flag_spouse == 1 & temp_shock_job_sp`i' != 0 & temp_shock_job_hd`i' != 1 ;
			
			gen temp_shock_broad_job`i' = temp_shock_bd_job_hd`i' ;
			replace temp_shock_broad_job`i' = temp_shock_bd_job_sp`i' 
						if flag_spouse == 1 & temp_shock_bd_job_sp`i' != 0 & temp_shock_bd_job_hd`i' != 1 ;
						
			gen temp_shock_job`i'_c = temp_shock_job_hd_cond`i' ;
			replace temp_shock_job`i'_c = temp_shock_job_sp_cond`i'
						if flag_spouse == 1 & temp_shock_job_sp_cond`i' != 0 & temp_shock_job_hd_cond`i' != 1 ;

		};
	

/* Hospital bill shock (spending $1000 more than the previous years) */
	
	/* medical bill more than 75 percentile */
	
	
	foreach num in 75 90 95{;
	
		gen temp_shock_OOP`num' = .;

		forval yr = 1998(2)2016{;
		
			sum OOP if year == `yr', det;
			local OOP`num'`yr' r(p`num');
			replace temp_shock_OOP`num' = 0 if OOP <= `OOP`num'`yr'' & OOP != . & year == `yr';
			replace temp_shock_OOP`num' = 1 if OOP > `OOP`num'`yr'' & OOP != . & year == `yr';
			tab temp_shock_OOP`num' if year == `yr', m ;
		};
		
		gen temp_shock_OOPall`num' = .;

		forval yr = 1998(2)2016{;
		
			sum OOP_all if year == `yr', det;
			local OOP_all`num'`yr' r(p`num');
			replace temp_shock_OOPall`num' = 0 if OOP_all <= `OOP_all`num'`yr'' & OOP_all != . & year == `yr';
			replace temp_shock_OOPall`num' = 1 if OOP_all > `OOP_all`num'`yr'' & OOP_all != . & year == `yr';
			tab temp_shock_OOPall`num' if year == `yr', m ;
		};
		
		
		gen temp_shock_medicalcare`num' = .;

		forval yr = 1998(2)2010{;
		
			sum medicalcare if year == `yr', det;
			local medicalcare`yr' r(p`num');
			replace temp_shock_medicalcare`num' = 0 if medicalcare <= `medicalcare`yr'' & medicalcare != . & year == `yr';
			replace temp_shock_medicalcare`num' = 1 if medicalcare > `medicalcare`yr'' & medicalcare != . & year == `yr';
			tab temp_shock_medicalcare`num' if year == `yr', m ;
		};
		
	
	/* 1. Experienced hospital bill shock x years ago */
	
		sort unique_id year;
			forval i = 0(2)4{;
				foreach var in OOP OOPall medicalcare{;
					by unique_id: gen temp_shock_`var'`num'_pre`i' = temp_shock_`var'`num'[_n-`i'/2] 
																if year[_n-`i'/2] == year - `i'; 
					
				};
			};
	
	/* 2. Experienced hospital bill shock in past x years */
	
		foreach var in OOP OOPall medicalcare{;
		
			gen temp_shock_`var'`num'_0 =.;
			replace temp_shock_`var'`num'_0 = temp_shock_`var'`num'_pre0;
			
			gen temp_shock_`var'`num'_2 =.;
			replace temp_shock_`var'`num'_2 = (temp_shock_`var'`num'_pre0 == 1|temp_shock_`var'`num'_pre2 == 1)
												if temp_shock_`var'`num'_pre0 != . & temp_shock_`var'`num'_pre2 != .;
			
			gen temp_shock_`var'`num'_4 =.;
			replace temp_shock_`var'`num'_4 = (temp_shock_`var'`num'_pre0 == 1|temp_shock_`var'`num'_pre2 == 1|temp_shock_`var'`num'_pre4 == 1)
												if temp_shock_`var'`num'_pre0 != . & temp_shock_`var'`num'_pre2 != . & 
												   temp_shock_`var'`num'_pre4 != .;
		
		};
		

	};
	
/* Age group */

	gen age_2534 = (24 < head_age & head_age < 35);
	gen age_pre35 = (head_age < 35 & head_age != .);
	gen age_3544 = (34 < head_age & head_age < 45);
	gen age_4554 = (44 < head_age & head_age < 55);
	gen age_5565 = (54 < head_age & head_age < 66);

/* Non-medical shock */
	
	
	gen temp_shock_non_medical = (temp_shock_job0 == 1|temp_shock_marriage == 1|temp_shock_moving_pre0 == 1)
									if temp_shock_job0 != . & temp_shock_marriage != . & temp_shock_moving_pre0 != .;

	gen temp_shock_non_medical4 = (temp_shock_job4 == 1|temp_shock_marriage4 == 1|temp_shock_moving4 == 1)
									if temp_shock_job4 != . & temp_shock_marriage != . & temp_shock_moving4 != .;
			
	gen temp_shock_non_medical_broad = (temp_shock_job0 == 1|temp_shock_marriage == 1|temp_shock_broad_moving0 == 1)
										if temp_shock_job0 != . & temp_shock_marriage != . & temp_shock_broad_moving0 != .;

	gen temp_shock_non_medical4_broad = (temp_shock_job4 == 1|temp_shock_marriage4 == 1|temp_shock_broad_moving4 == 1)
										if temp_shock_job4 != . & temp_shock_marriage != . & temp_shock_broad_moving4 != .;
	
/* Comparison with two years ago */

	gen flag_worse_2yrs_head = (compared_2yrs_head == 5) if compared_2yrs_head != .;
	gen flag_worse_2yrs_spouse = (compared_2yrs_spouse == 5) if compared_2yrs_spouse != .;
	
	gen flag_worse_2yrs = 0 if flag_worse_2yrs_spouse != . & flag_worse_2yrs_head != .;
	replace flag_worse_2yrs = 0 if flag_worse_2yrs_head != . & flag_spouse == 0;
	replace flag_worse_2yrs = 1 if flag_worse_2yrs_spouse == 1 | flag_worse_2yrs_head == 1;
	

	forval i = 0(2)2{;
	
		bysort unique_id: gen temp_flag_worse_2yrs`i' = flag_worse_2yrs[_n-`i'/2] if year[_n-`i'/2] == year - `i';
		
	};
	
	
	gen flag_worse_2yrs0 = temp_flag_worse_2yrs0;
	gen flag_worse_2yrs4 = 0 if temp_flag_worse_2yrs0 == 0 & temp_flag_worse_2yrs2 == 0;
	replace flag_worse_2yrs4 = 1 if temp_flag_worse_2yrs0 == 1 | temp_flag_worse_2yrs2 == 1;
	
/* Receiving UI */

		
	/* 1. Received UI x years ago */
	
		sort unique_id year;
		
		forval i = 0(1)5{;
			gen temp_flag_ui_pre`i' = .;
			
			forval yr = 1985(1)1996{;
				by unique_id: replace temp_flag_ui_pre`i' =  flag_ui[_n-`i'] if year == `yr' & year[_n-`i'] == `yr' - `i' ;
			};
		};

		forval i = 0(2)4{;
		
			forval yr = 1998(2)2016{;
				by unique_id: replace temp_flag_ui_pre`i' = flag_ui[_n-`i'/2] if year == `yr' & year[_n-`i'/2] == `yr' - `i' ;
			
			};
		};
	
	/* 2. Received UI in past x years */
	
	#delim;

		gen temp_flag_ui0 = temp_flag_ui_pre0;
		
		gen temp_flag_ui1_8596 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1)
											if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != .;
		
		gen temp_flag_ui2 =.;
		
		replace temp_flag_ui2 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1|temp_flag_ui_pre2 == 1)
											if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != . & 
											   temp_flag_ui_pre2 != . & year < 1997;
			
		replace temp_flag_ui2 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre2 == 1) 
											if temp_flag_ui_pre2 != . & temp_flag_ui_pre0 != . & year > 1997;
					
		gen temp_flag_ui3_8596 =.;
		
		replace temp_flag_ui3_8596 = (temp_flag_ui_pre0 == 1 |temp_flag_ui_pre1 == 1|
											 temp_flag_ui_pre2 == 1|temp_flag_ui_pre3 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != . & 
												   temp_flag_ui_pre2 != . & temp_flag_ui_pre3 != .;
						
		gen temp_flag_ui4 =.;
		
		replace temp_flag_ui4 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1|
										temp_flag_ui_pre2 == 1 | temp_flag_ui_pre3 == 1|temp_flag_ui_pre4 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != . & 
												   temp_flag_ui_pre2 != . & temp_flag_ui_pre3 != . & 
												   temp_flag_ui_pre4 != . & year < 1997;
								
		replace temp_flag_ui4 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre2 == 1|
										temp_flag_ui_pre4 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre2 != . & 
												   temp_flag_ui_pre4 != . & year > 1997;
					
		gen temp_flag_ui5_8596 =.;
		replace temp_flag_ui5_8596 = (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1|
											 temp_flag_ui_pre2 == 1 | temp_flag_ui_pre3 == 1|
											 temp_flag_ui_pre4 == 1|temp_flag_ui_pre5 == 1)
												if temp_flag_ui_pre0 != . & temp_flag_ui_pre1 != . & 
												   temp_flag_ui_pre2 != . & temp_flag_ui_pre3 != . & 
												   temp_flag_ui_pre4 != . & temp_flag_ui_pre5 != .;
				
				
		count if (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre1 == 1 | temp_flag_ui_pre2 == 1|
				  temp_flag_ui_pre3 == 1|temp_flag_ui_pre4 == 1) & temp_flag_ui_pre0 != . &
				  temp_flag_ui_pre1 != . & temp_flag_ui_pre2 != . & temp_flag_ui_pre3 != . & 
				  temp_flag_ui_pre4 != . & year < 1997;

		count if (temp_flag_ui_pre0 == 1 | temp_flag_ui_pre2 == 1|temp_flag_ui_pre4 == 1) & 
				  temp_flag_ui_pre0 != . & temp_flag_ui_pre2 != . & temp_flag_ui_pre4 != . & year > 1997;
		
		tab temp_flag_ui4, m ;

	
	
************************************************************************************************************************************


/* B. Process shock by each age group, preparing variables for heatmap */
#delim;
	gen temp_age_2534 = 1 if 24 < head_age & head_age < 35 ; 
	gen temp_age_3544 = 1 if 34 < head_age & head_age < 45 ; 	
	gen temp_age_4554 = 1 if 44 < head_age & head_age < 55 ; 	
	gen temp_age_5565 = 1 if 54 < head_age & head_age < 65 ; 
	
	foreach var in 2534 3544 4554 5565{;
		bysort unique_id: egen max_age_`var' = max(temp_age_`var'); 
		/* whether any age from the age range observed */
	};
	
	#delim;
	foreach var in moving_pre0 broad_moving_pre0 marriage_pre0
				pre0_job_hd pre0_job_sp pre0_bd_job_hd pre0_bd_job_sp
				OOP75 OOPall75 medicalcare75 non_medical non_medical_broad
				OOP90 OOPall90 medicalcare90
				OOP95 OOPall95 medicalcare95{;
				
				
		gen temp_`var'_2534 = . ;
		replace temp_`var'_2534 = temp_shock_`var' if 24 < head_age & head_age < 35 ;
		bysort unique_id: egen shock_`var'_2534  = max(temp_`var'_2534) ;
				
		gen temp_`var'_3544 = . ;
		replace temp_`var'_3544 = temp_shock_`var' if 34 < head_age & head_age < 45 ;
		bysort unique_id: egen shock_`var'_3544  = max(temp_`var'_3544) ;

		gen temp_`var'_4554 = . ;
		replace temp_`var'_4554 = temp_shock_`var' if 44 < head_age & head_age < 55 ;
		bysort unique_id: egen shock_`var'_4554  = max(temp_`var'_4554) ;

		gen temp_`var'_5565 = . ;
		replace temp_`var'_5565 = temp_shock_`var' if 54 < head_age & head_age < 65 ;
		bysort unique_id: egen shock_`var'_5565  = max(temp_`var'_5565) ;

		
	};
	
	gen temp_flag_ssqualified_2534 = flag_strict_ssqualified if 24 < head_age & head_age < 35 ;
	gen temp_flag_ssqualified_3544 = flag_strict_ssqualified if 34 < head_age & head_age < 45 ;
	gen temp_flag_ssqualified_4554 = flag_strict_ssqualified if 44 < head_age & head_age < 55 ;
	gen temp_flag_ssqualified_5565 = flag_strict_ssqualified if 54 < head_age & head_age < 65 ;
	
	foreach var in 2534 3544 4554 5565{;
		bysort unique_id: egen flag_ssqualified_`var' = max(temp_flag_ssqualified_`var');
	};
	
	foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{;
		bysort unique_id: egen `sev' = max(flag_`sev');
	};
	
	
	foreach med in OOP OOP_all medicalcare{;	
		gen `med'_2534 = `med' if 24 < head_age & head_age < 35 ;
		gen `med'_3544 = `med' if 34 < head_age & head_age < 45 ;
		gen `med'_4554 = `med' if 44 < head_age & head_age < 55 ;
		gen `med'_5565 = `med' if 54 < head_age & head_age < 65 ;
	};
		
	rename OOP_all_2534 OOPall_2534 ;
	rename OOP_all_3544 OOPall_3544 ;
	rename OOP_all_4554 OOPall_4554 ;
	rename OOP_all_5565 OOPall_5565 ;



	/* severe or not age each age group */
	foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp {;
		gen age_`sev' = .;
		replace age_`sev' = 0 if flag_`sev' == 0;
		replace age_`sev'= head_age if flag_`sev' == 1;
		
		gen temp_`sev'_2534 = .;
		replace temp_`sev'_2534 = (24 < age_`sev' & age_`sev' < 35) if max_age_2534 == 1 & age_`sev' != .;
		
		gen temp_`sev'_3544 = .;
		replace temp_`sev'_3544 = (34 < age_`sev' & age_`sev' < 45) if max_age_3544 == 1 & age_`sev' != .;

		gen temp_`sev'_4554 = .;
		replace temp_`sev'_4554 = (44 < age_`sev' & age_`sev' < 55) if max_age_4554 == 1 & age_`sev' != .;

		gen temp_`sev'_5565 = .;
		replace temp_`sev'_5565 = (54 < age_`sev' & age_`sev' < 65) if max_age_5565 == 1 & age_`sev' != .;

		tab temp_`sev'_2534, m ;
		tab temp_`sev'_3544, m ;
		tab temp_`sev'_4554, m ;
		tab temp_`sev'_5565, m ;
		
		sum temp_`sev'_* ;
	};
		


#delim;
	foreach age in 2534 3544 4554 5565{ ;
		foreach sev in severe severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp { ;

			bysort unique_id: egen `sev'_`age' = max(temp_`sev'_`age');
			
			tab `sev'_`age', m ;
			
			drop temp_`sev'_`age' ;
		} ;
	} ;



************************************************************************************************************************************

/* C. Preparing Variables used for bar chart */

#delim;

	sort unique_id year ;
		
/* Job shock (head, spouse, head or spouse)  */

	foreach var in hd sp{;
		gen temp_pre0_vol_quit_job_`var' = temp_vol_quit_job_`var' if first_di_rec_year == year ;
		bysort unique_id: egen pre0_vol_quit_job_`var' = max(temp_pre0_vol_quit_job_`var') ;
		tab pre0_vol_quit_job_`var' ;
		drop temp_pre0_vol_quit_job_`var' ;
	};

	gen pre0_vol_quit_job_c = . ;
	replace pre0_vol_quit_job_c = 0 if pre0_vol_quit_job_hd != . & pre0_vol_quit_job_sp != . ;
	replace pre0_vol_quit_job_c = 1 if pre0_vol_quit_job_c == 0 & (pre0_vol_quit_job_hd == 1 | pre0_vol_quit_job_sp == 1) ;
	
	tab pre0_vol_quit_job_c , m ;
	
	gen pre0_vol_quit_job = pre0_vol_quit_job_hd ;
	replace pre0_vol_quit_job = pre0_vol_quit_job_sp if flag_spouse == 1 & pre0_vol_quit_job_hd != 1 & pre0_vol_quit_job_sp != 0 ;
	
	tab pre0_vol_quit_job , m ;

	
	forval i = 0(2)4{;
		foreach var in hd sp{;
			/* Whether experienced job shock in i years before the first DI receipt year */
			gen temp_pre`i'_job_shock_`var' = temp_shock_job_`var'`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
			bysort unique_id: egen pre`i'_job_shock_`var' = max(temp_pre`i'_job_shock_`var');
			tab pre`i'_job_shock_`var', m ;
			drop temp_pre`i'_job_shock_`var' ;
		};
		
		gen temp_pre`i'_job_shock = temp_shock_job`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_job_shock = max(temp_pre`i'_job_shock);
		tab pre`i'_job_shock, m ;
		drop temp_pre`i'_job_shock ;
		
	};
	

	/* Conditional */

	forval i = 0(2)4{;
		foreach var in hd_cond sp_cond{;
			/* Whether experienced job shock in i years before the first DI receipt year */
			gen temp_pre`i'_job_shock_`var' = temp_shock_job_`var'`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
			bysort unique_id: egen pre`i'_job_shock_`var' = max(temp_pre`i'_job_shock_`var');
			tab pre`i'_job_shock_`var', m ;
			drop temp_pre`i'_job_shock_`var';
		};
		
		rename pre`i'_job_shock_hd_cond pre`i'_job_shock_hd_c ;
		rename pre`i'_job_shock_sp_cond pre`i'_job_shock_sp_c ;
		
		
		gen temp_pre`i'_job_shock_c = temp_shock_job`i'_c if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_job_shock_c = max(temp_pre`i'_job_shock_c);
		tab pre`i'_job_shock_c ;
		drop temp_pre`i'_job_shock_c ;
	};
	
	

	/* broad shock */ 
	
	forval i = 0(2)4{;
		foreach var in hd sp{;
			/* Whether experienced job shock in i years before the first DI receipt year */
			gen temp_pre`i'_broad_job_shock_`var' = temp_shock_bd_job_`var'`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
			bysort unique_id: egen pre`i'_job_broad_shock_`var' = max(temp_pre`i'_broad_job_shock_`var');
			tab pre`i'_job_broad_shock_`var', m ;
			drop temp_pre`i'_broad_job_shock_`var';
		};
		
		gen temp_pre`i'_broad_job_shock = temp_shock_broad_job`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_job_broad_shock = max(temp_pre`i'_broad_job_shock);
		tab pre`i'_job_broad_shock, m;
		drop temp_pre`i'_broad_job_shock;
	
	};
	
	
/* Hospital bill shock */ 

	#delim;
	foreach var in OOP OOPall medicalcare{;
		forval i = 0(2)4{;
			foreach num in 75 90 95{;
				/* Experienced 1000 dollars or more medical bill in i years before the first DI receipt year */
				gen temp_pre`i'_`var'`num'_shock = temp_shock_`var'`num'_`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
				bysort unique_id: egen pre`i'_`var'`num'_shock = max(temp_pre`i'_`var'`num'_shock);
				tab pre`i'_`var'`num'_shock, m ;
				drop temp_pre`i'_`var'`num'_shock ;
			};
		};
	};
	
	
/* Moving shock */

	forval i = 0(2)4{;
		/* Experienced distressed move in i years before the first DI receipt year */
		gen temp_pre`i'_moving_shock = temp_shock_moving`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_move_shock = max(temp_pre`i'_moving_shock);
		tab pre`i'_move_shock, m ;
		drop temp_pre`i'_moving_shock ;
	};

	
	/* broad shock */ 
	
	#delim;
	forval i = 0(2)4{;
		/* Experienced distressed move in i years before the first DI receipt year */
		gen temp_pre`i'_broad_moving_shock = temp_shock_broad_moving`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_move_broad_shock = max(temp_pre`i'_broad_moving_shock);
		tab pre`i'_move_broad_shock, m;
		drop temp_pre`i'_broad_moving_shock ;
	};

	
/* Divorce */
	
	forval i = 0(2)4{;
		/* Experienced marriage shock in i years before the first DI receipt year */
		gen temp_pre`i'_marriage_shock = temp_shock_marriage`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_marriage_shock = max(temp_pre`i'_marriage_shock);
		tab pre`i'_marriage_shock, m ;
		drop temp_pre`i'_marriage_shock ;
	};

	
/* Any non-medical shock above (including head/spouse lost job, distressed move, divorce) */

	#delim;
	forval i = 0(2)4{;
		gen pre`i'_non_medical_shock = (pre`i'_marriage_shock == 1 | pre`i'_move_shock == 1 | pre`i'_job_shock == 1)
										if pre`i'_marriage_shock != . & pre`i'_move_shock !=. & pre`i'_job_shock != .;
			
		gen pre`i'_non_medical_shock_broad = (pre`i'_marriage_shock == 1 | pre`i'_move_broad_shock == 1 | pre`i'_job_shock == 1)
										if pre`i'_marriage_shock != . & pre`i'_move_broad_shock !=. & pre`i'_job_shock != .;
													
		gen pre`i'_non_medical_shock_c = (pre`i'_marriage_shock == 1 | pre`i'_move_shock == 1 | pre`i'_job_shock_c == 1)
										if pre`i'_marriage_shock != . & pre`i'_move_shock !=. & pre`i'_job_shock_c  !=.;
					
		gen pre`i'_non_medical_shock_broad_c = (pre`i'_marriage_shock == 1 | pre`i'_move_broad_shock == 1 |pre`i'_job_shock_c == 1)
										if pre`i'_marriage_shock != . & pre`i'_move_broad_shock !=. & pre`i'_job_shock_c !=. ;
		
	};
	
	tab pre4_non_medical_shock, m ;
	tab pre4_non_medical_shock_broad, m ;
	tab pre4_non_medical_shock_c, m ;
	tab pre4_non_medical_shock_broad_c, m ;


	
 
/* Banking relation (at first rec, and 1 yr before rec) flag_banking */

	gen temp_pre0_app_banking = flag_banking if first_di_rec_year == year;
	gen temp_pre1_app_banking = flag_banking[_n-1] if first_di_rec_year == year;
	
	bysort unique_id: egen pre0_app_banking = max(temp_pre0_app_banking);
	bysort unique_id: egen pre1_app_banking = max(temp_pre1_app_banking);
	
	tab pre0_app_banking, m ;
	tab pre1_app_banking, m ;
	
	drop temp_pre0_app_banking temp_pre1_app_banking ;

/*	Marriage (at first rec, and 1 yr before rec) */

	gen temp_pre0_app_marriage = flag_married if first_di_rec_year == year;
	gen temp_pre1_app_marriage = flag_married[_n-1] if first_di_rec_year == year;
	
	bysort unique_id: egen pre0_app_marriage = max(temp_pre0_app_marriage);
	bysort unique_id: egen pre1_app_marriage = max(temp_pre1_app_marriage);

	tab pre0_app_marriage, m ;
	tab pre1_app_marriage, m ;
	
	drop temp_pre0_app_marriage temp_pre1_app_marriage ;

/*	Home own (at first rec, and 1 yr before rec) */

	gen temp_pre0_app_homeown = flag_home_own if first_di_rec_year == year;
	gen temp_pre1_app_homeown = flag_home_own[_n-1] if first_di_rec_year == year;
	
	bysort unique_id: egen pre0_app_homeown = max(temp_pre0_app_homeown);
	bysort unique_id: egen pre1_app_homeown = max(temp_pre1_app_homeown);

	tab pre0_app_homeown, m ;
	tab pre1_app_homeown, m ;
	
	drop temp_pre0_app_homeown temp_pre1_app_homeown;
	
/*	Insurance (at first rec, and 1 yr before rec) */
 
	foreach var in ins_private ins_public anyins{;
		gen temp_pre0_app_`var' = flag_`var'_head if first_di_rec_year == year;
		gen temp_pre1_app_`var' = flag_`var'_head[_n-1] if first_di_rec_year == year;
	
		bysort unique_id: egen pre0_app_`var' = max(temp_pre0_app_`var');
		bysort unique_id: egen pre1_app_`var' = max(temp_pre1_app_`var');
		
		tab pre0_app_`var', m ;
		tab pre1_app_`var', m ;
		
		drop temp_pre0_app_`var' temp_pre1_app_`var';
		
	};
 
/*	Severity (at first rec, and 1 yr before rec) */
 
	/* standard severity */
		foreach sev in severe severe2 severe3 moderate moderate3 moderate5 severe_mhd severe_mhp severe_mhdp
						{;
			gen temp_pre0_app_`sev' = flag_`sev' if first_di_rec_year == year;
			by unique_id: gen temp_pre1_app_`sev' = flag_`sev'[_n-1] if first_di_rec_year == year;
		 
			bysort unique_id: egen pre0_app_`sev' = max(temp_pre0_app_`sev');
			bysort unique_id: egen pre1_app_`sev' = max(temp_pre1_app_`sev');
		};

	/* answer there is limition, but not at all */
	
		gen temp_pre0_app_notatall7 = flag_notatall7 if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_notatall7 = flag_notatall7[_n-1] if first_di_rec_year == year;
		
		bysort unique_id: egen pre0_app_notatall7 = max(temp_pre0_app_notatall7);
		bysort unique_id: egen pre1_app_notatall7 = max(temp_pre1_app_notatall7);
	
	/* answer no limitation */
	
		gen temp_pre0_app_nolimit = flag_nolimit if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_nolimit = flag_nolimit[_n-1] if first_di_rec_year == year;
		
		bysort unique_id: egen pre0_app_nolimit = max(temp_pre0_app_nolimit);
		bysort unique_id: egen pre1_app_nolimit = max(temp_pre1_app_nolimit);
				
	/* general health care: Fair or poor */
	
		gen temp_pre0_app_health45 = flag_health_status45 if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_health45 = flag_health_status45[_n-1] if first_di_rec_year == year;
	 
		bysort unique_id: egen pre0_app_health45 = max(temp_pre0_app_health45);
		bysort unique_id: egen pre1_app_health45 = max(temp_pre1_app_health45);

	/* general health care: Poor */

		gen temp_pre0_app_health5 = flag_health_status5 if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_health5 = flag_health_status5[_n-1] if first_di_rec_year == year;
	 
		bysort unique_id: egen pre0_app_health5 = max(temp_pre0_app_health5);
		bysort unique_id: egen pre1_app_health5 = max(temp_pre1_app_health5);

	/* ADL */
	
		gen temp_pre0_app_adl = flag_adl if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_adl = flag_adl[_n-1] if first_di_rec_year == year;
	 
		bysort unique_id: egen pre0_app_adl = max(temp_pre0_app_adl);
		bysort unique_id: egen pre1_app_adl = max(temp_pre1_app_adl);

	/* IADL */
	
		gen temp_pre0_app_iadl = flag_iadl if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_iadl = flag_iadl[_n-1] if first_di_rec_year == year;
	 
		bysort unique_id: egen pre0_app_iadl = max(temp_pre0_app_iadl);
		bysort unique_id: egen pre1_app_iadl = max(temp_pre1_app_iadl);

	/* Some condition */
	
		gen temp_pre0_app_condition = flag_condition if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_condition = flag_condition[_n-1] if first_di_rec_year == year;
	 
		bysort unique_id: egen pre0_app_condition = max(temp_pre0_app_condition);
		bysort unique_id: egen pre1_app_condition = max(temp_pre1_app_condition);

	/* Any condition */
	
		gen temp_pre0_app_anycondition = flag_anycondition if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_anycondition = flag_anycondition[_n-1] if first_di_rec_year == year;
	 
		bysort unique_id: egen pre0_app_anycondition = max(temp_pre0_app_anycondition);
		bysort unique_id: egen pre1_app_anycondition = max(temp_pre1_app_anycondition);

/* Consumption */

	foreach i in total N_educ fd_ho_hlth_tp fd_ho_hlth fd_ho N_hlth{;
		gen temp_pre0_app_`i' = hhexp_`i' if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_`i' = hhexp_`i'[_n-1] if first_di_rec_year == year;

		bysort unique_id: egen pre0_app_hhexp_`i' = max(temp_pre0_app_`i');
		bysort unique_id: egen pre1_app_hhexp_`i' = max(temp_pre1_app_`i');
		
		drop temp_pre0_app_`i' temp_pre1_app_`i';
	};
	
/* Food stamp */
 
	gen temp_pre0_app_fdstamp = flag_foodstamp if first_di_rec_year == year;
	by unique_id: gen temp_pre1_app_fdstamp = flag_foodstamp[_n-1] if first_di_rec_year == year;
 
 	bysort unique_id: egen pre0_app_fdstamp = max(temp_pre0_app_fdstamp);
	bysort unique_id: egen pre1_app_fdstamp = max(temp_pre1_app_fdstamp);
	
	tab pre0_app_fdstamp, m ;
	tab pre1_app_fdstamp, m ;
	
	drop temp_pre0_app_fdstamp temp_pre1_app_fdstamp;
	
/* ADC/AFDC, Social Security, unemployment compensation, worker's compensation */

	foreach var in mean_tested si_all si_no_ss{;
	
		gen temp_pre0_app_`var' = flag_`var' if first_di_rec_year == year;
		by unique_id: gen temp_pre1_app_`var' = flag_`var'[_n-1] if first_di_rec_year == year;
 
		bysort unique_id: egen pre0_app_`var' = max(temp_pre0_app_`var');
		bysort unique_id: egen pre1_app_`var' = max(temp_pre1_app_`var');
		
		tab pre0_app_`var', m ;
		tab pre1_app_`var', m ;
		
		drop temp_pre0_app_`var' temp_pre1_app_`var';
	
	};

/* Getting worse comparing to 2 years ago */ 

	#delim;
	gen temp_pre4_app_worse_2yr = flag_worse_2yrs4 if first_di_rec_year == year; 
	bysort unique_id: egen pre4_app_worse_2yr = max(temp_pre4_app_worse_2yr);
	
	tab pre4_app_worse_2yr, m ;
	drop temp_pre4_app_worse_2yr ;

/* Cash assistance fron relative/non-relative */


	foreach var in relative nonrelative{;

		gen temp_pre0_cash_`var' = flag_cash_`var' if first_di_rec_year == year;
		by unique_id: gen temp_pre1_cash_`var' = flag_cash_`var'[_n-1] if first_di_rec_year == year;
		
		bysort unique_id: egen pre0_cash_`var' = max(temp_pre0_cash_`var');
		bysort unique_id: egen pre1_cash_`var' = max(temp_pre1_cash_`var');
		
		tab pre0_cash_`var', m ;
		tab pre1_cash_`var', m ;
		
		drop temp_pre0_cash_`var' temp_pre1_cash_`var';

	};
	
/* How many received UI in 4 years before receiving DI  */

	forval i = 0(2)4{;
		gen temp_pre`i'_ui = temp_flag_ui`i' if first_di_rec_year == year & flag_di_rec_ever == 1;
		bysort unique_id: egen pre`i'_ui = max(temp_pre`i'_ui);
		tab pre`i'_ui, m ;
		drop temp_pre`i'_ui ;
	};


/* Time */

foreach var in time_housework time_leisure time_work amt_care_adult amt_care_child {;
	gen temp_pre0_app_`var' = `var' if first_di_rec_year == year;
	by unique_id: gen temp_pre1_app_`var' = `var'[_n-1] if first_di_rec_year == year;
	
	bysort unique_id: egen pre0_app_`var' = max(temp_pre0_app_`var');
	bysort unique_id: egen pre1_app_`var' = max(temp_pre1_app_`var');

	tab pre0_app_`var', m ;
	tab pre1_app_`var', m ;

	drop temp_pre0_app_`var' temp_pre1_app_`var' ;
};
	
	
************************************************************************************************************************************
/* D. Mechanism */

	#delim ;
	
	sort unique_id year ;
	
/* 1. Spouse earnings at severity onset */
	

	gen temp_pre0_sev_spouse_earn_cond = inc_earn_spouse_cond if first_severe_year == year ;
	by unique_id: gen temp_pre1_sev_spouse_earn_cond = inc_earn_spouse_cond[_n-1] if first_severe_year == year ;

	bysort unique_id: egen pre0_sev_spouse_earn_cond = max(temp_pre0_sev_spouse_earn_cond) ;
	bysort unique_id: egen pre1_sev_spouse_earn_cond = max(temp_pre1_sev_spouse_earn_cond) ;

	count if pre0_sev_spouse_earn_cond == . ;
	count if pre1_sev_spouse_earn_cond == . ;
	
	sum pre0_sev_spouse_earn_cond ;
	sum pre1_sev_spouse_earn_cond ;
	
	drop temp_pre0_sev_spouse_earn_cond temp_pre1_sev_spouse_earn_cond ;
	
	
	gen temp_pre0_sev_spouse_earn = inc_earn_spouse if first_severe_year == year ;
	by unique_id: gen temp_pre1_sev_spouse_earn = inc_earn_spouse[_n-1] if first_severe_year == year ;

	bysort unique_id: egen pre0_sev_spouse_earn = max(temp_pre0_sev_spouse_earn) ;
	bysort unique_id: egen pre1_sev_spouse_earn = max(temp_pre1_sev_spouse_earn) ;

	count if pre0_sev_spouse_earn == . ;
	count if pre1_sev_spouse_earn == . ;
	
	sum pre0_sev_spouse_earn ;
	sum pre1_sev_spouse_earn ;
	
	drop temp_pre0_sev_spouse_earn temp_pre1_sev_spouse_earn ;
	
	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{ ;
	
		gen temp_pre0_`sev'_sp_earn_c = inc_earn_spouse_cond if first_`sev'_year == year ;
		by unique_id: gen temp_pre1_`sev'_sp_earn_c = inc_earn_spouse_cond[_n-1] if first_`sev'_year == year ;

		bysort unique_id: egen pre0_`sev'_spouse_earn_c = max(temp_pre0_`sev'_sp_earn_c) ;
		bysort unique_id: egen pre1_`sev'_spouse_earn_c = max(temp_pre1_`sev'_sp_earn_c) ;

		count if pre0_`sev'_spouse_earn_c == . ;
		count if pre1_`sev'_spouse_earn_c == . ;
		
		sum pre0_`sev'_spouse_earn_c ;
		sum pre1_`sev'_spouse_earn_c ;
		
		drop temp_pre0_`sev'_sp_earn_c temp_pre1_`sev'_sp_earn_c ;
		
		
		gen temp_pre0_`sev'_sp_earn = inc_earn_spouse if first_`sev'_year == year ;
		by unique_id: gen temp_pre1_`sev'_sp_earn = inc_earn_spouse[_n-1] if first_`sev'_year == year ;

		bysort unique_id: egen pre0_`sev'_spouse_earn = max(temp_pre0_`sev'_sp_earn) ;
		bysort unique_id: egen pre1_`sev'_spouse_earn = max(temp_pre1_`sev'_sp_earn) ;

		count if pre0_`sev'_spouse_earn == . ;
		count if pre1_`sev'_spouse_earn == . ;
		
		sum pre0_`sev'_spouse_earn ;
		sum pre1_`sev'_spouse_earn ;
		
		drop temp_pre0_`sev'_sp_earn temp_pre1_`sev'_sp_earn ;
	
	} ;

	
/* 2. Food stamp at severity onset */

	gen temp_pre0_sev_fdstamp = flag_foodstamp if first_severe_year == year;
	by unique_id: gen temp_pre1_sev_fdstamp = flag_foodstamp[_n-1] if first_severe_year == year;
 
 	bysort unique_id: egen pre0_sev_fdstamp = max(temp_pre0_sev_fdstamp);
	bysort unique_id: egen pre1_sev_fdstamp = max(temp_pre1_sev_fdstamp);
	
	tab pre0_sev_fdstamp, m ;
	tab pre1_sev_fdstamp, m ;
	
	drop temp_pre0_sev_fdstamp temp_pre1_sev_fdstamp;

	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					 {;
	
		gen temp_pre0_`sev'_fdstamp = flag_foodstamp if first_`sev'_year == year;
		by unique_id: gen temp_pre1_`sev'_fdstamp = flag_foodstamp[_n-1] if first_`sev'_year == year;
	 
		bysort unique_id: egen pre0_`sev'_fdstamp = max(temp_pre0_`sev'_fdstamp);
		bysort unique_id: egen pre1_`sev'_fdstamp = max(temp_pre1_`sev'_fdstamp);
		
		tab pre0_`sev'_fdstamp, m ;
		tab pre1_`sev'_fdstamp, m ;
		
		drop temp_pre0_`sev'_fdstamp temp_pre1_`sev'_fdstamp;	

	};
	
/* 3. banking relation at severity onset  */

	gen temp_pre0_sev_banking = flag_banking if first_severe_year == year;
	by unique_id: gen temp_pre1_sev_banking = flag_banking[_n-1] if first_severe_year == year;
	
	bysort unique_id: egen pre0_sev_banking = max(temp_pre0_sev_banking);
	bysort unique_id: egen pre1_sev_banking = max(temp_pre1_sev_banking);
	
	tab pre0_sev_banking, m ;
	tab pre1_sev_banking, m ;
	
	drop temp_pre0_sev_banking temp_pre1_sev_banking ;

	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{ ;
	
		gen temp_pre0_`sev'_banking = flag_banking if first_`sev'_year == year;
		by unique_id: gen temp_pre1_`sev'_banking = flag_banking[_n-1] if first_`sev'_year == year;
		
		bysort unique_id: egen pre0_`sev'_banking = max(temp_pre0_`sev'_banking);
		bysort unique_id: egen pre1_`sev'_banking = max(temp_pre1_`sev'_banking);
		
		tab pre0_`sev'_banking, m ;
		tab pre1_`sev'_banking, m ;
		
		drop temp_pre0_`sev'_banking temp_pre1_`sev'_banking ;

	};
	
/* 4. UI/WC at severity onset  */

	gen temp_pre0_sev_ui = flag_ui if first_severe_year == year;
	by unique_id: gen temp_pre1_sev_ui = flag_si_no_ss[_n-1] if first_severe_year == year;
	
	bysort unique_id: egen pre0_sev_ui = max(temp_pre0_sev_ui);
	bysort unique_id: egen pre1_sev_ui = max(temp_pre1_sev_ui);
	
	tab pre0_sev_ui, m ;
	tab pre1_sev_ui, m ;
	
	drop temp_pre0_sev_ui temp_pre1_sev_ui ;
	
	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{ ;

		gen temp_pre0_`sev'_ui = flag_ui if first_`sev'_year == year;
		by unique_id: gen temp_pre1_`sev'_ui = flag_si_no_ss[_n-1] if first_`sev'_year == year;
		
		bysort unique_id: egen pre0_`sev'_ui = max(temp_pre0_`sev'_ui);
		bysort unique_id: egen pre1_`sev'_ui = max(temp_pre1_`sev'_ui);
		
		tab pre0_`sev'_ui, m ;
		tab pre1_`sev'_ui, m ;
		
		drop temp_pre0_`sev'_ui temp_pre1_`sev'_ui ;
	
	};

/* 5. home own at severity onset  */

	gen temp_pre0_sev_homeown = flag_home_own if first_severe_year == year;
	by unique_id: gen temp_pre1_sev_homeown = flag_home_own[_n-1] if first_severe_year == year;
	
	bysort unique_id: egen pre0_sev_homeown = max(temp_pre0_sev_homeown);
	bysort unique_id: egen pre1_sev_homeown = max(temp_pre1_sev_homeown);

	tab pre0_sev_homeown, m ;
	tab pre1_sev_homeown, m ;
	
	drop temp_pre0_sev_homeown temp_pre1_sev_homeown;

	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					 { ;

		gen temp_pre0_`sev'_homeown = flag_home_own if first_`sev'_year == year;
		by unique_id: gen temp_pre1_`sev'_homeown = flag_home_own[_n-1] if first_`sev'_year == year;
		
		bysort unique_id: egen pre0_`sev'_homeown = max(temp_pre0_`sev'_homeown);
		bysort unique_id: egen pre1_`sev'_homeown = max(temp_pre1_`sev'_homeown);

		tab pre0_`sev'_homeown, m ;
		tab pre1_`sev'_homeown, m ;
		
		drop temp_pre0_`sev'_homeown temp_pre1_`sev'_homeown;
	
	} ;
	
/* 6. Insurance at severity onset */

	foreach var in ins_private ins_public anyins{;
		gen temp_pre0_sev_`var' = flag_`var'_head if first_severe_year == year;
		by unique_id: gen temp_pre1_sev_`var' = flag_`var'_head[_n-1] if first_severe_year == year;
	
		bysort unique_id: egen pre0_sev_`var' = max(temp_pre0_sev_`var');
		bysort unique_id: egen pre1_sev_`var' = max(temp_pre1_sev_`var');
		
		tab pre0_sev_`var', m ;
		tab pre1_sev_`var', m ;
		
		drop temp_pre0_sev_`var' temp_pre1_sev_`var';
		
	};
	
	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					 { ;
		foreach var in ins_private ins_public anyins{;
			gen t_pre0_`sev'_`var' = flag_`var'_head if first_`sev'_year == year;
			by unique_id: gen t_pre1_`sev'_`var' = flag_`var'_head[_n-1] if first_`sev'_year == year;
		
			bysort unique_id: egen pre0_`sev'_`var' = max(t_pre0_`sev'_`var');
			bysort unique_id: egen pre1_`sev'_`var' = max(t_pre1_`sev'_`var');
			
			tab pre0_`sev'_`var', m ;
			tab pre1_`sev'_`var', m ;
			
			drop t_pre0_`sev'_`var' t_pre1_`sev'_`var';
			
		};	
	};

/* 7. Marriage at severity onset */

	gen temp_pre0_sev_marriage = flag_married if first_severe_year == year;
	by unique_id: gen temp_pre1_sev_marriage = flag_married[_n-1] if first_severe_year == year;
	
	bysort unique_id: egen pre0_sev_marriage = max(temp_pre0_sev_marriage);
	bysort unique_id: egen pre1_sev_marriage = max(temp_pre1_sev_marriage);

	tab pre0_sev_marriage, m ;
	tab pre1_sev_marriage, m ;
	
	drop temp_pre0_sev_marriage temp_pre1_sev_marriage ;

	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
				 { ;

		gen t_pre0_`sev'_marriage = flag_married if first_`sev'_year == year;
		by unique_id: gen t_pre1_`sev'_marriage = flag_married[_n-1] if first_`sev'_year == year;
		
		bysort unique_id: egen pre0_`sev'_marriage = max(t_pre0_`sev'_marriage);
		bysort unique_id: egen pre1_`sev'_marriage = max(t_pre1_`sev'_marriage);

		tab pre0_`sev'_marriage, m ;
		tab pre1_`sev'_marriage, m ;
		
		drop t_pre0_`sev'_marriage t_pre1_`sev'_marriage ;
	
	};
	
/* 8. ADC/AFDC, Social Security, unemployment compensation, worker's compensation at severity onset */

	foreach var in mean_tested si_all si_no_ss{;
	
		gen temp_pre0_sev_`var' = flag_`var' if first_severe_year == year;
		by unique_id: gen temp_pre1_sev_`var' = flag_`var'[_n-1] if first_severe_year == year;
 
		bysort unique_id: egen pre0_sev_`var' = max(temp_pre0_sev_`var');
		bysort unique_id: egen pre1_sev_`var' = max(temp_pre1_sev_`var');
		
		tab pre0_sev_`var', m ;
		tab pre1_sev_`var', m ;
		
		drop temp_pre0_sev_`var' temp_pre1_sev_`var';
	
	};
	
	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{ ;

		foreach var in mean_tested si_all si_no_ss{;
	
			gen t_pre0_`sev'_`var' = flag_`var' if first_`sev'_year == year;
			by unique_id: gen t_pre1_`sev'_`var' = flag_`var'[_n-1] if first_`sev'_year == year;
	 
			bysort unique_id: egen pre0_`sev'_`var' = max(t_pre0_`sev'_`var');
			bysort unique_id: egen pre1_`sev'_`var' = max(t_pre1_`sev'_`var');
			
			tab pre0_`sev'_`var', m ;
			tab pre1_`sev'_`var', m ;
			
			drop t_pre0_`sev'_`var' t_pre1_`sev'_`var';
		};
	};



/* 9. SS credits at severity onset*/

	gen temp_pre0_sev_SScredit = total_SScredit if first_severe_year == year ;
	by unique_id: gen temp_pre1_sev_SScredit = total_SScredit[_n-1] if first_severe_year == year ;
	
	bysort unique_id: egen pre0_sev_SScredit = max(temp_pre0_sev_SScredit) ;
	bysort unique_id: egen pre1_sev_SScredit = max(temp_pre1_sev_SScredit) ;

	count if pre0_sev_SScredit == . ;
	count if pre1_sev_SScredit == . ;
	
	sum pre0_sev_SScredit ;
	sum pre1_sev_SScredit ;
	
	drop temp_pre0_sev_SScredit temp_pre1_sev_SScredit ;

	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{ ;

		gen t_pre0_`sev'_SScredit = total_SScredit if first_`sev'_year == year ;
		by unique_id: gen t_pre1_`sev'_SScredit = total_SScredit[_n-1] if first_`sev'_year == year ;
		
		bysort unique_id: egen pre0_`sev'_SScredit = max(t_pre0_`sev'_SScredit) ;
		bysort unique_id: egen pre1_`sev'_SScredit = max(t_pre1_`sev'_SScredit) ;

		count if pre0_`sev'_SScredit == . ;
		count if pre1_`sev'_SScredit == . ;
		
		sum pre0_`sev'_SScredit ;
		sum pre1_`sev'_SScredit ;
		
		drop t_pre0_`sev'_SScredit t_pre1_`sev'_SScredit ;

	};

/* 10. Cash assistance fron relative/non-relative at severe onset */


	foreach var in relative nonrelative{;

		gen temp_pre0_sev_cash_`var' = flag_cash_`var' if first_severe_year == year;
		by unique_id: gen temp_pre1_sev_cash_`var' = flag_cash_`var'[_n-1] if first_severe_year == year;
		
		bysort unique_id: egen pre0_sev_cash_`var' = max(temp_pre0_sev_cash_`var');
		bysort unique_id: egen pre1_sev_cash_`var' = max(temp_pre1_sev_cash_`var');
		
		tab pre0_sev_cash_`var', m ;
		tab pre1_sev_cash_`var', m ;
		
		drop temp_pre0_sev_cash_`var' temp_pre1_sev_cash_`var';

	};
	
	

	
/* 11. Consumption */

foreach var in total fd_ho_hlth fd_ho N_hlth{;

	gen t_pre0_hhexp_`var' = hhexp_`var' if first_severe_year == year;
	by unique_id: gen t_pre1_hhexp_`var' = hhexp_`var'[_n-1] if first_severe_year == year ;
	
	bysort unique_id: egen pre0_sev_hhexp_`var' = max(t_pre0_hhexp_`var') ;
	bysort unique_id: egen pre1_sev_hhexp_`var' = max(t_pre1_hhexp_`var') ;
	
	count ;
	summ pre0_sev_hhexp_`var' ;
	summ pre1_sev_hhexp_`var' ;
	

	drop t_pre0_hhexp_`var' t_pre1_hhexp_`var' ;

};

	foreach sev in severe2 severe3 moderate severe_mhd severe_mhp severe_mhdp
					{ ;
		foreach var in total fd_ho_hlth fd_ho N_hlth {;

			gen t_pre0_hh_`var'_`sev' = hhexp_`var' if first_`sev'_year == year;
			by unique_id: gen t_pre1_hh_`var'_`sev' = hhexp_`var'[_n-1] if first_`sev'_year == year ;
			
			bysort unique_id: egen pre0_`sev'_hexp_`var' = max(t_pre0_hh_`var'_`sev') ;
			bysort unique_id: egen pre1_`sev'_hexp_`var' = max(t_pre1_hh_`var'_`sev') ;
			
			count ;
			summ pre0_`sev'_hexp_`var' ;
			summ pre1_`sev'_hexp_`var' ;
			

			drop t_pre0_hh_`var'_`sev' t_pre1_hh_`var'_`sev' ;

		};
	};
	
/* 12. Time */

foreach var in time_housework time_leisure time_work amt_care_adult amt_care_child {;
	gen temp_pre0_`var' = `var' if first_severe_year == year;
	by unique_id: gen temp_pre1_`var' = `var'[_n-1] if first_severe_year == year;
	
	bysort unique_id: egen pre0_sev_`var' = max(temp_pre0_`var');
	bysort unique_id: egen pre1_sev_`var' = max(temp_pre1_`var');

	tab pre0_sev_`var', m ;
	tab pre1_sev_`var', m ;

	drop temp_pre0_`var' temp_pre1_`var' ;
};


***********************************************************************************************************************************	

/* Additional variables */

/* 1. The youngest age entering the dataset for each sample */

	#delim ;
	
	bysort unique_id: egen min_age = min(head_age) ;



/* 2. The number of observations for each sample */
	
	bysort unique_id: gen temp_num_observation = _n ;
	bysort unique_id: egen num_observation = max(temp_num_observation) ;
	drop temp_num_observation ;
	
/* 3. observable 4 yr before DI */

	#delim;

	sort unique_id year ;
	
	gen temp_flag_observe_pre4 = . ; /* missing if not receiving DI at all */
	replace temp_flag_observe_pre4 = 0 if flag_di_rec_ever == 1 ; /* 0 if we cannot observe entire 4 years before DI rec */
	bysort unique_id: replace temp_flag_observe_pre4 = 1 
				if first_di_rec_year < 1997 & year[_n-4] == first_di_rec_year - 4 & first_di_rec_year != .;
	bysort unique_id: replace temp_flag_observe_pre4 = 1 
				if first_di_rec_year == 1998 & year[_n-3] == first_di_rec_year - 4 & first_di_rec_year != . ;
	bysort unique_id: replace temp_flag_observe_pre4 = 1 
				if first_di_rec_year > 1998 & year[_n-2] == first_di_rec_year - 4 & first_di_rec_year != . ;
	
	bysort unique_id: egen flag_observe_pre4 = max(temp_flag_observe_pre4) ;
	tab flag_observe_pre4, m ;

	
***********************************************************************************************************************************	

#delim;

sum pre1_app_hhexp_total, det;
replace pre1_app_hhexp_total = . if pre1_app_hhexp_total > 150000;

sum pre1_sev_hhexp_total, det;
replace pre1_sev_hhexp_total = . if pre1_sev_hhexp_total > 150000;

sum pre0_sev_hhexp_total, det;
replace pre0_sev_hhexp_total = . if pre0_sev_hhexp_total > 150000;

sum pre1_app_hhexp_N_hlth, det;
replace pre1_app_hhexp_N_hlth = . if pre1_app_hhexp_N_hlth > 150000;

sum pre1_sev_hhexp_N_hlth, det;
replace pre1_sev_hhexp_N_hlth = . if pre1_sev_hhexp_N_hlth > 150000;

sum pre0_sev_hhexp_N_hlth, det;
replace pre0_sev_hhexp_N_hlth = . if pre0_sev_hhexp_N_hlth > 150000;

save "`output'/psid_figure_`z'.dta", replace;

};

capture log close;
 
************************************************************************************************************************************
