#delim;

/*
Standardized sample ZIP selection for all periods
*/

local start0004 2000;
local end0004   2004;
local start0509 2005;
local end0509   2009;
local start1014 2010;
local end1014   2014;

/* *************************** */
/* **** OUTCOME: EVICTION **** */
/* *************************** */

if "`progtype'" == "evict" {;

local evictcutoff_zip		5	 ;
local evictcutoff_fips		15	 ; /* Each FIPS has an average of 13 ZIP, the IQR is 3-14 */
local evictcutoff_lowyear 	.0001; 

foreach geo in fips zip {;

foreach period in 0509 1014 {;

	global evictlist`period'_`geo' ;
	use "`data'\\evict\eviction_counts_state`geo'year.dta", clear;
	gen state=lower(state_abb);
	
	/* Get average number of evictions in data time period */
	keep if year >= `start`period'' & year <= `end`period'';
	gen temp = evict_count;
	egen avgcount = mean(temp), by(state `geo') ; 
	drop temp ; 		
	summ avgcount, d;
	
	foreach state in 
		al ar az ca co ct dc de fl ga ia id il in ks 
		ky la ma md me mi mn mo ms mt nc ne nj nm nv 
		nh nd ny oh ok or pa ri sd tn tx ut vt va 
		wa wi wv wy /*sc*/ /* 08/13/2018: Remove SC per AIRS Kevin's email */
		{;
		preserve;
		di "Running eviction `geo' selection on `state' ...";
		qui {;
			
			keep if state == "`state'" ;
			
			if _N>0 {;
				drop if `geo' == .;
				drop if `geo' == 0;
			};
				
			if _N>0 {;
				drop if avgcount < `evictcutoff_`geo''; /* select eviction by count */
			};
			
			if _N>0 {;
				/* Add restrictions to individual years to make sure data is well populated 
				   within the time period. I use unconditional rates to filter as some FIPS 
				   code have smaller population */
				gen evict_per_capita = evict_count / total_pop;
				gen num_goodyear = (evict_per_capita >= `evictcutoff_lowyear' & evict_per_capita != .);
				collapse (sum) num_goodyear, by(state_abb `geo');
				keep if num_goodyear >= 4; /* requires at least 80% of coverage */
			};
			
			if _N>0 {;
				global evictlist`period'_`geo'  ${evictlist`period'_`geo'} `state';
				keep state_abb `geo';
				tempfile `geo'_`state'`period';
				save ``geo'_`state'`period'';
			};
			
		  };
		  restore;	
		  };

	dis "Final eviction `geo' sample states (Period `period'): ${evictlist`period'_`geo'} ";		  
}; /* END OF LOOP: period */
}; /* END OF LOOP: geo */
}; /* END OF LOOP: outcome */
