capture log close
clear all
set maxvar 10000
set matsize 11000
set linesize 200
set more off
pause off
# delimit;

local log "";
local data "";
local lee "";
local do "";


/* *************************************** */
/* **** GET LIST OF STATES BY PERIOD  **** */
/* *************************************** */
local progtype "frcl"; 
include "`do'\\foreclose_2selectsample.do";
dis "$frcllist0509";
dis "$frcllist1014";
global frclcommon: list global(frcllist0509) & global(frcllist1014); /* States in both period */
global frcl_u0509: list global(frcllist0509) - global(frclcommon);   /* States only in 0509 */
global frcl_u1014: list global(frcllist1014) - global(frclcommon);   /* States only in 1014 */
global frcl_union $frcl_u0509 $frclcommon $frcl_u1014 ; /* A unique list of states regardless of period */
dis "$frclcommon";	dis "$frcl_u0509";	dis "$frcl_u1014";	dis "$frcl_union";

/* Figure out the first state for appending dataset */
local first_state: word 1 of $frcl_union ;

/* Figure out the rest of states for appending */
local frcllist_append: subinstr global frcl_union "`first_state'" "", all;	


/* *********************************************** */
/* **** PREP DEEDS DATA FOR HOMEOWNER RECORDS **** */
/* *********************************************** */

/* the prep1 files have all the 831 applicants who match to deeds records (i.e., homeowners) */
use ssn using 					"`data'\ztraxcl\prep1\ztraxcl_831_merge_`first_state'_0004.dta", clear;
append using 					"`data'\ztraxcl\prep1\ztraxcl_831_merge_`first_state'_0509.dta", keep(ssn) ;
append using 					"`data'\ztraxcl\prep1\ztraxcl_831_merge_`first_state'_1014.dta", keep(ssn) ;

foreach state in `frcllist_append' 
	{;
	append using "`data'\ztraxcl\prep1\ztraxcl_831_merge_`state'_0004.dta", keep(ssn);
	append using "`data'\ztraxcl\prep1\ztraxcl_831_merge_`state'_0509.dta", keep(ssn);
	append using "`data'\ztraxcl\prep1\ztraxcl_831_merge_`state'_1014.dta", keep(ssn);
	};

/* Drop duplicates so we can do 1 to 1 merge */
duplicates report ssn;
gen homeowner=1;
collapse homeowner, by(ssn);

tempfile homeowner;
save `homeowner';

	
/* ******************************* */
/* **** PREP FORECLOSURE DATA **** */
/* ******************************* */

foreach state in $frcl_union

	{;
	
	local stateinlist `state'; /* This is used to test whether a given state is in the list */

	if `: list stateinlist in global(frclcommon)' {;	
		use 			"`data'\foreclose\prep2\foreclose_831_remerge_`state'_0509.dta", clear;
		gen period = 	"0509" ;
	
		append using 	"`data'\foreclose\prep2\foreclose_831_remerge_`state'_1014.dta";
		replace period = "1014" if period == "" ;
	};
	
	if `: list stateinlist in global(frcl_u0509)' {;		
		use 			"`data'\foreclose\prep2\foreclose_831_remerge_`state'_0509.dta", clear;
		gen period		= "0509" ;
	};
	
	if `: list stateinlist in global(frcl_u1014)' {;		
		use 			"`data'\foreclose\prep2\foreclose_831_remerge_`state'_1014.dta", clear;
		gen period		= "1014" ;
	};
	
	gen state_abb = "`state'" ;

	/* Keep only DI adults and SSI adults */
	keep if toc_diadult == 1 | toc_ssiadult == 1 ;
	
	/* Count number of applications for each person so later we can restrict to first/last */
	duplicates report ssn fld ;
	duplicates drop ssn fld, force ;
	sort ssn fld ;
	by ssn: gen apprank = _n ;
	egen totapp = max(apprank), by(ssn) ;
	
	
	/* ****************************************** */
	/* **** CATEGORIZE APPLICANTS INTO STEPS **** */
	/* ****************************************** */	
		
	gen byte rb_step12deny = 
					( rb=="N1" | rb=="N2" | rb=="F1" | rb=="F2" | rb=="E1" | rb=="E2" | rb=="E3" | rb=="E4" /* DI codes */
					| rb=="33" | rb=="30" | rb=="41" | rb=="34" | rb=="35" | rb=="45" | rb=="46"			  /* SSI codes */ 
					);
	
	gen byte rb_step3allow = 
			( rb=="A1" | rb=="B1"  /* DI code */ 
			| rb=="61" | rb=="62"  /* SSI code */
			);		
					
	gen byte rb_step4deny = 
					( rb=="H1" | rb=="H2" 							 /* DI codes */
				    | rb=="31" | rb=="42"  					    	/* SSI codes */
					);
	
	gen byte rb_step5allow =
		(rb=="C1" | rb=="D1" 						/* DI codes */
		| rb=="63" | rb=="64" 						/* SSI codes */
		) ;
	
	gen byte rb_step5deny = 
		(rb=="G1" | rb=="G2" | rb=="J1" | rb=="J2" 	/* DI codes */
		| rb=="32" | rb=="43" 						/* SSI codes */
		);
	
	
	/* ****************************** */
	/* **** CREATE AGE VARIABLES **** */
	/* ****************************** */
	
	foreach stub in dob fld { ;
		gen `stub'_yy=substr(`stub',1,4);
		gen `stub'_mm=substr(`stub',5,2);
		gen `stub'_dd=substr(`stub',7,2);
		rename `stub' `stub'_string;
		destring `stub'_yy, replace;
		destring `stub'_mm, replace;
		destring `stub'_dd, replace;
		gen `stub'=mdy(`stub'_mm, `stub'_dd, `stub'_yy);
		format `stub' %td;
	} ;
	
	/* Calculate age at decision */
	gen age1mo = (year(dds_date) - dob_yy) + ( (month(dds_date) - dob_mm) / 12) ;
	
	/* Find min and max years for foreclosure in this state to determine denominator */
	gen frcl_yy = year(frcldate1) ;
	summ frcl_yy, det ;
	local frcl_max = r(p95) ;
	local frcl_min = r(p5) ;
	display `frcl_min' ;
	display `frcl_max' ;
	
	
	/* ************************************** */
	/* **** CREATE FORECLOSURE VARIABLES **** */
	/* ************************************** */
	
	/* Foreclosure relative to application */
	
	foreach i in 1 3 5 {;
		gen frclpre_`i'app=0;

		forval j=1(1)10 {;
			replace frclpre_`i'app =1 if (frcldate`j'<=fld & frcldate`j'!=. & frcldate`j'>fld-(365*`i') & frcltype`j'!="R");
		};
	};
	
	
	/* ********************************* */
	/* **** KEEP VARIABLES AND SAVE **** */
	/* ********************************* */
	
	/* Keep only necessary variables */
	keep ssn fld frclpre* frcl_* n_male dob_yy allow_dds allow_fin dr_* toc_* rb_* ed ;
	
	tempfile frcl_`state';
	save `frcl_`state'';
};
	
	
/* *************************** */
/* **** APPEND ALL STATES **** */
/* *************************** */

use `frcl_`first_state'', clear;

foreach state in `frcllist_append' 
	{;
		append using `frcl_`state'';
	};
	
count;


/* ************************************************* */
/* **** MERGE IN HOMEOWNER INDICATOR FROM DEEDS **** */
/* ************************************************* */
		
merge m:1 ssn using `homeowner';

/* Keep only those who match (homeowners) */
keep if _merge == 3 ;
drop _merge ;


/* ************************************* */
/* **** CREATE EARNINGS/ED VARIABLES **** */
/* ************************************* */

merge m:1 ssn using "`lee'\prep1_ser.dta" ;
drop if _merge == 2 ;
drop _merge ;

/* Earnings at age 35, 31-35 (as control) */
forval age = 31(1)35 { ;
	gen z`age' = . ;
	forval yr=1990(1)2013 { ;
		replace z`age' = ser`yr' if `yr' == dob_yy + `age' ;
	} ;
} ;

egen z3135 = rowmean(z31 z32 z33 z34 z35) ;
summ z35 z3135 ;

xtile z35_qt = z35, nq(4) ;
xtile z3135_qt = z3135, nq(4) ;

xtile z35_dec = z35, nq(10) ;
xtile z3135_dec = z3135, nq(10) ;

/* Education */
	tab ed, m ;
	gen cov_ed = ed ;
	destring cov_ed, replace ;
	tab ed, m ;

save "`lee'/bh_frcl_data.dta", replace ;
*/

/* *********************** */
/* **** CREATE GROUPS **** */
/* *********************** */

use "`lee'/bh_frcl_data.dta", clear ;

/* Education */
gen 	ed_cat = 1 if (cov_ed < 12) ;
replace ed_cat = 2 if (cov_ed >= 12 & cov_ed < 16) ;
replace ed_cat = 3 if (cov_ed >= 16 & cov_ed != .) ;
tab ed_cat, m ;

/* Diary */
gen byte gp_sev_mine 	= (dr_mine == 1) ;
gen byte gp_sev_mie		= (dr_mie == 1) ;
gen byte gp_sev_mip  	= (dr_mip == 1) ;
gen byte gp_sev_minemip = (dr_mine == 1 | dr_mip == 1) ;
gen byte gp_sev_mipmie  = (dr_mip == 1 | dr_mie == 1) ;

/* Program */
gen byte gp_dionly = (toc_diadult == 1) ;
gen byte gp_dissi  = (toc_diadult == 1 | toc_ssiadult ==1 ) ;

/* Interact groups */
foreach pgm in dionly dissi { ;
	gen byte gp_`pgm'_initial 	= (gp_`pgm' == 1 &  allow_fin == 1 & allow_dds == 1) ;
	gen byte gp_`pgm'_step3   	= (gp_`pgm' == 1 &  allow_fin == 1 & allow_dds == 1 & rb_step3allow == 1) ;
	gen byte gp_`pgm'_step5   	= (gp_`pgm' == 1 &  allow_fin == 1 & allow_dds == 1 & rb_step5allow == 1) ;
	gen byte gp_`pgm'_appeal  	= (gp_`pgm' == 1 &  allow_fin == 1 & allow_dds != 1) ;
	gen byte gp_`pgm'_reject  	= (gp_`pgm' == 1 &  allow_fin == 0) ;
	
	foreach sev in mine mie mip minemip mipmie { ;
		gen byte gp_`pgm'_`sev'		= (gp_`pgm' == 1 &  allow_fin == 1 & gp_sev_`sev' == 1) ;
	} ;
} ;


/* **************************************** */
/* **** SUMMARIZE RATES FOR EACH GROUP **** */
/* **************************************** */

local fin "frcl" ;

local level_list "initial step3 step5 appeal reject mine mie mip minemip mipmie" ;
local coltotal = 0 ;
foreach level in `level_list' { ;
	local coltotal = `coltotal' + 1 ;
} ;

local yr_list "1 3 5" ;
local rowtotal = 0 ;
foreach level in `yr_list' { ;
	local rowtotal = `rowtotal' + 1 ;
} ;

local name "" ;

foreach pgm in dissi dionly { ;

	matrix `fin'_`pgm' = J(`rowtotal',`coltotal',.) ;
	local countcol = 0 ;
	
	foreach level in `level_list' { ;
		
		local countrow = 0 ;
		local countcol = `countcol' + 1 ;

		foreach yr in `yr_list' { ;
		
			local countrow = `countrow' + 1 ;
			summ `fin'pre_`yr'app if gp_`pgm'_`level' == 1 ;
			matrix `fin'_`pgm'[`countrow',`countcol'] = r(mean) ;
			
		} ; /* end yr */
		
		if "`pgm'" == "dissi" { ;
				local name "`name' `level'" ;
			} ;
			
	} ; /* end level */
	
	
	preserve ;
	clear ;
	svmat `fin'_`pgm' ; 
	rename (`fin'_`pgm'*) (`name') ;
	gen label = "" ;
	local yr_num = 0 ;
	foreach yr in `yr_list' { ;
		local yr_num = `yr_num' + 1 ;
		replace label = "pre`yr'" if _n == `yr_num' ;
	} ;
	order label ;
	save "`lee'\\bh_means_`fin'_`pgm'.dta", replace ;
	restore ;

} ; /* end pgm */


	
/* Regressions */
summ dob_yy, det ;
replace dob_yy = r(p5)  if dob_yy < r(p5) ;
replace dob_yy = r(p95) if dob_yy > r(p95) & dob_yy != . & dob_yy != 9999 ;

foreach pgm in dissi dionly { ;

	xi: reg `fin'pre_3app gp_`pgm'_appeal 			
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) replace;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_none.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal					
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_ed.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy 	
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz35qt.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z35_qt 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz35dec.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z35_dec 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz3135qt.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z3135_qt 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz3135dec.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z3135_dec 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

} ; /* end pgm */

capture log close ;
