#delim;

# delimit;

/*
Standardized sample ZIP selection for all periods
*/

local start0004 2000;
local end0004   2004;
local start0509 2005;
local end0509   2009;
local start1014 2010;
local end1014   2014;

/* ****************************** */
/* **** OUTCOME: FORECLOSURE **** */
/* ****************************** */

if "`progtype'" == "frcl" {;

foreach period in 0509 1014 {;
	
	global frcllist`period';

	use "`data'\\foreclose\foreclosure_quality_statezipyear.dta", clear;
	gen state=lower(state_abb);
	drop state_abb;

	/* Get average number of foreclosures in data time period */
	gen temp = fcl_count if year >= `start`period'' & year <= `end`period'' ;
	egen avgcount = mean(temp), by(state zip) ; 
	drop temp ; 
	summ avgcount, d ;

	foreach state in 
		al ar az ca co ct dc de fl ga ia id il in ks ky 
		la ma md me mi mn mo ms mt nc nd ne nh nj nm nv 
		ny oh ok or pa ri sc sd tn tx ut va vt wa wi wv wy 
		{;
		preserve;
		di "Running ZIP selection on `state' ...";
		qui {;
			
			keep if state=="`state'" & year==`start`period'';
			
			/* Bring in USPS ZIPCODE CLASSIFICATION to eliminate PO BOX and other nonstandard ZIPs */
			merge 1:1 zip using "`data'\\zipcode_database_usa.dta";
			drop if _merge != 3;
			drop _merge;
			drop if zip_standard != 1;
			
			/* Drop ZIPs with fewer than 5 foreclosures in that year */
			drop if avgcount < 5;
			
			/* Drop ZIPs with more than 20% of missing names */
			drop if frac_missing_def1 > .2;
			
			/* Add state to buy/sell list if it has any observations */
			if _N>0 {;
				global frcllist`period' ${frcllist`period'} `state';
			};
				
			tempfile zip_`state'`period';
			save `zip_`state'`period'';
		};
		restore;
		};

	dis "Final SAMPLE STATES (Period `period'): ${frcllist`period'} ";
}; /* END OF LOOP: period */
}; /* END OF LOOP: outcome
