Signon ;
RSubmit ;

options compress=YES;
libname data ''; 
libname lee ''; 
%let data = ;

***** COLLAPSE DER TO EIN LEVEL TO CLASSIFY EINs BY MASS LAYOFF ***** ;
* USE DEFINITION OF MASS LAYOFF FROM VON WACHTER, MANCHESTER, AND SONG 2009 :
  KEEP ONLY ONLY OBSERVATION FOR SSN-EIN-YEAR CORRESPONDING TO WORKER'S HIGHEST EARNINGS IN THAT YEAR,
  CALCULATE TOTAL NUMBER OF WORKERS WITH POSITIVE EARNINGS AT THAT EMPLOYER IN THAT YEAR, 
  IDENTIFY EMPLOYERS WITH AT LEAST 50 EMPLOYEES IN A GIVEN YEAR WITH AT LEAST 30% REDUCTION OVER TWO YEARS,
  IMPOSE STABILITY IN EMPLOYMENT BEFORE AND AFTER THE DROP
  ;

%macro derprep(num) ;
filename inzip ZIP "&data.der_seg&num..zip"
               member = "der_seg&num..sas7bdat";
filename ds "%sysfunc(getoption(work))\der_seg&num..sas7bdat" ;

* Read in the first wave ;
data _null_;
   * reference the member name WITH folder path ;
   infile inzip
    lrecl=256 recfm=F length=length eof=eof unbuf;
   file   ds lrecl=256 recfm=N;
   input;
   put _infile_ $varying256. length;
   return;
 eof:
   stop;
run;

data work.der_seg&num.;
    set work.der_seg&num.
    (
	keep = ssn year ein wage_tips_irs 
    rename=(wage_tips_irs=earn)
    );

	if earn>0 then emp = 1 ; else emp = 0 ;

	year = input(year,4.) ;
	if year<=2017 ;
run;

* KEEP ONLY HIGHEST EARNINGS FOR SSN-EIN-YEAR ;
proc sort data=work.der_seg&num. out=work.der_seg&num. ;
	by ssn ein year descending earn ;
run;

proc sort data=work.der_seg&num. out=work.der_seg&num. nodupkey ;
	by ssn ein year ;
run;

* CALCULATE TOTAL NUMBER OF WORKERS WITH POSITIVE EARNINGS AT THAT EMPLOYER IN THAT YEAR ;
* Collapse to EIN-year level ;
proc means noprint data=work.der_seg&num. nway ;
	class ein year ;
	var emp ;
	output out=work.der_seg&num. sum= ;
run ;
%mend derprep ;

%derprep(02) ;
%derprep(03) ;
%derprep(05) ;
%derprep(06) ;
%derprep(09) ;
%derprep(10) ;
%derprep(15) ;
%derprep(16) ;
%derprep(19) ;
%derprep(20) ;

* Combine all segments ;
data lee.cwhs_der_prep1 ;
	set work.der_seg02 
		work.der_seg03
		work.der_seg05
		work.der_seg06
		work.der_seg09
		work.der_seg10
		work.der_seg15
		work.der_seg16
		work.der_seg19
		work.der_seg20
		;
run ;

proc sort data=lee.cwhs_der_prep1 out=lee.cwhs_der_prep1 ;
	by ein year ;
run;

proc means noprint data=lee.cwhs_der_prep1 nway ;
	class ein year ;
	var emp ;
	output out=lee.cwhs_der_prep1 sum= ;
run ;

* IDENTIFY EMPLOYERS WITH AT LEAST 50 EMPLOYEES IN A GIVEN YEAR WITH AT LEAST 30% REDUCTION OVER TWO YEARS ;
* Reshape wide to get one observation per employer ;
* Collapse to SSN-EIN level ;
data lee.cwhs_der_prep1 ;
	set lee.cwhs_der_prep1 
	(where=(ein^="000000000"));

	by ein;

	keep 	ein 
			emp_1978-emp_2017 ;
	
	retain  emp_1978-emp_2017 ;

	array	aemp(1978:2017) 		emp_1978-emp_2017 ; 
	
	if first.ein then
	do;
		do i=1978 to 2017 ;
			aemp(i) 		=.;	
		end;
	end;

	aemp(year) 		= emp ;	

	if last.ein then output;

run;

data lee.cwhs_der_prep1 ;
	set lee.cwhs_der_prep1 ;
	
	* von Wachter: at least 50 employees in some year (but this CWHS10% so needs to be smaller) ;
	array emp(1978:2017) emp_1978-emp_2017 ;
	do i = 1978 to 2017 ;
		if emp(i) = . then emp(i) = 0 ;
	end ;

	temp_max_emp = max(of emp:) ;
	
	%macro mass(cut,drop) ;
	if temp_max_emp >= &cut. & ein^="000000000" then max&cut. = 1; else max&cut. = 0 ;

	* Drop >= 30% of workforce ;
	array mass&cut.&drop.(1979:2017) mass&cut.&drop._1979-mass&cut.&drop._2017 ;
	do i = 1980 to 2017 ;
		if 
			( emp(i-2)>=&cut. & (emp(i)-emp(i-2))/emp(i-2)<-.&drop. ) |
			( emp(i-1)>=&cut. & (emp(i)-emp(i-1))/emp(i-1)<-.&drop. )
		then mass&cut.&drop.(i) = 1 ; else mass&cut.&drop.(i) = 0 ;
	end ;
	%mend mass ;

	%mass(15,3) ;
	%mass(15,2) ;
	%mass(5,3) ;
	%mass(5,2) ;

	array empdelt2(1980:2017) empdelt2_1980-empdelt2_2017 ;
	array empdelt1(1980:2017) empdelt1_1980-empdelt1_2017 ;

	do i = 1980 to 2017 ;
		empdelt2(i) = (emp(i)-emp(i-2))/emp(i-2) ;
		empdelt1(i) = (emp(i)-emp(i-1))/emp(i-1) ;
	end ;

	keep ein max: mass: emp_: empdelt2_: empdelt1_: ;

run ;

proc sort data=lee.cwhs_der_prep1  out=lee.cwhs_der_prep1  ;
	by ein ;
run;

run; quit;
endrsubmit;
signoff ;
