Signon ;
RSubmit ;

options compress=YES;
libname data ''; 
libname lee ''; 
%let data = ;

***** IDENTIFY WORKERS WHOSE JOB LOSS IS LIKELY DUE TO MASS LAYOFF ***** ;

* IDENTIFY WORKERS WITH LARGE EARNINGS DROP AT A PARTICULAR EMPLOYER ;
%macro earndrop(num) ;
filename inzip ZIP "&data.der_seg&num..zip"
               member = "der_seg&num..sas7bdat";
filename ds "%sysfunc(getoption(work))\der_seg&num..sas7bdat" ;

* Read in the first wave ;
data _null_;
   * reference the member name WITH folder path ;
   infile inzip
    lrecl=256 recfm=F length=length eof=eof unbuf;
   file   ds lrecl=256 recfm=N;
   input;
   put _infile_ $varying256. length;
   return;
 eof:
   stop;
run;

data work.der_seg&num.;
    set work.der_seg&num.
    (
	keep = ssn year ein wage_tips_irs 
    rename=(wage_tips_irs=earn)
    );

	if earn>0 then emp = 1 ; else emp = 0 ;

	year = input(year,4.) ;
	if year<=2017 ;
run;

* KEEP ONLY HIGHEST EARNINGS FOR SSN-EIN-YEAR ;
proc sort data=work.der_seg&num. out=work.der_seg&num. ;
	by ssn ein year descending earn ;
run;

proc sort data=work.der_seg&num. out=work.der_seg&num. nodupkey ;
	by ssn ein year ;
run;

* Collapse to SSN-EIN level ;
data work.der_seg&num. ;
	set work.der_seg&num. ;
	by ssn ein;

	keep 	ssn ein earn_1978-earn_2017 emp_1978-emp_2017 ;
	
	retain 	earn_1978-earn_2017 
			emp_1978-emp_2017
			;

	array	aearn(1978:2017) 		earn_1978-earn_2017 ; 
	array	aemp(1978:2017) 		emp_1978-emp_2017 ; 
	
	if first.ssn & first.ein then
	do;
		do i=1978 to 2017;
			aearn(i) 		=.;	
			aemp(i) 		=.;
		end;
	end;

	aearn(year) 		= earn ;	
	aemp(year) 			= emp ;	

	if last.ssn & last.ein then output;

run;

* Separation in each year ;
data work.der_seg&num. ;
	set work.der_seg&num. ;
	
	array emp(1978:2017)  emp_1978-emp_2017 ;
	array earn(1978:2017) earn_1978-earn_2017 ;
	array delt(1979:2017) delt_1979-delt_2017 ;

	do i = 1978 to 2017 ;
		if earn(i)=. then earn(i)=0 ;
		if emp(i) =. then emp(i) =0 ;
	end ;

	do i = 1980 to 2017 ;
		if 
			(emp(i-2)=1 & emp(i)=0) | (emp(i-1)=1 & emp(i)=0)
			then delt(i) = 1 ;
		else delt(i) = 0 ;
	end ;

	drop earn: i ;
	
run ;

proc sort data=work.der_seg&num. out=work.der_seg&num. ;
	by ein ;
run;

* MERGE PREP1 INTO DER USING EIN ;
data work.der_seg&num.;				
	merge 

		work.der_seg&num. (in=mainx)
		lee.cwhs_der_prep1 
			(keep = ein max: mass:)

	;
	by ein ;
	if mainx=1 ;

run;

* Determine if year of earnings drop at an EIN corresponds with year of a mass layoff at EIN ;
data work.der_seg&num.;
	set work.der_seg&num.;

	array delt(1979:2017) delt_1979-delt_2017 ;

	%macro mass(cut,drop) ;
	array mass&cut.&drop.(1979:2017) mass&cut.&drop._1979-mass&cut.&drop._2017 ;
	array dmass&cut.&drop.(1979:2017) dmass&cut.&drop._1979-dmass&cut.&drop._2017 ;

	do i = 1980 to 2016 ;
		if delt(i) = 1 & (mass&cut.&drop.(i-1) = 1 | mass&cut.&drop.(i) = 1 | mass&cut.&drop.(i+1) = 1)
			then dmass&cut.&drop.(i) = 1 ; 
			else dmass&cut.&drop.(i) = 0 ;
	end ;
	%mend mass ;

	%mass(15,3) ;
	%mass(15,2) ;
	%mass(5,3) ;
	%mass(5,2) ;

run ;

* Collapse to SSN level ;
proc sort data=work.der_seg&num. out=work.der_seg&num. ;
	by ssn ein ;
run;

proc means noprint data=work.der_seg&num. nway ;
	class ssn ;
	var delt: dmass: mass: emp: ;
	output out=lee.der_seg&num. max= ;
run ;

%mend earndrop ;

%earndrop(02) ;
%earndrop(03) ;
%earndrop(05) ;
%earndrop(06) ;
%earndrop(09) ;
%earndrop(10) ;
%earndrop(15) ;
%earndrop(16) ;
%earndrop(19) ;
%earndrop(20) ;

* COLLAPSE BY EIN TO GET EMPLOYMENT AND EARNINGS BY YEAR ;
data lee.cwhs_der_prep2 ;
	set lee.der_seg02 
		lee.der_seg03
		lee.der_seg05
		lee.der_seg06
		lee.der_seg09
		lee.der_seg10
		lee.der_seg15
		lee.der_seg16
		lee.der_seg19
		lee.der_seg20
		;
run ;

proc means n nmiss mean data=lee.cwhs_der_prep2 ;
	var delt: dmass: mass: emp: ;
run;

run; quit;
endrsubmit;
signoff ;
