capture log close
clear all
set maxvar 10000
set matsize 11000
set linesize 200
set more off
pause off
# delimit;

local log "";
local data "";
local lee "";
local do "";

use "`data'/cwhs_merge_dissider_stata.dta", clear ;

/* Earnings at age 35, 31-35 (as control) */
forval age = 31(1)35 { ;
	gen z`age' = . ;
	forval yr=1978(1)2017 { ;
		replace z`age' = earn_`yr' if `yr' == dob_yy + `age' ;
	} ;
} ;

egen z3135 = rowmean(z31 z32 z33 z34 z35) ;
summ z35 z3135 ;

xtile z35_qt = z35, nq(4) ;
xtile z3135_qt = z3135, nq(4) ;

xtile z35_dec = z35, nq(10) ;
xtile z3135_dec = z3135, nq(10) ;

/* Education groups */
gen 	ed_cat = 1 if (n_ed < 12) ;
replace ed_cat = 2 if (n_ed >= 12 & n_ed < 16) ;
replace ed_cat = 3 if (n_ed >= 16 & n_ed != .) ;
tab ed_cat, m ;

/* Diary */
gen byte gp_sev_mine 	= (sev3_dissi == 4 | sev3_di == 4) ;
gen byte gp_sev_mip  	= (sev3_dissi == 3 | sev3_di == 3) ;
gen byte gp_sev_mie		= (sev3_dissi == 2 | sev3_di == 2) ;
gen byte gp_sev_minemip = (sev1_dissi == 3 | sev1_di == 3) ;
gen byte gp_sev_mipmie  = (sev2_dissi == 2 | sev2_di == 2) ;

/* Program */
rename toc_di gp_dionly ; 
rename toc_dissi gp_dissi ;

/* Interact groups */
foreach pgm in dionly dissi { ;
	gen byte gp_`pgm'_initial 	= (gp_`pgm' == 1 &  (sevrb_dissi == 3 | sevrb_di == 3 | sevrb_dissi == 2 | sevrb_di == 2)) ;
	gen byte gp_`pgm'_step3   	= (gp_`pgm' == 1 &  (sevrb_dissi == 3 | sevrb_di == 3)) ;
	gen byte gp_`pgm'_step5   	= (gp_`pgm' == 1 &  (sevrb_dissi == 2 | sevrb_di == 2)) ;
	gen byte gp_`pgm'_appeal  	= (gp_`pgm' == 1 &  (sevrb_dissi == 1 | sevrb_di == 1)) ;
	gen byte gp_`pgm'_reject  	= (gp_`pgm' == 1 &  (sevrb_dissi == 0 | sevrb_di == 0)) ;
	
	foreach sev in mine mie mip minemip mipmie { ;
		gen byte gp_`pgm'_`sev'		= (gp_`pgm' == 1 &  gp_sev_`sev' == 1) ;
	} ;
} ;

/* Regressions */
rename shock3app_mass153 masspre_3app ;
summ dob_yy, det ;
replace dob_yy = r(p5)  if dob_yy < r(p5) ;
replace dob_yy = r(p95) if dob_yy > r(p95) & dob_yy != . & dob_yy != 9999 ;

local fin "mass" ;

gen byte allow_fin = (gp_dionly_initial == 1 | gp_dissi_initial== 1 | gp_dionly_appeal == 1 | gp_dissi_initial) ;

foreach pgm in dissi dionly { ;

	xi: reg `fin'pre_3app gp_`pgm'_appeal 			
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) replace;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_none.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal					
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_ed.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy 	
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz35qt.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z35_qt 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz35dec.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z35_dec 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz3135qt.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z3135_qt 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

	xi: statsby _b _se e(N), saving("`lee'/statsby/bh_`fin'_`pgm'_rb_edz3135dec.dta", replace): 
		reg `fin'pre_3app gp_`pgm'_appeal i.ed_cat i.dob_yy i.z3135_dec 
		if allow_fin == 1 & gp_`pgm' == 1 ;
	outreg2 using "`lee'\\bh_`fin'_abilityregs_`pgm'.xls", e(N) append;

} ; /* end pgm */

capture log close;
