rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")
#install.packages("tidyr")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)
library(tidyr)

################################################################################################################################################
# Data from the statistics generated from previous codes
df1 <- read.csv('./ssa/positive/data/pre_cat_bysevrb_dissi.csv')  
df2 <- read_dta('./ssa/positive/data/bh_means_combine.dta')  

# Mass layoff
sub.df1 <- subset(df1, select = c("sevrb_dissi","num","shock3app_mass153"))
maslayoff <- sub.df1[c(2:5),]

rownames(maslayoff) <- seq(length=nrow(maslayoff))
maslayoff['var'] <- c('Rejected applicants', 'Allowed on appeal','Initially allowed, at Step 5', 'Initially allowed, at Step 3')
maslayoff['group'] <- c('Mass layoff', 'Mass layoff', 'Mass layoff', 'Mass layoff')
maslayoff <- rename(maslayoff, c("mean"="shock3app_mass153"))
maslayoff <- subset(maslayoff, select = c("var","mean","group"))
rm(df1,sub.df1)

# Bk/frcl/evict 
sub.df2 <- filter(df2, label == "pre3", pgm == "dissi")
sub.df2 <- subset(sub.df2, select = c("fin","appeal","reject","step5","step3"))
other <- gather(sub.df2, variable, mean, appeal:step3, factor_key=TRUE)
other$var[other$variable == 'reject'] <- 'Rejected applicants'
other$var[other$variable == 'appeal'] <- 'Allowed on appeal'
other$var[other$variable == 'step5'] <- 'Initially allowed, at Step 5'
other$var[other$variable == 'step3'] <- 'Initially allowed, at Step 3'

other$group[other$fin == 'bk'] <- 'Bankruptcy'
other$group[other$fin == 'frcl'] <- 'Foreclosure'
other$group[other$fin == 'evict'] <- 'Eviction'
other <- subset(other, select = c("var","mean","group"))

# All
admin.sev2.full <- rbind(maslayoff,other)
rownames(admin.sev2.full) <- seq(length=nrow(admin.sev2.full))
admin.sev2.full <- admin.sev2[c(1, 2, 3, 4, 8, 5, 11, 14, 9, 6, 12, 15, 10, 7, 16, 13, 16),] 

# Decide the order to be represented 
admin.sev2.full$group <- factor(admin.sev2.full$group, levels = c("Mass layoff", "Bankruptcy", "Foreclosure", "Eviction"))
admin.sev2.full$var <- factor(admin.sev2.full$var, levels = c('Rejected applicants', 'Allowed on appeal',
                                                              'Initially allowed, at Step 5', 'Initially allowed, at Step 3'))

cols <- c("Rejected applicants"= "green", 
          "Allowed on appeal" = "blue", 
          "Initially allowed, at Step 5" = "deeppink4",
          "Initially allowed, at Step 3" = "lightpink")

(financial <- (ggplot(admin.sev2.full, aes(factor(group), mean, fill = factor(var))) +
                 geom_bar(stat="identity", position = "dodge", width = 0.6)))

# Final Figure 
(financial <- financial + ylim(0, 0.12) + labs(x = "",y = "Fraction with event in 3 years before app") + theme_classic()
  + theme(axis.text=element_text(size=12), legend.text = element_text(size=6), 
          legend.title = element_blank(), legend.position = "bottom", axis.title=element_text(size=12), plot.title = element_text(hjust = 0.5, size=12))
  + scale_fill_manual(values=cols) 
  + scale_y_continuous(expand = c(0, 0), limits = c(0, 0.12)))

# Export the figure
ggsave(paste0(figure,'figG5.png'), height = 4, width = 6)


