rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages(reshape2)
#install.packages("grid")
#install.packages("tidyr")

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)
library(grid)
library(tidyr)

################################################################################################################################################
# SSDI only
df1 <- read.csv('./ssa/positive/data/pre_cat_bysevrb_di.csv')  
df2 <- read_dta('./ssa/positive/data/bh_means_combine.dta')  

# Mass layoff
sub.df1 <- subset(df1, select = c("sevrb_di","num","shock3app_mass153"))
sub.df1.mdi <- sub.df1[4:5,]
sub.df1.mdi$means <- weighted.mean(sub.df1.mdi$shock3app_mass153, sub.df1.mdi$num)
sub.df1.mdi <- subset(sub.df1.mdi, select = c("sevrb_di","num","means"))
sub.df1.mdi <- rename(sub.df1.mdi, c("shock3app_mass153"="means"))

maslayoff <- rbind(sub.df1, sub.df1.mdi)
rownames(maslayoff) <- seq(length=nrow(maslayoff))
maslayoff <- maslayoff[c(3,7),]
maslayoff['var'] <- c('L-DI','M-DI')
maslayoff['group'] <- c('Mass layoff','Mass layoff')
maslayoff <- rename(maslayoff, c("mean"="shock3app_mass153"))
maslayoff <- subset(maslayoff, select = c("var","mean","group"))
rm(df1,sub.df1,sub.df1.mdi)

# Bk/frcl/evict 
sub.df2 <- filter(df2, label == "pre3", pgm == "dionly")
sub.df2 <- subset(sub.df2, select = c("fin","appeal","initial"))
other <- gather(sub.df2, variable, mean, appeal:initial, factor_key=TRUE)
other$var[other$variable == 'appeal'] <- 'L-DI'
other$var[other$variable == 'initial'] <- 'M-DI'
other$group[other$fin == 'bk'] <- 'Bankruptcy'
other$group[other$fin == 'frcl'] <- 'Foreclosure'
other$group[other$fin == 'evict'] <- 'Eviction'
other <- subset(other, select = c("var","mean","group"))

# All
admin.sev2 <- rbind(maslayoff,other)
rownames(admin.sev2) <- seq(length=nrow(admin.sev2))
admin.sev2 <- admin.sev2[c(1, 2, 3, 6, 4, 7, 5, 8),] 

# Decide the position of the plots
admin.sev2$num[admin.sev2$var == "L-DI"] <- 1/3
admin.sev2$num[admin.sev2$var == "M-DI"] <- 5/6
  
# Draft Figure
  (sample.new6 <- ggplot(admin.sev2) + geom_line(aes(x=num, y=mean, color = group), linetype = "dotted", size = 0.7) 
    + geom_point(aes(x = num, y = mean, color = var, shape = group, size = group, fill = var)) 
    + geom_vline(xintercept = 2/3, linetype="dashed") 
    + coord_cartesian(xlim = c(0,1), ylim = c(0, 0.1), clip="off") + scale_y_continuous(name ="Fraction with event in 3 years before DI receipt", expand = c(0, 0))
    + scale_size_manual(values=c(4,4,4,4)) + scale_shape_manual(values=c(21,24,22,23)) 
    + scale_color_manual(values=c("gray", "gray", "gray", "blue", "deeppink4", "gray"), guide = FALSE) 
    + scale_fill_manual(values=c("blue", "deeppink4"), guide = FALSE) 
  )
  
# Final Figure
  (sample.new7 <- sample.new6 + theme_classic() 
    + theme(legend.title = element_blank(), 
            legend.position = "none",
            plot.title = element_text(hjust = 0.5, size=12),
            axis.title.x=element_blank(),
            axis.text.x=element_blank(),
            axis.ticks.x=element_blank(),
            plot.margin=unit(c(0.5,0.5,1,0.5),"cm"))
    + annotate("text", c(1/3, 5/6), size = 4, y =  -0.003, label = c("Less-severe (L)", "More-severe (M)"))
    + annotate("text", x = c(0.2, 0.2, 0.2, 0.2), size = 3, y = c(0.065, 0.02, 0.035, 0.05), label = c("Mass layoff", "Foreclosure", "Bankruptcy", "Eviction"))
    + annotate("text", x = c(0.5, 0.71), size = 3, y = 0.025, label = c("L-DI", "M-DI"))
    + geom_segment(x = 0.259 , y = 0.065, xend = 0.32, yend = 0.0938, colour = "black",
                   arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.243 , y = 0.05, xend = 0.32, yend = 0.045, colour = "black",
                   arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))      
    + geom_segment(x = 0.256 , y = 0.035, xend = 0.315, yend = 0.037, colour = "black",
                   arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.26 , y = 0.02, xend = 0.32, yend = 0.035, colour = "black",
                   arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))  
    + geom_segment(x = 0.476 , y = 0.025, xend = 0.35, yend = 0.035, colour = "black",
                   arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))   
    + geom_segment(x = 0.74 , y = 0.025, xend = 0.815, yend = 0.03, colour = "black",
                   arrow = arrow(length = unit(0.02, "npc"), ends = "last", type = "closed"))       
  )
  
# Export the figure
  ggsave(paste0(figure, 'figJ1b.png'), height = 4, width = 6)
  
  
