rm(list=ls())

# Load the working directory
source(load_directories_R.R)

figure <- "./temp/fig/"

# install necessary packages

#install.packages('openxlsx')
#install.packages('ggplot2')
#install.packages('reshape2')

# choose library necessary

library(openxlsx)
library(ggplot2)
library(reshape2)

################################################################################################################################################

# Read Excel file

df1 <- read.csv('./ssa/positive/data/age65_cat_rec_di.csv')
      
keep <- c("cat_rec_di", "shockpre35_mass153", "shock35_mass153", "shock45_mass153", "shock55_mass153")
df2 <- df1[keep]
df3 <- melt(df2, id = 'cat_rec_di')

# Renaming group names 
df3$cat_rec_di <- as.character(df3$cat_rec_di)
df3$cat_rec_di[df3$cat_rec_di == '2'] <- 'DI, < 35'
df3$cat_rec_di[df3$cat_rec_di == '3'] <- 'DI, 35 - 44'
df3$cat_rec_di[df3$cat_rec_di == '4'] <- 'DI, 45 - 54'
df3$cat_rec_di[df3$cat_rec_di == '5'] <- 'DI, 55 - 64'
df3$cat_rec_di[df3$cat_rec_di == '99'] <- 'NDI'
      
df3$variable <- as.character(df3$variable)
df3$variable[df3$variable == 'shockpre35_mass153'] <- '25 - 34'
df3$variable[df3$variable == 'shock35_mass153'] <- '35 - 44'
df3$variable[df3$variable == 'shock45_mass153'] <- '45 - 54'
df3$variable[df3$variable == 'shock55_mass153'] <- '55 - 64'
      
df3$variable <- factor(df3$variable, levels = c('55 - 64', '45 - 54', '35 - 44', '25 - 34'))
      
# Final Figure
(gph_masslayoff1 <-ggplot(df3, aes(as.factor(cat_rec_di),as.factor(variable)))
        + geom_tile(aes(fill=value)) 
        + scale_fill_gradient(low='white',high='deeppink4') + scale_x_discrete(expand = c(0, 0), position = 'top')
        + labs(x = '',y = '') + scale_y_discrete(expand = c(0, 0)) 
        + labs(x = 'First DI receipt at age...', y = 'Mass layoff at age...')
        + theme(legend.title = element_blank(), axis.ticks = element_blank(), 
                axis.text.x = element_text(size = 8, angle = 0, hjust = 0.5), 
                axis.title=element_text(size=10), plot.title = element_text(hjust = 0.5, size=12, vjust = 5), 
                plot.margin = margin(20, 20, 20, 20)) + coord_equal()
      )
      
# Export the figure      
ggsave(paste0(figure, 'figJ7.png'), height = 4, width = 6)
      

  